<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}


if ( !class_exists( 'WOOPCD_PartialCOD_Admin_Amount_Type_Cart_Items' ) ) {

    class WOOPCD_PartialCOD_Admin_Amount_Type_Cart_Items {

        public static function init() {

            add_filter( 'woopcd_partialcod-admin/get-amount-type-groups', array( new self(), 'get_groups' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/get-amount-group-types-cart_items', array( new self(), 'get_types' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/get-item-based-on-required-ids', array( new self(), 'get_based_on_required_ids' ), 10, 2 );
            add_filter( 'woopcd_partialcod-admin/get-products-required-ids', array( new self(), 'get_products_required_ids' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/get-amount-box-fields', array( new self(), 'get_item_qty_fields' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/process-amount-type-item_qty-options', array( new self(), 'process_item_qty_options' ), 10, 3 );
            add_filter( 'woopcd_partialcod-admin/process-amount-type-item_per-options', array( new self(), 'process_item_per_options' ), 10, 3 );
        }

        public static function get_groups( $in_groups, $args ) {

            $types_data = self::get_amount_type_data( $args );

            $in_groups[ 'cart_items' ] = $types_data[ 'cart_items' ];

            return $in_groups;
        }

        public static function get_types( $in_types, $args ) {

            $types_data = self::get_amount_type_data( $args );

            $in_types[ 'item_line' ] = $types_data[ 'item_line' ];
            $in_types[ 'item_qty' ] = $types_data[ 'item_qty' ];
            $in_types[ 'item_id' ] = $types_data[ 'item_id' ];
            $in_types[ 'item_variation_id' ] = $types_data[ 'item_variation_id' ];
            $in_types[ 'item_per' ] = $types_data[ 'item_per' ];

            return $in_types;
        }

        public static function get_based_on_required_ids( $in_ids, $args ) {

            $in_ids[] = 'item_per';

            return $in_ids;
        }

        public static function get_products_required_ids( $in_ids, $args ) {

            $in_ids[] = 'item_line';
            $in_ids[] = 'item_qty';
            $in_ids[] = 'item_id';
            $in_ids[] = 'item_variation_id';
            $in_ids[] = 'item_per';


            return $in_ids;
        }

        public static function get_item_qty_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'quantity',
                'type' => 'textbox',
                'input_type' => 'number',
                'tooltip' => esc_html__( 'Controls the item quantity', 'woopcd-partialcod-pro' ),
                'column_size' => 2,
                'column_title' => esc_html__( 'Quantity', 'woopcd-partialcod-pro' ),
                'default' => '1',
                'placeholder' => esc_html__( '0', 'woopcd-partialcod-pro' ),
                'width' => '100%',
                'attributes' => array(
                    'min' => '1',
                    'step' => '1',
                ),
                'fold' => array(
                    'target' => $args[ 'fold_id' ],
                    'attribute' => 'value',
                    'value' => array( 'item_qty' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            return $in_fields;
        }

        public static function process_item_qty_options( $amount, $raw_amount, $args ) {

            $amount[ 'quantity' ] = 0;

            if ( isset( $raw_amount[ 'quantity' ] ) && is_numeric( $raw_amount[ 'quantity' ] ) ) {
                $amount[ 'quantity' ] = $raw_amount[ 'quantity' ];
            }

            return $amount;
        }

        public static function process_item_per_options( $amount, $raw_amount, $args ) {

            if ( isset( $raw_amount[ 'item_base_on' ] ) ) {
                $amount[ 'item_base_on' ] = $raw_amount[ 'item_base_on' ];
            }

            return $amount;
        }

        private static function get_amount_type_data( $args ) {

            if ( 'cart-discounts' == $args[ 'module' ] ) {
                return array(
                    'cart_items' => esc_html__( 'Discounts Per Items', 'woopcd-partialcod-pro' ),
                    'item_line' => esc_html__( 'Discount per cart line', 'woopcd-partialcod-pro' ),
                    'item_qty' => esc_html__( 'Discount per item quantity', 'woopcd-partialcod-pro' ),
                    'item_id' => esc_html__( 'Discount per product', 'woopcd-partialcod-pro' ),
                    'item_variation_id' => esc_html__( 'Discount per variation', 'woopcd-partialcod-pro' ),
                    'item_per' => esc_html__( 'Percentage discount per item', 'woopcd-partialcod-pro' ),
                );
            }

            return array(
                'cart_items' => esc_html__( 'Fee Per Items', 'woopcd-partialcod-pro' ),
                'item_line' => esc_html__( 'Fee per cart line', 'woopcd-partialcod-pro' ),
                'item_qty' => esc_html__( 'Fee per item quantity', 'woopcd-partialcod-pro' ),
                'item_id' => esc_html__( 'Fee per product', 'woopcd-partialcod-pro' ),
                'item_variation_id' => esc_html__( 'Fee per variation', 'woopcd-partialcod-pro' ),
                'item_per' => esc_html__( 'Percentage fee per item', 'woopcd-partialcod-pro' ),
            );
        }

    }

    WOOPCD_PartialCOD_Admin_Amount_Type_Cart_Items::init();
}