<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}


if ( !class_exists( 'WOOPCD_PartialCOD_Premium_Admin_Amount_Type_Cart' ) ) {

    class WOOPCD_PartialCOD_Premium_Admin_Amount_Type_Cart {

        public static function init() {
            add_filter( 'woopcd_partialcod-admin/get-amount-group-types-cart', array( new self(), 'get_types' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/get-amount-type-cart_product_categories-fields', array( new self(), 'get_product_categories_amount_fields' ), 10, 2 );
            add_filter( 'woopcd_partialcod-admin/get-amount-type-cart_product_tags-fields', array( new self(), 'get_product_tags_amount_fields' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/process-amount-type-cart_product_categories-options', array( new self(), 'process_product_categories_amount_options' ), 10, 3 );
            add_filter( 'woopcd_partialcod-admin/process-amount-type-cart_product_tags-options', array( new self(), 'process_product_tags_amount_options' ), 10, 3 );
        }

        public static function get_types( $in_types, $args ) {

            $types_data = self::get_amount_type_data( $args );

            $in_types[ 'cart_product_categories' ] = $types_data[ 'cart_product_categories' ];
            $in_types[ 'cart_product_tags' ] = $types_data[ 'cart_product_tags' ];

            return $in_types;
        }

        public static function get_product_categories_amount_fields( $in_fields, $args ) {
            $in_fields[] = array(
                'id' => 'product_categories_args',
                'type' => 'columns-field',
                'columns' => 8,
                'merge_fields' => true,
                'fields' => array(
                    array(
                        'id' => 'product_categories',
                        'type' => 'select2',
                        'column_size' => 6,
                        'column_title' => esc_html__( 'Product Categories', 'woopcd-partialcod-pro' ),
                        'tooltip' => esc_html__( 'Controls which product categories should be included', 'woopcd-partialcod-pro' ),
                        'default' => '',
                        'multiple' => true,
                        'minimum_input_length' => 1,
                        'minimum_results_forsearch' => 10,
                        'placeholder' => esc_html__( 'Search product categories...', 'woopcd-partialcod-pro' ),
                        'data' => array(
                            'source' => 'categories:product_cat',
                            'ajax' => true,
                            'value_col' => 'slug',
                            'show_value' => false,
                        ),
                        'width' => '100%',
                    ),
                    array(
                        'id' => 'compare',
                        'type' => 'select2',
                        'column_size' => 2,
                        'column_title' => esc_html__( 'Equals To', 'woopcd-partialcod-pro' ),
                        'tooltip' => esc_html__( 'Controls how the categories should be included', 'woopcd-partialcod-pro' ),
                        'default' => 'in_list',
                        'options' => array(
                            'in_list' => esc_html__( 'Any in the list', 'woopcd-partialcod-pro' ),
                            'none' => esc_html__( 'Any NOT in the list', 'woopcd-partialcod-pro' ),
                        ),
                        'width' => '100%',
                    ),
                ),
            );
            return $in_fields;
        }

        public static function get_product_tags_amount_fields( $in_fields, $args ) {
            $in_fields[] = array(
                'id' => 'product_tags_args',
                'type' => 'columns-field',
                'columns' => 8,
                'merge_fields' => true,
                'fields' => array(
                    array(
                        'id' => 'product_tags',
                        'type' => 'select2',
                        'column_size' => 6,
                        'column_title' => esc_html__( 'Product Tags', 'woopcd-partialcod-pro' ),
                        'tooltip' => esc_html__( 'Controls which product tags should be included', 'woopcd-partialcod-pro' ),
                        'default' => '',
                        'multiple' => true,
                        'minimum_input_length' => 1,
                        'minimum_results_forsearch' => 10,
                        'placeholder' => esc_html__( 'Search product tags...', 'woopcd-partialcod-pro' ),
                        'data' => array(
                            'source' => 'categories:product_tag',
                            'ajax' => true,
                            'value_col' => 'slug',
                            'show_value' => false,
                        ),
                        'width' => '100%',
                    ),
                    array(
                        'id' => 'compare',
                        'type' => 'select2',
                        'column_size' => 2,
                        'column_title' => esc_html__( 'Equals To', 'woopcd-partialcod-pro' ),
                        'tooltip' => esc_html__( 'Controls how the product tags should be included', 'woopcd-partialcod-pro' ),
                        'default' => 'in_list',
                        'options' => array(
                            'in_list' => esc_html__( 'Any in the list', 'woopcd-partialcod-pro' ),
                            'none' => esc_html__( 'Any NOT in the list', 'woopcd-partialcod-pro' ),
                        ),
                        'width' => '100%',
                    ),
                ),
            );
            return $in_fields;
        }

        public static function process_product_categories_amount_options( $amount, $raw_amount, $args ) {

            if ( isset( $raw_amount[ 'product_categories_args' ] ) ) {
                $amount[ 'product_categories_args' ] = $raw_amount[ 'product_categories_args' ];
            }

            return $amount;
        }
        
        public static function process_product_tags_amount_options( $amount, $raw_amount, $args ) {

            if ( isset( $raw_amount[ 'product_tags_args' ] ) ) {
                $amount[ 'product_tags_args' ] = $raw_amount[ 'product_tags_args' ];
            }

            return $amount;
        }

        private static function get_amount_type_data( $args ) {

            if ( 'cart-discounts' == $args[ 'module' ] ) {
                return array(
                    'cart_product_categories' => esc_html__( 'Discount per categories', 'woopcd-partialcod-pro' ),
                    'cart_product_tags' => esc_html__( 'Discount per tags', 'woopcd-partialcod-pro' ),
                );
            }

            return array(
                'cart_product_categories' => esc_html__( 'Fee per categories', 'woopcd-partialcod-pro' ),
                'cart_product_tags' => esc_html__( 'Fee per tags', 'woopcd-partialcod-pro' ),
            );
        }

        
        
    }

    WOOPCD_PartialCOD_Premium_Admin_Amount_Type_Cart::init();
}
