<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}


if ( !class_exists( 'WOOPCD_PartialCOD_Admin_Amount_Type_Height' ) ) {

    class WOOPCD_PartialCOD_Admin_Amount_Type_Height {

        public static function init() {
            add_filter( 'woopcd_partialcod-admin/get-amount-type-groups', array( new self(), 'get_groups' ), 60, 2 );
            add_filter( 'woopcd_partialcod-admin/get-amount-group-types-per_heights', array( new self(), 'get_types' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/get-amount-box-fields', array( new self(), 'get_height_fields' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/get-products-required-ids', array( new self(), 'get_products_required_ids' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/process-amount-type-per_height-options', array( new self(), 'process_height_options' ), 10, 3 );
        }

        public static function get_groups( $in_groups, $args ) {

            $types_data = self::get_amount_type_data( $args );

            $in_groups[ 'per_heights' ] = $types_data[ 'per_heights' ];

            return $in_groups;
        }

        public static function get_types( $in_types, $args ) {

            $types_data = self::get_amount_type_data( $args );

            $in_types[ 'per_height' ] = $types_data[ 'per_height' ];
            $in_types[ 'by_height' ] = $types_data[ 'by_height' ];


            return $in_types;
        }

        public static function get_products_required_ids( $in_ids, $args ) {

            $in_ids[] = 'per_height';
            $in_ids[] = 'by_height';

            return $in_ids;
        }

        public static function get_height_fields( $in_fields, $args ) {

            $height_unit = get_option( 'woocommerce_dimension_unit' );
            $height_text = str_replace( '[0]', $height_unit, esc_html__( 'Height ([0])', 'woopcd-partialcod-pro' ) );
            $height_desc = str_replace( '[0]', $height_unit, esc_html__( 'Controls the height multiplier in ([0])', 'woopcd-partialcod-pro' ) );


            $in_fields[] = array(
                'id' => 'height',
                'type' => 'textbox',
                'input_type' => 'number',
                'tooltip' => $height_desc,
                'column_size' => 2,
                'column_title' => $height_text,
                'default' => '1',
                'placeholder' => esc_html__( '0.00', 'woopcd-partialcod-pro' ),
                'width' => '100%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '0.01',
                ),
                'fold' => array(
                    'target' => $args[ 'fold_id' ],
                    'attribute' => 'value',
                    'value' => array( 'per_height' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            return $in_fields;
        }

        public static function process_height_options( $amount, $raw_amount, $args ) {

            $amount[ 'height' ] = 0;

            if ( isset( $raw_amount[ 'height' ] ) && is_numeric( $raw_amount[ 'height' ] ) ) {
                $amount[ 'height' ] = $raw_amount[ 'height' ];
            }

            return $amount;
        }

        private static function get_amount_type_data( $args ) {

            $height_unit = get_option( 'woocommerce_dimension_unit' );

            if ( 'cart-discounts' == $args[ 'module' ] ) {

                $d_per_height = str_replace( '[0]', $height_unit, esc_html__( 'Discount per height ([0])', 'woopcd-partialcod-pro' ) );
                $d_by_height = str_replace( '[0]', $height_unit, esc_html__( 'Discount x height ([0])', 'woopcd-partialcod-pro' ) );

                return array(
                    'per_heights' => esc_html__( 'Discount Per Height', 'woopcd-partialcod-pro' ),
                    'per_height' => $d_per_height,
                    'by_height' => $d_by_height,
                );
            }

            $f_per_height = str_replace( '[0]', $height_unit, esc_html__( 'Fee per height ([0])', 'woopcd-partialcod-pro' ) );
            $f_by_height = str_replace( '[0]', $height_unit, esc_html__( 'Fee x height ([0])', 'woopcd-partialcod-pro' ) );

            return array(
                'per_heights' => esc_html__( 'Fee Per Height', 'woopcd-partialcod-pro' ),
                'per_height' => $f_per_height,
                'by_height' => $f_by_height,
            );
        }

    }

    WOOPCD_PartialCOD_Admin_Amount_Type_Height::init();
}
