<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}


if ( !class_exists( 'WOOPCD_PartialCOD_Admin_Amount_Type_Length' ) ) {

    class WOOPCD_PartialCOD_Admin_Amount_Type_Length {

        public static function init() {
            add_filter( 'woopcd_partialcod-admin/get-amount-type-groups', array( new self(), 'get_groups' ), 40, 2 );
            add_filter( 'woopcd_partialcod-admin/get-amount-group-types-per_lengths', array( new self(), 'get_types' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/get-amount-box-fields', array( new self(), 'get_length_fields' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/get-products-required-ids', array( new self(), 'get_products_required_ids' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/process-amount-type-per_length-options', array( new self(), 'process_length_options' ), 10, 3 );
        }

        public static function get_groups( $in_groups, $args ) {

            $types_data = self::get_amount_type_data( $args );

            $in_groups[ 'per_lengths' ] = $types_data[ 'per_lengths' ];

            return $in_groups;
        }

        public static function get_types( $in_types, $args ) {

            $types_data = self::get_amount_type_data( $args );

            $in_types[ 'per_length' ] = $types_data[ 'per_length' ];
            $in_types[ 'by_length' ] = $types_data[ 'by_length' ];


            return $in_types;
        }

        public static function get_products_required_ids( $in_ids, $args ) {

            $in_ids[] = 'per_length';
            $in_ids[] = 'by_length';



            return $in_ids;
        }

        public static function get_length_fields( $in_fields, $args ) {

            $length_unit = get_option( 'woocommerce_dimension_unit' );
            $length_text = str_replace( '[0]', $length_unit, esc_html__( 'Length ([0])', 'woopcd-partialcod-pro' ) );
            $length_desc = str_replace( '[0]', $length_unit, esc_html__( 'Controls the length multiplier in ([0])', 'woopcd-partialcod-pro' ) );


            $in_fields[] = array(
                'id' => 'lengths',
                'type' => 'textbox',
                'input_type' => 'number',
                'tooltip' => $length_desc,
                'column_size' => 2,
                'column_title' => $length_text,
                'default' => '1',
                'placeholder' => esc_html__( '0.00', 'woopcd-partialcod-pro' ),
                'width' => '100%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '0.01',
                ),
                'fold' => array(
                    'target' => $args[ 'fold_id' ],
                    'attribute' => 'value',
                    'value' => array( 'per_length' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            return $in_fields;
        }

        public static function process_length_options( $amount, $raw_amount, $args ) {

            $amount[ 'lengths' ] = 0;

            if ( isset( $raw_amount[ 'lengths' ] ) && is_numeric( $raw_amount[ 'lengths' ] ) ) {
                $amount[ 'lengths' ] = $raw_amount[ 'lengths' ];
            }

            return $amount;
        }

        private static function get_amount_type_data( $args ) {

            $length_unit = get_option( 'woocommerce_dimension_unit' );

            if ( 'cart-discounts' == $args[ 'module' ] ) {

                $d_prem_10 = str_replace( '[0]', $length_unit, esc_html__( 'Discount per length ([0])', 'woopcd-partialcod-pro' ) );
                $d_prem_11 = str_replace( '[0]', $length_unit, esc_html__( 'Discount x length ([0])', 'woopcd-partialcod-pro' ) );

                return array(
                    'per_lengths' => esc_html__( 'Discount Per Length', 'woopcd-partialcod-pro' ),
                    'per_length' => $d_prem_10,
                    'by_length' => $d_prem_11,
                );
            }

            $f_prem_10 = str_replace( '[0]', $length_unit, esc_html__( 'Fee per length ([0])', 'woopcd-partialcod-pro' ) );
            $f_prem_11 = str_replace( '[0]', $length_unit, esc_html__( 'Fee x length ([0])', 'woopcd-partialcod-pro' ) );

            return array(
                'per_lengths' => esc_html__( 'Fee Per Length', 'woopcd-partialcod-pro' ),
                'per_length' => $f_prem_10,
                'by_length' => $f_prem_11,
            );
        }

    }

    WOOPCD_PartialCOD_Admin_Amount_Type_Length::init();
}