<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}


if ( !class_exists( 'WOOPCD_PartialCOD_Admin_Amount_Type_Surface_Area' ) ) {

    class WOOPCD_PartialCOD_Admin_Amount_Type_Surface_Area {

        public static function init() {
            add_filter( 'woopcd_partialcod-admin/get-amount-type-groups', array( new self(), 'get_groups' ), 70, 2 );
            add_filter( 'woopcd_partialcod-admin/get-amount-group-types-per_surface_areas', array( new self(), 'get_types' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/get-amount-box-fields', array( new self(), 'get_surface_area_fields' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/get-products-required-ids', array( new self(), 'get_products_required_ids' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/process-amount-type-per_surface_area-options', array( new self(), 'process_surface_area_options' ), 10, 3 );
        }

        public static function get_groups( $in_groups, $args ) {

            $types_data = self::get_amount_type_data( $args );

            $in_groups[ 'per_surface_areas' ] = $types_data[ 'per_surface_areas' ];

            return $in_groups;
        }

        public static function get_types( $in_types, $args ) {

            $types_data = self::get_amount_type_data( $args );

            $in_types[ 'per_surface_area' ] = $types_data[ 'per_surface_area' ];
            $in_types[ 'by_surface_area' ] = $types_data[ 'by_surface_area' ];


            return $in_types;
        }

        public static function get_products_required_ids( $in_ids, $args ) {

            $in_ids[] = 'per_surface_area';
            $in_ids[] = 'by_surface_area';

            return $in_ids;
        }

        public static function get_surface_area_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'surface_area',
                'type' => 'textbox',
                'input_type' => 'number',
                'tooltip' => esc_html__( 'Controls the surface area multiplier', 'woopcd-partialcod-pro' ),
                'column_size' => 2,
                'column_title' => esc_html__( 'Surface Area', 'woopcd-partialcod-pro' ),
                'default' => '1',
                'placeholder' => esc_html__( '0.00', 'woopcd-partialcod-pro' ),
                'width' => '100%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '0.01',
                ),
                'fold' => array(
                    'target' => $args[ 'fold_id' ],
                    'attribute' => 'value',
                    'value' => array( 'per_surface_area' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            return $in_fields;
        }

        public static function process_surface_area_options( $amount, $raw_amount, $args ) {

            $amount[ 'surface_area' ] = 0;

            if ( isset( $raw_amount[ 'surface_area' ] ) && is_numeric( $raw_amount[ 'surface_area' ] ) ) {
                $amount[ 'surface_area' ] = $raw_amount[ 'surface_area' ];
            }

            return $amount;
        }

        private static function get_amount_type_data( $args ) {

            if ( 'cart-discounts' == $args[ 'module' ] ) {
                return array(
                    'per_surface_areas' => esc_html__( 'Discount Per Surface Area', 'woopcd-partialcod-pro' ),
                    'per_surface_area' => esc_html__( 'Discount per surface area', 'woopcd-partialcod-pro' ),
                    'by_surface_area' => esc_html__( 'Discount x surface area', 'woopcd-partialcod-pro' ),
                );
            }

            return array(
                'per_surface_areas' => esc_html__( 'Fee Per Surface Area', 'woopcd-partialcod-pro' ),
                'per_surface_area' => esc_html__( 'Fee per surface area', 'woopcd-partialcod-pro' ),
                'by_surface_area' => esc_html__( 'Fee x surface area', 'woopcd-partialcod-pro' ),
            );
        }

    }

    WOOPCD_PartialCOD_Admin_Amount_Type_Surface_Area::init();
}

