<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}


if ( !class_exists( 'WOOPCD_PartialCOD_Admin_Amount_Type_Volume' ) ) {

    class WOOPCD_PartialCOD_Admin_Amount_Type_Volume {

        public static function init() {
            add_filter( 'woopcd_partialcod-admin/get-amount-type-groups', array( new self(), 'get_groups' ), 80, 2 );
            add_filter( 'woopcd_partialcod-admin/get-amount-group-types-per_volumes', array( new self(), 'get_types' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/get-amount-box-fields', array( new self(), 'get_volume_fields' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/get-products-required-ids', array( new self(), 'get_products_required_ids' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/process-amount-type-per_volume-options', array( new self(), 'process_volume_options' ), 10, 3 );
        }

        public static function get_groups( $in_groups, $args ) {

            $types_data = self::get_amount_type_data( $args );

            $in_groups[ 'per_volumes' ] = $types_data[ 'per_volumes' ];

            return $in_groups;
        }

        public static function get_types( $in_types, $args ) {

            $types_data = self::get_amount_type_data( $args );

            $in_types[ 'per_volume' ] = $types_data[ 'per_volume' ];
            $in_types[ 'by_volume' ] = $types_data[ 'by_volume' ];


            return $in_types;
        }

        public static function get_products_required_ids( $in_ids, $args ) {

            $in_ids[] = 'per_volume';
            $in_ids[] = 'by_volume';

            return $in_ids;
        }

        public static function get_volume_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'volume',
                'type' => 'textbox',
                'input_type' => 'number',
                'tooltip' => esc_html__( 'Controls the volume multiplier', 'woopcd-partialcod-pro' ),
                'column_size' => 2,
                'column_title' => esc_html__( 'Volume', 'woopcd-partialcod-pro' ),
                'default' => '1',
                'placeholder' => esc_html__( '0.00', 'woopcd-partialcod-pro' ),
                'width' => '100%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '0.01',
                ),
                'fold' => array(
                    'target' => $args[ 'fold_id' ],
                    'attribute' => 'value',
                    'value' => array( 'per_volume' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            return $in_fields;
        }

        public static function process_volume_options( $amount, $raw_amount, $args ) {

            $amount[ 'volume' ] = 0;

            if ( isset( $raw_amount[ 'volume' ] ) && is_numeric( $raw_amount[ 'volume' ] ) ) {
                $amount[ 'volume' ] = $raw_amount[ 'volume' ];
            }

            return $amount;
        }

        private static function get_amount_type_data( $args ) {

            if ( 'cart-discounts' == $args[ 'module' ] ) {
                return array(
                    'per_volumes' => esc_html__( 'Discount Per Volume', 'woopcd-partialcod-pro' ),
                    'per_volume' => esc_html__( 'Discount per volume', 'woopcd-partialcod-pro' ),
                    'by_volume' => esc_html__( 'Discount x volume', 'woopcd-partialcod-pro' ),
                );
            }

            return array(
                'per_volumes' => esc_html__( 'Fee Per Volume', 'woopcd-partialcod-pro' ),
                'per_volume' => esc_html__( 'Fee per volume', 'woopcd-partialcod-pro' ),
                'by_volume' => esc_html__( 'Fee x volume', 'woopcd-partialcod-pro' ),
            );
        }

    }

    WOOPCD_PartialCOD_Admin_Amount_Type_Volume::init();
}

