<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}


if ( !class_exists( 'WOOPCD_PartialCOD_Admin_Amount_Type_Weight' ) ) {

    class WOOPCD_PartialCOD_Admin_Amount_Type_Weight {

        public static function init() {
            add_filter( 'woopcd_partialcod-admin/get-amount-type-groups', array( new self(), 'get_groups' ), 10, 2 );
            add_filter( 'woopcd_partialcod-admin/get-amount-group-types-per_weights', array( new self(), 'get_types' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/get-amount-box-fields', array( new self(), 'get_weight_fields' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/get-products-required-ids', array( new self(), 'get_products_required_ids' ), 10, 2 );

            
            add_filter( 'woopcd_partialcod-admin/process-amount-type-per_weight-options', array( new self(), 'process_weight_options' ), 10, 3 );
        }

        public static function get_groups( $in_groups, $args ) {

            $types_data = self::get_amount_type_data( $args );

            $in_groups[ 'per_weights' ] = $types_data[ 'per_weights' ];

            return $in_groups;
        }

        public static function get_types( $in_types, $args ) {

            $types_data = self::get_amount_type_data( $args );

            $in_types[ 'per_weight' ] = $types_data[ 'per_weight' ];
            $in_types[ 'by_weight' ] = $types_data[ 'by_weight' ];


            return $in_types;
        }

        public static function get_products_required_ids( $in_ids, $args ) {

            $in_ids[] = 'per_weight';
            $in_ids[] = 'by_weight';



            return $in_ids;
        }

        public static function get_weight_fields( $in_fields, $args ) {

            $weight_unit = get_option( 'woocommerce_weight_unit' );
            $weight_text = str_replace( '[0]', $weight_unit, esc_html__( 'Weight ([0])', 'woopcd-partialcod-pro' ) );
            $weight_desc = str_replace( '[0]', $weight_unit, esc_html__( 'Controls the weight multiplier in ([0])', 'woopcd-partialcod-pro' ) );


            $in_fields[] = array(
                'id' => 'weight',
                'type' => 'textbox',
                'input_type' => 'number',
                'tooltip' => $weight_desc,
                'column_size' => 2,
                'column_title' => $weight_text,
                'default' => '0.5',
                'placeholder' => esc_html__( '0.00', 'woopcd-partialcod-pro' ),
                'width' => '100%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '0.01',
                ),
                'fold' => array(
                    'target' => $args[ 'fold_id' ],
                    'attribute' => 'value',
                    'value' => array( 'per_weight' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            return $in_fields;
        }

        public static function process_weight_options( $amount, $raw_amount, $args ) {

            $amount[ 'weight' ] = 0;

            if ( isset( $raw_amount[ 'weight' ] ) && is_numeric( $raw_amount[ 'weight' ] ) ) {
                $amount[ 'weight' ] = $raw_amount[ 'weight' ];
            }

            return $amount;
        }

        private static function get_amount_type_data( $args ) {

            $weight_unit = get_option( 'woocommerce_weight_unit' );

            if ( 'cart-discounts' == $args[ 'module' ] ) {

                $d_per_weight = str_replace( '[0]', $weight_unit, esc_html__( 'Discount per weight ([0])', 'woopcd-partialcod-pro' ) );
                $d_by_weight = str_replace( '[0]', $weight_unit, esc_html__( 'Discount x weight ([0])', 'woopcd-partialcod-pro' ) );

                return array(
                    'per_weights' => esc_html__( 'Discount Per Weight', 'woopcd-partialcod-pro' ),
                    'per_weight' => $d_per_weight,
                    'by_weight' => $d_by_weight,
                );
            }

            $f_per_weight = str_replace( '[0]', $weight_unit, esc_html__( 'Fee per weight ([0])', 'woopcd-partialcod-pro' ) );
            $f_by_weight = str_replace( '[0]', $weight_unit, esc_html__( 'Fee x weight ([0])', 'woopcd-partialcod-pro' ) );

            return array(
                'per_weights' => esc_html__( 'Fee Per Weight', 'woopcd-partialcod-pro' ),
                'per_weight' => $f_per_weight,
                'by_weight' => $f_by_weight,
            );
        }

    }

    WOOPCD_PartialCOD_Admin_Amount_Type_Weight::init();
}