<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}


if ( !class_exists( 'WOOPCD_PartialCOD_Admin_Amount_Type_Width' ) ) {

    class WOOPCD_PartialCOD_Admin_Amount_Type_Width {

        public static function init() {
            add_filter( 'woopcd_partialcod-admin/get-amount-type-groups', array( new self(), 'get_groups' ), 50, 2 );
            add_filter( 'woopcd_partialcod-admin/get-amount-group-types-per_widths', array( new self(), 'get_types' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/get-amount-box-fields', array( new self(), 'get_width_fields' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/get-products-required-ids', array( new self(), 'get_products_required_ids' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/process-amount-type-per_width-options', array( new self(), 'process_width_options' ), 10, 3 );
        }

        public static function get_groups( $in_groups, $args ) {

            $types_data = self::get_amount_type_data( $args );

            $in_groups[ 'per_widths' ] = $types_data[ 'per_widths' ];

            return $in_groups;
        }

        public static function get_types( $in_types, $args ) {

            $types_data = self::get_amount_type_data( $args );

            $in_types[ 'per_width' ] = $types_data[ 'per_width' ];
            $in_types[ 'by_width' ] = $types_data[ 'by_width' ];


            return $in_types;
        }

        public static function get_products_required_ids( $in_ids, $args ) {

            $in_ids[] = 'per_width';
            $in_ids[] = 'by_width';

            return $in_ids;
        }

        public static function get_width_fields( $in_fields, $args ) {

            $width_unit = get_option( 'woocommerce_dimension_unit' );
            $width_text = str_replace( '[0]', $width_unit, esc_html__( 'Width ([0])', 'woopcd-partialcod-pro' ) );
            $width_desc = str_replace( '[0]', $width_unit, esc_html__( 'Controls the width multiplier in ([0])', 'woopcd-partialcod-pro' ) );


            $in_fields[] = array(
                'id' => 'width',
                'type' => 'textbox',
                'input_type' => 'number',
                'tooltip' => $width_desc,
                'column_size' => 2,
                'column_title' => $width_text,
                'default' => '1',
                'placeholder' => esc_html__( '0.00', 'woopcd-partialcod-pro' ),
                'width' => '100%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '0.01',
                ),
                'fold' => array(
                    'target' => $args[ 'fold_id' ],
                    'attribute' => 'value',
                    'value' => array( 'per_width' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            return $in_fields;
        }

        public static function process_width_options( $amount, $raw_amount, $args ) {

            $amount[ 'width' ] = 0;

            if ( isset( $raw_amount[ 'width' ] ) && is_numeric( $raw_amount[ 'width' ] ) ) {
                $amount[ 'width' ] = $raw_amount[ 'width' ];
            }

            return $amount;
        }

        private static function get_amount_type_data( $args ) {

            $width_unit = get_option( 'woocommerce_dimension_unit' );

            if ( 'cart-discounts' == $args[ 'module' ] ) {

                $d_per_width = str_replace( '[0]', $width_unit, esc_html__( 'Discount per width ([0])', 'woopcd-partialcod-pro' ) );
                $d_by_width = str_replace( '[0]', $width_unit, esc_html__( 'Discount x width ([0])', 'woopcd-partialcod-pro' ) );

                return array(
                    'per_widths' => esc_html__( 'Discount Per Width', 'woopcd-partialcod-pro' ),
                    'per_width' => $d_per_width,
                    'by_width' => $d_by_width,
                );
            }

            $f_per_width = str_replace( '[0]', $width_unit, esc_html__( 'Fee per width ([0])', 'woopcd-partialcod-pro' ) );
            $f_by_width = str_replace( '[0]', $width_unit, esc_html__( 'Fee x width ([0])', 'woopcd-partialcod-pro' ) );

            return array(
                'per_widths' => esc_html__( 'Fee Per Width', 'woopcd-partialcod-pro' ),
                'per_width' => $f_per_width,
                'by_width' => $f_by_width,
            );
        }

    }

    WOOPCD_PartialCOD_Admin_Amount_Type_Width::init();
}
