<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WOOPCD_PartialCOD_Admin_Conditions_Cart' ) ) {

    class WOOPCD_PartialCOD_Admin_Conditions_Cart {

        public static function init() {

            add_filter( 'woopcd_partialcod-admin/get-condition-groups', array( new self(), 'get_groups' ), 50 );

            add_filter( 'woopcd_partialcod-admin/get-cart-group-conditions', array( new self(), 'get_conditions' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/get-cart_quantity-condition-fields', array( new self(), 'get_cart_quantity_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-cart_weight-condition-fields', array( new self(), 'get_cart_weight_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-cart_line_count-condition-fields', array( new self(), 'get_cart_line_count_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-cart_coupons-condition-fields', array( new self(), 'get_applied_coupons_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-advance_pay_methods-condition-fields', array( new self(), 'get_advance_pay_methods_fields' ), 10 );
        }

        public static function get_groups( $in_groups ) {
            $in_groups[ 'cart' ] = esc_html__( 'Cart', 'woopcd-partialcod-pro' );
            return $in_groups;
        }

        public static function get_conditions( $in_list, $args ) {

            $in_list[ 'cart_quantity' ] = esc_html__( 'Cart Total Quantity', 'woopcd-partialcod-pro' );

            $weight_text = str_replace( '[0]', get_option( 'woocommerce_weight_unit' ), esc_html__( 'Cart Total Weight ([0])', 'woopcd-partialcod-pro' ) );
            $in_list[ 'cart_weight' ] = $weight_text;

            $in_list[ 'cart_line_count' ] = esc_html__( 'Number Of Cart Items', 'woopcd-partialcod-pro' );


            $in_list[ 'cart_coupons' ] = esc_html__( 'Applied Coupons', 'woopcd-partialcod-pro' );

            
            
            if ( (WOOPCD_PartialCOD_Main::is_risky_method( $args[ 'method_id' ] ) && 'method-options' != $args[ 'module' ]&& 'partial-payment' != $args[ 'module' ]) || defined( 'DOING_AJAX' ) ) {
                $in_list[ 'advance_pay_methods' ] = esc_html__( 'Partial Payment Method', 'woopcd-partialcod-pro' );
            }

            return $in_list;
        }

        public static function get_cart_quantity_fields( $in_fields ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'woopcd-partialcod-pro' ),
                    '>' => esc_html__( 'More than', 'woopcd-partialcod-pro' ),
                    '<=' => esc_html__( 'Less than or equal to', 'woopcd-partialcod-pro' ),
                    '<' => esc_html__( 'Less than', 'woopcd-partialcod-pro' ),
                    '==' => esc_html__( 'Equal to', 'woopcd-partialcod-pro' ),
                    '!=' => esc_html__( 'Not equal to', 'woopcd-partialcod-pro' ),
                ),
                'width' => '99%',
                'box_width' => '45%',
            );
            $in_fields[] = array(
                'id' => 'total_quantity',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'woopcd-partialcod-pro' ),
                'width' => '100%',
                'box_width' => '55%',
                'attributes' => array(
                    'min' => '1',
                    'step' => '1',
                ),
            );

            return $in_fields;
        }

        public static function get_cart_weight_fields( $in_fields ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'woopcd-partialcod-pro' ),
                    '>' => esc_html__( 'More than', 'woopcd-partialcod-pro' ),
                    '<=' => esc_html__( 'Less than or equal to', 'woopcd-partialcod-pro' ),
                    '<' => esc_html__( 'Less than', 'woopcd-partialcod-pro' ),
                    '==' => esc_html__( 'Equal to', 'woopcd-partialcod-pro' ),
                    '!=' => esc_html__( 'Not equal to', 'woopcd-partialcod-pro' ),
                ),
                'width' => '99%',
                'box_width' => '45%',
            );
            $in_fields[] = array(
                'id' => 'total_weight',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '0.0',
                'placeholder' => esc_html__( '0.0', 'woopcd-partialcod-pro' ),
                'width' => '100%',
                'box_width' => '55%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '0.01',
                ),
            );




            return $in_fields;
        }

        public static function get_cart_line_count_fields( $in_fields ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'woopcd-partialcod-pro' ),
                    '>' => esc_html__( 'More than', 'woopcd-partialcod-pro' ),
                    '<=' => esc_html__( 'Less than or equal to', 'woopcd-partialcod-pro' ),
                    '<' => esc_html__( 'Less than', 'woopcd-partialcod-pro' ),
                    '==' => esc_html__( 'Equal to', 'woopcd-partialcod-pro' ),
                    '!=' => esc_html__( 'Not equal to', 'woopcd-partialcod-pro' ),
                ),
                'width' => '99%',
                'box_width' => '45%',
            );
            $in_fields[] = array(
                'id' => 'line_count',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '0',
                'placeholder' => esc_html__( '0', 'woopcd-partialcod-pro' ),
                'width' => '100%',
                'box_width' => '55%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '1',
                ),
            );

            return $in_fields;
        }

        public static function get_applied_coupons_fields( $in_fields ) {
            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'any' => esc_html__( 'Any list?', 'woopcd-partialcod-pro' ),
                    'in_list' => esc_html__( 'Any in the list', 'woopcd-partialcod-pro' ),
                    'in_all_list' => esc_html__( 'All in the list', 'woopcd-partialcod-pro' ),
                    'in_list_only' => esc_html__( 'Only in the list', 'woopcd-partialcod-pro' ),
                    'in_all_list_only' => esc_html__( 'Only all in the list', 'woopcd-partialcod-pro' ),
                    'none' => esc_html__( 'None in the list', 'woopcd-partialcod-pro' ),
                ),
                'fold_id' => 'coupons_compare',
                'width' => '99%',
                'box_width' => '34%',
            );

            $in_fields[] = array(
                'id' => 'is_any',
                'type' => 'select2',
                'default' => 'yes',
                'options' => array(
                    'no' => esc_html__( 'No', 'woopcd-partialcod-pro' ),
                    'yes' => esc_html__( 'Yes', 'woopcd-partialcod-pro' ),
                ),
                'fold' => array(
                    'target' => 'coupons_compare',
                    'attribute' => 'value',
                    'value' => 'any',
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '100%',
                'box_width' => '66%',
            );

            $in_fields[] = array(
                'id' => 'coupons',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 2,
                'placeholder' => esc_html__( 'Search coupons...', 'woopcd-partialcod-pro' ),
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'posts:shop_coupon',
                    'ajax' => true,
                ),
                'fold' => array(
                    'target' => 'coupons_compare',
                    'attribute' => 'value',
                    'value' => 'any',
                    'oparator' => 'neq',
                    'clear' => false,
                ),
                'width' => '100%',
                'box_width' => '66%',
            );

            return $in_fields;
        }

        public static function get_advance_pay_methods_fields( $in_fields ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'woopcd-partialcod-pro' ),
                    'none' => esc_html__( 'None in the list', 'woopcd-partialcod-pro' ),
                ),
                'width' => '99%',
                'box_width' => '27%',
            );

            $in_fields[] = array(
                'id' => 'method_ids',
                'type' => 'select2',
                'multiple' => true,
                'placeholder' => 'Select payment methods...',
                'options' => self::get_other_methods(),
                'width' => '100%',
                'box_width' => '73%',
            );

            return $in_fields;
        }

        private static function get_other_methods() {
            $methods = array();
            foreach ( WOOPCD_PartialCOD_Admin_Page::get_all_payment_methods() as $key => $method ) {
                if ( !WOOPCD_PartialCOD_Main::is_risky_method( $key ) ) {
                    $methods[ $key ] = $method[ 'method_title' ];
                }
            }
            return $methods;
        }

    }

    WOOPCD_PartialCOD_Admin_Conditions_Cart::init();
}
