<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WOOPCD_PartialCOD_Admin_Conditions_Customer_Value' ) ) {

    class WOOPCD_PartialCOD_Admin_Conditions_Customer_Value {

        public static function init() {
            add_filter( 'woopcd_partialcod-admin/get-condition-groups', array( new self(), 'get_groups' ), 110, 2 );

            add_filter( 'woopcd_partialcod-admin/get-customer_value-group-conditions', array( new self(), 'get_conditions' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/get-coupons_used-condition-fields', array( new self(), 'get_coupons_used_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-total_spent-condition-fields', array( new self(), 'get_total_spent_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-last_order_date-condition-fields', array( new self(), 'get_last_order_date_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-last_order_amount-condition-fields', array( new self(), 'get_last_order_amount_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-average_per_order-condition-fields', array( new self(), 'get_average_per_order_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-maximum_per_order-condition-fields', array( new self(), 'get_maximum_per_order_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-minimum_per_order-condition-fields', array( new self(), 'get_minimum_per_order_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-number_of_orders-condition-fields', array( new self(), 'get_number_of_orders_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-number_of_reviews-condition-fields', array( new self(), 'get_number_of_reviews_fields' ), 10 );
        }

        public static function get_groups( $in_groups, $args ) {
            $in_groups[ 'customer_value' ] = esc_html__( 'Customer Value', 'woopcd-partialcod-pro' );
            return $in_groups;
        }

        public static function get_conditions( $in_list, $args ) {

            $currency = get_woocommerce_currency_symbol( get_woocommerce_currency() );

            $in_list[ 'coupons_used' ] = esc_html__( 'Coupons Used', 'woopcd-partialcod-pro' );
            $in_list[ 'total_spent' ] = str_replace( '[0]', $currency, esc_html__( 'Totals Spent ([0])', 'woopcd-partialcod-pro' ) );
            $in_list[ 'last_order_date' ] = esc_html__( 'Last Order Date', 'woopcd-partialcod-pro' );
            $in_list[ 'last_order_amount' ] = str_replace( '[0]', $currency, esc_html__( 'Last Order Amount ([0])', 'woopcd-partialcod-pro' ) );

            $in_list[ 'average_per_order' ] = str_replace( '[0]', $currency, esc_html__( 'Average ([0]) Per Order', 'woopcd-partialcod-pro' ) );
            $in_list[ 'maximum_per_order' ] = str_replace( '[0]', $currency, esc_html__( 'Maximum ([0]) Per Order', 'woopcd-partialcod-pro' ) );
            $in_list[ 'minimum_per_order' ] = str_replace( '[0]', $currency, esc_html__( 'Minimum ([0]) Per Order', 'woopcd-partialcod-pro' ) );

            $in_list[ 'number_of_orders' ] = esc_html__( 'Number Of Orders', 'woopcd-partialcod-pro' );
            $in_list[ 'number_of_reviews' ] = esc_html__( 'Number Of Reviews', 'woopcd-partialcod-pro' );

            return $in_list;
        }

        public static function get_coupons_used_fields( $in_fields ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'woopcd-partialcod-pro' ),
                    'in_all_list' => esc_html__( 'All in the list', 'woopcd-partialcod-pro' ),
                    'in_list_only' => esc_html__( 'Only in the list', 'woopcd-partialcod-pro' ),
                    'in_all_list_only' => esc_html__( 'Only all in the list', 'woopcd-partialcod-pro' ),
                    'none' => esc_html__( 'None in the list', 'woopcd-partialcod-pro' ),
                ),
                'width' => '98%',
                'box_width' => '25%',
            );

            $in_fields[] = array(
                'id' => 'date_type',
                'type' => 'select2',
                'default' => 'all_time',
                'options' => array(
                    'all_time' => esc_html__( 'All time', 'woopcd-partialcod-pro' ),
                    'current' => esc_html__( 'Current', 'woopcd-partialcod-pro' ),
                    'hours' => esc_html__( 'Hours', 'woopcd-partialcod-pro' ),
                    'days' => esc_html__( 'Days', 'woopcd-partialcod-pro' ),
                    'weeks' => esc_html__( 'Weeks', 'woopcd-partialcod-pro' ),
                    'months' => esc_html__( 'Months', 'woopcd-partialcod-pro' ),
                    'years' => esc_html__( 'Years', 'woopcd-partialcod-pro' ),
                ),
                'fold_id' => 'date_type',
                'width' => '98%',
                'box_width' => '17%',
            );

            $in_fields[] = array(
                'id' => 'current',
                'type' => 'select2',
                'default' => 'day',
                'options' => array(
                    'day' => esc_html__( 'Day', 'woopcd-partialcod-pro' ),
                    'week' => esc_html__( 'Week', 'woopcd-partialcod-pro' ),
                    'month' => esc_html__( 'Month', 'woopcd-partialcod-pro' ),
                    'year' => esc_html__( 'Year', 'woopcd-partialcod-pro' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'current' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '15%',
            );

            $in_fields[] = array(
                'id' => 'date_offset',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'woopcd-partialcod-pro' ),
                'width' => '98%',
                'box_width' => '15%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'hours', 'days', 'weeks', 'months', 'years' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'attributes' => array(
                    'min' => '0',
                    'step' => '1',
                ),
            );

            $in_fields[] = array(
                'id' => 'all_time_applied_coupons',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 1,
                'minimum_results_forsearch' => 10,
                'placeholder' => esc_html__( 'Coupons...', 'woopcd-partialcod-pro' ),
                'data' => array(
                    'source' => 'posts:shop_coupon',
                    'ajax' => true,
                    'value_col' => 'slug',
                    'show_value' => false,
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '100%',
                'box_width' => '58%',
            );

            $in_fields[] = array(
                'id' => 'applied_coupons',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 1,
                'minimum_results_forsearch' => 10,
                'placeholder' => esc_html__( 'Coupons...', 'woopcd-partialcod-pro' ),
                'data' => array(
                    'source' => 'posts:shop_coupon',
                    'ajax' => true,
                    'value_col' => 'slug',
                    'show_value' => false,
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'neq',
                    'clear' => false,
                ),
                'width' => '100%',
                'box_width' => '43%',
            );


            return $in_fields;
        }

        public static function get_total_spent_fields( $in_fields ) {

            $in_fields[] = array(
                'id' => 'date_type',
                'type' => 'select2',
                'default' => 'all_time',
                'options' => array(
                    'all_time' => esc_html__( 'All time', 'woopcd-partialcod-pro' ),
                    'current' => esc_html__( 'Current', 'woopcd-partialcod-pro' ),
                    'hours' => esc_html__( 'Hours', 'woopcd-partialcod-pro' ),
                    'days' => esc_html__( 'Days', 'woopcd-partialcod-pro' ),
                    'weeks' => esc_html__( 'Weeks', 'woopcd-partialcod-pro' ),
                    'months' => esc_html__( 'Months', 'woopcd-partialcod-pro' ),
                    'years' => esc_html__( 'Years', 'woopcd-partialcod-pro' ),
                ),
                'fold_id' => 'date_type',
                'width' => '98%',
                'box_width' => '19%',
            );

            $in_fields[] = array(
                'id' => 'current',
                'type' => 'select2',
                'default' => 'day',
                'options' => array(
                    'day' => esc_html__( 'Day', 'woopcd-partialcod-pro' ),
                    'week' => esc_html__( 'Week', 'woopcd-partialcod-pro' ),
                    'month' => esc_html__( 'Month', 'woopcd-partialcod-pro' ),
                    'year' => esc_html__( 'Year', 'woopcd-partialcod-pro' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'current' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '18%',
            );

            $in_fields[] = array(
                'id' => 'date_offset',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'woopcd-partialcod-pro' ),
                'width' => '98%',
                'box_width' => '18%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'hours', 'days', 'weeks', 'months', 'years' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'attributes' => array(
                    'min' => '0',
                    'step' => '1',
                ),
            );

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'woopcd-partialcod-pro' ),
                    '>' => esc_html__( 'More than', 'woopcd-partialcod-pro' ),
                    '<=' => esc_html__( 'Less than or equal to', 'woopcd-partialcod-pro' ),
                    '<' => esc_html__( 'Less than', 'woopcd-partialcod-pro' ),
                    '==' => esc_html__( 'Equal to', 'woopcd-partialcod-pro' ),
                    '!=' => esc_html__( 'Not equal to', 'woopcd-partialcod-pro' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'neq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '35%',
            );

            $in_fields[] = array(
                'id' => 'all_time_compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'woopcd-partialcod-pro' ),
                    '>' => esc_html__( 'More than', 'woopcd-partialcod-pro' ),
                    '<=' => esc_html__( 'Less than or equal to', 'woopcd-partialcod-pro' ),
                    '<' => esc_html__( 'Less than', 'woopcd-partialcod-pro' ),
                    '==' => esc_html__( 'Equal to', 'woopcd-partialcod-pro' ),
                    '!=' => esc_html__( 'Not equal to', 'woopcd-partialcod-pro' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '99%',
                'box_width' => '53%',
            );

            $in_fields[] = array(
                'id' => 'total_spent',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '0.00',
                'placeholder' => esc_html__( '0.00', 'woopcd-partialcod-pro' ),
                'width' => '100%',
                'box_width' => '28%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '0.01',
                ),
            );


            return $in_fields;
        }

        public static function get_last_order_date_fields( $in_fields ) {

            $in_fields[] = array(
                'id' => 'date_compare',
                'type' => 'select2',
                'default' => 'after',
                'options' => array(
                    '<=' => esc_html__( 'Earlier than', 'woopcd-partialcod-pro' ),
                    '>=' => esc_html__( 'Within the past', 'woopcd-partialcod-pro' ),
                ),
                'width' => '98%',
                'box_width' => '40%',
            );

            $in_fields[] = array(
                'id' => 'date_type',
                'type' => 'select2',
                'default' => 'days',
                'options' => array(
                    'current' => esc_html__( 'Current', 'woopcd-partialcod-pro' ),
                    'hours' => esc_html__( 'Hours', 'woopcd-partialcod-pro' ),
                    'days' => esc_html__( 'Days', 'woopcd-partialcod-pro' ),
                    'weeks' => esc_html__( 'Weeks', 'woopcd-partialcod-pro' ),
                    'months' => esc_html__( 'Months', 'woopcd-partialcod-pro' ),
                    'years' => esc_html__( 'Years', 'woopcd-partialcod-pro' ),
                ),
                'fold_id' => 'date_type',
                'width' => '98%',
                'box_width' => '30%',
            );

            $in_fields[] = array(
                'id' => 'current',
                'type' => 'select2',
                'default' => 'day',
                'options' => array(
                    'day' => esc_html__( 'Day', 'woopcd-partialcod-pro' ),
                    'week' => esc_html__( 'Week', 'woopcd-partialcod-pro' ),
                    'month' => esc_html__( 'Month', 'woopcd-partialcod-pro' ),
                    'year' => esc_html__( 'Year', 'woopcd-partialcod-pro' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'current',
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '100%',
                'box_width' => '30%',
            );

            $in_fields[] = array(
                'id' => 'date_offset',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'woopcd-partialcod-pro' ),
                'width' => '100%',
                'box_width' => '30%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'current',
                    'oparator' => 'neq',
                    'clear' => false,
                ),
                'attributes' => array(
                    'min' => '0',
                    'step' => '1',
                ),
            );


            return $in_fields;
        }

        public static function get_last_order_amount_fields( $in_fields ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'woopcd-partialcod-pro' ),
                    '>' => esc_html__( 'More than', 'woopcd-partialcod-pro' ),
                    '<=' => esc_html__( 'Less than or equal to', 'woopcd-partialcod-pro' ),
                    '<' => esc_html__( 'Less than', 'woopcd-partialcod-pro' ),
                    '==' => esc_html__( 'Equal to', 'woopcd-partialcod-pro' ),
                    '!=' => esc_html__( 'Not equal to', 'woopcd-partialcod-pro' ),
                ),
                'width' => '99%',
                'box_width' => '55%',
            );

            $in_fields[] = array(
                'id' => 'last_spent',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '0.00',
                'placeholder' => esc_html__( '0.00', 'woopcd-partialcod-pro' ),
                'width' => '100%',
                'box_width' => '45%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '0.01',
                ),
            );


            return $in_fields;
        }

        public static function get_average_per_order_fields( $in_fields ) {

            $in_fields[] = array(
                'id' => 'date_type',
                'type' => 'select2',
                'default' => 'all_time',
                'options' => array(
                    'all_time' => esc_html__( 'All time', 'woopcd-partialcod-pro' ),
                    'current' => esc_html__( 'Current', 'woopcd-partialcod-pro' ),
                    'hours' => esc_html__( 'Hours', 'woopcd-partialcod-pro' ),
                    'days' => esc_html__( 'Days', 'woopcd-partialcod-pro' ),
                    'weeks' => esc_html__( 'Weeks', 'woopcd-partialcod-pro' ),
                    'months' => esc_html__( 'Months', 'woopcd-partialcod-pro' ),
                    'years' => esc_html__( 'Years', 'woopcd-partialcod-pro' ),
                ),
                'fold_id' => 'date_type',
                'width' => '98%',
                'box_width' => '20%',
            );

            $in_fields[] = array(
                'id' => 'current',
                'type' => 'select2',
                'default' => 'day',
                'options' => array(
                    'day' => esc_html__( 'Day', 'woopcd-partialcod-pro' ),
                    'week' => esc_html__( 'Week', 'woopcd-partialcod-pro' ),
                    'month' => esc_html__( 'Month', 'woopcd-partialcod-pro' ),
                    'year' => esc_html__( 'Year', 'woopcd-partialcod-pro' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'current' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '20%',
            );

            $in_fields[] = array(
                'id' => 'date_offset',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'woopcd-partialcod-pro' ),
                'width' => '98%',
                'box_width' => '20%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'hours', 'days', 'weeks', 'months', 'years' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'attributes' => array(
                    'min' => '0',
                    'step' => '1',
                ),
            );

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'woopcd-partialcod-pro' ),
                    '>' => esc_html__( 'More than', 'woopcd-partialcod-pro' ),
                    '<=' => esc_html__( 'Less than or equal to', 'woopcd-partialcod-pro' ),
                    '<' => esc_html__( 'Less than', 'woopcd-partialcod-pro' ),
                    '==' => esc_html__( 'Equal to', 'woopcd-partialcod-pro' ),
                    '!=' => esc_html__( 'Not equal to', 'woopcd-partialcod-pro' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'neq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '35%',
            );

            $in_fields[] = array(
                'id' => 'all_time_compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'woopcd-partialcod-pro' ),
                    '>' => esc_html__( 'More than', 'woopcd-partialcod-pro' ),
                    '<=' => esc_html__( 'Less than or equal to', 'woopcd-partialcod-pro' ),
                    '<' => esc_html__( 'Less than', 'woopcd-partialcod-pro' ),
                    '==' => esc_html__( 'Equal to', 'woopcd-partialcod-pro' ),
                    '!=' => esc_html__( 'Not equal to', 'woopcd-partialcod-pro' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '99%',
                'box_width' => '55%',
            );

            $in_fields[] = array(
                'id' => 'average_spent',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '0.00',
                'placeholder' => esc_html__( '0.00', 'woopcd-partialcod-pro' ),
                'width' => '100%',
                'box_width' => '25%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '0.01',
                ),
            );


            return $in_fields;
        }

        public static function get_maximum_per_order_fields( $in_fields ) {

            $in_fields[] = array(
                'id' => 'date_type',
                'type' => 'select2',
                'default' => 'all_time',
                'options' => array(
                    'all_time' => esc_html__( 'All time', 'woopcd-partialcod-pro' ),
                    'current' => esc_html__( 'Current', 'woopcd-partialcod-pro' ),
                    'hours' => esc_html__( 'Hours', 'woopcd-partialcod-pro' ),
                    'days' => esc_html__( 'Days', 'woopcd-partialcod-pro' ),
                    'weeks' => esc_html__( 'Weeks', 'woopcd-partialcod-pro' ),
                    'months' => esc_html__( 'Months', 'woopcd-partialcod-pro' ),
                    'years' => esc_html__( 'Years', 'woopcd-partialcod-pro' ),
                ),
                'fold_id' => 'date_type',
                'width' => '98%',
                'box_width' => '20%',
            );

            $in_fields[] = array(
                'id' => 'current',
                'type' => 'select2',
                'default' => 'day',
                'options' => array(
                    'day' => esc_html__( 'Day', 'woopcd-partialcod-pro' ),
                    'week' => esc_html__( 'Week', 'woopcd-partialcod-pro' ),
                    'month' => esc_html__( 'Month', 'woopcd-partialcod-pro' ),
                    'year' => esc_html__( 'Year', 'woopcd-partialcod-pro' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'current' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '20%',
            );

            $in_fields[] = array(
                'id' => 'date_offset',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'woopcd-partialcod-pro' ),
                'width' => '98%',
                'box_width' => '20%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'hours', 'days', 'weeks', 'months', 'years' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'attributes' => array(
                    'min' => '0',
                    'step' => '1',
                ),
            );

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'woopcd-partialcod-pro' ),
                    '>' => esc_html__( 'More than', 'woopcd-partialcod-pro' ),
                    '<=' => esc_html__( 'Less than or equal to', 'woopcd-partialcod-pro' ),
                    '<' => esc_html__( 'Less than', 'woopcd-partialcod-pro' ),
                    '==' => esc_html__( 'Equal to', 'woopcd-partialcod-pro' ),
                    '!=' => esc_html__( 'Not equal to', 'woopcd-partialcod-pro' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'neq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '35%',
            );

            $in_fields[] = array(
                'id' => 'all_time_compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'woopcd-partialcod-pro' ),
                    '>' => esc_html__( 'More than', 'woopcd-partialcod-pro' ),
                    '<=' => esc_html__( 'Less than or equal to', 'woopcd-partialcod-pro' ),
                    '<' => esc_html__( 'Less than', 'woopcd-partialcod-pro' ),
                    '==' => esc_html__( 'Equal to', 'woopcd-partialcod-pro' ),
                    '!=' => esc_html__( 'Not equal to', 'woopcd-partialcod-pro' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '99%',
                'box_width' => '55%',
            );

            $in_fields[] = array(
                'id' => 'max_spent',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '0.00',
                'placeholder' => esc_html__( '0.00', 'woopcd-partialcod-pro' ),
                'width' => '100%',
                'box_width' => '25%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '0.01',
                ),
            );


            return $in_fields;
        }

        public static function get_minimum_per_order_fields( $in_fields ) {

            $in_fields[] = array(
                'id' => 'date_type',
                'type' => 'select2',
                'default' => 'all_time',
                'options' => array(
                    'all_time' => esc_html__( 'All time', 'woopcd-partialcod-pro' ),
                    'current' => esc_html__( 'Current', 'woopcd-partialcod-pro' ),
                    'hours' => esc_html__( 'Hours', 'woopcd-partialcod-pro' ),
                    'days' => esc_html__( 'Days', 'woopcd-partialcod-pro' ),
                    'weeks' => esc_html__( 'Weeks', 'woopcd-partialcod-pro' ),
                    'months' => esc_html__( 'Months', 'woopcd-partialcod-pro' ),
                    'years' => esc_html__( 'Years', 'woopcd-partialcod-pro' ),
                ),
                'fold_id' => 'date_type',
                'width' => '98%',
                'box_width' => '20%',
            );

            $in_fields[] = array(
                'id' => 'current',
                'type' => 'select2',
                'default' => 'day',
                'options' => array(
                    'day' => esc_html__( 'Day', 'woopcd-partialcod-pro' ),
                    'week' => esc_html__( 'Week', 'woopcd-partialcod-pro' ),
                    'month' => esc_html__( 'Month', 'woopcd-partialcod-pro' ),
                    'year' => esc_html__( 'Year', 'woopcd-partialcod-pro' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'current' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '20%',
            );

            $in_fields[] = array(
                'id' => 'date_offset',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'woopcd-partialcod-pro' ),
                'width' => '98%',
                'box_width' => '20%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'hours', 'days', 'weeks', 'months', 'years' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'attributes' => array(
                    'min' => '0',
                    'step' => '1',
                ),
            );

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'woopcd-partialcod-pro' ),
                    '>' => esc_html__( 'More than', 'woopcd-partialcod-pro' ),
                    '<=' => esc_html__( 'Less than or equal to', 'woopcd-partialcod-pro' ),
                    '<' => esc_html__( 'Less than', 'woopcd-partialcod-pro' ),
                    '==' => esc_html__( 'Equal to', 'woopcd-partialcod-pro' ),
                    '!=' => esc_html__( 'Not equal to', 'woopcd-partialcod-pro' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'neq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '35%',
            );

            $in_fields[] = array(
                'id' => 'all_time_compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'woopcd-partialcod-pro' ),
                    '>' => esc_html__( 'More than', 'woopcd-partialcod-pro' ),
                    '<=' => esc_html__( 'Less than or equal to', 'woopcd-partialcod-pro' ),
                    '<' => esc_html__( 'Less than', 'woopcd-partialcod-pro' ),
                    '==' => esc_html__( 'Equal to', 'woopcd-partialcod-pro' ),
                    '!=' => esc_html__( 'Not equal to', 'woopcd-partialcod-pro' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '99%',
                'box_width' => '55%',
            );

            $in_fields[] = array(
                'id' => 'min_spent',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '0.00',
                'placeholder' => esc_html__( '0.00', 'woopcd-partialcod-pro' ),
                'width' => '100%',
                'box_width' => '25%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '0.01',
                ),
            );


            return $in_fields;
        }

        public static function get_number_of_orders_fields( $in_fields ) {

            $in_fields[] = array(
                'id' => 'date_type',
                'type' => 'select2',
                'default' => 'all_time',
                'options' => array(
                    'all_time' => esc_html__( 'All time', 'woopcd-partialcod-pro' ),
                    'current' => esc_html__( 'Current', 'woopcd-partialcod-pro' ),
                    'hours' => esc_html__( 'Hours', 'woopcd-partialcod-pro' ),
                    'days' => esc_html__( 'Days', 'woopcd-partialcod-pro' ),
                    'weeks' => esc_html__( 'Weeks', 'woopcd-partialcod-pro' ),
                    'months' => esc_html__( 'Months', 'woopcd-partialcod-pro' ),
                    'years' => esc_html__( 'Years', 'woopcd-partialcod-pro' ),
                ),
                'fold_id' => 'date_type',
                'width' => '98%',
                'box_width' => '20%',
            );

            $in_fields[] = array(
                'id' => 'current',
                'type' => 'select2',
                'default' => 'day',
                'options' => array(
                    'day' => esc_html__( 'Day', 'woopcd-partialcod-pro' ),
                    'week' => esc_html__( 'Week', 'woopcd-partialcod-pro' ),
                    'month' => esc_html__( 'Month', 'woopcd-partialcod-pro' ),
                    'year' => esc_html__( 'Year', 'woopcd-partialcod-pro' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'current' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '20%',
            );

            $in_fields[] = array(
                'id' => 'date_offset',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'woopcd-partialcod-pro' ),
                'width' => '98%',
                'box_width' => '20%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'hours', 'days', 'weeks', 'months', 'years' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'attributes' => array(
                    'min' => '0',
                    'step' => '1',
                ),
            );

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'woopcd-partialcod-pro' ),
                    '>' => esc_html__( 'More than', 'woopcd-partialcod-pro' ),
                    '<=' => esc_html__( 'Less than or equal to', 'woopcd-partialcod-pro' ),
                    '<' => esc_html__( 'Less than', 'woopcd-partialcod-pro' ),
                    '==' => esc_html__( 'Equal to', 'woopcd-partialcod-pro' ),
                    '!=' => esc_html__( 'Not equal to', 'woopcd-partialcod-pro' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'neq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '35%',
            );

            $in_fields[] = array(
                'id' => 'all_time_compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'woopcd-partialcod-pro' ),
                    '>' => esc_html__( 'More than', 'woopcd-partialcod-pro' ),
                    '<=' => esc_html__( 'Less than or equal to', 'woopcd-partialcod-pro' ),
                    '<' => esc_html__( 'Less than', 'woopcd-partialcod-pro' ),
                    '==' => esc_html__( 'Equal to', 'woopcd-partialcod-pro' ),
                    '!=' => esc_html__( 'Not equal to', 'woopcd-partialcod-pro' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '99%',
                'box_width' => '55%',
            );

            $in_fields[] = array(
                'id' => 'orders_count',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'woopcd-partialcod-pro' ),
                'width' => '100%',
                'box_width' => '25%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '1',
                ),
            );


            return $in_fields;
        }

        public static function get_number_of_reviews_fields( $in_fields ) {

            $in_fields[] = array(
                'id' => 'date_type',
                'type' => 'select2',
                'default' => 'all_time',
                'options' => array(
                    'all_time' => esc_html__( 'All time', 'woopcd-partialcod-pro' ),
                    'current' => esc_html__( 'Current', 'woopcd-partialcod-pro' ),
                    'hours' => esc_html__( 'Hours', 'woopcd-partialcod-pro' ),
                    'days' => esc_html__( 'Days', 'woopcd-partialcod-pro' ),
                    'weeks' => esc_html__( 'Weeks', 'woopcd-partialcod-pro' ),
                    'months' => esc_html__( 'Months', 'woopcd-partialcod-pro' ),
                    'years' => esc_html__( 'Years', 'woopcd-partialcod-pro' ),
                ),
                'fold_id' => 'date_type',
                'width' => '98%',
                'box_width' => '20%',
            );

            $in_fields[] = array(
                'id' => 'current',
                'type' => 'select2',
                'default' => 'day',
                'options' => array(
                    'day' => esc_html__( 'Day', 'woopcd-partialcod-pro' ),
                    'week' => esc_html__( 'Week', 'woopcd-partialcod-pro' ),
                    'month' => esc_html__( 'Month', 'woopcd-partialcod-pro' ),
                    'year' => esc_html__( 'Year', 'woopcd-partialcod-pro' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'current' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '20%',
            );

            $in_fields[] = array(
                'id' => 'date_offset',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'woopcd-partialcod-pro' ),
                'width' => '98%',
                'box_width' => '20%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'hours', 'days', 'weeks', 'months', 'years' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'attributes' => array(
                    'min' => '0',
                    'step' => '1',
                ),
            );

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'woopcd-partialcod-pro' ),
                    '>' => esc_html__( 'More than', 'woopcd-partialcod-pro' ),
                    '<=' => esc_html__( 'Less than or equal to', 'woopcd-partialcod-pro' ),
                    '<' => esc_html__( 'Less than', 'woopcd-partialcod-pro' ),
                    '==' => esc_html__( 'Equal to', 'woopcd-partialcod-pro' ),
                    '!=' => esc_html__( 'Not equal to', 'woopcd-partialcod-pro' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'neq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '35%',
            );

            $in_fields[] = array(
                'id' => 'all_time_compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'woopcd-partialcod-pro' ),
                    '>' => esc_html__( 'More than', 'woopcd-partialcod-pro' ),
                    '<=' => esc_html__( 'Less than or equal to', 'woopcd-partialcod-pro' ),
                    '<' => esc_html__( 'Less than', 'woopcd-partialcod-pro' ),
                    '==' => esc_html__( 'Equal to', 'woopcd-partialcod-pro' ),
                    '!=' => esc_html__( 'Not equal to', 'woopcd-partialcod-pro' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '99%',
                'box_width' => '55%',
            );

            $in_fields[] = array(
                'id' => 'reviews_count',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'woopcd-partialcod-pro' ),
                'width' => '100%',
                'box_width' => '25%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '1',
                ),
            );


            return $in_fields;
        }

    }

    WOOPCD_PartialCOD_Admin_Conditions_Customer_Value::init();
}