<?php

if (!class_exists('Reon')) {
    return;
}


if (!class_exists('WOOPCD_PartialCOD_Admin_Logic_Types_Order_Conditions')) {

    class WOOPCD_PartialCOD_Admin_Logic_Types_Order_Conditions {

        public static function init() {
            add_filter('woopcd_partialcod-admin/get-order-rule-panel-conditions-fields', array(new self(), 'get_fields'), 10, 2);

            add_filter('reon/get-simple-repeater-field-order_conditions-templates', array(new self(), 'get_condition_templates'), 10, 2);
            add_filter('roen/get-simple-repeater-template-order_conditions-conditions-fields', array(new self(), 'get_condition_fields'), 10, 2);
        }

        public static function get_fields($in_fields, $args) {

            $in_fields[] = array(
                'id' => 'match_mode',
                'type' => 'select2',
                'full_width' => true,
                'center_head' => true,
                'title' => esc_html__('Order Conditions', 'woopcd-partialcod-pro'),
                'desc' => esc_html__('List of conditions in which this autopilot should apply, empty conditions will apply in all cases', 'woopcd-partialcod-pro'),
                'default' => 'match_all',
                'options' => array(
                    'match_all' => esc_html__('All conditions should match', 'woopcd-partialcod-pro'),
                    'match_one' => esc_html__('At least one condition should match', 'woopcd-partialcod-pro'),
                ),
                'width' => '300px',
            );


            $in_fields[] = array(
                'id' => 'conditions',
                'type' => 'simple-repeater',
                'filter_id' => 'order_conditions',
                'new_field_args' => $args,
                'white_repeater' => false,
                'repeater_size' => 'smaller',
                'buttons_sep' => false,
                'buttons_box_width' => '65px',
                'width' => '100%',
                'css_class' => array('partialcod_gateway_conditions'),
                'sortable' => array(
                    'enabled' => true,
                ),
                'template_adder' => array(
                    'position' => 'right',
                    'show_list' => false,
                    'button_text' => esc_html__('Add Condition', 'woopcd-partialcod-pro'),
                ),
            );

            return $in_fields;
        }

        public static function get_condition_templates($in_templates, $repeater_args) {
            if ($repeater_args['screen'] == 'option-page' && $repeater_args['option_name'] == WOOPCD_PartialCOD_Admin_Page::get_option_name()) {
                $in_templates[] = array(
                    'id' => 'conditions',
                );
            }

            return $in_templates;
        }

        public static function get_condition_fields($in_fields, $repeater_args) {

            $args = $repeater_args['field_args'];

            $list = array();

            $groups = WOOPCD_PartialCOD_Admin_Order_Condition_Types::get_groups($args);

            foreach ($groups as $key => $group_label) {
                $list[$key]['label'] = $group_label;
                $list[$key]['options'] = WOOPCD_PartialCOD_Admin_Order_Condition_Types::get_conditions($key, $args);
            }



            $in_fields[] = array(
                'id' => 'condition_type',
                'type' => 'select2',
                'default' => '',
                'options' => $list,
                'width' => '98%',
                'box_width' => '33%',
                'dyn_switcher_id' => 'condition_type',
            );


            $conds = array();
            foreach ($list as $grp) {
                if (count($grp['options']) > 0) {
                    $conds = array_merge($conds, array_keys($grp['options']));
                }
            }

            foreach ($conds as $cond) {
                $in_fields[] = array(
                    'id' => 'condition_type_' . $cond,
                    'type' => 'group-field',
                    'dyn_switcher_target' => 'condition_type',
                    'dyn_switcher_target_value' => $cond,
                    'fluid-group' => true,
                    'width' => '67%',
                    'css_class' => array('rn-last'),
                    'fields' => WOOPCD_PartialCOD_Admin_Order_Condition_Types::get_condition_fields($cond, $args),
                );
            }

            return $in_fields;
        }

    }

    WOOPCD_PartialCOD_Admin_Logic_Types_Order_Conditions::init();
}