<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}


if ( !class_exists( 'WOOPCD_PartialCOD_Admin_Logic_Types_Product_Filters' ) ) {

    class WOOPCD_PartialCOD_Admin_Logic_Types_Product_Filters {

        public static function init() {
            add_filter( 'woopcd_partialcod-admin/get-amount-type-fields', array( new self(), 'get_fields' ), 10, 2 );
            add_filter( 'woopcd_partialcod-admin/get-payment-amount-type-fields', array( new self(), 'get_fields' ), 10, 2 );


            add_filter( 'reon/get-simple-repeater-field-product_filters-templates', array( new self(), 'get_product_templates' ), 10, 2 );
            add_filter( 'roen/get-simple-repeater-template-product_filters-product_filter-fields', array( new self(), 'get_product_template_fields' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/process-amount-options', array( new self(), 'process_options' ), 10, 3 );
            add_filter( 'woopcd_partialcod-admin/process-payment-amount-options', array( new self(), 'process_options' ), 10, 3 );
        }

        public static function get_fields( $in_fields, $args ) {


            $in_fields[] = array(
                'id' => 'any_id',
                'type' => 'paneltitle',
                'full_width' => true,
                'center_head' => true,
                'title' => esc_html__( 'Products', 'woopcd-partialcod-pro' ),
                'desc' => esc_html__( 'List of products to include, empty list will include all products in the cart', 'woopcd-partialcod-pro' ),
                'field_css_class' => array( 'partialcod_logic_title' ),
                'last' => true,
                'fold' => array(
                    'target' => $args[ 'fold_id' ],
                    'attribute' => 'value',
                    'value' => self::get_required_ids( $args ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );


            $in_fields[] = array(
                'id' => 'products_args',
                'filter_id' => 'product_filters',
                'type' => 'simple-repeater',
                'new_field_args' => $args,
                'white_repeater' => false,
                'repeater_size' => 'smaller',
                'buttons_sep' => false,
                'buttons_box_width' => '65px',
                'width' => '100%',
                'css_class' => array( 'partialcod_gateway_conditions' ),
                'sortable' => array(
                    'enabled' => true,
                ),
                'template_adder' => array(
                    'position' => 'right',
                    'show_list' => false,
                    'button_text' => esc_html__( 'Add Product', 'woopcd-partialcod-pro' ),
                ),
                'fold' => array(
                    'target' => $args[ 'fold_id' ],
                    'attribute' => 'value',
                    'value' => self::get_required_ids( $args ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );


            return $in_fields;
        }

        public static function get_product_templates( $in_templates, $repeater_args ) {

            if ( $repeater_args[ 'screen' ] == 'option-page' && $repeater_args[ 'option_name' ] == WOOPCD_PartialCOD_Admin_Page::get_option_name() ) {
                $in_templates[] = array(
                    'id' => 'product_filter',
                );
            }

            return $in_templates;
        }

        public static function get_product_template_fields( $in_fields, $repeater_args ) {

            $args = $repeater_args[ 'field_args' ];

            $list = array();

            $groups = WOOPCD_PartialCOD_Admin_Product_Filter_Types::get_groups( $args );

            foreach ( $groups as $key => $group_label ) {
                $list[ $key ][ 'label' ] = $group_label;
                $list[ $key ][ 'options' ] = WOOPCD_PartialCOD_Admin_Product_Filter_Types::get_product_filters( $key, $args );
            }


            $in_fields[] = array(
                'id' => 'filter_type',
                'type' => 'select2',
                'default' => '',
                'options' => $list,
                'width' => '98%',
                'box_width' => '31%',
                'dyn_switcher_id' => 'filter_type',
            );


            $filters = array();
            foreach ( $list as $grp ) {
                if ( count( $grp[ 'options' ] ) > 0 ) {
                    $filters = array_merge( $filters, array_keys( $grp[ 'options' ] ) );
                }
            }



            foreach ( $filters as $filter ) {

                $in_fields[] = array(
                    'id' => 'filter_type_' . $filter,
                    'type' => 'group-field',
                    'dyn_switcher_target' => 'filter_type',
                    'dyn_switcher_target_value' => $filter,
                    'fluid-group' => true,
                    'width' => '69%',
                    'css_class' => array( 'rn-last' ),
                    'last' => true,
                    'fields' => WOOPCD_PartialCOD_Admin_Product_Filter_Types::get_product_filter_fields( $filter, $args ),
                );
            }

            return $in_fields;
        }

        public static function process_options( $amount, $raw_amount, $args ) {

            if ( in_array( $raw_amount[ 'amount_type' ], self::get_required_ids( $args ) ) && isset( $raw_amount[ 'products_args' ] ) ) {
                $amount[ 'products_args' ] = $raw_amount[ 'products_args' ];
            }

            return $amount;
        }

        private static function get_required_ids( $args ) {

            return apply_filters( 'woopcd_partialcod-admin/' .$args['module'].'/get-products-required-ids', apply_filters( 'woopcd_partialcod-admin/get-products-required-ids', array(), $args ), $args );
        }

    }

    WOOPCD_PartialCOD_Admin_Logic_Types_Product_Filters::init();
}