<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WOOPCD_PartialCOD_Premium_Admin_Method_Options_Checkout_All' ) ) {

    class WOOPCD_PartialCOD_Premium_Admin_Method_Options_Checkout_All {

        public static function init() {

            add_filter( 'woopcd_partialcod-admin/method-options/get-rule-option-all-fields', array( new self(), 'get_fields' ), 10, 2 );
            add_filter( 'woopcd_partialcod-admin/process-option-type-all', array( new self(), 'process_options' ), 10, 3 );
        }

        public static function get_fields( $in_fields, $method_id ) {

            $method = WOOPCD_PartialCOD_Admin_Page::get_payment_method( $method_id );

            $method_title = $method[ 'title' ];

            $button_text = $method[ 'order_button_text' ];
            if ( $button_text == '' ) {
                $button_text = esc_html__( 'Place Order', 'woopcd-partialcod-pro' );
            }

            $icon_url = $method[ 'icon' ];
            if ( $icon_url == '' ) {
                $icon_url = esc_html__( 'Icon url', 'woopcd-partialcod-pro' );
            }

            $in_fields[] = array(
                'id' => 'any_ids',
                'type' => 'columns-field',
                'columns' => 5,
                'merge_fields' => false,
                'field_css_class' => array( 'rn-first' ),
                'fields' => array(
                    array(
                        'id' => 'enabled',
                        'type' => 'select2',
                        'column_size' => 1,
                        'column_title' => esc_html__( 'Restriction', 'woopcd-partialcod-pro' ),
                        'tooltip' => esc_html__( 'Controls payment method availability on checkout page', 'woopcd-partialcod-pro' ),
                        'default' => 'yes',
                        'options' => array(
                            'yes' => esc_html__( 'Is available', 'woopcd-partialcod-pro' ),
                            'no' => esc_html__( 'Is restricted', 'woopcd-partialcod-pro' ),
                        ),
                        'width' => '100%',
                        'fold_id' => 'all_enabled'
                    ),
                    array(
                        'id' => 'title',
                        'type' => 'textbox',
                        'column_size' => 2,
                        'column_title' => esc_html__( 'Title', 'woopcd-partialcod-pro' ),
                        'tooltip' => esc_html__( 'Controls payment method title on checkout page', 'woopcd-partialcod-pro' ),
                        'default' => '',
                        'placeholder' => $method_title,
                        'width' => '100%',
                        'fold' => array(
                            'target' => 'all_enabled',
                            'attribute' => 'value',
                            'value' => array( 'yes' ),
                            'oparator' => 'eq',
                            'clear' => false,
                        ),
                    ),
                    array(
                        'id' => 'order_button_text',
                        'type' => 'textbox',
                        'column_size' => 2,
                        'column_title' => esc_html__( 'Place Order Button Text', 'woopcd-partialcod-pro' ),
                        'tooltip' => esc_html__( 'Controls payment method order button text on checkout page', 'woopcd-partialcod-pro' ),
                        'default' => '',
                        'placeholder' => $button_text,
                        'width' => '100%',
                        'fold' => array(
                            'target' => 'all_enabled',
                            'attribute' => 'value',
                            'value' => array( 'yes' ),
                            'oparator' => 'eq',
                            'clear' => false,
                        ),
                    ),
                ),
            );

            $in_fields[] = array(
                'id' => 'any_ids',
                'type' => 'columns-field',
                'columns' => 1,
                'merge_fields' => false,
                'fields' => array(
                    array(
                        'id' => 'icon_url',
                        'type' => 'textbox',
                        'column_size' => 1,
                        'column_title' => esc_html__( 'Icon Url', 'woopcd-partialcod-pro' ),
                        'tooltip' => esc_html__( 'Controls payment method icon url on checkout page', 'woopcd-partialcod-pro' ),
                        'default' => '',
                        'placeholder' => $icon_url,
                        'width' => '100%',
                    ),
                ),
                'fold' => array(
                    'target' => 'all_enabled',
                    'attribute' => 'value',
                    'value' => array( 'yes' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            $in_fields[] = array(
                'id' => 'any_ids',
                'type' => 'columns-field',
                'columns' => 2,
                'merge_fields' => false,
                'fields' => array(
                    array(
                        'id' => 'desc',
                        'type' => 'textarea',
                        'column_size' => 1,
                        'column_title' => esc_html__( 'Description', 'woopcd-partialcod-pro' ),
                        'tooltip' => esc_html__( 'Controls payment method description on checkout page', 'woopcd-partialcod-pro' ),
                        'default' => '',
                        'placeholder' => 'Descriptions....',
                        'width' => '100%',
                        'fold' => array(
                            'target' => 'all_enabled',
                            'attribute' => 'value',
                            'value' => array( 'yes' ),
                            'oparator' => 'eq',
                            'clear' => false,
                        ),
                    ),
                    array(
                        'id' => 'message',
                        'type' => 'textarea',
                        'column_size' => 1,
                        'column_title' => esc_html__( 'Restriction Message', 'woopcd-partialcod-pro' ),
                        'tooltip' => esc_html__( 'Controls payment method the restriction message on checkout page', 'woopcd-partialcod-pro' ),
                        'default' => '',
                        'placeholder' => 'Restriction message....',
                        'width' => '100%',
                        'fold' => array(
                            'target' => 'all_enabled',
                            'attribute' => 'value',
                            'value' => array( 'no' ),
                            'oparator' => 'eq',
                            'clear' => false,
                        ),
                    ),
                ),
            );
            return $in_fields;
        }

        public static function process_options( $options, $raw_options, $args = array() ) {


            $options[ 'enabled' ] = 'yes';

            if ( isset( $raw_options[ 'enabled' ] ) ) {
                $options[ 'enabled' ] = $raw_options[ 'enabled' ];
            }

            if ( $options[ 'enabled' ] == 'yes' ) {

                if ( !empty( $raw_options[ 'title' ] ) ) {
                    $options[ 'title' ] = $raw_options[ 'title' ];
                }

                if ( !empty( $raw_options[ 'order_button_text' ] ) ) {
                    $options[ 'order_button_text' ] = $raw_options[ 'order_button_text' ];
                }

                if ( !empty( $raw_options[ 'icon_url' ] ) ) {
                    $options[ 'icon_url' ] = $raw_options[ 'icon_url' ];
                }

                if ( !empty( $raw_options[ 'desc' ] ) ) {
                    $options[ 'desc' ] = $raw_options[ 'desc' ];
                }
            } else {

                if ( !empty( $raw_options[ 'message' ] ) ) {
                    $options[ 'message' ] = $raw_options[ 'message' ];
                }
            }

            
            return $options;
        }

    }

    WOOPCD_PartialCOD_Premium_Admin_Method_Options_Checkout_All::init();
}
