<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WOOPCD_PartialCOD_Admin_Order_Activity_Customers' ) ) {

    class WOOPCD_PartialCOD_Admin_Order_Activity_Customers {

        public static function init() {
            add_filter( 'woopcd_partialcod-admin/order-activities/get-activity-groups', array( new self(), 'get_groups' ), 20, 2 );
            add_filter( 'woopcd_partialcod-admin/order-activities/get-activity-types', array( new self(), 'get_option' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/order-activities/get-activity-customer_update_role-fields', array( new self(), 'get_set_role_fields' ), 10, 2 );
            add_filter( 'woopcd_partialcod-admin/order-activities/get-activity-customer_update_meta-fields', array( new self(), 'get_update_meta_fields' ), 10, 2 );
            add_filter( 'woopcd_partialcod-admin/order-activities/get-activity-customer_remove_meta-fields', array( new self(), 'get_remove_meta_fields' ), 10, 2 );
        }

        public static function get_groups( $in_groups, $method_id ) {

            $in_groups[ 'customers' ] = esc_html__( 'Customers', 'woopcd-partialcod-pro' );

            return $in_groups;
        }

        public static function get_option( $in_options, $method_id ) {

            $in_options[ 'customer_update_role' ] = array(
                'title' => esc_html__( 'Customers - Set User Role', 'woopcd-partialcod-pro' ),
                'group_id' => 'customers',
                'tooltip' => esc_html__( 'Updates customers user roles', 'woopcd-partialcod-pro' ),
            );

            $in_options[ 'customer_update_meta' ] = array(
                'title' => esc_html__( 'Customers - Set Meta Data', 'woopcd-partialcod-pro' ),
                'group_id' => 'customers',
                'tooltip' => esc_html__( 'Updates or adds new meta data to customers', 'woopcd-partialcod-pro' ),
            );

            $in_options[ 'customer_remove_meta' ] = array(
                'title' => esc_html__( 'Customers - Remove Meta Data', 'woopcd-partialcod-pro' ),
                'group_id' => 'customers',
                'tooltip' => esc_html__( 'Removes meta data from customers', 'woopcd-partialcod-pro' ),
            );

            return $in_options;
        }

        public static function get_set_role_fields( $in_fields, $method_id ) {

            $in_fields[] = array(
                'id' => 'any_ids',
                'type' => 'columns-field',
                'columns' => 2,
                'merge_fields' => false,
                'field_css_class' => array( 'rn-first' ),
                'fields' => array(
                    array(
                        'id' => 'user_role',
                        'type' => 'select2',
                        'column_size' => 1,
                        'column_title' => esc_html__( 'User Role', 'woopcd-partialcod-pro' ),
                        'tooltip' => esc_html__( 'User role to apply', 'woopcd-partialcod-pro' ),
                        'placeholder' => esc_html__( 'Search user roles...', 'woopcd-partialcod-pro' ),
                        'minimum_results_forsearch' => 10,
                        'data' => 'roles',
                        'width' => '100%',
                    )
                ),
            );


            return $in_fields;
        }

        public static function get_update_meta_fields( $in_fields, $method_id ) {

            $in_fields[] = array(
                'id' => 'any_ids',
                'type' => 'columns-field',
                'columns' => 2,
                'merge_fields' => false,
                'field_css_class' => array( 'rn-first' ),
                'fields' => array(
                    array(
                        'id' => 'meta_key',
                        'type' => 'textbox',
                        'column_size' => 1,
                        'column_title' => esc_html__( 'Meta Key', 'woopcd-partialcod-pro' ),
                        'tooltip' => esc_html__( 'Customers metadata key to add or update', 'woopcd-partialcod-pro' ),
                        'default' => '',
                        'placeholder' => esc_html__( 'Meta key...', 'woopcd-partialcod-pro' ),
                        'width' => '100%',
                    ),
                    array(
                        'id' => 'meta_value',
                        'type' => 'textbox',
                        'column_size' => 1,
                        'column_title' => esc_html__( 'Meta Value', 'woopcd-partialcod-pro' ),
                        'tooltip' => esc_html__( 'Customers metadata value to add or update', 'woopcd-partialcod-pro' ),
                        'default' => '',
                        'placeholder' => esc_html__( 'Meta value...', 'woopcd-partialcod-pro' ),
                        'width' => '100%',
                    ),
                ),
            );


            return $in_fields;
        }

        public static function get_remove_meta_fields( $in_fields, $method_id ) {

            $in_fields[] = array(
                'id' => 'any_ids',
                'type' => 'columns-field',
                'columns' => 2,
                'merge_fields' => false,
                'field_css_class' => array( 'rn-first' ),
                'fields' => array(
                    array(
                        'id' => 'meta_key',
                        'type' => 'textbox',
                        'column_size' => 1,
                        'column_title' => esc_html__( 'Meta Key', 'woopcd-partialcod-pro' ),
                        'tooltip' => esc_html__( 'Customers metadata key to remove', 'woopcd-partialcod-pro' ),
                        'default' => '',
                        'placeholder' => esc_html__( 'Meta key...', 'woopcd-partialcod-pro' ),
                        'width' => '100%',
                    ),
                ),
            );


            return $in_fields;
        }

    }

    WOOPCD_PartialCOD_Admin_Order_Activity_Customers::init();
}
