<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WOOPCD_PartialCOD_Admin_Order_Activity_Orders' ) ) {

    class WOOPCD_PartialCOD_Admin_Order_Activity_Orders {

        public static function init() {
            add_filter( 'woopcd_partialcod-admin/order-activities/get-activity-groups', array( new self(), 'get_groups' ), 10, 2 );
            add_filter( 'woopcd_partialcod-admin/order-activities/get-activity-types', array( new self(), 'get_option' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/order-activities/get-activity-order_update_status-fields', array( new self(), 'get_update_status_fields' ), 10, 2 );
            add_filter( 'woopcd_partialcod-admin/order-activities/get-activity-order_add_note-fields', array( new self(), 'get_add_note_fields' ), 10, 2 );
            add_filter( 'woopcd_partialcod-admin/order-activities/get-activity-order_update_meta-fields', array( new self(), 'get_update_meta_fields' ), 10, 2 );
            add_filter( 'woopcd_partialcod-admin/order-activities/get-activity-order_remove_meta-fields', array( new self(), 'get_remove_meta_fields' ), 10, 2 );
        }

        public static function get_groups( $in_groups, $method_id ) {

            $in_groups[ 'orders' ] = esc_html__( 'Orders', 'woopcd-partialcod-pro' );

            return $in_groups;
        }

        public static function get_option( $in_options, $method_id ) {

            $in_options[ 'order_update_status' ] = array(
                'title' => esc_html__( 'Orders - Update Status', 'woopcd-partialcod-pro' ),
                'group_id' => 'orders',
                'tooltip' => esc_html__( 'Modifies order status', 'woopcd-partialcod-pro' ),
            );

            $in_options[ 'order_add_note' ] = array(
                'title' => esc_html__( 'Orders - Add Note', 'woopcd-partialcod-pro' ),
                'group_id' => 'orders',
                'tooltip' => esc_html__( 'Adds note to orders', 'woopcd-partialcod-pro' ),
            );

            $in_options[ 'order_update_meta' ] = array(
                'title' => esc_html__( 'Orders - Set Meta Data', 'woopcd-partialcod-pro' ),
                'group_id' => 'orders',
                'tooltip' => esc_html__( 'Updates or adds new meta data to orders', 'woopcd-partialcod-pro' ),
            );

            $in_options[ 'order_remove_meta' ] = array(
                'title' => esc_html__( 'Orders - Remove Meta Data', 'woopcd-partialcod-pro' ),
                'group_id' => 'orders',
                'tooltip' => esc_html__( 'Removes meta data from orders', 'woopcd-partialcod-pro' ),
            );

            return $in_options;
        }

        public static function get_update_status_fields( $in_fields, $method_id ) {

            $in_fields[] = array(
                'id' => 'any_ids',
                'type' => 'columns-field',
                'columns' => 1,
                'merge_fields' => false,
                'field_css_class' => array( 'rn-first' ),
                'fields' => array(
                    array(
                        'id' => 'new_status',
                        'type' => 'select2',
                        'column_size' => 1,
                        'column_title' => esc_html__( 'Order Status', 'woopcd-partialcod-pro' ),
                        'tooltip' => esc_html__( 'Status to change the order to', 'woopcd-partialcod-pro' ),
                        'minimum_results_forsearch' => 10,
                        'data' => 'partialcod:order_statuses',
                        'width' => '100%',
                    ),
                ),
            );

            $in_fields[] = array(
                'id' => 'any_ids',
                'type' => 'columns-field',
                'columns' => 1,
                'merge_fields' => false,
                'fields' => array(
                    array(
                        'id' => 'note',
                        'type' => 'textarea',
                        'column_size' => 1,
                        'column_title' => esc_html__( 'Note', 'woopcd-partialcod-pro' ),
                        'tooltip' => esc_html__( 'Note to add (optional)', 'woopcd-partialcod-pro' ),
                        'default' => '',
                        'placeholder' => esc_html__( 'Note to add (optional)....', 'woopcd-partialcod-pro' ),
                        'width' => '100%',
                    ),
                ),
            );

            return $in_fields;
        }

        public static function get_add_note_fields( $in_fields, $method_id ) {

            $in_fields[] = array(
                'id' => 'any_ids',
                'type' => 'columns-field',
                'columns' => 1,
                'merge_fields' => false,
                'field_css_class' => array( 'rn-first' ),
                'fields' => array(
                    array(
                        'id' => 'note',
                        'type' => 'textarea',
                        'column_size' => 1,
                        'column_title' => esc_html__( 'Note', 'woopcd-partialcod-pro' ),
                        'tooltip' => esc_html__( 'Note to add', 'woopcd-partialcod-pro' ),
                        'default' => '',
                        'placeholder' => esc_html__( 'Note to add....', 'woopcd-partialcod-pro' ),
                        'width' => '100%',
                    ),
                ),
            );

            $in_fields[] = array(
                'id' => 'any_ids',
                'type' => 'columns-field',
                'columns' => 2,
                'merge_fields' => false,
                'fields' => array(
                    array(
                        'id' => 'is_customer_note',
                        'type' => 'select2',
                        'column_size' => 1,
                        'column_title' => esc_html__( 'Is Customer Note', 'woopcd-partialcod-pro' ),
                        'tooltip' => esc_html__( 'Is this a note for the customer', 'woopcd-partialcod-pro' ),
                        'default' => 'no',
                        'options' => array(
                            'yes' => esc_html__( 'Yes', 'woopcd-partialcod-pro' ),
                            'no' => esc_html__( 'No', 'woopcd-partialcod-pro' ),
                        ),
                        'width' => '100%',
                    ),
                    array(
                        'id' => 'added_by_email',
                        'type' => 'select2',
                        'column_size' => 1,
                        'column_title' => esc_html__( 'Added By User', 'woopcd-partialcod-pro' ),
                        'tooltip' => esc_html__( 'Was the note added by a user?', 'woopcd-partialcod-pro' ),
                        'multiple' => false,
                        'minimum_input_length' => 2,
                        'placeholder' => esc_html__( 'Search users...', 'woopcd-partialcod-pro' ),
                        'allow_clear' => true,
                        'minimum_results_forsearch' => 10,
                        'data' => array(
                            'source' => 'users',
                            'ajax' => true,
                            'value_col' => 'email',
                            'show_value' => true,
                        ),
                        'width' => '100%',
                    )
                ),
            );



            return $in_fields;
        }

        public static function get_update_meta_fields( $in_fields, $method_id ) {

            $in_fields[] = array(
                'id' => 'any_ids',
                'type' => 'columns-field',
                'columns' => 2,
                'merge_fields' => false,
                'field_css_class' => array( 'rn-first' ),
                'fields' => array(
                    array(
                        'id' => 'meta_key',
                        'type' => 'textbox',
                        'column_size' => 1,
                        'column_title' => esc_html__( 'Meta Key', 'woopcd-partialcod-pro' ),
                        'tooltip' => esc_html__( 'Order metadata key to add or update', 'woopcd-partialcod-pro' ),
                        'default' => '',
                        'placeholder' => esc_html__( 'Meta key...', 'woopcd-partialcod-pro' ),
                        'width' => '100%',
                    ),
                    array(
                        'id' => 'meta_value',
                        'type' => 'textbox',
                        'column_size' => 1,
                        'column_title' => esc_html__( 'Meta Value', 'woopcd-partialcod-pro' ),
                        'tooltip' => esc_html__( 'Order metadata value to add or update', 'woopcd-partialcod-pro' ),
                        'default' => '',
                        'placeholder' => esc_html__( 'Meta value...', 'woopcd-partialcod-pro' ),
                        'width' => '100%',
                    ),
                ),
            );


            return $in_fields;
        }

        public static function get_remove_meta_fields( $in_fields, $method_id ) {

            $in_fields[] = array(
                'id' => 'any_ids',
                'type' => 'columns-field',
                'columns' => 2,
                'merge_fields' => false,
                'field_css_class' => array( 'rn-first' ),
                'fields' => array(
                    array(
                        'id' => 'meta_key',
                        'type' => 'textbox',
                        'column_size' => 1,
                        'column_title' => esc_html__( 'Meta Key', 'woopcd-partialcod-pro' ),
                        'tooltip' => esc_html__( 'Order metadata key to remove', 'woopcd-partialcod-pro' ),
                        'default' => '',
                        'placeholder' => esc_html__( 'Meta key...', 'woopcd-partialcod-pro' ),
                        'width' => '100%',
                    ),
                ),
            );


            return $in_fields;
        }

    }

    WOOPCD_PartialCOD_Admin_Order_Activity_Orders::init();
}
