<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WOOPCD_PartialCOD_Admin_Order_Conditions_Customer' ) ) {

    class WOOPCD_PartialCOD_Admin_Order_Conditions_Customer {

        public static function init() {
            add_filter( 'woopcd_partialcod-admin/get-order-condition-groups', array( new self(), 'get_groups' ), 100, 2 );

            add_filter( 'woopcd_partialcod-admin/get-order-customer-group-conditions', array( new self(), 'get_conditions' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/get-order-users-condition-fields', array( new self(), 'get_users_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-order-user_roles-condition-fields', array( new self(), 'get_user_roles_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-order-user_caps-condition-fields', array( new self(), 'get_user_caps_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-order-user_meta-condition-fields', array( new self(), 'get_user_meta_fields' ), 10 );
        }

        public static function get_groups( $in_groups, $args ) {
            $in_groups[ 'customer' ] = esc_html__( 'Customer', 'woopcd-partialcod-pro' );
            return $in_groups;
        }

        public static function get_conditions( $in_list, $args ) {

            $in_list[ 'users' ] = esc_html__( 'Customers', 'woopcd-partialcod-pro' );            
            $in_list[ 'user_roles' ] = esc_html__( 'User Roles', 'woopcd-partialcod-pro' );
            $in_list[ 'user_caps' ] = esc_html__( 'User Capabilities', 'woopcd-partialcod-pro' );
            $in_list[ 'user_meta' ] = esc_html__( 'User Meta Field', 'woopcd-partialcod-pro' );

            return $in_list;
        }

        public static function get_users_fields( $in_fields ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'woopcd-partialcod-pro' ),
                    'none' => esc_html__( 'None in the list', 'woopcd-partialcod-pro' ),
                ),
                'width' => '98%',
                'box_width' => '25%',
            );

            $in_fields[] = array(
                'id' => 'user_emails',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 2,
                'placeholder' => esc_html__( 'Search users...', 'woopcd-partialcod-pro' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'users',
                    'ajax' => true,
                    'value_col' => 'email',
                    'show_value' => true,
                ),
                'width' => '100%',
                'box_width' => '75%',
            );



            return $in_fields;
        }

        public static function get_user_roles_fields( $in_fields ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'woopcd-partialcod-pro' ),
                    'in_all_list' => esc_html__( 'All in the list', 'woopcd-partialcod-pro' ),
                    'in_list_only' => esc_html__( 'Only in the list', 'woopcd-partialcod-pro' ),
                    'in_all_list_only' => esc_html__( 'Only all in the list', 'woopcd-partialcod-pro' ),
                    'none' => esc_html__( 'None in the list', 'woopcd-partialcod-pro' ),
                ),
                'width' => '98%',
                'box_width' => '25%',
            );

            $in_fields[] = array(
                'id' => 'user_roles',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 1,
                'placeholder' => esc_html__( 'Search user roles...', 'woopcd-partialcod-pro' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'roles',
                    'ajax' => true,
                ),
                'width' => '100%',
                'box_width' => '75%',
            );



            return $in_fields;
        }

        public static function get_user_caps_fields( $in_fields ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'woopcd-partialcod-pro' ),
                    'in_all_list' => esc_html__( 'All in the list', 'woopcd-partialcod-pro' ),
                    'in_list_only' => esc_html__( 'Only in the list', 'woopcd-partialcod-pro' ),
                    'in_all_list_only' => esc_html__( 'Only all in the list', 'woopcd-partialcod-pro' ),
                    'none' => esc_html__( 'None in the list', 'woopcd-partialcod-pro' ),
                ),
                'width' => '98%',
                'box_width' => '25%',
            );

            $in_fields[] = array(
                'id' => 'user_caps',
                'type' => 'select2',
                'multiple' => true,
                'allow_clear' => true,
                'minimum_input_length' => 1,
                'placeholder' => esc_html__( 'Search capabilities...', 'woopcd-partialcod-pro' ),
                'data' => array(
                    'source' => 'wp_caps',
                    'ajax' => true,
                ),
                'width' => '100%',
                'box_width' => '75%',
            );



            return $in_fields;
        }

        public static function get_user_meta_fields( $in_fields ) {

            $in_fields[] = array(
                'id' => 'meta_key',
                'type' => 'textbox',
                'input_type' => 'text',
                'default' => '',
                'placeholder' => esc_html__( 'Meta field key', 'woopcd-partialcod-pro' ),
                'width' => '98%',
                'box_width' => '40%',
            );

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'empty',
                'options' => array(
                    'empty' => esc_html__( 'Empty', 'woopcd-partialcod-pro' ),
                    'contains' => esc_html__( 'Contains', 'woopcd-partialcod-pro' ),
                    'not_contains' => esc_html__( 'Not contains', 'woopcd-partialcod-pro' ),
                    'begins' => esc_html__( 'Begins with', 'woopcd-partialcod-pro' ),
                    'ends' => esc_html__( 'Ends with', 'woopcd-partialcod-pro' ),
                    '>=' => esc_html__( 'More than or equal to', 'woopcd-partialcod-pro' ),
                    '>' => esc_html__( 'More than', 'woopcd-partialcod-pro' ),
                    '<=' => esc_html__( 'Less than or equal to', 'woopcd-partialcod-pro' ),
                    '<' => esc_html__( 'Less than', 'woopcd-partialcod-pro' ),
                    '==' => esc_html__( 'Equal to', 'woopcd-partialcod-pro' ),
                    '!=' => esc_html__( 'Not equal to', 'woopcd-partialcod-pro' ),
                    'checked' => esc_html__( 'Checked', 'woopcd-partialcod-pro' ),
                ),
                'fold_id' => 'user_meta_field_compare',
                'width' => '98%',
                'box_width' => '34%',
            );

            $in_fields[] = array(
                'id' => 'meta_value',
                'type' => 'textbox',
                'input_type' => 'text',
                'default' => '',
                'placeholder' => esc_html__( 'Value', 'woopcd-partialcod-pro' ),
                'fold' => array(
                    'target' => 'user_meta_field_compare',
                    'attribute' => 'value',
                    'value' => array( 'contains', 'not_contains', 'begins', 'ends', '>=', '>', '<=', '<', '==', '!=' ),
                    'oparator' => 'eq',
                    'clear' => true,
                ),
                'width' => '100%',
                'box_width' => '26%',
            );

            $in_fields[] = array(
                'id' => 'yes_no',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    'no' => esc_html__( 'No', 'woopcd-partialcod-pro' ),
                    'yes' => esc_html__( 'Yes', 'woopcd-partialcod-pro' ),
                ),
                'fold' => array(
                    'target' => 'user_meta_field_compare',
                    'attribute' => 'value',
                    'value' => array( 'empty', 'checked' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '100%',
                'box_width' => '26%',
            );



            return $in_fields;
        }

    }

    WOOPCD_PartialCOD_Admin_Order_Conditions_Customer::init();
}