<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WOOPCD_PartialCOD_Admin_Order_Conditions_DateTime_Created' ) ) {

    class WOOPCD_PartialCOD_Admin_Order_Conditions_DateTime_Created {

        public static function init() {
            add_filter( 'woopcd_partialcod-admin/get-order-condition-groups', array( new self(), 'get_groups' ), 120, 2 );

            add_filter( 'woopcd_partialcod-admin/get-order-datetime_created-group-conditions', array( new self(), 'get_conditions' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/get-order-date_created-condition-fields', array( new self(), 'get_date_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-order-time_created-condition-fields', array( new self(), 'get_time_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-order-date_time_created-condition-fields', array( new self(), 'get_date_time_fields' ), 10 );
        }

        public static function get_groups( $in_groups, $args ) {
            $in_groups[ 'datetime_created' ] = esc_html__( 'Date &amp; Time Created', 'woopcd-partialcod-pro' );
            return $in_groups;
        }

        public static function get_conditions( $in_list, $args ) {

            $in_list[ 'date_created' ] = esc_html__( 'Date Created', 'woopcd-partialcod-pro' );
            $in_list[ 'time_created' ] = esc_html__( 'Time Created', 'woopcd-partialcod-pro' );
            $in_list[ 'date_time_created' ] = esc_html__( 'Date &amp; Time Created', 'woopcd-partialcod-pro' );
            
            return $in_list;
        }

        public static function get_date_fields( $in_fields ) {

            $in_fields[] = array(
                'id' => 'date_type',
                'type' => 'select2',
                'default' => 'date',
                'options' => array(
                    'date' => esc_html__( 'Specific date', 'woopcd-partialcod-pro' ),
                    'from' => esc_html__( 'From', 'woopcd-partialcod-pro' ),
                    'to' => esc_html__( 'To', 'woopcd-partialcod-pro' ),
                    'between' => esc_html__( 'Between', 'woopcd-partialcod-pro' ),
                ),
                'fold_id' => 'date_type',
                'width' => '98%',
                'box_width' => '26%',
            );

            $in_fields[] = array(
                'id' => 'from_date',
                'type' => 'date',
                'default' => '',
                'placeholder' => esc_html__( 'yy-mm-dd', 'woopcd-partialcod-pro' ),
                'date_format' => 'yy-mm-dd',
                'number_of_months' => 1,
                'show_button_panel' => false,
                'change_month' => true,
                'change_year' => true,
                'first_day' => 0,
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'between',
                    'oparator' => 'eq',
                    'clear' => true,
                ),
                'width' => '98%',
                'box_width' => '37%',
            );

            $in_fields[] = array(
                'id' => 'to_date',
                'type' => 'date',
                'default' => '',
                'placeholder' => esc_html__( 'yy-mm-dd', 'woopcd-partialcod-pro' ),
                'date_format' => 'yy-mm-dd',
                'number_of_months' => 1,
                'show_button_panel' => false,
                'change_month' => true,
                'change_year' => true,
                'first_day' => 0,
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'between',
                    'oparator' => 'eq',
                    'clear' => true,
                ),
                'width' => '100%',
                'box_width' => '37%',
            );

            $in_fields[] = array(
                'id' => 'date',
                'type' => 'date',
                'default' => '',
                'placeholder' => esc_html__( 'yy-mm-dd', 'woopcd-partialcod-pro' ),
                'date_format' => 'yy-mm-dd',
                'number_of_months' => 1,
                'show_button_panel' => false,
                'change_month' => true,
                'change_year' => true,
                'first_day' => 0,
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'between',
                    'oparator' => 'neq',
                    'clear' => true,
                ),
                'width' => '100%',
                'box_width' => '74%',
            );

            return $in_fields;
        }

        public static function get_time_fields( $in_fields ) {

            $in_fields[] = array(
                'id' => 'time_type',
                'type' => 'select2',
                'default' => 'from',
                'options' => array(
                    'from' => esc_html__( 'From', 'woopcd-partialcod-pro' ),
                    'to' => esc_html__( 'To', 'woopcd-partialcod-pro' ),
                    'between' => esc_html__( 'Between', 'woopcd-partialcod-pro' ),
                ),
                'fold_id' => 'time_type',
                'width' => '98%',
                'box_width' => '26%',
            );

            $in_fields[] = array(
                'id' => 'from_time',
                'type' => 'time',
                'default' => '',
                'placeholder' => esc_html__( '00:00:00', 'woopcd-partialcod-pro' ),
                'time_format' => 'HH:mm:ss',
                'one_line' => true,
                'fold' => array(
                    'target' => 'time_type',
                    'attribute' => 'value',
                    'value' => 'between',
                    'oparator' => 'eq',
                    'clear' => true,
                ),
                'width' => '98%',
                'box_width' => '37%',
            );

            $in_fields[] = array(
                'id' => 'to_time',
                'type' => 'time',
                'default' => '',
                'placeholder' => esc_html__( '00:00:00', 'woopcd-partialcod-pro' ),
                'time_format' => 'HH:mm:ss',
                'one_line' => true,
                'fold' => array(
                    'target' => 'time_type',
                    'attribute' => 'value',
                    'value' => 'between',
                    'oparator' => 'eq',
                    'clear' => true,
                ),
                'width' => '100%',
                'box_width' => '37%',
            );

            $in_fields[] = array(
                'id' => 'time',
                'type' => 'time',
                'default' => '',
                'placeholder' => esc_html__( '00:00:00', 'woopcd-partialcod-pro' ),
                'time_format' => 'HH:mm:ss',
                'one_line' => true,
                'fold' => array(
                    'target' => 'time_type',
                    'attribute' => 'value',
                    'value' => 'between',
                    'oparator' => 'neq',
                    'clear' => true,
                ),
                'width' => '100%',
                'box_width' => '74%',
            );

            return $in_fields;
        }

        public static function get_date_time_fields( $in_fields ) {

            $in_fields[] = array(
                'id' => 'date_type',
                'type' => 'select2',
                'default' => 'from',
                'options' => array(
                    'from' => esc_html__( 'From', 'woopcd-partialcod-pro' ),
                    'to' => esc_html__( 'To', 'woopcd-partialcod-pro' ),
                    'between' => esc_html__( 'Between', 'woopcd-partialcod-pro' ),
                ),
                'fold_id' => 'date_type',
                'width' => '98%',
                'box_width' => '26%',
            );

            $in_fields[] = array(
                'id' => 'from_date_time',
                'type' => 'datetime',
                'default' => '',
                'placeholder' => esc_html__( 'yy-mm-dd 00:00:00', 'woopcd-partialcod-pro' ),
                'date_format' => 'yy-mm-dd',
                'number_of_months' => 1,
                'change_month' => true,
                'change_year' => true,
                'first_day' => 0,
                'time_format' => 'HH:mm:ss',
                'one_line' => true,
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'between',
                    'oparator' => 'eq',
                    'clear' => true,
                ),
                'width' => '98%',
                'box_width' => '37%',
            );

            $in_fields[] = array(
                'id' => 'to_date_time',
                'type' => 'datetime',
                'default' => '',
                'placeholder' => esc_html__( 'yy-mm-dd 00:00:00', 'woopcd-partialcod-pro' ),
                'date_format' => 'yy-mm-dd',
                'number_of_months' => 1,
                'change_month' => true,
                'change_year' => true,
                'first_day' => 0,
                'time_format' => 'HH:mm:ss',
                'one_line' => true,
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'between',
                    'oparator' => 'eq',
                    'clear' => true,
                ),
                'width' => '100%',
                'box_width' => '37%',
            );

            $in_fields[] = array(
                'id' => 'date_time',
                'type' => 'datetime',
                'default' => '',
                'placeholder' => esc_html__( 'yy-mm-dd 00:00:00', 'woopcd-partialcod-pro' ),
                'date_format' => 'yy-mm-dd',
                'number_of_months' => 1,
                'change_month' => true,
                'change_year' => true,
                'first_day' => 0,
                'time_format' => 'HH:mm:ss',
                'one_line' => true,
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'between',
                    'oparator' => 'neq',
                    'clear' => true,
                ),
                'width' => '100%',
                'box_width' => '74%',
            );

            return $in_fields;
        }

    }

    WOOPCD_PartialCOD_Admin_Order_Conditions_DateTime_Created::init();
}