<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WOOPCD_PartialCOD_Admin_Order_Conditions_Item_Quantity' ) ) {

    class WOOPCD_PartialCOD_Admin_Order_Conditions_Item_Quantity {

        public static function init() {

            add_filter( 'woopcd_partialcod-admin/get-order-condition-groups', array( new self(), 'get_groups' ), 90, 2 );

            add_filter( 'woopcd_partialcod-admin/get-order-item_quantity-group-conditions', array( new self(), 'get_conditions' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/get-order-quantity_products-condition-fields', array( new self(), 'get_quantity_products_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-order-quantity_variations-condition-fields', array( new self(), 'get_quantity_variations_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-order-quantity_categories-condition-fields', array( new self(), 'get_quantity_categories_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-order-quantity_tags-condition-fields', array( new self(), 'get_quantity_tags_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-order-quantity_attributes-condition-fields', array( new self(), 'get_quantity_attributes_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-order-quantity_virtuals-condition-fields', array( new self(), 'get_quantity_virtual_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-order-quantity_tax_classes-condition-fields', array( new self(), 'get_quantity_tax_classes_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-order-quantity_shipping_classes-condition-fields', array( new self(), 'get_quantity_shipping_classes_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-order-quantity_metas-condition-fields', array( new self(), 'get_quantity_metas_fields' ), 10 );
        }

        public static function get_groups( $in_groups, $args ) {

            $in_groups[ 'item_quantity' ] = esc_html__( 'Order Item Quantity', 'woopcd-partialcod-pro' );

            return $in_groups;
        }

        public static function get_conditions( $in_list, $args ) {

            $in_list[ 'quantity_products' ] = esc_html__( 'Products Quantity', 'woopcd-partialcod-pro' );
            $in_list[ 'quantity_variations' ] = esc_html__( 'Variations Quantity', 'woopcd-partialcod-pro' );
            $in_list[ 'quantity_categories' ] = esc_html__( 'Categories Quantity', 'woopcd-partialcod-pro' );
            $in_list[ 'quantity_tags' ] = esc_html__( 'Tags Quantity', 'woopcd-partialcod-pro' );
            $in_list[ 'quantity_attributes' ] = esc_html__( 'Attributes Quantity', 'woopcd-partialcod-pro' );
            $in_list[ 'quantity_virtuals' ] = esc_html__( 'Virtual Products Quantity', 'woopcd-partialcod-pro' );
            $in_list[ 'quantity_tax_classes' ] = esc_html__( 'Tax Classes Quantity', 'woopcd-partialcod-pro' );
            $in_list[ 'quantity_shipping_classes' ] = esc_html__( 'Shipping Classes Quantity', 'woopcd-partialcod-pro' );
            $in_list[ 'quantity_metas' ] = esc_html__( 'Product Meta Fields Quantity', 'woopcd-partialcod-pro' );

            return $in_list;
        }

        public static function get_quantity_products_fields( $in_fields ) {

            $in_fields[] = array(
                'id' => 'product_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 1,
                'placeholder' => 'Search products...',
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'wc:products',
                    'ajax' => true,
                    'value_col' => 'slug',
                    'show_value' => false,
                ),
                'width' => '99%',
                'box_width' => '52%',
            );

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'woopcd-partialcod-pro' ),
                    '>' => esc_html__( 'More than', 'woopcd-partialcod-pro' ),
                    '<=' => esc_html__( 'Less than or equal to', 'woopcd-partialcod-pro' ),
                    '<' => esc_html__( 'Less than', 'woopcd-partialcod-pro' ),
                    '==' => esc_html__( 'Equal to', 'woopcd-partialcod-pro' ),
                    '!=' => esc_html__( 'Not equal to', 'woopcd-partialcod-pro' ),
                ),
                'width' => '99%',
                'box_width' => '33%',
            );

            $in_fields[] = array(
                'id' => 'quantity',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'woopcd-partialcod-pro' ),
                'width' => '100%',
                'box_width' => '15%',
                'attributes' => array(
                    'min' => '0',
                ),
            );


            return $in_fields;
        }

        public static function get_quantity_variations_fields( $in_fields ) {
            $in_fields[] = array(
                'id' => 'variation_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 1,
                'placeholder' => 'Search variations...',
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'wc:product_variations',
                    'ajax' => true,
                    'value_col' => 'slug',
                    'show_value' => false,
                ),
                'width' => '99%',
                'box_width' => '52%',
            );

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'woopcd-partialcod-pro' ),
                    '>' => esc_html__( 'More than', 'woopcd-partialcod-pro' ),
                    '<=' => esc_html__( 'Less than or equal to', 'woopcd-partialcod-pro' ),
                    '<' => esc_html__( 'Less than', 'woopcd-partialcod-pro' ),
                    '==' => esc_html__( 'Equal to', 'woopcd-partialcod-pro' ),
                    '!=' => esc_html__( 'Not equal to', 'woopcd-partialcod-pro' ),
                ),
                'width' => '99%',
                'box_width' => '33%',
            );

            $in_fields[] = array(
                'id' => 'quantity',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'woopcd-partialcod-pro' ),
                'width' => '100%',
                'box_width' => '15%',
                'attributes' => array(
                    'min' => '0',
                ),
            );


            return $in_fields;
        }

        public static function get_quantity_categories_fields( $in_fields ) {

            $in_fields[] = array(
                'id' => 'category_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 1,
                'placeholder' => 'Search categories...',
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'categories:product_cat',
                    'ajax' => true,
                    'value_col' => 'slug',
                    'show_value' => false,
                ),
                'width' => '99%',
                'box_width' => '52%',
            );

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'woopcd-partialcod-pro' ),
                    '>' => esc_html__( 'More than', 'woopcd-partialcod-pro' ),
                    '<=' => esc_html__( 'Less than or equal to', 'woopcd-partialcod-pro' ),
                    '<' => esc_html__( 'Less than', 'woopcd-partialcod-pro' ),
                    '==' => esc_html__( 'Equal to', 'woopcd-partialcod-pro' ),
                    '!=' => esc_html__( 'Not equal to', 'woopcd-partialcod-pro' ),
                ),
                'width' => '99%',
                'box_width' => '33%',
            );

            $in_fields[] = array(
                'id' => 'quantity',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'woopcd-partialcod-pro' ),
                'width' => '100%',
                'box_width' => '15%',
                'attributes' => array(
                    'min' => '0',
                ),
            );


            return $in_fields;
        }

        public static function get_quantity_tags_fields( $in_fields ) {

            $in_fields[] = array(
                'id' => 'tag_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 1,
                'placeholder' => 'Search tags...',
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'categories:product_tag',
                    'ajax' => true,
                    'value_col' => 'slug',
                    'show_value' => false,
                ),
                'width' => '99%',
                'box_width' => '52%',
            );

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'woopcd-partialcod-pro' ),
                    '>' => esc_html__( 'More than', 'woopcd-partialcod-pro' ),
                    '<=' => esc_html__( 'Less than or equal to', 'woopcd-partialcod-pro' ),
                    '<' => esc_html__( 'Less than', 'woopcd-partialcod-pro' ),
                    '==' => esc_html__( 'Equal to', 'woopcd-partialcod-pro' ),
                    '!=' => esc_html__( 'Not equal to', 'woopcd-partialcod-pro' ),
                ),
                'width' => '99%',
                'box_width' => '33%',
            );

            $in_fields[] = array(
                'id' => 'quantity',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'woopcd-partialcod-pro' ),
                'width' => '100%',
                'box_width' => '15%',
                'attributes' => array(
                    'min' => '0',
                ),
            );


            return $in_fields;
        }

        public static function get_quantity_attributes_fields( $in_fields ) {
            $in_fields[] = array(
                'id' => 'attribute_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 1,
                'placeholder' => 'Search attributes...',
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'wc:attributes',
                    'ajax' => true,
                    'value_col' => 'slug',
                    'show_value' => false,
                ),
                'width' => '99%',
                'box_width' => '52%',
            );

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'woopcd-partialcod-pro' ),
                    '>' => esc_html__( 'More than', 'woopcd-partialcod-pro' ),
                    '<=' => esc_html__( 'Less than or equal to', 'woopcd-partialcod-pro' ),
                    '<' => esc_html__( 'Less than', 'woopcd-partialcod-pro' ),
                    '==' => esc_html__( 'Equal to', 'woopcd-partialcod-pro' ),
                    '!=' => esc_html__( 'Not equal to', 'woopcd-partialcod-pro' ),
                ),
                'width' => '99%',
                'box_width' => '33%',
            );

            $in_fields[] = array(
                'id' => 'quantity',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'woopcd-partialcod-pro' ),
                'width' => '100%',
                'box_width' => '15%',
                'attributes' => array(
                    'min' => '0',
                ),
            );


            return $in_fields;
        }

        public static function get_quantity_virtual_fields( $in_fields ) {
            $in_fields[] = array(
                'id' => 'is_virtual',
                'type' => 'select2',
                'default' => 'yes',
                'options' => array(
                    'no' => esc_html__( 'None-virtual products', 'woopcd-partialcod-pro' ),
                    'yes' => esc_html__( 'Virtual products', 'woopcd-partialcod-pro' ),
                ),
                'width' => '99%',
                'box_width' => '50%',
            );

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'woopcd-partialcod-pro' ),
                    '>' => esc_html__( 'More than', 'woopcd-partialcod-pro' ),
                    '<=' => esc_html__( 'Less than or equal to', 'woopcd-partialcod-pro' ),
                    '<' => esc_html__( 'Less than', 'woopcd-partialcod-pro' ),
                    '==' => esc_html__( 'Equal to', 'woopcd-partialcod-pro' ),
                    '!=' => esc_html__( 'Not equal to', 'woopcd-partialcod-pro' ),
                ),
                'width' => '99%',
                'box_width' => '35%',
            );

            $in_fields[] = array(
                'id' => 'quantity',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'woopcd-partialcod-pro' ),
                'width' => '100%',
                'box_width' => '15%',
                'attributes' => array(
                    'min' => '0',
                ),
            );


            return $in_fields;
        }

        public static function get_quantity_tax_classes_fields( $in_fields ) {
            $in_fields[] = array(
                'id' => 'tax_classes',
                'type' => 'select2',
                'multiple' => true,
                'placeholder' => esc_html__( 'Select tax classes...', 'woopcd-partialcod-pro' ),
                'options' => array(
                    '--0' => esc_html__( 'Standard Rate', 'woopcd-partialcod-pro' )
                ),
                'data' => array(
                    'source' => 'wc:tax_classes',
                    'ajax' => false,
                    'value_col' => 'slug',
                ),
                'width' => '99%',
                'box_width' => '52%',
            );

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'woopcd-partialcod-pro' ),
                    '>' => esc_html__( 'More than', 'woopcd-partialcod-pro' ),
                    '<=' => esc_html__( 'Less than or equal to', 'woopcd-partialcod-pro' ),
                    '<' => esc_html__( 'Less than', 'woopcd-partialcod-pro' ),
                    '==' => esc_html__( 'Equal to', 'woopcd-partialcod-pro' ),
                    '!=' => esc_html__( 'Not equal to', 'woopcd-partialcod-pro' ),
                ),
                'width' => '99%',
                'box_width' => '33%',
            );

            $in_fields[] = array(
                'id' => 'quantity',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'woopcd-partialcod-pro' ),
                'width' => '100%',
                'box_width' => '15%',
                'attributes' => array(
                    'min' => '0',
                ),
            );


            return $in_fields;
        }

        public static function get_quantity_shipping_classes_fields( $in_fields ) {
            $in_fields[] = array(
                'id' => 'shipping_classes',
                'type' => 'select2',
                'multiple' => true,
                'placeholder' => esc_html__( 'Select shipping classes...', 'woopcd-partialcod-pro' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'wc:shipping_classes',
                    'ajax' => false,
                    'value_col' => 'slug',
                ),
                'width' => '99%',
                'box_width' => '52%',
            );

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'woopcd-partialcod-pro' ),
                    '>' => esc_html__( 'More than', 'woopcd-partialcod-pro' ),
                    '<=' => esc_html__( 'Less than or equal to', 'woopcd-partialcod-pro' ),
                    '<' => esc_html__( 'Less than', 'woopcd-partialcod-pro' ),
                    '==' => esc_html__( 'Equal to', 'woopcd-partialcod-pro' ),
                    '!=' => esc_html__( 'Not equal to', 'woopcd-partialcod-pro' ),
                ),
                'width' => '99%',
                'box_width' => '33%',
            );

            $in_fields[] = array(
                'id' => 'quantity',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'woopcd-partialcod-pro' ),
                'width' => '100%',
                'box_width' => '15%',
                'attributes' => array(
                    'min' => '0',
                ),
            );


            return $in_fields;
        }

        public static function get_quantity_metas_fields( $in_fields ) {

            $in_fields[] = array(
                'id' => 'meta_key',
                'type' => 'textbox',
                'input_type' => 'text',
                'default' => '',
                'placeholder' => esc_html__( 'Meta field key', 'woopcd-partialcod-pro' ),
                'width' => '98%',
                'box_width' => '26%',
            );

            $in_fields[] = array(
                'id' => 'meta_value',
                'type' => 'textbox',
                'input_type' => 'text',
                'default' => '',
                'placeholder' => esc_html__( 'Meta field value', 'woopcd-partialcod-pro' ),
                'width' => '98%',
                'box_width' => '26%',
            );

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'woopcd-partialcod-pro' ),
                    '>' => esc_html__( 'More than', 'woopcd-partialcod-pro' ),
                    '<=' => esc_html__( 'Less than or equal to', 'woopcd-partialcod-pro' ),
                    '<' => esc_html__( 'Less than', 'woopcd-partialcod-pro' ),
                    '==' => esc_html__( 'Equal to', 'woopcd-partialcod-pro' ),
                    '!=' => esc_html__( 'Not equal to', 'woopcd-partialcod-pro' ),
                ),
                'width' => '99%',
                'box_width' => '33%',
            );

            $in_fields[] = array(
                'id' => 'quantity',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'woopcd-partialcod-pro' ),
                'width' => '100%',
                'box_width' => '15%',
                'attributes' => array(
                    'min' => '0',
                ),
            );


            return $in_fields;
        }

    }

    WOOPCD_PartialCOD_Admin_Order_Conditions_Item_Quantity::init();
}