<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WOOPCD_PartialCOD_Admin__Order_Conditions_Orders' ) ) {

    class WOOPCD_PartialCOD_Admin__Order_Conditions_Orders {

        public static function init() {

            add_filter( 'woopcd_partialcod-admin/get-order-condition-groups', array( new self(), 'get_groups' ), 50 );

            add_filter( 'woopcd_partialcod-admin/get-order-orders-group-conditions', array( new self(), 'get_conditions' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/get-order-currency-condition-fields', array( new self(), 'get_currency_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-order-status-condition-fields', array( new self(), 'get_status_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-order-quantity-condition-fields', array( new self(), 'get_quantity_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-order-weight-condition-fields', array( new self(), 'get_weight_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-order-line_count-condition-fields', array( new self(), 'get_line_count_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-order-coupons-condition-fields', array( new self(), 'get_applied_coupons_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-order-advance_pay_methods-condition-fields', array( new self(), 'get_advance_pay_methods_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-order-needs_payment-condition-fields', array( new self(), 'get_is_needed_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-order-needs_processing-condition-fields', array( new self(), 'get_is_needed_fields' ), 10 );
            add_filter( 'woopcd_partialcod-admin/get-order-is_paid-condition-fields', array( new self(), 'get_is_needed_fields' ), 10 );
        }

        public static function get_groups( $in_groups ) {
            $in_groups[ 'orders' ] = esc_html__( 'Orders', 'woopcd-partialcod-pro' );
            return $in_groups;
        }

        public static function get_conditions( $in_list, $args ) {

            $in_list[ 'currency' ] = esc_html__( 'Order Currency', 'woopcd-partialcod-pro' );
            $in_list[ 'status' ] = esc_html__( 'Order Status', 'woopcd-partialcod-pro' );
                        
            $in_list[ 'quantity' ] = esc_html__( 'Order Total Quantity', 'woopcd-partialcod-pro' );

            $weight_text = str_replace( '[0]', get_option( 'woocommerce_weight_unit' ), esc_html__( 'Order Total Weight ([0])', 'woopcd-partialcod-pro' ) );
            $in_list[ 'weight' ] = $weight_text;

            $in_list[ 'line_count' ] = esc_html__( 'Number Of Order Items', 'woopcd-partialcod-pro' );

            $in_list[ 'coupons' ] = esc_html__( 'Applied Coupons', 'woopcd-partialcod-pro' );

            if ( WOOPCD_PartialCOD_Main::is_risky_method( $args[ 'method_id' ] ) || defined( 'DOING_AJAX' ) ) {
                $in_list[ 'advance_pay_methods' ] = esc_html__( 'Partial Payment Methods', 'woopcd-partialcod-pro' );
            }

            $in_list[ 'needs_payment' ] = esc_html__( 'Needs Payment', 'woopcd-partialcod-pro' );
            $in_list[ 'needs_processing' ] = esc_html__( 'Needs Processing', 'woopcd-partialcod-pro' );
            $in_list[ 'is_paid' ] = esc_html__( 'Is Paid', 'woopcd-partialcod-pro' );

            return $in_list;
        }

        
        public static function get_currency_fields( $in_fields ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'woopcd-partialcod-pro' ),                    
                    'none' => esc_html__( 'None in the list', 'woopcd-partialcod-pro' ),
                ),
                'width' => '98%',
                'box_width' => '25%',
            );

            $in_fields[] = array(
                'id' => 'currencies',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 1,
                'placeholder' => esc_html__( 'Search currencies...', 'woopcd-partialcod-pro' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'partialcod:currencies',
                    'ajax' => false,
                ),
                'width' => '100%',
                'box_width' => '75%',
            );



            return $in_fields;
        }
        
        
        public static function get_status_fields( $in_fields ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'woopcd-partialcod-pro' ),                    
                    'none' => esc_html__( 'None in the list', 'woopcd-partialcod-pro' ),
                ),
                'width' => '98%',
                'box_width' => '25%',
            );

            $in_fields[] = array(
                'id' => 'statuses',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 1,
                'placeholder' => esc_html__( 'Search order statuses...', 'woopcd-partialcod-pro' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'partialcod:order_statuses',
                    'ajax' => true,
                ),
                'width' => '100%',
                'box_width' => '75%',
            );



            return $in_fields;
        }
        
        
        public static function get_quantity_fields( $in_fields ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'woopcd-partialcod-pro' ),
                    '>' => esc_html__( 'More than', 'woopcd-partialcod-pro' ),
                    '<=' => esc_html__( 'Less than or equal to', 'woopcd-partialcod-pro' ),
                    '<' => esc_html__( 'Less than', 'woopcd-partialcod-pro' ),
                    '==' => esc_html__( 'Equal to', 'woopcd-partialcod-pro' ),
                    '!=' => esc_html__( 'Not equal to', 'woopcd-partialcod-pro' ),
                ),
                'width' => '99%',
                'box_width' => '45%',
            );
            $in_fields[] = array(
                'id' => 'total_quantity',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'woopcd-partialcod-pro' ),
                'width' => '100%',
                'box_width' => '55%',
                'attributes' => array(
                    'min' => '1',
                    'step' => '1',
                ),
            );

            return $in_fields;
        }

        public static function get_weight_fields( $in_fields ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'woopcd-partialcod-pro' ),
                    '>' => esc_html__( 'More than', 'woopcd-partialcod-pro' ),
                    '<=' => esc_html__( 'Less than or equal to', 'woopcd-partialcod-pro' ),
                    '<' => esc_html__( 'Less than', 'woopcd-partialcod-pro' ),
                    '==' => esc_html__( 'Equal to', 'woopcd-partialcod-pro' ),
                    '!=' => esc_html__( 'Not equal to', 'woopcd-partialcod-pro' ),
                ),
                'width' => '99%',
                'box_width' => '45%',
            );
            $in_fields[] = array(
                'id' => 'total_weight',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '0.0',
                'placeholder' => esc_html__( '0.0', 'woopcd-partialcod-pro' ),
                'width' => '100%',
                'box_width' => '55%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '0.01',
                ),
            );




            return $in_fields;
        }

        public static function get_line_count_fields( $in_fields ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'woopcd-partialcod-pro' ),
                    '>' => esc_html__( 'More than', 'woopcd-partialcod-pro' ),
                    '<=' => esc_html__( 'Less than or equal to', 'woopcd-partialcod-pro' ),
                    '<' => esc_html__( 'Less than', 'woopcd-partialcod-pro' ),
                    '==' => esc_html__( 'Equal to', 'woopcd-partialcod-pro' ),
                    '!=' => esc_html__( 'Not equal to', 'woopcd-partialcod-pro' ),
                ),
                'width' => '99%',
                'box_width' => '45%',
            );
            $in_fields[] = array(
                'id' => 'line_count',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '0',
                'placeholder' => esc_html__( '0', 'woopcd-partialcod-pro' ),
                'width' => '100%',
                'box_width' => '55%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '1',
                ),
            );

            return $in_fields;
        }

        public static function get_applied_coupons_fields( $in_fields ) {
            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'any' => esc_html__( 'Any list?', 'woopcd-partialcod-pro' ),
                    'in_list' => esc_html__( 'Any in the list', 'woopcd-partialcod-pro' ),
                    'in_all_list' => esc_html__( 'All in the list', 'woopcd-partialcod-pro' ),
                    'in_list_only' => esc_html__( 'Only in the list', 'woopcd-partialcod-pro' ),
                    'in_all_list_only' => esc_html__( 'Only all in the list', 'woopcd-partialcod-pro' ),
                    'none' => esc_html__( 'None in the list', 'woopcd-partialcod-pro' ),
                ),
                'fold_id' => 'coupons_compare',
                'width' => '99%',
                'box_width' => '34%',
            );

            $in_fields[] = array(
                'id' => 'is_any',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'no' => esc_html__( 'No', 'woopcd-partialcod-pro' ),
                    'yes' => esc_html__( 'Yes', 'woopcd-partialcod-pro' ),
                ),
                'fold' => array(
                    'target' => 'coupons_compare',
                    'attribute' => 'value',
                    'value' => 'any',
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '100%',
                'box_width' => '66%',
            );

            $in_fields[] = array(
                'id' => 'coupons',
                'type' => 'select2',
                'multiple' => true,
                'placeholder' => 'Coupons...',
                'data' => 'posts:shop_coupon',
                'fold' => array(
                    'target' => 'coupons_compare',
                    'attribute' => 'value',
                    'value' => 'any',
                    'oparator' => 'neq',
                    'clear' => false,
                ),
                'width' => '100%',
                'box_width' => '66%',
            );

            return $in_fields;
        }

        public static function get_advance_pay_methods_fields( $in_fields ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'woopcd-partialcod-pro' ),
                    'none' => esc_html__( 'None in the list', 'woopcd-partialcod-pro' ),
                ),
                'width' => '99%',
                'box_width' => '27%',
            );

            $in_fields[] = array(
                'id' => 'method_ids',
                'type' => 'select2',
                'multiple' => true,
                'placeholder' => 'Select payment methods...',
                'options' => self::get_other_methods(),
                'width' => '100%',
                'box_width' => '73%',
            );

            return $in_fields;
        }

        public static function get_is_needed_fields( $in_fields ) {

            $in_fields[] = array(
                'id' => 'is_needed',
                'type' => 'select2',
                'default' => 'yes',
                'options' => array(
                    'yes' => esc_html__( 'Yes', 'woopcd-partialcod-pro' ),
                    'no' => esc_html__( 'No', 'woopcd-partialcod-pro' ),
                ),
                'width' => '100%',
                'box_width' => '100%',
            );



            return $in_fields;
        }

        private static function get_other_methods() {
            $methods = array();
            foreach ( WOOPCD_PartialCOD_Admin_Page::get_all_payment_methods() as $key => $method ) {
                if ( !WOOPCD_PartialCOD_Main::is_risky_method( $key ) ) {
                    $methods[ $key ] = $method[ 'method_title' ];
                }
            }
            return $methods;
        }

    }

    WOOPCD_PartialCOD_Admin__Order_Conditions_Orders::init();
}

