<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WOOPCD_PartialCOD_Admin_Product_Filter_Type_Products' ) ) {

    class WOOPCD_PartialCOD_Admin_Product_Filter_Type_Products {

        public static function init() {

            add_filter( 'woopcd_partialcod-admin/get-product-filter-groups', array( new self(), 'get_groups' ), 10, 2 );
            add_filter( 'woopcd_partialcod-admin/get-products-group-product-filters', array( new self(), 'get_filters' ), 10, 2 );

            add_filter( 'woopcd_partialcod-admin/get-spec_products-product-filter-fields', array( new self(), 'get_specific_products_fields' ), 10, 2 );
            add_filter( 'woopcd_partialcod-admin/get-product_var-product-filter-fields', array( new self(), 'get_product_variations_fields' ), 10, 2 );
            add_filter( 'woopcd_partialcod-admin/get-product_cats-product-filter-fields', array( new self(), 'get_product_categories_fields' ), 10, 2 );
            add_filter( 'woopcd_partialcod-admin/get-product_tags-product-filter-fields', array( new self(), 'get_product_tags_fields' ), 10, 2 );
            add_filter( 'woopcd_partialcod-admin/get-product_attrs-product-filter-fields', array( new self(), 'get_product_attributes_fields' ), 10, 2 );
            add_filter( 'woopcd_partialcod-admin/get-product_qty-product-filter-fields', array( new self(), 'get_product_quantity_fields' ), 10, 2 );
        }

        public static function get_groups( $in_groups, $args ) {

            $in_groups[ 'products' ] = esc_html__( 'Products', 'woopcd-partialcod-pro' );

            return $in_groups;
        }

        public static function get_filters( $in_list, $args ) {

            $in_list[ 'spec_products' ] = esc_html__( 'Specific Products', 'woopcd-partialcod-pro' );
            $in_list[ 'product_var' ] = esc_html__( 'Product Variations', 'woopcd-partialcod-pro' );
            $in_list[ 'product_cats' ] = esc_html__( 'Product Categories', 'woopcd-partialcod-pro' );
            $in_list[ 'product_tags' ] = esc_html__( 'Product Tags', 'woopcd-partialcod-pro' );
            $in_list[ 'product_attrs' ] = esc_html__( 'Product Attributes', 'woopcd-partialcod-pro' );
            $in_list[ 'product_qty' ] = esc_html__( 'Product Quantity In Cart', 'woopcd-partialcod-pro' );

            return $in_list;
        }

        public static function get_specific_products_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'woopcd-partialcod-pro' ),
                    'none' => esc_html__( 'None in the list', 'woopcd-partialcod-pro' ),
                ),
                'width' => '98%',
                'box_width' => '25%',
            );

            $in_fields[] = array(
                'id' => 'product_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 2,
                'placeholder' => esc_html__( 'Search products...', 'woopcd-partialcod-pro' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'wc:products',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '100%',
                'box_width' => '56%',
            );

            return $in_fields;
        }

        public static function get_product_variations_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'woopcd-partialcod-pro' ),
                    'none' => esc_html__( 'None in the list', 'woopcd-partialcod-pro' ),
                ),
                'width' => '98%',
                'box_width' => '25%',
            );

            $in_fields[] = array(
                'id' => 'variation_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 2,
                'placeholder' => esc_html__( 'Search variations...', 'woopcd-partialcod-pro' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'wc:product_variations',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '100%',
                'box_width' => '56%',
            );

            return $in_fields;
        }

        public static function get_product_categories_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'woopcd-partialcod-pro' ),
                    'in_all_list' => esc_html__( 'All in the list', 'woopcd-partialcod-pro' ),
                    'in_list_only' => esc_html__( 'Only in the list', 'woopcd-partialcod-pro' ),
                    'in_all_list_only' => esc_html__( 'Only all in the list', 'woopcd-partialcod-pro' ),
                    'none' => esc_html__( 'None in the list', 'woopcd-partialcod-pro' ),
                ),
                'width' => '98%',
                'box_width' => '25%',
            );

            $in_fields[] = array(
                'id' => 'category_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 1,
                'placeholder' => esc_html__( 'Search categories...', 'woopcd-partialcod-pro' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'categories:product_cat',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '100%',
                'box_width' => '56%',
            );

            return $in_fields;
        }

        public static function get_product_tags_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'woopcd-partialcod-pro' ),
                    'in_all_list' => esc_html__( 'All in the list', 'woopcd-partialcod-pro' ),
                    'in_list_only' => esc_html__( 'Only in the list', 'woopcd-partialcod-pro' ),
                    'in_all_list_only' => esc_html__( 'Only all in the list', 'woopcd-partialcod-pro' ),
                    'none' => esc_html__( 'None in the list', 'woopcd-partialcod-pro' ),
                ),
                'width' => '98%',
                'box_width' => '25%',
            );

            $in_fields[] = array(
                'id' => 'tag_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 1,
                'placeholder' => esc_html__( 'Search tags...', 'woopcd-partialcod-pro' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'categories:product_tag',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '100%',
                'box_width' => '56%',
            );

            return $in_fields;
        }

        public static function get_product_attributes_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'woopcd-partialcod-pro' ),
                    'in_all_list' => esc_html__( 'All in the list', 'woopcd-partialcod-pro' ),
                    'in_list_only' => esc_html__( 'Only in the list', 'woopcd-partialcod-pro' ),
                    'in_all_list_only' => esc_html__( 'Only all in the list', 'woopcd-partialcod-pro' ),
                    'none' => esc_html__( 'None in the list', 'woopcd-partialcod-pro' ),
                ),
                'width' => '98%',
                'box_width' => '25%',
            );

            $in_fields[] = array(
                'id' => 'attribute_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 1,
                'placeholder' => esc_html__( 'Search attributes...', 'woopcd-partialcod-pro' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'wc:attributes',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '100%',
                'box_width' => '56%',
            );

            return $in_fields;
        }

        public static function get_product_quantity_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'woopcd-partialcod-pro' ),
                    '>' => esc_html__( 'More than', 'woopcd-partialcod-pro' ),
                    '<=' => esc_html__( 'Less than or equal to', 'woopcd-partialcod-pro' ),
                    '<' => esc_html__( 'Less than', 'woopcd-partialcod-pro' ),
                    '==' => esc_html__( 'Equal to', 'woopcd-partialcod-pro' ),
                    '!=' => esc_html__( 'Not equal to', 'woopcd-partialcod-pro' ),
                ),
                'width' => '98%',
                'box_width' => '35%',
            );

            $in_fields[] = array(
                'id' => 'quantity',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'woopcd-partialcod-pro' ),
                'width' => '100%',
                'box_width' => '55%',
                'attributes' => array(
                    'min' => '1',
                    'step' => '1',
                ),
                'width' => '100%',
                'box_width' => '46%',
            );

            return $in_fields;
        }

        
    }

    WOOPCD_PartialCOD_Admin_Product_Filter_Type_Products::init();
}