<?php

if (!class_exists('Reon')) {
    return;
}

if (!class_exists('WOOPCD_PartialCOD_Premium_Admin_Fee_Rules_Page')) {
    WOOPCD_PartialCOD_Main::required_paths(dirname(__FILE__), array('cart-fees-section.php'));

    class WOOPCD_PartialCOD_Premium_Admin_Fee_Rules_Page {

        public static function init() {
            $option_name = WOOPCD_PartialCOD_Admin_Page::get_option_name();
            foreach (WOOPCD_PartialCOD_Admin_Page::get_all_payment_method_ids() as $method_ids) {
                add_filter('get-option-page-' . $option_name . 'section-' . $method_ids . '-fee-rules-fields', array(new self(), 'get_method_fee_rules_page_fields'), 20, 2);
            }
            add_filter('woopcd_partialcod-admin/cart-fees/get-rules-modes', array(new self(), 'get_rule_modes'), 10);
        }

        public static function get_method_fee_rules_page_fields($in_fields, $section_id) {

            $method_id = WOOPCD_PartialCOD_Admin_Page::get_payment_method_id_by_section_id($section_id, '', '-fee-rules');


            $in_fields[] = array(
                'id' => $method_id . '_fee_rules_settings',
                'type' => 'panel',
                'last' => true,
                'white_panel' => false,
                'panel_size' => 'smaller',
                'width' => '100%',
                'field_css_class' => array('partialcod_rules_apply_mode'),
                'fields' => array(
                    array(
                        'id' => $method_id . 'any_id_fee',
                        'type' => 'columns-field',
                        'columns' => 8,
                        'merge_fields' => false,
                        'fields' => array(
                            array(
                                'id' => 'max_fee_type',
                                'type' => 'select2',
                                'column_size' => 2,
                                'column_title' => esc_html__('Gateway Fees Limit', 'woopcd-partialcod-pro'),
                                'tooltip' => esc_html__('Controls gateway fees limit', 'woopcd-partialcod-pro'),
                                'default' => 'no',
                                'options' => array(
                                    'no' => esc_html__('No limit', 'woopcd-partialcod-pro'),
                                    'fixed_amount' => esc_html__('Fixed amount', 'woopcd-partialcod-pro'),
                                    'per_amount' => esc_html__('Percentage amount', 'woopcd-partialcod-pro'),
                                ),
                                'width' => '100%',
                                'fold_id' => 'max_fee_type',
                            ),
                            array(
                                'id' => 'max_fee_amount',
                                'type' => 'textbox',
                                'input_type' => 'number',
                                'column_size' => 1,
                                'column_title' => esc_html__('Limit', 'woopcd-partialcod-pro'),
                                'tooltip' => esc_html__('Controls gateway fees amount limit', 'woopcd-partialcod-pro'),
                                'default' => '',
                                'placeholder' => esc_html__('0.00', 'woopcd-partialcod-pro'),
                                'width' => '100%',
                                'attributes' => array(
                                    'min' => '0',
                                    'step' => '0.01',
                                ),
                                'fold' => array(
                                    'target' => 'max_fee_type',
                                    'attribute' => 'value',
                                    'value' => 'no',
                                    'oparator' => 'neq',
                                    'clear' => true,
                                ),
                            ),
                            array(
                                'id' => 'base_on',
                                'type' => 'select2',
                                'column_size' => 2,
                                'column_title' => esc_html__('Limit Based On', 'woopcd-partialcod-pro'),
                                'tooltip' => esc_html__('Controls cart percentage fee limit bases on cart subtotals', 'woopcd-partialcod-pro'),
                                'default' => '2234343',
                                'data' => 'partialcod:cartfees_carttotals',
                                'width' => '100%',
                                'fold' => array(
                                    'target' => 'max_fee_type',
                                    'attribute' => 'value',
                                    'value' => 'per_amount',
                                    'oparator' => 'eq',
                                    'clear' => true,
                                    'empty' => '2234343',
                                ),
                            ),
                            array(
                                'id' => 'mode',
                                'type' => 'select2',
                                'column_size' => 3,
                                'column_title' => esc_html__('Apply Mode', 'woopcd-partialcod-pro'),
                                'tooltip' => esc_html__('Controls fees apply mode', 'woopcd-partialcod-pro'),
                                'default' => 'all',
                                'options' => self::get_rules_apply_methods(),
                                'width' => '100%',
                            ),
                        ),
                    ),
                ),
            );

            return $in_fields;
        }

        public static function get_rule_modes($in_rule_modes) {

            $in_rule_modes['only_this'] = esc_html__('Apply only this fee', 'woopcd-partialcod-pro');
            $in_rule_modes['if_others'] = esc_html__('Apply if other fees are valid', 'woopcd-partialcod-pro');
            $in_rule_modes['if_no_others'] = esc_html__('Apply if no other valid fees', 'woopcd-partialcod-pro');

            return $in_rule_modes;
        }

        public static function get_rules_apply_methods() {

            $rules_apply_methods = apply_filters('woopcd_partialcod-admin/cart-fees/get-rules-apply-methods', array(
                'all' => esc_html__('Apply all valid fees', 'woopcd-partialcod-pro'),
                'first' => esc_html__('Apply first valid fee', 'woopcd-partialcod-pro'),
                'last' => esc_html__('Apply last valid fee', 'woopcd-partialcod-pro'),
                'higher' => esc_html__('Apply the highest valid fee', 'woopcd-partialcod-pro'),
                'lower' => esc_html__('Apply the lowest valid fee', 'woopcd-partialcod-pro'),
            ));

            $rules_apply_methods['no'] = esc_html__('Do not apply any fee', 'woopcd-partialcod-pro');

            return $rules_apply_methods;
        }

    }

}