<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WOOPCD_PartialCOD_Premium_Admin_Order_Activity_Rules_Page' ) ) {
    WOOPCD_PartialCOD_Main::required_paths( dirname( __FILE__ ), array( 'order-activities-section.php' ) );

    class WOOPCD_PartialCOD_Premium_Admin_Order_Activity_Rules_Page {

        public static function init() {

            $option_name = WOOPCD_PartialCOD_Admin_Page::get_option_name();
            foreach ( WOOPCD_PartialCOD_Admin_Page::get_all_payment_method_ids() as $method_ids ) {
                add_filter( 'get-option-page-' . $option_name . 'section-' . $method_ids . '-activitys-fields', array( new self(), 'get_order_activity_rules_page_fields' ), 10, 2 );
            }
            add_filter( 'reon/get-repeater-field-order_activity_rules-templates', array( new self(), 'get_order_activity_rules_template' ), 10, 2 );
            add_filter( 'roen/get-repeater-template-order_activity_rules-order_activity_rule-fields', array( new self(), 'get_order_activity_rule_fields' ), 10, 2 );
            add_filter( 'roen/get-repeater-template-order_activity_rules-order_activity_rule-head-fields', array( new self(), 'get_order_activity_rule_head_fields' ), 10, 2 );

            add_filter( 'reon/process-save-options-' . $option_name, array( new self(), 'process_options' ), 10 );
        }

        public static function get_order_activity_rules_page_fields( $in_fields, $section_id ) {

            $method_id = WOOPCD_PartialCOD_Admin_Page::get_payment_method_id_by_section_id( $section_id, '', '-activitys' );

            $in_fields[] = array(
                'id' => $method_id . '_order_activity_rules_settings',
                'type' => 'panel',
                'last' => true,
                'white_panel' => false,
                'panel_size' => 'smaller',
                'width' => '100%',
                'field_css_class' => array( 'partialcod_rules_apply_mode' ),
                'fields' => array(
                    array(
                        'id' => $method_id . 'any_id_activity',
                        'type' => 'columns-field',
                        'columns' => 2,
                        'merge_fields' => false,
                        'fields' => array(
                            array(
                                'id' => 'mode',
                                'type' => 'select2',
                                'column_size' => 1,
                                'column_title' => esc_html__( 'Apply Mode', 'woopcd-partialcod-pro' ),
                                'tooltip' => esc_html__( 'Controls order autopilots apply mode', 'woopcd-partialcod-pro' ),
                                'default' => 'all',
                                'options' => self::get_rules_apply_methods(),
                                'width' => '100%',
                            ),
                        ),
                    ),
                ),
            );


            $in_fields[] = array(
                'id' => $method_id . '_order_activity_rules',
                'filter_id' => 'order_activity_rules',
                'field_args' => $method_id,
                'type' => 'repeater',
                'white_repeater' => false,
                'repeater_size' => 'small',
                'accordions' => true,
                'buttons_sep' => false,
                'delete_button' => true,
                'clone_button' => true,
                'width' => '100%',
                'field_css_class' => array( 'partialcod_rules' ),
                'css_class' => 'partialcod_gateway_rules',
                'auto_expand' => array(
                    'new_section' => true,
                    'cloned_section' => true,
                ),
                'sortable' => array(
                    'enabled' => true,
                ),
                'template_adder' => array(
                    'position' => 'right',
                    'show_list' => false,
                    'button_text' => esc_html__( 'New Autopilots', 'woopcd-partialcod-pro' ),
                ),
            );

            return $in_fields;
        }

        public static function get_order_activity_rules_template( $in_templates, $repeater_args ) {
            if ( $repeater_args[ 'screen' ] == 'option-page' && $repeater_args[ 'option_name' ] == WOOPCD_PartialCOD_Admin_Page::get_option_name() ) {

                $in_templates[] = array(
                    'id' => 'order_activity_rule',
                    'head' => array(
                        'title' => '',
                        'defaut_title' => 'Autopilots Trigger',
                        'title_field' => 'activities_trigger',
                        'subtitle_field' => 'admin_note',
                    )
                );
            }

            return $in_templates;
        }

        public static function get_order_activity_rule_fields( $in_fields, $repeater_args ) {

            $method_id = $repeater_args[ 'field_args' ];

            return apply_filters( 'woopcd_partialcod-admin/order-activities/get-' . $method_id . '-rule-panels', apply_filters( 'woopcd_partialcod-admin/order-activities/get-rule-panels', array(), $method_id ), $method_id );
        }

        public static function get_order_activity_rule_head_fields( $in_fields, $repeater_args ) {

            $method_id = $repeater_args[ 'field_args' ];

            $in_fields[] = array(
                'id' => $method_id . 'any_id_activity',
                'type' => 'group-field',
                'position' => 'right',
                'width' => '100%',
                'merge_fields' => false,
                'fields' => array(
                    array(
                        'id' => 'apply_mode',
                        'type' => 'select2',
                        'default' => 'with_others',
                        'options' => self::get_rules_modes(),
                        'width' => '265px',
                    ),
                    array(
                        'id' => 'enable',
                        'type' => 'select2',
                        'default' => 'yes',
                        'options' => array(
                            'yes' => esc_html__( 'Enable', 'woopcd-partialcod-pro' ),
                            'no' => esc_html__( 'Disable', 'woopcd-partialcod-pro' ),
                        ),
                        'width' => '95px',
                    ),
                ),
            );



            return $in_fields;
        }

        public static function process_options( $options ) {

            delete_transient( 'woopcd_partialcod_active_trigger_types' );

            return $options;
        }

        private static function get_rules_modes() {
            $rules_modes = array(
                'with_others' => esc_html__( 'Apply this and other similar triggers', 'woopcd-partialcod-pro' ),
                'only_this' => esc_html__( 'Apply only this settings', 'woopcd-partialcod-pro' ),
                'if_others' => esc_html__( 'Apply if other similar triggers are valid', 'woopcd-partialcod-pro' ),
                'if_no_others' => esc_html__( 'Apply if no other similar & valid triggers', 'woopcd-partialcod-pro' ),
            );


            return apply_filters( 'woopcd_partialcod-admin/order-activities/get-rules-modes', $rules_modes );
        }

        private static function get_rules_apply_methods() {
            $rules_apply_methods = apply_filters( 'woopcd_partialcod-admin/order-activities/get-rules-apply-methods', array(
                'all' => esc_html__( 'Apply all valid settings', 'woopcd-partialcod-pro' ),
                'first' => esc_html__( 'Apply first valid settings', 'woopcd-partialcod-pro' ),
                'last' => esc_html__( 'Apply last valid settings', 'woopcd-partialcod-pro' ),
                    ) );

            $rules_apply_methods[ 'no' ] = esc_html__( 'Do not apply any settings', 'woopcd-partialcod-pro' );

            return $rules_apply_methods;
        }

    }

}
