<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WOOPCD_PartialCOD_Admin_Risk_Free_Order_Screen' ) ) {

    class WOOPCD_PartialCOD_Admin_Risk_Free_Order_Screen {

        private static $order_data_list = array();

        public static function init() {
            add_filter( 'manage_edit-shop_order_columns', array( new self(), 'shop_order_columns' ), 999, 1 );
            add_action( 'manage_shop_order_posts_custom_column', array( new self(), 'shop_order_custom_column' ), 10, 2 );
            add_action( 'woocommerce_admin_order_totals_after_total', array( new self(), 'shop_order_totals_after_total' ), 10, 1 );

            //HPOS Screen
            add_filter( 'woocommerce_shop_order_list_table_columns', array( new self(), 'get_columns' ), 999, 1 );
            add_action( 'woocommerce_shop_order_list_table_custom_column', array( new self(), 'render_column' ), 10, 2 );
        }

        public static function get_columns( $columns ) {

            return self::shop_order_columns( $columns );
        }

        public static function render_column( $column, $order ) {

            $order_id = $order->get_id();

            self::shop_order_custom_column( $column, $order_id );
        }

        public static function shop_order_columns( $columns ) {

            $clonms = array();
           
            foreach ( $columns as $key => $column ) {
            
                if ( 'order_total' == $key ) {
                
                    $clonms[ 'woopcd_partialcod_risk_free' ] = '<strong>' . esc_html__( 'Partial Payment', 'woopcd-partialcod-pro' ) . '</strong>';
                }
                
                $clonms[ $key ] = $column;
            }

            return $clonms;
        }

        public static function shop_order_custom_column( $column, $order_id = 0 ) {

            if ( 'woopcd_partialcod_risk_free' == $column ) {

                $order_data = self::get_order_data( $order_id );

                if ( count( $order_data ) ) {

                    $allowed_html = WOOPCD_PartialCOD_Main::get_allow_html();

                    $rf_text = wp_kses( __( 'Paid <strong>{{pd}}</strong>, remaining <strong>{{rm}}</strong>', 'woopcd-partialcod-pro' ), $allowed_html );
                    $rf_text = preg_replace( '/{{pd}}/', wc_price( $order_data[ 'advance_pay' ], array( 'currency' => $order_data[ 'currency' ] ) ), $rf_text );
                    $rf_text = preg_replace( '/{{rm}}/', wc_price( $order_data[ 'delivery_pay' ], array( 'currency' => $order_data[ 'currency' ] ) ), $rf_text );

                    echo wp_kses( $rf_text, $allowed_html );
                }
            }
        }

        public static function shop_order_totals_after_total( $order_id = 0 ) {

            $order_data = self::get_order_data( $order_id );

            if ( count( $order_data ) ) {
                include 'risk-free-order-screen-html.php';
            }
        }

        private static function get_order_data( $order_id ) {

            if ( 0 >= $order_id ) {
                return array();
            }

            // get order data from memory
            if ( isset( self::$order_data_list[ $order_id ] ) ) {

                return self::$order_data_list[ $order_id ];
            }


            // Get order partial payment data from database and store it in memory

            $order = WOOPCD_PartialCOD_Order::get_order( $order_id, false );

            if ( !$order ) {

                self::$order_data_list[ $order_id ] = array();

                return array();
            }

            $order_data = $order->get_meta( 'woopcd_partialcod_riskfree', true );

            if ( $order_data ) {

                $order_data[ 'order_total' ] = $order->get_total();
                $order_data[ 'currency' ] = $order->get_currency();
                $order_data[ 'delivery_pay' ] = $order_data[ 'order_total' ] - $order_data[ 'advance_pay' ];

                self::$order_data_list[ $order_id ] = $order_data;
            } else {

                self::$order_data_list[ $order_id ] = array();
            }

            return self::$order_data_list[ $order_id ];
        }

    }

    WOOPCD_PartialCOD_Admin_Risk_Free_Order_Screen::init();
}