<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WOOPCD_PartialCOD_Premium_Admin_Risk_Free_Rules_Page' ) ) {
    WOOPCD_PartialCOD_Main::required_paths( dirname( __FILE__ ), array( 'risk-free-section.php', 'risk-free-order-screen-html.php' ) );

    class WOOPCD_PartialCOD_Premium_Admin_Risk_Free_Rules_Page {

        public static function init() {

            $option_name = WOOPCD_PartialCOD_Admin_Page::get_option_name();
            foreach ( WOOPCD_PartialCOD_Admin_Page::get_all_payment_method_ids() as $method_ids ) {
                add_filter( 'get-option-page-' . $option_name . 'section-' . $method_ids . '-riskfree-rules-fields', array( new self(), 'get_method_riskyfree_rules_page_fields' ), 10, 2 );
            }

            add_filter( 'reon/get-repeater-field-riskfree_rules-templates', array( new self(), 'get_method_riskyfree_template' ), 10, 2 );

            add_filter( 'roen/get-repeater-template-riskfree_rules-riskfree_rule-fields', array( new self(), 'get_method_riskyfree_rule_fields' ), 10, 2 );
            add_filter( 'roen/get-repeater-template-riskfree_rules-riskfree_rule-head-fields', array( new self(), 'get_method_riskyfree_rule_head_fields' ), 10, 2 );

            add_filter( 'reon/process-save-options-' . $option_name, array( new self(), 'process_options' ), 10 );
        }

        public static function get_method_riskyfree_rules_page_fields( $in_fields, $section_id ) {

            $method_id = WOOPCD_PartialCOD_Admin_Page::get_payment_method_id_by_section_id( $section_id, '', '-riskfree-rules' );

            $in_fields[] = array(
                'id' => $method_id . '_riskfree_rules_settings',
                'type' => 'panel',
                'last' => true,
                'white_panel' => false,
                'panel_size' => 'smaller',
                'width' => '100%',
                'field_css_class' => array( 'partialcod_rules_apply_mode' ),
                'fields' => array(
                    array(
                        'id' => $method_id . 'any_id_riskfree',
                        'type' => 'columns-field',
                        'columns' => 8,
                        'merge_fields' => false,
                        'fields' => array(
                            array(
                                'id' => 'max_amount_type',
                                'type' => 'select2',
                                'column_size' => 2,
                                'column_title' => esc_html__( 'Partial Amount Limit', 'woopcd-partialcod-pro' ),
                                'tooltip' => esc_html__( 'Controls partial payment amount limit', 'woopcd-partialcod-pro' ),
                                'default' => 'no',
                                'options' => array(
                                    'no' => esc_html__( 'No limit', 'woopcd-partialcod-pro' ),
                                    'fixed_amount' => esc_html__( 'Fixed amount', 'woopcd-partialcod-pro' ),
                                    'per_amount' => esc_html__( 'Percentage amount', 'woopcd-partialcod-pro' ),
                                ),
                                'width' => '100%',
                                'fold_id' => 'max_amount_type',
                            ),
                            array(
                                'id' => 'max_amount',
                                'type' => 'textbox',
                                'input_type' => 'number',
                                'column_size' => 1,
                                'column_title' => esc_html__( 'Limit', 'woopcd-partialcod-pro' ),
                                'tooltip' => esc_html__( 'Controls partial payment amount limit', 'woopcd-partialcod-pro' ),
                                'default' => '',
                                'placeholder' => esc_html__( '0.00', 'woopcd-partialcod-pro' ),
                                'width' => '100%',
                                'attributes' => array(
                                    'min' => '0',
                                    'step' => '0.01',
                                ),
                                'fold' => array(
                                    'target' => 'max_amount_type',
                                    'attribute' => 'value',
                                    'value' => 'no',
                                    'oparator' => 'neq',
                                    'clear' => true,
                                ),
                            ),
                            array(
                                'id' => 'base_on',
                                'type' => 'select2',
                                'column_size' => 2,
                                'column_title' => esc_html__( 'Limit Based On', 'woopcd-partialcod-pro' ),
                                'tooltip' => esc_html__( 'Controls partial payment amount limit bases on cart totals', 'woopcd-partialcod-pro' ),
                                'default' => '2234343',
                                'data' => 'partialcod:riskfree_carttotals',
                                'width' => '100%',
                                'fold' => array(
                                    'target' => 'max_amount_type',
                                    'attribute' => 'value',
                                    'value' => 'per_amount',
                                    'oparator' => 'eq',
                                    'clear' => true,
                                    'empty' => '2234343',
                                ),
                            ),
                            array(
                                'id' => 'mode',
                                'type' => 'select2',
                                'column_size' => 3,
                                'column_title' => esc_html__( 'Apply Mode', 'woopcd-partialcod-pro' ),
                                'tooltip' => esc_html__( 'Controls partial payments apply mode', 'woopcd-partialcod-pro' ),
                                'default' => 'last',
                                'options' => array(
                                    'first' => esc_html__( 'Apply first valid partial payments', 'woopcd-partialcod-pro' ),
                                    'last' => esc_html__( 'Apply last valid partial payment', 'woopcd-partialcod-pro' ),
                                    'higher' => esc_html__( 'Apply partial payment with higher amount', 'woopcd-partialcod-pro' ),
                                    'lower' => esc_html__( 'Apply partial payment with lower amount', 'woopcd-partialcod-pro' ),
                                    'no' => esc_html__( 'Do not apply any partial payment', 'woopcd-partialcod-pro' ),
                                ),
                                'width' => '100%',
                            ),
                        ),
                    ),
                ),
            );

            $in_fields[] = array(
                'id' => $method_id . '_riskfree_rules',
                'filter_id' => 'riskfree_rules',
                'field_args' => $method_id,
                'type' => 'repeater',
                'white_repeater' => false,
                'repeater_size' => 'small',
                'accordions' => true,
                'buttons_sep' => false,
                'delete_button' => true,
                'clone_button' => true,
                'width' => '100%',
                'field_css_class' => array( 'partialcod_rules' ),
                'css_class' => 'partialcod_gateway_rules',
                'auto_expand' => array(
                    'new_section' => true,
                    'cloned_section' => true,
                ),
                'sortable' => array(
                    'enabled' => true,
                ),
                'template_adder' => array(
                    'position' => 'right',
                    'show_list' => false,
                    'button_text' => esc_html__( 'New Payment', 'woopcd-partialcod-pro' ),
                ),
            );




            return $in_fields;
        }

        public static function get_method_riskyfree_template( $in_templates, $repeater_args ) {
            if ( $repeater_args[ 'screen' ] == 'option-page' && $repeater_args[ 'option_name' ] == WOOPCD_PartialCOD_Admin_Page::get_option_name() ) {

                $method = WOOPCD_PartialCOD_Admin_Page::get_payment_method( $repeater_args[ 'field_args' ] );

                $method_text = str_replace( '[0]', $method[ 'title' ], esc_html__( 'Partial [0]', 'woopcd-partialcod-pro' ) );

                $in_templates[] = array(
                    'id' => 'riskfree_rule',
                    'head' => array(
                        'title' => '',
                        'defaut_title' => $method_text,
                        'title_field' => 'admin_note',
                    )
                );
            }

            return $in_templates;
        }

        public static function get_method_riskyfree_rule_fields( $in_fields, $repeater_args ) {

            $method_id = $repeater_args[ 'field_args' ];

            return apply_filters( 'woopcd_partialcod-admin/partial-payment/get-' . $method_id . '-rule-panels', apply_filters( 'woopcd_partialcod-admin/partial-payment/get-rule-panels', array(), $method_id ), $method_id );
        }

        public static function get_method_riskyfree_rule_head_fields( $in_fields, $repeater_args ) {

            $method_id = $repeater_args[ 'field_args' ];

            $in_fields[] = array(
                'id' => $method_id . 'any_id_riskfree',
                'type' => 'group-field',
                'position' => 'right',
                'width' => '100%',
                'merge_fields' => false,
                'fields' => array(
                    array(
                        'id' => 'enable',
                        'type' => 'select2',
                        'default' => 'yes',
                        'options' => array(
                            'yes' => esc_html__( 'Enable', 'woopcd-partialcod-pro' ),
                            'no' => esc_html__( 'Disable', 'woopcd-partialcod-pro' ),
                        ),
                        'width' => '95px',
                    ),
                ),
            );



            return $in_fields;
        }

        public static function process_options( $options ) {

            foreach ( WOOPCD_PartialCOD_Admin_Page::get_all_payment_method_ids() as $method_id ) {
                if ( isset( $options[ $method_id . '_riskfree_rules' ] ) ) {
                    $options[ $method_id . '_riskfree_rules' ] = self::process_rules( $options[ $method_id . '_riskfree_rules' ], $method_id );
                }
            }

            return $options;
        }

        private static function process_rules( $rules, $method_id ) {

            foreach ( $rules as $key => $rule ) {
                $rules[ $key ] = self::process_rule( $rule, $method_id );
            }
            return $rules;
        }

        private static function process_rule( $rule, $method_id ) {
            $args = array(
                'method_id' => $method_id,
                'module' => 'partial-payment',
            );

            if ( isset( $rule[ 'payment_amounts' ] ) ) {
                foreach ( $rule[ 'payment_amounts' ] as $key => $raw_amount ) {
                    $amount = array();
                    $amount[ 'amount_type' ] = $raw_amount[ 'amount_type' ];
                    $amount = apply_filters( 'woopcd_partialcod-admin/process-payment-amount-options', apply_filters( 'woopcd_partialcod-admin/process-payment-amount-type-' . $raw_amount[ 'amount_type' ] . '-options', $amount, $raw_amount, $args ), $raw_amount, $args );

                    $rule[ 'payment_amounts' ][ $key ] = $amount;
                }
            }

            return apply_filters( 'woopcd_partialcod-admin/partial-payment/save-rule', $rule );
        }

    }

}
     