"use strict";
jQuery(document).ready(function($) {
    
    init_data();
    init_riskfree();

    $(document.body).on("updated_checkout", function(e, data) {

        setTimeout(function() {
            init_data(data);
            init_riskfree();
        }, 50);

    });

    function init_data(data) {

        if (data && data.fragments['#riskfree_data']) {
            var data_div = $(data.fragments['#riskfree_data']);
            process_data_div(data_div);
        } else {
            var data_div = $('#riskfree_data');
            process_data_div(data_div);
        }

        $('#riskfree_data').remove();
    }

    function init_riskfree() {

        if (woopcd_partialcod['rf_methods']) {

            var custom_rf_box = false;

            if (woopcd_partialcod['custom_rf_box']) {
                custom_rf_box = woopcd_partialcod['custom_rf_box'];
            }



            for (var i = 0; i < woopcd_partialcod['rf_methods'].length; i++) {

                init_method(woopcd_partialcod['rf_methods'][i].id, custom_rf_box);
                select_applied_method();

            }

            $('.partialcod_input_rf').each(function() {
                var rf_mthd = $(this);

                var mthd_id = rf_mthd.val();

                if (rf_mthd.attr('initialized') != 'yes') {

                    rf_mthd.on('change', function() {

                        var is_checked = rf_mthd.is(':checked');

                        var send_id = '';

                        if (true === is_checked) {
                            send_id = mthd_id;
                        }

                        send_rf(send_id, function(response) {
                            $(document.body).trigger('update_checkout');
                        });


                        return false;

                    });
                }

                rf_mthd.attr('initialized', 'yes');

            });
        }
    }

    function init_method(method_id, use_custom_box) {

        var rf_id = 'payment_method_' + method_id;
        var rf_mthd = $('form.checkout').find('#' + rf_id);

        if (rf_mthd.length > 0) {

            rf_mthd.prop('id', rf_id + '_partialcod_rf');
            rf_mthd.prop('name', rf_id + '_partialcod_rf');
            rf_mthd.prop('type', 'checkbox');
            rf_mthd.addClass('partialcod_input_rf');

            var rf_mthd_label = rf_mthd.parent().find('label[for^="' + rf_id + '"]')

            rf_mthd_label.prop('for', rf_id + '_partialcod_rf');


            if (use_custom_box == true) {
                rf_mthd.parent().addClass('rf_custom_box');
                if (rf_mthd_label.find('.rf_span').length == 0) {
                    rf_mthd_label.prepend('<span class="rf_span"></span>');
                }
            }

        }
    }

    function select_applied_method() {

        for (var i = 0; i < woopcd_partialcod['rf_methods'].length; i++) {
            if (woopcd_partialcod['rf_methods'][i].selected == true) {

                $('.partialcod_input_rf').each(function() {

                    var inp = $(this);

                    if (inp.val() == woopcd_partialcod['rf_methods'][i].id) {

                        inp.prop('checked', true);
                        var desc = $('.payment_method_' + woopcd_partialcod['rf_methods'][i].id);
                        desc.show();

                        var rf_desc = desc.find('.rf_desc');

                        if (rf_desc.length == 0) {

                            rf_desc = $('<p class="rf_desc"></p>');
                            desc.append(rf_desc);

                        }

                        rf_desc.html(woopcd_partialcod['rf_methods'][i].desc);
                        $('li > .rf_desc').remove();

                    } else {

                        var desc = $('.payment_method_' + woopcd_partialcod['rf_methods'][i].id);
                        desc.hide();

                    }
                });

            }
        }
    }

    function process_data_div(data_div) {
        var rf_data = [];
        data_div.children('div').each(function() {
            var rf_div = $(this);

            var rf_id = rf_div.attr('data-prf-id');
            var rf_selected = (rf_div.attr('data-prf-selected') == 'true');
            var rf_desc = rf_div.html();

            var rf_obj = {
                'id': rf_id,
                'selected': rf_selected,
                'desc': rf_desc
            };

            rf_data.push(rf_obj);
        });
        woopcd_partialcod['rf_methods'] = rf_data;
    }

    function send_rf(method_id, onsuccess, onerror) {

        var data = {
            'action': 'partialcod_rfp',
            'method_id': method_id,
        };

        show_overlay(true);

        jQuery.post(woopcd_partialcod.ajaxurl, data, function(response, status, xhr) {

            show_overlay(false);
            onsuccess(response, status, xhr);

        }).fail(function() {

            show_overlay(false);

            if (onerror) {
                onerror();
            }
        });
    }

    function show_overlay(visible) {

        if (true == visible) {
            $('.woocommerce-checkout-payment').block({
                message: null,
                overlayCSS: {
                    background: '#fff',
                    opacity: 0.6
                }
            });

        } else {
            $('.woocommerce-checkout-payment').unblock();
        }
    }
});