<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WOOPCD_PartialCOD_Polylang' ) && class_exists( 'Polylang' ) ) {

    require_once 'polylang-options/polylang-options.php';
    require_once 'polylang-partial-cod.php';
    require_once 'polylang-cart-fees.php';
    require_once 'polylang-cart-discounts.php';
    require_once 'polylang-settings.php';

    class WOOPCD_PartialCOD_Polylang {

        private $method_options;
        private $partial_cod;
        private $cart_fees;
        private $cart_discounts;
        private $settings;

        public function __construct() {

            $option_name = WOOPCD_PARTIALCOD_OPTION_NAME;

            $this->method_options = new WOOPCD_PartialCOD_Polylang_Method_Options();
            $this->partial_cod = new WOOPCD_PartialCOD_Polylang_Partial_COD();
            $this->cart_fees = new WOOPCD_PartialCOD_Polylang_Cart_Fees();
            $this->cart_discounts = new WOOPCD_PartialCOD_Polylang_Cart_Discounts();
            $this->settings = new WOOPCD_PartialCOD_Polylang_Settings();

            add_filter( 'reon/process-save-options-' . $option_name, array( $this, 'register_translations' ), 10 );
        }

        public function register_translations( $options ) {

            foreach ( WOOPCD_PartialCOD_Admin_Page::get_all_payment_method_ids() as $method_id ) {

                // Register method options strings
                foreach ( $this->method_options->get_strings( $options, $method_id ) as $string_id => $string_data ) {

                    $this->register_string( $string_id, $string_data[ 'value' ], $string_data[ 'is_multiline' ] );
                }

                // Register partial cod strings
                foreach ( $this->partial_cod->get_strings( $options, $method_id ) as $string_id => $string_data ) {

                    $this->register_string( $string_id, $string_data[ 'value' ], $string_data[ 'is_multiline' ] );
                }

                // Register cart fees strings
                foreach ( $this->cart_fees->get_strings( $options, $method_id ) as $string_id => $string_data ) {

                    $this->register_string( $string_id, $string_data[ 'value' ], $string_data[ 'is_multiline' ] );
                }

                // Register cart discounts strings
                foreach ( $this->cart_discounts->get_strings( $options, $method_id ) as $string_id => $string_data ) {

                    $this->register_string( $string_id, $string_data[ 'value' ], $string_data[ 'is_multiline' ] );
                }
            }

            // Register settings strings
            foreach ( $this->settings->get_strings( $options ) as $string_id => $string_data ) {

                $this->register_string( $string_id, $string_data[ 'value' ], $string_data[ 'is_multiline' ] );
            }

            return $options;
        }

        public static function get_translated_string( $string_value, $string_id ) {

            if ( function_exists( 'pll__' ) ) {

                return pll__( $string_value );
            } else if ( function_exists( 'icl_t' ) ) {

                return icl_t( 'woopcd-partialcod-pro', $string_id, $string_value );
            }

            return $string_value;
        }

        private function register_string( $string_id, $string_value, $is_multiline = true ) {

            if ( function_exists( 'icl_register_string' ) ) {

                icl_register_string( 'woopcd-partialcod-pro', $string_id, $string_value );
            } else if ( function_exists( 'pll_register_string' ) ) {

                pll_register_string( $string_id, $string_value, 'woopcd-partialcod-pro', $is_multiline );
            }
        }

    }

    new WOOPCD_PartialCOD_Polylang();
}