<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WOOPCD_PartialCOD_Amount_Type_Cart_Items' ) ) {

    class WOOPCD_PartialCOD_Amount_Type_Cart_Items {

        public function __construct() {

            add_filter( 'woopcd_partialcod/calculate-item_line-amount', array( $this, 'process_item_line_amount' ), 1, 3 );
            add_filter( 'woopcd_partialcod/calculate-item_qty-amount', array( $this, 'process_item_quantity_amount' ), 1, 3 );
            add_filter( 'woopcd_partialcod/calculate-item_id-amount', array( $this, 'process_product_id_amount' ), 1, 3 );
            add_filter( 'woopcd_partialcod/calculate-item_variation_id-amount', array( $this, 'process_variation_id_amount' ), 1, 3 );
            add_filter( 'woopcd_partialcod/calculate-item_per-amount', array( $this, 'process_item_percentage_amount' ), 1, 3 );
        }

        public function process_item_line_amount( $amount, $amount_args, $cart_data ) {

            $cart_items = $this->get_cart_items( $cart_data, $amount_args );

            $items_count = count( $cart_items );

            if ( !$items_count ) {
                return $amount;
            }
            $calc_amount = $amount_args[ 'amount' ] * $items_count;

            return WOOPCD_PartialCOD_Amount_Types::prepare_amount( $amount, $calc_amount, $cart_items, $amount_args );
        }

        public function process_item_quantity_amount( $amount, $amount_args, $cart_data ) {

            $qty = $amount_args[ 'quantity' ];

            if ( 0 >= $qty ) {
                return $amount;
            }

            $cart_items = $this->get_cart_items( $cart_data, $amount_args );


            $total_qty = $this->get_total_qty( $cart_items );

            if ( 0 >= $total_qty ) {
                return $amount;
            }

            $calc_amount = ($total_qty / $qty) * $amount_args[ 'amount' ];

            return WOOPCD_PartialCOD_Amount_Types::prepare_amount( $amount, $calc_amount, $cart_items, $amount_args );
        }

        public function process_product_id_amount( $amount, $amount_args, $cart_data ) {

            $cart_items = $this->get_cart_items( $cart_data, $amount_args );

            $item_ids_count = count( $this->get_item_ids( $cart_items ) );

            if ( !$item_ids_count ) {
                return $amount;
            }

            $calc_amount = $amount_args[ 'amount' ] * $item_ids_count;

            return WOOPCD_PartialCOD_Amount_Types::prepare_amount( $amount, $calc_amount, $cart_items, $amount_args );
        }

        public function process_variation_id_amount( $amount, $amount_args, $cart_data ) {

            $cart_items = $this->get_cart_items( $cart_data, $amount_args );

            $item_ids_count = count( $this->get_item_variation_ids( $cart_items ) );

            if ( !$item_ids_count ) {
                return $amount;
            }

            $calc_amount = $amount_args[ 'amount' ] * $item_ids_count;

            return WOOPCD_PartialCOD_Amount_Types::prepare_amount( $amount, $calc_amount, $cart_items, $amount_args );
        }

        public function process_item_percentage_amount( $amount, $amount_args, $cart_data ) {

            if ( !isset( $amount_args[ 'item_base_on' ] ) ) {
                return $amount;
            }

            $item_based_on = $amount_args[ 'item_base_on' ];

            $cart_items = $this->get_cart_items( $cart_data, $amount_args );

            $subtotal = $this->get_item_subtotals( $cart_items, $item_based_on );

            if ( 0 >= $subtotal ) {
                return $amount;
            }

            $calc_amount = ($amount_args[ 'amount' ] / 100) * $subtotal;

            return WOOPCD_PartialCOD_Amount_Types::prepare_amount( $amount, $calc_amount, $cart_items, $amount_args );
        }

        private function get_total_qty( $cart_items ) {
            $qty = 0;
            foreach ( $cart_items as $cart_item ) {
                $qty += $cart_item[ 'quantity' ];
            }
            return $qty;
        }

        private function get_item_ids( $cart_items ) {

            $item_ids = array();

            foreach ( $cart_items as $cart_item ) {

                if ( in_array( $cart_item[ 'product_id' ], $item_ids ) ) {
                    continue;
                }

                $item_ids[] = $cart_item[ 'product_id' ];
            }
            return $item_ids;
        }

        private function get_item_variation_ids( $cart_items ) {

            $variation_ids = array();

            foreach ( $cart_items as $cart_item ) {

                if ( 0 >= $cart_item[ 'variation_id' ] ) {
                    continue;
                }

                if ( in_array( $cart_item[ 'variation_id' ], $variation_ids ) ) {
                    continue;
                }

                $variation_ids[] = $cart_item[ 'variation_id' ];
            }

            return $variation_ids;
        }

        private function get_item_subtotals( $cart_items, $item_based_on ) {
            $subtotal = 0;

            foreach ( $cart_items as $cart_item ) {

                switch ( $item_based_on ) {
                    case 'excl_tax':

                        $subtotal += $cart_item[ 'line_subtotal' ];
                        break;

                    case 'incl_tax_after':

                        $subtotal += $cart_item[ 'line_total' ];
                        $subtotal += $cart_item[ 'line_tax' ];
                        break;

                    case 'excl_tax_after':

                        $subtotal += $cart_item[ 'line_total' ];
                        break;

                    default:

                        $subtotal += $cart_item[ 'line_subtotal' ];
                        $subtotal += $cart_item[ 'line_subtotal_tax' ];
                        break;
                }
            }
            return $subtotal;
        }

        private function get_cart_items( $cart_data, $amount_args ) {

            $product_args = array();

            if ( isset( $amount_args[ 'products_args' ] ) && is_array( $amount_args[ 'products_args' ] ) ) {
                $product_args = $amount_args[ 'products_args' ];
            }

            return WOOPCD_PartialCOD_Product_Filter_Types::get_cart_items( $cart_data, $product_args );
        }

    }

    new WOOPCD_PartialCOD_Amount_Type_Cart_Items();
}