<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WOOPCD_PartialCOD_Premium_Amount_Type_Cart' ) ) {

    class WOOPCD_PartialCOD_Premium_Amount_Type_Cart {

        public function __construct() {

            add_filter( 'woopcd_partialcod/calculate-cart_product_categories-amount', array( $this, 'process_product_categories_amount' ), 1, 3 );
            add_filter( 'woopcd_partialcod/calculate-cart_product_tags-amount', array( $this, 'process_product_tags_amount' ), 1, 3 );
        }

        public function process_product_categories_amount( $amount, $amount_args, $cart_data ) {

            if ( !isset( $amount_args[ 'product_categories_args' ] ) ) {
                return $amount;
            }

            $product_categories_args = $amount_args[ 'product_categories_args' ];

            $cart_items = $this->get_items_by_product_categories( $cart_data, $product_categories_args );

            $product_categories_count = $this->get_product_categories_count( $cart_items, $product_categories_args );


            $calc_amount = $amount_args[ 'amount' ] * $product_categories_count;

            return WOOPCD_PartialCOD_Amount_Types::prepare_amount( $amount, $calc_amount, $cart_items, $amount_args );
        }

        public function process_product_tags_amount( $amount, $amount_args, $cart_data ) {

            if ( !isset( $amount_args[ 'product_tags_args' ] ) ) {
                return $amount;
            }

            $product_tags_args = $amount_args[ 'product_tags_args' ];

            $cart_items = $this->get_items_by_product_tags( $cart_data, $product_tags_args );

            $product_tags_count = $this->get_product_tags_count( $cart_items, $product_tags_args );


            $calc_amount = $amount_args[ 'amount' ] * $product_tags_count;

            return WOOPCD_PartialCOD_Amount_Types::prepare_amount( $amount, $calc_amount, $cart_items, $amount_args );
        }

        private function get_product_categories_count( $cart_items, $product_categories_args ) {

            $compare = 'in_list';
            if ( isset( $product_categories_args[ 'compare' ] ) ) {
                $compare = $product_categories_args[ 'compare' ];
            }

            $rule_categories = array();

            if ( isset( $product_categories_args[ 'product_categories' ] ) ) {
                $rule_categories = $product_categories_args[ 'product_categories' ];
            }

            $rule_product_category_ids = WOOPCD_PartialCOD_Util::get_product_term_ids_by_slugs( $rule_categories, 'product_cat' );


            $product_categories = array();

            foreach ( $cart_items as $cart_item ) {

                $item_category_ids = $cart_item[ 'data' ][ 'category_ids' ];

                $product_categories = $this->merge_product_terms( $product_categories, $item_category_ids, $rule_product_category_ids, $compare );
            }

            return count( $product_categories );
        }

        private function get_product_tags_count( $cart_items, $product_tags_args ) {

            $compare = 'in_list';
            if ( isset( $product_tags_args[ 'compare' ] ) ) {
                $compare = $product_tags_args[ 'compare' ];
            }

            $rule_tags = array();

            if ( isset( $product_tags_args[ 'product_tags' ] ) ) {
                $rule_tags = $product_tags_args[ 'product_tags' ];
            }

            $rule_product_tags_ids = WOOPCD_PartialCOD_Util::get_product_term_ids_by_slugs( $rule_tags, 'product_tag' );


            $product_tags = array();

            foreach ( $cart_items as $cart_item ) {

                $item_tag_ids = $cart_item[ 'data' ][ 'tag_ids' ];

                $product_tags = $this->merge_product_terms( $product_tags, $item_tag_ids, $rule_product_tags_ids, $compare );
            }

            return count( $product_tags );
        }

        private function get_items_by_product_categories( $cart_data, $product_categories_args ) {

            if ( !isset( $cart_data[ 'wc' ][ 'cart_items' ] ) ) {
                return array();
            }


            if ( !isset( $product_categories_args[ 'product_categories' ] ) || !is_array( $product_categories_args[ 'product_categories' ] ) ) {
                return $cart_data[ 'wc' ][ 'cart_items' ];
            }


            $product_categories = $product_categories_args[ 'product_categories' ];

            $product_category_ids = WOOPCD_PartialCOD_Util::get_product_term_ids_by_slugs( $product_categories, 'product_cat' );

            $compare = 'in_list';
            if ( isset( $product_categories_args[ 'compare' ] ) ) {
                $compare = $product_categories_args[ 'compare' ];
            }

            $cart_items = array();

            foreach ( $cart_data[ 'wc' ][ 'cart_items' ] as $cart_item ) {

                if ( !isset( $cart_item[ 'data' ][ 'category_ids' ] ) ) {
                    continue;
                }

                $item_category_ids = $cart_item[ 'data' ][ 'category_ids' ];

                if ( !count( $item_category_ids ) ) {
                    continue;
                }


                if ( WOOPCD_PartialCOD_Validation_Util::validate_list_list( $item_category_ids, $product_category_ids, $compare ) != true ) {
                    continue;
                }

                $cart_items[] = $cart_item;
            }

            return $cart_items;
        }

        private function get_items_by_product_tags( $cart_data, $product_tags_args ) {

            if ( !isset( $cart_data[ 'wc' ][ 'cart_items' ] ) ) {
                return array();
            }


            if ( !isset( $product_tags_args[ 'product_tags' ] ) || !is_array( $product_tags_args[ 'product_tags' ] ) ) {
                return $cart_data[ 'wc' ][ 'cart_items' ];
            }


            $product_tags = $product_tags_args[ 'product_tags' ];

            $product_tag_ids = WOOPCD_PartialCOD_Util::get_product_term_ids_by_slugs( $product_tags, 'product_tag' );

            $compare = 'in_list';
            if ( isset( $product_tags_args[ 'compare' ] ) ) {
                $compare = $product_tags_args[ 'compare' ];
            }

            $cart_items = array();

            foreach ( $cart_data[ 'wc' ][ 'cart_items' ] as $cart_item ) {

                if ( !isset( $cart_item[ 'data' ][ 'tag_ids' ] ) ) {
                    continue;
                }

                $item_tag_ids = $cart_item[ 'data' ][ 'tag_ids' ];

                if ( !count( $item_tag_ids ) ) {
                    continue;
                }


                if ( WOOPCD_PartialCOD_Validation_Util::validate_list_list( $item_tag_ids, $product_tag_ids, $compare ) != true ) {
                    continue;
                }

                $cart_items[] = $cart_item;
            }

            return $cart_items;
        }

        private function merge_product_terms( $product_terms, $item_term_ids, $rule_product_term_ids, $rule_compare ) {

            foreach ( $item_term_ids as $item_term_id ) {

                if ( in_array( $item_term_id, $product_terms ) ) {
                    continue;
                }

                if ( !count( $rule_product_term_ids ) ) {
                    $product_terms[] = $item_term_id;
                    continue;
                }

                if ( WOOPCD_PartialCOD_Validation_Util::validate_value_list( $item_term_id, $rule_product_term_ids, $rule_compare ) != true ) {
                    continue;
                }

                $product_terms[] = $item_term_id;
            }

            return $product_terms;
        }

    }

    new WOOPCD_PartialCOD_Premium_Amount_Type_Cart();
}