<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WOOPCD_PartialCOD_Amount_Type_Height' ) ) {

    class WOOPCD_PartialCOD_Amount_Type_Height {

        public function __construct() {

            add_filter( 'woopcd_partialcod/calculate-per_height-amount', array( $this, 'process_per_height_amount' ), 1, 3 );
            add_filter( 'woopcd_partialcod/calculate-by_height-amount', array( $this, 'process_by_height_amount' ), 1, 3 );
        }

        public function process_per_height_amount( $amount, $amount_args, $cart_data ) {

            $height = $amount_args[ 'height' ];

            if ( 0 >= $height ) {
                return $amount;
            }

            $cart_items = $this->get_cart_items( $cart_data, $amount_args );

            $total_height = $this->get_total_height( $cart_items );

            if ( 0 >= $total_height ) {
                return $amount;
            }

            $calc_amount = $amount_args[ 'amount' ] * ($total_height / $height);

            return WOOPCD_PartialCOD_Amount_Types::prepare_amount( $amount, $calc_amount, $cart_items, $amount_args );
        }

        public function process_by_height_amount( $amount, $amount_args, $cart_data ) {

            $cart_items = $this->get_cart_items( $cart_data, $amount_args );

            $total_height = $this->get_total_height( $cart_items );

            if ( 0 >= $total_height ) {
                return $amount;
            }

            $calc_amount = $total_height * $amount_args[ 'amount' ];

            return WOOPCD_PartialCOD_Amount_Types::prepare_amount( $amount, $calc_amount, $cart_items, $amount_args );
        }

        private function get_total_height( $cart_items ) {

            $total_height = 0;

            foreach ( $cart_items as $cart_item ) {

                if ( isset( $cart_item[ 'data' ][ 'dimensions' ][ 'height' ] ) && is_numeric( $cart_item[ 'data' ][ 'dimensions' ][ 'height' ] ) ) {

                    $height = $cart_item[ 'data' ][ 'dimensions' ][ 'height' ] * $cart_item[ 'quantity' ];
                    $total_height += $height;
                }
            }

            return $total_height;
        }

        private function get_cart_items( $cart_data, $amount_args ) {

            $product_args = array();

            if ( isset( $amount_args[ 'products_args' ] ) && is_array( $amount_args[ 'products_args' ] ) ) {
                $product_args = $amount_args[ 'products_args' ];
            }

            return WOOPCD_PartialCOD_Product_Filter_Types::get_cart_items( $cart_data, $product_args );
        }

    }

    new WOOPCD_PartialCOD_Amount_Type_Height();
}