<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WOOPCD_PartialCOD_Amount_Type_Length' ) ) {

    class WOOPCD_PartialCOD_Amount_Type_Length {

        public function __construct() {

            add_filter( 'woopcd_partialcod/calculate-per_length-amount', array( $this, 'process_per_length_amount' ), 1, 3 );
            add_filter( 'woopcd_partialcod/calculate-by_length-amount', array( $this, 'process_by_length_amount' ), 1, 3 );
        }

        public function process_per_length_amount( $amount, $amount_args, $cart_data ) {

            $length = $amount_args[ 'lengths' ];

            if ( 0 >= $length ) {
                return $amount;
            }

            $cart_items = $this->get_cart_items( $cart_data, $amount_args );

            $total_length = $this->get_total_length( $cart_items );

            if ( 0 >= $total_length ) {
                return $amount;
            }

            $calc_amount = $amount_args[ 'amount' ] * ($total_length / $length);

            return WOOPCD_PartialCOD_Amount_Types::prepare_amount( $amount, $calc_amount, $cart_items, $amount_args );
        }

        public function process_by_length_amount( $amount, $amount_args, $cart_data ) {

            $cart_items = $this->get_cart_items( $cart_data, $amount_args );

            $total_length = $this->get_total_length( $cart_items );

            if ( 0 >= $total_length ) {
                return $amount;
            }

            $calc_amount = $total_length * $amount_args[ 'amount' ];

            return WOOPCD_PartialCOD_Amount_Types::prepare_amount( $amount, $calc_amount, $cart_items, $amount_args );
        }

        private function get_total_length( $cart_items ) {

            $total_length = 0;

            foreach ( $cart_items as $cart_item ) {

                if ( isset( $cart_item[ 'data' ][ 'dimensions' ][ 'length' ] ) && is_numeric( $cart_item[ 'data' ][ 'dimensions' ][ 'length' ] ) ) {

                    $length = $cart_item[ 'data' ][ 'dimensions' ][ 'length' ] * $cart_item[ 'quantity' ];
                    $total_length += $length;
                }
            }

            return $total_length;
        }

        private function get_cart_items( $cart_data, $amount_args ) {

            $product_args = array();

            if ( isset( $amount_args[ 'products_args' ] ) && is_array( $amount_args[ 'products_args' ] ) ) {
                $product_args = $amount_args[ 'products_args' ];
            }

            return WOOPCD_PartialCOD_Product_Filter_Types::get_cart_items( $cart_data, $product_args );
        }

    }

    new WOOPCD_PartialCOD_Amount_Type_Length();
}