<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WOOPCD_PartialCOD_Amount_Type_Surface_Area' ) ) {

    class WOOPCD_PartialCOD_Amount_Type_Surface_Area {

        public function __construct() {

            add_filter( 'woopcd_partialcod/calculate-per_surface_area-amount', array( $this, 'process_per_surface_area_amount' ), 1, 3 );
            add_filter( 'woopcd_partialcod/calculate-by_surface_area-amount', array( $this, 'process_by_surface_area_amount' ), 1, 3 );
        }

        public function process_per_surface_area_amount( $amount, $amount_args, $cart_data ) {

            $surface_area = $amount_args[ 'surface_area' ];

            if ( 0 >= $surface_area ) {
                return $amount;
            }

            $cart_items = $this->get_cart_items( $cart_data, $amount_args );

            $total_surface_area = $this->get_total_surface_area( $cart_items );

            if ( 0 >= $total_surface_area ) {
                return $amount;
            }

            $calc_amount = $amount_args[ 'amount' ] * ($total_surface_area / $surface_area);

            return WOOPCD_PartialCOD_Amount_Types::prepare_amount( $amount, $calc_amount, $cart_items, $amount_args );
        }

        public function process_by_surface_area_amount( $amount, $amount_args, $cart_data ) {

            $cart_items = $this->get_cart_items( $cart_data, $amount_args );

            $total_surface_area = $this->get_total_surface_area( $cart_items );

            if ( 0 >= $total_surface_area ) {
                return $amount;
            }

            $calc_amount = $total_surface_area * $amount_args[ 'amount' ];

            return WOOPCD_PartialCOD_Amount_Types::prepare_amount( $amount, $calc_amount, $cart_items, $amount_args );
        }

        private function get_total_surface_area( $cart_items ) {

            $total_surface_area = 0;

            foreach ( $cart_items as $cart_item ) {

                if ( !isset( $cart_item[ 'data' ][ 'dimensions' ][ 'length' ] ) ) {
                    continue;
                }
                
                if ( !isset( $cart_item[ 'data' ][ 'dimensions' ][ 'width' ] ) ) {
                    continue;
                }

                $length = $cart_item[ 'data' ][ 'dimensions' ][ 'length' ];
                $width = $cart_item[ 'data' ][ 'dimensions' ][ 'width' ];

                if ( !is_numeric( $length ) || !is_numeric( $width ) ) {
                    continue;
                }

                $qty = $cart_item[ 'quantity' ];

                $total_surface_area += (($length * $width) * $qty);
            }

            return $total_surface_area;
        }

        private function get_cart_items( $cart_data, $amount_args ) {

            $product_args = array();

            if ( isset( $amount_args[ 'products_args' ] ) && is_array( $amount_args[ 'products_args' ] ) ) {
                $product_args = $amount_args[ 'products_args' ];
            }

            return WOOPCD_PartialCOD_Product_Filter_Types::get_cart_items( $cart_data, $product_args );
        }

    }

    new WOOPCD_PartialCOD_Amount_Type_Surface_Area();
}
