<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WOOPCD_PartialCOD_Amount_Type_Volume' ) ) {

    class WOOPCD_PartialCOD_Amount_Type_Volume {

        public function __construct() {

            add_filter( 'woopcd_partialcod/calculate-per_volume-amount', array( $this, 'process_per_volume_amount' ), 1, 3 );
            add_filter( 'woopcd_partialcod/calculate-by_volume-amount', array( $this, 'process_by_volume_amount' ), 1, 3 );
        }

        public function process_per_volume_amount( $amount, $amount_args, $cart_data ) {

            $volume = $amount_args[ 'volume' ];

            if ( 0 >= $volume ) {
                return $amount;
            }

            $cart_items = $this->get_cart_items( $cart_data, $amount_args );

            $total_volume = $this->get_total_volume( $cart_items );

            if ( 0 >= $total_volume ) {
                return $amount;
            }

            $calc_amount = $amount_args[ 'amount' ] * ($total_volume / $volume);

            return WOOPCD_PartialCOD_Amount_Types::prepare_amount( $amount, $calc_amount, $cart_items, $amount_args );
        }

        public function process_by_volume_amount( $amount, $amount_args, $cart_data ) {

            $cart_items = $this->get_cart_items( $cart_data, $amount_args );

            $total_volume = $this->get_total_volume( $cart_items );

            if ( 0 >= $total_volume ) {
                return $amount;
            }

            $calc_amount = $total_volume * $amount_args[ 'amount' ];

            return WOOPCD_PartialCOD_Amount_Types::prepare_amount( $amount, $calc_amount, $cart_items, $amount_args );
        }

        private function get_total_volume( $cart_items ) {

            $total_volume = 0;

            foreach ( $cart_items as $cart_item ) {

                if ( !isset( $cart_item[ 'data' ][ 'dimensions' ][ 'length' ] ) ) {
                    continue;
                }

                if ( !isset( $cart_item[ 'data' ][ 'dimensions' ][ 'width' ] ) ) {
                    continue;
                }

                $length = $cart_item[ 'data' ][ 'dimensions' ][ 'length' ];
                $width = $cart_item[ 'data' ][ 'dimensions' ][ 'width' ];
                $height = $cart_item[ 'data' ][ 'dimensions' ][ 'height' ];

                if ( !is_numeric( $length ) || !is_numeric( $width ) || !is_numeric( $height ) ) {
                    continue;
                }

                $qty = $cart_item[ 'quantity' ];

                $total_volume += (($length * $width * $height) * $qty);
            }

            return $total_volume;
        }

        private function get_cart_items( $cart_data, $amount_args ) {

            $product_args = array();

            if ( isset( $amount_args[ 'products_args' ] ) && is_array( $amount_args[ 'products_args' ] ) ) {
                $product_args = $amount_args[ 'products_args' ];
            }

            return WOOPCD_PartialCOD_Product_Filter_Types::get_cart_items( $cart_data, $product_args );
        }

    }

    new WOOPCD_PartialCOD_Amount_Type_Volume();
}
