<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WOOPCD_PartialCOD_Amount_Type_Weight' ) ) {

    class WOOPCD_PartialCOD_Amount_Type_Weight {

        public function __construct() {

            add_filter( 'woopcd_partialcod/calculate-per_weight-amount', array( $this, 'process_per_weight_amount' ), 1, 3 );
            add_filter( 'woopcd_partialcod/calculate-by_weight-amount', array( $this, 'process_by_weight_amount' ), 1, 3 );
        }

        public function process_per_weight_amount( $amount, $amount_args, $cart_data ) {

            $weight = $amount_args[ 'weight' ];

            if ( 0 >= $weight ) {
                return $amount;
            }

            $cart_items = $this->get_cart_items( $cart_data, $amount_args );

            $total_weight = $this->get_total_weight( $cart_items );

            if ( 0 >= $total_weight ) {
                return $amount;
            }

            $calc_amount = $amount_args[ 'amount' ] * ($total_weight / $weight);

            return WOOPCD_PartialCOD_Amount_Types::prepare_amount( $amount, $calc_amount, $cart_items, $amount_args );
        }

        public function process_by_weight_amount( $amount, $amount_args, $cart_data ) {

            $cart_items = $this->get_cart_items( $cart_data, $amount_args );

            $total_weight = $this->get_total_weight( $cart_items );

            if ( 0 >= $total_weight ) {
                return $amount;
            }

            $calc_amount = $total_weight * $amount_args[ 'amount' ];

            return WOOPCD_PartialCOD_Amount_Types::prepare_amount( $amount, $calc_amount, $cart_items, $amount_args );
        }

        private function get_total_weight( $cart_items ) {

            $total_weight = 0;

            foreach ( $cart_items as $cart_item ) {

                if ( isset( $cart_item[ 'data' ][ 'weight' ] ) && is_numeric( $cart_item[ 'data' ][ 'weight' ] ) ) {

                    $weight = $cart_item[ 'data' ][ 'weight' ] * $cart_item[ 'quantity' ];
                    $total_weight += $weight;
                }
            }

            return $total_weight;
        }

        private function get_cart_items( $cart_data, $amount_args ) {

            $product_args = array();

            if ( isset( $amount_args[ 'products_args' ] ) && is_array( $amount_args[ 'products_args' ] ) ) {
                $product_args = $amount_args[ 'products_args' ];
            }

            return WOOPCD_PartialCOD_Product_Filter_Types::get_cart_items( $cart_data, $product_args );
        }

    }

    new WOOPCD_PartialCOD_Amount_Type_Weight();
}
