<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WOOPCD_PartialCOD_Amount_Type_Width' ) ) {

    class WOOPCD_PartialCOD_Amount_Type_Width {

        public function __construct() {

            add_filter( 'woopcd_partialcod/calculate-per_width-amount', array( $this, 'process_per_width_amount' ), 1, 3 );
            add_filter( 'woopcd_partialcod/calculate-by_width-amount', array( $this, 'process_by_width_amount' ), 1, 3 );
        }

        public function process_per_width_amount( $amount, $amount_args, $cart_data ) {

            $width = $amount_args[ 'width' ];

            if ( 0 >= $width ) {
                return $amount;
            }

            $cart_items = $this->get_cart_items( $cart_data, $amount_args );

            $total_width = $this->get_total_width( $cart_items );

            if ( 0 >= $total_width ) {
                return $amount;
            }

            $calc_amount = $amount_args[ 'amount' ] * ($total_width / $width);

            return WOOPCD_PartialCOD_Amount_Types::prepare_amount( $amount, $calc_amount, $cart_items, $amount_args );
        }

        public function process_by_width_amount( $amount, $amount_args, $cart_data ) {

            $cart_items = $this->get_cart_items( $cart_data, $amount_args );

            $total_width = $this->get_total_width( $cart_items );

            if ( 0 >= $total_width ) {
                return $amount;
            }

            $calc_amount = $total_width * $amount_args[ 'amount' ];

            return WOOPCD_PartialCOD_Amount_Types::prepare_amount( $amount, $calc_amount, $cart_items, $amount_args );
        }

        private function get_total_width( $cart_items ) {

            $total_width = 0;

            foreach ( $cart_items as $cart_item ) {

                if ( isset( $cart_item[ 'data' ][ 'dimensions' ][ 'width' ] ) && is_numeric( $cart_item[ 'data' ][ 'dimensions' ][ 'width' ] ) ) {

                    $width = $cart_item[ 'data' ][ 'dimensions' ][ 'width' ] * $cart_item[ 'quantity' ];
                    $total_width += $width;
                }
            }

            return $total_width;
        }

        private function get_cart_items( $cart_data, $amount_args ) {

            $product_args = array();

            if ( isset( $amount_args[ 'products_args' ] ) && is_array( $amount_args[ 'products_args' ] ) ) {
                $product_args = $amount_args[ 'products_args' ];
            }

            return WOOPCD_PartialCOD_Product_Filter_Types::get_cart_items( $cart_data, $product_args );
        }

    }

    new WOOPCD_PartialCOD_Amount_Type_Width();
}