<?php

if (!defined('ABSPATH')) {
    exit;
}

if (!class_exists('WOOPCD_PartialCOD_Premium_Amount_Types')) {
    WOOPCD_PartialCOD_Main::required_paths(dirname(__FILE__), array('amount-types.php'));

    class WOOPCD_PartialCOD_Premium_Amount_Types {

        public static function can_calculate_amount($amount_args, $cart_data) {

            if ('no' == $amount_args['set_conditions']) {
                return true;
            }
            if (!isset($amount_args['conditions'])) {
                return true;
            }

            $conditions = $amount_args['conditions'];

            for ($key = 0; $key < count($conditions); $key++) {
                $conditions[$key]['module'] = $amount_args['module'];
            }

            return WOOPCD_PartialCOD_Premium_Condition_Types::validate_amount_conditions($conditions, $cart_data);
        }

        public static function merge_amounts($amounts) {

            $calc_amount = array(
                'amount' => 0,
                'amount_tax' => 0,
                'taxes' => array(),
            );

            foreach ($amounts as $amount) {
                if ('set' == $amount['add_type']) {
                    $calc_amount['amount'] = $amount['amount'];
                    $calc_amount['amount_tax'] = $amount['amount_tax'];
                    $calc_amount['taxes'] = $amount['taxes'];
                } else if ('sub' == $amount['add_type']) {
                    $calc_amount['amount'] -= $amount['amount'];

                    $taxes = self::sub_taxes($calc_amount['amount_tax'], $amount['amount_tax'], $calc_amount['taxes']);
                    $calc_amount['amount_tax'] -= $amount['amount_tax'];

                    $calc_amount['taxes'] = $taxes;
                } else {
                    $calc_amount['amount'] += $amount['amount'];
                    $calc_amount['amount_tax'] += $amount['amount_tax'];

                    $calc_amount['taxes'] = self::add_taxes($calc_amount['taxes'], $amount['taxes']);
                }
            }


            if ($calc_amount['amount'] < 0) {
                $calc_amount['amount'] = 0;
            }

            if ($calc_amount['amount_tax'] < 0) {
                $calc_amount['amount_tax'] = 0;
                $calc_amount['taxes'] = array();
            }

            return $calc_amount;
        }

        private static function add_taxes($prev_amount_taxes, $new_amount_taxes) {

            foreach ($new_amount_taxes as $key => $tax) {
                if (isset($prev_amount_taxes[$key])) {
                    $prev_amount_taxes[$key] += $tax;
                } else {
                    $prev_amount_taxes[$key] = $tax;
                }
            }
            return $prev_amount_taxes;
        }

        private static function sub_taxes($prev_amount_tax, $new_amount_tax, $prev_taxes) {
            $taxes = array();

            $amount_tax = $prev_amount_tax - $new_amount_tax;

            foreach ($prev_taxes as $key => $tax) {
                $tax_amount = (($tax / $prev_amount_tax) * $amount_tax);
                if (isset($taxes[$key])) {
                    $taxes[$key] += $tax_amount;
                } else {
                    $taxes[$key] = $tax_amount;
                }
            }

            return $taxes;
        }

    }

    new WOOPCD_PartialCOD_Premium_Amount_Types();
}