<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WOOPCD_PartialCOD_Conditions_Cart_Item_Subtotals' ) ) {

    class WOOPCD_PartialCOD_Conditions_Cart_Item_Subtotals {

        public function __construct() {
            add_filter( 'woopcd_partialcod/validate-cart_subtotal_products-condition', array( $this, 'validate_cart_subtotal_products' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-cart_subtotal_variations-condition', array( $this, 'validate_cart_subtotal_variations' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-cart_subtotal_categories-condition', array( $this, 'validate_cart_subtotal_categories' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-cart_subtotal_tags-condition', array( $this, 'validate_cart_subtotal_tags' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-cart_subtotal_attributes-condition', array( $this, 'validate_cart_subtotal_attributes' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-cart_subtotal_virtuals-condition', array( $this, 'validate_cart_subtotal_virtuals' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-cart_subtotal_tax_classes-condition', array( $this, 'validate_cart_subtotal_tax_classes' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-cart_subtotal_shipping_classes-condition', array( $this, 'validate_cart_subtotal_shipping_classes' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-cart_subtotal_metas-condition', array( $this, 'validate_cart_subtotal_metas' ), 10, 2 );
        }

        public function validate_cart_subtotal_products( $condition, $cart_data ) {

            if ( !isset( $condition[ 'product_slugs' ] ) ) {
                return false;
            }


            if ( $this->is_empty_items( $cart_data ) ) {
                return false;
            }

            $rule_product_ids = WOOPCD_PartialCOD_Util::get_product_ids_by_slugs( $condition[ 'product_slugs' ] );

            if ( !count( $rule_product_ids ) ) {
                return false;
            }

            $subtotals = $this->get_subtotals( WOOPCD_PartialCOD_Cart_Util::get_items_by_ids( $cart_data, $rule_product_ids ) );

            $rule_subtotals = $condition[ 'subtotal' ];

            if ( !is_numeric( $rule_subtotals ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $rule_compare, $subtotals, $rule_subtotals, 'no' );
        }

        public function validate_cart_subtotal_variations( $condition, $cart_data ) {

            if ( !isset( $condition[ 'variation_slugs' ] ) ) {
                return false;
            }


            if ( $this->is_empty_items( $cart_data ) ) {
                return false;
            }

            $rule_variation_ids = WOOPCD_PartialCOD_Util::get_variation_ids_by_slugs( $condition[ 'variation_slugs' ] );

            if ( !count( $rule_variation_ids ) ) {
                return false;
            }

            $subtotals = $this->get_subtotals( WOOPCD_PartialCOD_Cart_Util::get_items_by_variation_ids( $cart_data, $rule_variation_ids ) );

            $rule_subtotals = $condition[ 'subtotal' ];

            if ( !is_numeric( $rule_subtotals ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $rule_compare, $subtotals, $rule_subtotals, 'no' );
        }

        public function validate_cart_subtotal_categories( $condition, $cart_data ) {


            if ( !isset( $condition[ 'category_slugs' ] ) ) {
                return false;
            }


            if ( $this->is_empty_items( $cart_data ) ) {
                return false;
            }

            $rule_category_ids = WOOPCD_PartialCOD_Util::get_product_term_ids_by_slugs( $condition[ 'category_slugs' ], 'product_cat' );

            if ( !count( $rule_category_ids ) ) {
                return false;
            }

            $subtotals = $this->get_subtotals( WOOPCD_PartialCOD_Cart_Util::get_items_by_category_ids( $cart_data, $rule_category_ids ) );

            $rule_subtotals = $condition[ 'subtotal' ];

            if ( !is_numeric( $rule_subtotals ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $rule_compare, $subtotals, $rule_subtotals, 'no' );
        }

        public function validate_cart_subtotal_tags( $condition, $cart_data ) {

            if ( !isset( $condition[ 'tag_slugs' ] ) ) {
                return false;
            }


            if ( $this->is_empty_items( $cart_data ) ) {
                return false;
            }

            $rule_tag_ids = WOOPCD_PartialCOD_Util::get_product_term_ids_by_slugs( $condition[ 'tag_slugs' ], 'product_tag' );

            if ( !count( $rule_tag_ids ) ) {
                return false;
            }

            $subtotals = $this->get_subtotals( WOOPCD_PartialCOD_Cart_Util::get_items_by_tag_ids( $cart_data, $rule_tag_ids ) );

            $rule_subtotals = $condition[ 'subtotal' ];

            if ( !is_numeric( $rule_subtotals ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $rule_compare, $subtotals, $rule_subtotals, 'no' );
        }

        public function validate_cart_subtotal_attributes( $condition, $cart_data ) {

            if ( !isset( $condition[ 'attribute_slugs' ] ) ) {
                return false;
            }


            if ( $this->is_empty_items( $cart_data ) ) {
                return false;
            }

            $rule_attribute_ids = WOOPCD_PartialCOD_Util::get_attribute_ids_by_slugs($condition[ 'attribute_slugs' ]);

            if ( !count( $rule_attribute_ids ) ) {
                return false;
            }

            $subtotals = $this->get_subtotals( WOOPCD_PartialCOD_Cart_Util::get_items_by_attribute_ids( $cart_data, $rule_attribute_ids ) );

            $rule_subtotals = $condition[ 'subtotal' ];

            if ( !is_numeric( $rule_subtotals ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $rule_compare, $subtotals, $rule_subtotals, 'no' );
        }

        public function validate_cart_subtotal_virtuals( $condition, $cart_data ) {

            if ( !isset( $condition[ 'is_virtual' ] ) ) {
                return false;
            }


            if ( $this->is_empty_items( $cart_data ) ) {
                return false;
            }

            $rule_is_virtual = $condition[ 'is_virtual' ];


            $subtotals = $this->get_subtotals( WOOPCD_PartialCOD_Cart_Util::get_items_by_virtuals( $cart_data, $rule_is_virtual ) );

            $rule_subtotals = $condition[ 'subtotal' ];

            if ( !is_numeric( $rule_subtotals ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $rule_compare, $subtotals, $rule_subtotals, 'no' );
        }

        public function validate_cart_subtotal_tax_classes( $condition, $cart_data ) {

            if ( !isset( $condition[ 'tax_classes' ] ) ) {
                return false;
            }


            if ( $this->is_empty_items( $cart_data ) ) {
                return false;
            }

            $rule_tax_classes = $condition[ 'tax_classes' ];

            if ( !count( $rule_tax_classes ) ) {
                return false;
            }

            $subtotals = $this->get_subtotals( WOOPCD_PartialCOD_Cart_Util::get_items_by_tax_classes( $cart_data, $rule_tax_classes ) );

            $rule_subtotals = $condition[ 'subtotal' ];

            if ( !is_numeric( $rule_subtotals ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $rule_compare, $subtotals, $rule_subtotals, 'no' );
        }

        public function validate_cart_subtotal_shipping_classes( $condition, $cart_data ) {

            if ( !isset( $condition[ 'shipping_classes' ] ) ) {
                return false;
            }


            if ( $this->is_empty_items( $cart_data ) ) {
                return false;
            }

            $rule_shipping_classe_ids = WOOPCD_PartialCOD_Util::get_product_term_ids_by_slugs( $condition[ 'shipping_classes' ], 'product_shipping_class' );

            if ( !count( $rule_shipping_classe_ids ) ) {
                return false;
            }

            $subtotals = $this->get_subtotals( WOOPCD_PartialCOD_Cart_Util::get_items_by_shipping_class_ids( $cart_data, $rule_shipping_classe_ids ) );

            $rule_subtotals = $condition[ 'subtotal' ];

            if ( !is_numeric( $rule_subtotals ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $rule_compare, $subtotals, $rule_subtotals, 'no' );
        }

        public function validate_cart_subtotal_metas( $condition, $cart_data ) {

            if ( !isset( $condition[ 'meta_key' ] ) || !isset( $condition[ 'meta_value' ] ) ) {
                return false;
            }

            if ( $this->is_empty_items( $cart_data ) ) {
                return false;
            }

            $meta_key = $condition[ 'meta_key' ];
            $meta_value = $condition[ 'meta_value' ];


            $subtotals = $this->get_subtotals( WOOPCD_PartialCOD_Cart_Util::get_items_by_meta( $cart_data, $meta_key, $meta_value ) );

            $rule_subtotals = $condition[ 'subtotal' ];

            if ( !is_numeric( $rule_subtotals ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $rule_compare, $subtotals, $rule_subtotals, 'no' );
        }

        private function get_subtotals( $cart_items ) {

            $subtotals = 0;

            if ( !count( $cart_items ) ) {
                return $subtotals;
            }

            foreach ( $cart_items as $cart_item ) {

                $subtotals += $cart_item[ 'line_subtotal' ];
                $subtotals += $cart_item[ 'line_subtotal_tax' ];
            }

            return $subtotals;
        }

        private function is_empty_items( $cart_data ) {

            if ( !isset( $cart_data[ 'wc' ][ 'cart_items' ] ) ) {
                return true;
            }

            return false;
        }

    }

    new WOOPCD_PartialCOD_Conditions_Cart_Item_Subtotals();
}