<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WOOPCD_PartialCOD_Conditions_Cart_Items' ) ) {

    class WOOPCD_PartialCOD_Conditions_Cart_Items {

        public function __construct() {
            add_filter( 'woopcd_partialcod/validate-cart_item_products-condition', array( $this, 'validate_cart_item_products' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-cart_item_variations-condition', array( $this, 'validate_cart_item_variations' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-cart_item_categories-condition', array( $this, 'validate_cart_item_categories' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-cart_item_tags-condition', array( $this, 'validate_cart_item_tags' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-cart_item_attributes-condition', array( $this, 'validate_cart_item_attributes' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-cart_item_virtuals-condition', array( $this, 'validate_cart_item_virtuals' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-cart_item_tax_classes-condition', array( $this, 'validate_cart_item_tax_classes' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-cart_item_shipping_classes-condition', array( $this, 'validate_cart_item_shipping_classes' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-cart_item_metas-condition', array( $this, 'validate_cart_item_metas' ), 10, 2 );
        }

        public function validate_cart_item_products( $condition, $cart_data ) {

            if ( !isset( $condition[ 'product_slugs' ] ) ) {
                return false;
            }

            $rule_product_ids = WOOPCD_PartialCOD_Util::get_product_ids_by_slugs( $condition[ 'product_slugs' ] );

            if ( !count( $rule_product_ids ) ) {
                return false;
            }

            $product_ids = WOOPCD_PartialCOD_Cart_Util::get_product_ids( $cart_data );

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_list_list( $product_ids, $rule_product_ids, $rule_compare );
        }

        public function validate_cart_item_variations( $condition, $cart_data ) {

            if ( !isset( $condition[ 'variation_slugs' ] ) ) {
                return false;
            }

            $rule_variation_ids = WOOPCD_PartialCOD_Util::get_variation_ids_by_slugs( $condition[ 'variation_slugs' ] );

            if ( !count( $rule_variation_ids ) ) {
                return false;
            }

            $variation_ids = WOOPCD_PartialCOD_Cart_Util::get_variation_ids( $cart_data );

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_list_list( $variation_ids, $rule_variation_ids, $rule_compare );
        }

        public function validate_cart_item_categories( $condition, $cart_data ) {

            if ( !isset( $condition[ 'category_slugs' ] ) ) {
                return false;
            }

            $rule_category_ids = WOOPCD_PartialCOD_Util::get_product_term_ids_by_slugs( $condition[ 'category_slugs' ], 'product_cat' );

            if ( !count( $rule_category_ids ) ) {
                return false;
            }

            $category_ids = WOOPCD_PartialCOD_Cart_Util::get_category_ids( $cart_data );

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_list_list( $category_ids, $rule_category_ids, $rule_compare );
        }

        public function validate_cart_item_tags( $condition, $cart_data ) {

            if ( !isset( $condition[ 'tag_slugs' ] ) ) {
                return false;
            }

            $rule_tag_ids = WOOPCD_PartialCOD_Util::get_product_term_ids_by_slugs( $condition[ 'tag_slugs' ], 'product_tag' );

            if ( !count( $rule_tag_ids ) ) {
                return false;
            }

            $tag_ids = WOOPCD_PartialCOD_Cart_Util::get_tag_ids( $cart_data );

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_list_list( $tag_ids, $rule_tag_ids, $rule_compare );
        }

        public function validate_cart_item_attributes( $condition, $cart_data ) {
            
            
           if ( !isset( $condition[ 'attribute_slugs' ] ) ) {
                return false;
            }

            $rule_attribute_ids = WOOPCD_PartialCOD_Util::get_attribute_ids_by_slugs( $condition[ 'attribute_slugs' ] );

            if ( !count( $rule_attribute_ids ) ) {
                return false;
            }

            $attribute_ids = WOOPCD_PartialCOD_Cart_Util::get_attribute_ids( $cart_data );

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_list_list( $attribute_ids, $rule_attribute_ids, $rule_compare ); 
            
        }

        public function validate_cart_item_virtuals( $condition, $cart_data ) {

            $rule_is_virtual = $condition[ 'is_virtual' ];

            $has_virtual = WOOPCD_PartialCOD_Cart_Util::get_has_virtual( $cart_data );

            return WOOPCD_PartialCOD_Validation_Util::validate_yes_no( $has_virtual, $rule_is_virtual );
        }

        public function validate_cart_item_tax_classes( $condition, $cart_data ) {

            if ( !isset( $condition[ 'tax_classes' ] ) ) {
                return false;
            }

            $rule_tax_classes = $condition[ 'tax_classes' ];

            $tax_classes = WOOPCD_PartialCOD_Cart_Util::get_tax_classes( $cart_data );

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_list_list( $tax_classes, $rule_tax_classes, $rule_compare );
        }

        public function validate_cart_item_shipping_classes( $condition, $cart_data ) {


            if ( !isset( $condition[ 'shipping_classes' ] ) ) {
                return false;
            }

            $rule_shipping_classes = WOOPCD_PartialCOD_Util::get_product_term_ids_by_slugs( $condition[ 'shipping_classes' ], 'product_shipping_class' );

            if ( !count( $rule_shipping_classes ) ) {
                return false;
            }

            $shipping_classes = WOOPCD_PartialCOD_Cart_Util::get_shipping_classes( $cart_data );

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_list_list( $shipping_classes, $rule_shipping_classes, $rule_compare );
        }

        public function validate_cart_item_metas( $condition, $cart_data ) {

            $rule_meta_key = $condition[ 'meta_key' ];

            $rule_yes_no = 'no';
            $rule_meta_value = '';

            if ( isset( $condition[ 'yes_no' ] ) ) {
                $rule_yes_no = $condition[ 'yes_no' ];
            }

            if ( isset( $condition[ 'meta_value' ] ) ) {
                $rule_meta_value = $condition[ 'meta_value' ];
            }

            $product_metas = WOOPCD_PartialCOD_Cart_Util::get_product_metas( $cart_data, $rule_meta_key );


            $rule_compare = $condition[ 'compare' ];

            foreach ( $product_metas as $product_meta ) {

                $is_valid = WOOPCD_PartialCOD_Validation_Util::validate_value( $rule_compare, $product_meta, $rule_meta_value, $rule_yes_no );
                if ( $is_valid ) {
                    return true;
                }
            }

            return false;
        }

    }

    new WOOPCD_PartialCOD_Conditions_Cart_Items();
}