<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WOOPCD_PartialCOD_Conditions_Cart' ) ) {

    class WOOPCD_PartialCOD_Conditions_Cart {

        public function __construct() {
            add_filter( 'woopcd_partialcod/validate-cart_quantity-condition', array( $this, 'validate_cart_quantity' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-cart_weight-condition', array( $this, 'validate_cart_weight' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-cart_line_count-condition', array( $this, 'validate_cart_item_count' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-cart_coupons-condition', array( $this, 'validate_cart_coupons' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-advance_pay_methods-condition', array( $this, 'validate_advance_pay_methods' ), 10, 2 );
        }

        public function validate_cart_quantity( $condition, $cart_data ) {

            $rule_total_quantity = $condition[ 'total_quantity' ];

            if ( empty( $rule_total_quantity ) ) {
                return false;
            }

            $quantity = $this->get_quantity( $cart_data );

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $rule_compare, $quantity, $rule_total_quantity, 'no' );
        }

        public function validate_cart_weight( $condition, $cart_data ) {

            $rule_total_weight = $condition[ 'total_weight' ];

            if ( empty( $rule_total_weight ) ) {
                return false;
            }

            $weight = $this->get_weight( $cart_data );

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $rule_compare, $weight, $rule_total_weight, 'no' );
        }

        public function validate_cart_item_count( $condition, $cart_data ) {

            $rule_line_count = $condition[ 'line_count' ];

            if ( empty( $rule_line_count ) ) {
                return false;
            }

            $line_count = $this->get_line_count( $cart_data );

            if ( empty( $line_count ) ) {
                return false;
            }


            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $rule_compare, $line_count, $rule_line_count, 'no' );
        }

        public function validate_cart_coupons( $condition, $cart_data ) {
            $coupon_ids = $this->get_coupon_ids( $cart_data );

            $rule_compare = $condition[ 'compare' ];

            if ( $rule_compare === 'any' ) {

                $is_any = 'yes';

                if ( !empty( $condition[ 'is_any' ] ) ) {
                    
                    $is_any = $condition[ 'is_any' ];
                }

                return WOOPCD_PartialCOD_Validation_Util::validate_list_empty( $coupon_ids, $is_any );
            }

            $rule_coupons = $condition[ 'coupons' ];


            if ( !is_array( $rule_coupons ) ) {
                return false;
            }

            return WOOPCD_PartialCOD_Validation_Util::validate_list_list( $coupon_ids, $rule_coupons, $rule_compare );
        }

        public function validate_advance_pay_methods( $condition, $cart_data ) {

            $rule_method_ids = $condition[ 'method_ids' ];

            if ( !is_array( $rule_method_ids ) ) {
                return false;
            }

            $method_id = $this->get_method_id( $cart_data );

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value_list( $method_id, $rule_method_ids, $rule_compare );
        }

        private function get_quantity( $cart_data ) {

            $quantity = 0;

            if ( !isset( $cart_data[ 'wc' ][ 'cart_items' ] ) ) {
                return $quantity;
            }

            foreach ( $cart_data[ 'wc' ][ 'cart_items' ] as $cart_item ) {
                $quantity += $cart_item[ 'quantity' ];
            }

            return $quantity;
        }

        private function get_weight( $cart_data ) {
            $weight = 0;

            if ( !isset( $cart_data[ 'wc' ][ 'cart_items' ] ) ) {
                return $weight;
            }

            foreach ( $cart_data[ 'wc' ][ 'cart_items' ] as $cart_item ) {
                $wght = $cart_item[ 'data' ][ 'weight' ];
                if ( is_numeric( $wght ) && $wght > 0 ) {
                    $weight += ($wght * $cart_item[ 'quantity' ]);
                }
            }

            return $weight;
        }

        private function get_line_count( $cart_data ) {

            if ( !isset( $cart_data[ 'wc' ][ 'cart_items' ] ) ) {
                return 0;
            }

            return count( $cart_data[ 'wc' ][ 'cart_items' ] );
        }

        private function get_coupon_ids( $cart_data ) {
            $coupon_ids = array();

            if ( !isset( $cart_data[ 'wc' ][ 'applied_coupons' ] ) ) {
                return $coupon_ids;
            }

            $partialcod_coupons = array();
            if ( isset( $cart_data[ 'wc' ][ 'partialcod_coupons' ] ) ) {
                $partialcod_coupons = $cart_data[ 'wc' ][ 'partialcod_coupons' ];
            }

            $coupon_codes = array();

            foreach ( $cart_data[ 'wc' ][ 'applied_coupons' ] as $coupon ) {
                if ( !in_array( $coupon[ 'coupon_code' ], $partialcod_coupons ) ) {
                    $coupon_codes[] = $coupon[ 'coupon_code' ];
                }
            }

            foreach ( $coupon_codes as $coupon_code ) {
                $coupon_id = wc_get_coupon_id_by_code( $coupon_code );
                if ( $coupon_id > 0 ) {
                    $coupon_ids[] = $coupon_id;
                }
            }

            return $coupon_ids;
        }

        private function get_method_id( $cart_data ) {

            if ( isset( $cart_data[ 'wc' ][ 'method_ids' ][ 'method_id' ] ) ) {
                return $cart_data[ 'wc' ][ 'method_ids' ][ 'method_id' ];
            }

            return '';
        }

    }

    new WOOPCD_PartialCOD_Conditions_Cart();
}