<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WOOPCD_PartialCOD_Conditions_Customer_Value' ) ) {

    class WOOPCD_PartialCOD_Conditions_Customer_Value {

        public function __construct() {

            add_filter( 'woopcd_partialcod/validate-coupons_used-condition', array( $this, 'validate_coupons_used' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-total_spent-condition', array( $this, 'validate_total_spent' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-last_order_date-condition', array( $this, 'validate_last_order_date' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-last_order_amount-condition', array( $this, 'validate_last_order_amount' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-average_per_order-condition', array( $this, 'validate_average_per_order' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-maximum_per_order-condition', array( $this, 'validate_maximum_per_order' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-minimum_per_order-condition', array( $this, 'validate_minimum_per_order' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-number_of_orders-condition', array( $this, 'validate_number_of_orders' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-number_of_reviews-condition', array( $this, 'validate_number_of_reviews' ), 10, 2 );
        }

        public function validate_coupons_used( $condition, $cart_data ) {

            $rule_applied_coupons = $condition[ 'all_time_applied_coupons' ];

            if ( $condition[ 'date_type' ] != 'all_time' && $condition[ 'date_type' ] != '' ) {

                $rule_applied_coupons = $condition[ 'applied_coupons' ];
            }

            if ( !is_array( $rule_applied_coupons ) ) {

                return false;
            }

            $hash_key = $this->get_hash_key( $condition );

            $from_date = WOOPCD_PartialCOD_DateTime_Util::get_date_from_args( $condition );

            $coupon_used = WOOPCD_PartialCOD_Customer_Util::get_coupon_used( $cart_data, $from_date, $hash_key );

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_list_list( $coupon_used, $rule_applied_coupons, $rule_compare );
        }

        public function validate_total_spent( $condition, $cart_data ) {

            $compare = $condition[ 'all_time_compare' ];
            if ( $condition[ 'date_type' ] != 'all_time' && $condition[ 'date_type' ] != '' ) {
                $compare = $condition[ 'compare' ];
            }

            $rule_total_spent = $condition[ 'total_spent' ];

            $from_date = WOOPCD_PartialCOD_DateTime_Util::get_date_from_args( $condition );

            $hash_key = $this->get_hash_key( $condition );

            $total_spent = WOOPCD_PartialCOD_Customer_Util::get_order_total( $cart_data, $from_date, "SUM", $hash_key );

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $compare, $total_spent, $rule_total_spent );
        }

        public function validate_last_order_date( $condition, $cart_data ) {

            $last_order_date = WOOPCD_PartialCOD_Customer_Util::get_last_order_date( $cart_data );

            if ( empty( $last_order_date ) ) {
                return false;
            }

            $from_date = WOOPCD_PartialCOD_DateTime_Util::get_date_from_args( $condition );

            $rule_date_compare = $condition[ 'date_compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_date( $rule_date_compare, $last_order_date, $from_date, 'Y-m-d H:i:s', 'Y-m-d H:i:s' );
        }

        public function validate_last_order_amount( $condition, $cart_data ) {

            $rule_last_spent = $condition[ 'last_spent' ];

            if ( !is_numeric( $rule_last_spent ) ) {
                
                return false;
            }

            $last_order_totals = WOOPCD_PartialCOD_Customer_Util::get_last_order_totals( $cart_data );

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $rule_compare, $last_order_totals, $rule_last_spent );
        }

        public function validate_average_per_order( $condition, $cart_data ) {

            $compare = $condition[ 'all_time_compare' ];
            if ( $condition[ 'date_type' ] != 'all_time' && $condition[ 'date_type' ] != '' ) {
                $compare = $condition[ 'compare' ];
            }

            $rule_average_spent = $condition[ 'average_spent' ];

            $from_date = WOOPCD_PartialCOD_DateTime_Util::get_date_from_args( $condition );

            $hash_key = $this->get_hash_key( $condition );

            $average_spent = WOOPCD_PartialCOD_Customer_Util::get_order_total( $cart_data, $from_date, "AVG", $hash_key );

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $compare, $average_spent, $rule_average_spent );
        }

        public function validate_maximum_per_order( $condition, $cart_data ) {

            $compare = $condition[ 'all_time_compare' ];

            if ( $condition[ 'date_type' ] != 'all_time' && $condition[ 'date_type' ] != '' ) {
                $compare = $condition[ 'compare' ];
            }

            $rule_max_spent = $condition[ 'max_spent' ];

            $from_date = WOOPCD_PartialCOD_DateTime_Util::get_date_from_args( $condition );

            $hash_key = $this->get_hash_key( $condition );

            $max_spent = WOOPCD_PartialCOD_Customer_Util::get_order_total( $cart_data, $from_date, "MAX", $hash_key );

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $compare, $max_spent, $rule_max_spent );
        }

        public function validate_minimum_per_order( $condition, $cart_data ) {

            $compare = $condition[ 'all_time_compare' ];

            if ( $condition[ 'date_type' ] != 'all_time' && $condition[ 'date_type' ] != '' ) {
                $compare = $condition[ 'compare' ];
            }

            $rule_min_spent = $condition[ 'min_spent' ];

            $from_date = WOOPCD_PartialCOD_DateTime_Util::get_date_from_args( $condition );

            $hash_key = $this->get_hash_key( $condition );

            $min_spent = WOOPCD_PartialCOD_Customer_Util::get_order_total( $cart_data, $from_date, "MIN", $hash_key );

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $compare, $min_spent, $rule_min_spent );
        }

        public function validate_number_of_orders( $condition, $cart_data ) {

            $compare = $condition[ 'all_time_compare' ];

            if ( $condition[ 'date_type' ] != 'all_time' && $condition[ 'date_type' ] != '' ) {
                $compare = $condition[ 'compare' ];
            }

            $rule_orders_count = $condition[ 'orders_count' ];

            $from_date = WOOPCD_PartialCOD_DateTime_Util::get_date_from_args( $condition );

            $hash_key = $this->get_hash_key( $condition );

            $orders_count = WOOPCD_PartialCOD_Customer_Util::get_order_total( $cart_data, $from_date, "COUNT", $hash_key );

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $compare, $orders_count, $rule_orders_count );
        }

        public function validate_number_of_reviews( $condition, $cart_data ) {

            $compare = $condition[ 'all_time_compare' ];

            if ( $condition[ 'date_type' ] != 'all_time' && $condition[ 'date_type' ] != '' ) {
                $compare = $condition[ 'compare' ];
            }

            $rule_reviews_count = $condition[ 'reviews_count' ];

            $from_date = WOOPCD_PartialCOD_DateTime_Util::get_date_from_args( $condition );

            $hash_key = $this->get_hash_key( $condition );

            $reviews_count = WOOPCD_PartialCOD_Customer_Util::get_reviews_count( $cart_data, $from_date, $hash_key );

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $compare, $reviews_count, $rule_reviews_count );
        }

        private function get_hash_key( $condition ) {

            $hash_args = array();

            if ( isset( $condition[ 'date_type' ] ) ) {
                $hash_args[ 'date_type' ] = $condition[ 'date_type' ];
            }

            if ( isset( $condition[ 'current' ] ) ) {
                $hash_args[ 'current' ] = $condition[ 'current' ];
            }

            if ( isset( $condition[ 'date_offset' ] ) ) {
                $hash_args[ 'date_offset' ] = $condition[ 'date_offset' ];
            }

            return md5( wp_json_encode( $hash_args ) );
        }

    }

    new WOOPCD_PartialCOD_Conditions_Customer_Value();
}