<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WOOPCD_PartialCOD_Conditions_Customer' ) ) {

    class WOOPCD_PartialCOD_Conditions_Customer {

        public function __construct() {

            add_filter( 'woopcd_partialcod/validate-users-condition', array( $this, 'validate_users' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-logged_in_user-condition', array( $this, 'validate_logged_in_user' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-user_roles-condition', array( $this, 'validate_user_roles' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-user_caps-condition', array( $this, 'validate_user_caps' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-user_meta-condition', array( $this, 'validate_user_meta' ), 10, 2 );
        }

        public function validate_users( $condition, $cart_data ) {

            if ( !isset( $condition[ 'user_emails' ] ) ) {
                return false;
            }

            $rule_user_emails = $condition[ 'user_emails' ];

            if ( !count( $rule_user_emails ) ) {
                return false;
            }


            $user_email = WOOPCD_PartialCOD_Customer_Util::get_user_email( $cart_data );

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value_list( $user_email, $rule_user_emails, $rule_compare );
        }

        public function validate_logged_in_user( $condition, $cart_data ) {

            $rule_is_logged_in = $condition[ 'is_logged_in' ];

            $is_logged_in = WOOPCD_PartialCOD_Customer_Util::get_is_logged_in( $cart_data );

            return WOOPCD_PartialCOD_Validation_Util::validate_yes_no( $is_logged_in, $rule_is_logged_in );
        }

        public function validate_user_roles( $condition, $cart_data ) {

            if ( !isset( $condition[ 'user_roles' ] ) ) {
                return false;
            }

            $rule_user_roles = $condition[ 'user_roles' ];

            if ( !count( $rule_user_roles ) ) {
                return false;
            }


            $user_roles = WOOPCD_PartialCOD_Customer_Util::get_user_roles( $cart_data );

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_list_list( $user_roles, $rule_user_roles, $rule_compare );
        }

        public function validate_user_caps( $condition, $cart_data ) {

            if ( !isset( $condition[ 'user_caps' ] ) ) {
                return false;
            }

            $rule_user_caps = $condition[ 'user_caps' ];

            if ( !count( $rule_user_caps ) ) {
                return false;
            }

            $user_caps = WOOPCD_PartialCOD_Customer_Util::get_user_caps($cart_data);


            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_list_list( $user_caps, $rule_user_caps, $rule_compare );
        }

        public function validate_user_meta( $condition, $cart_data ) {

            if ( !isset( $condition[ 'meta_key' ] ) ) {
                return false;
            }


            $rule_meta_key = $condition[ 'meta_key' ];

            if ( $rule_meta_key == '' ) {
                return false;
            }

            $rule_yes_no = 'no';

            if ( isset( $condition[ 'yes_no' ] ) && !empty( $condition[ 'yes_no' ] ) ) {
                $rule_yes_no = $condition[ 'yes_no' ];
            }

            $rule_meta_value = '';

            if ( isset( $condition[ 'meta_value' ] ) ) {
                $rule_meta_value = $condition[ 'meta_value' ];
            }

            $meta_value = WOOPCD_PartialCOD_Customer_Util::get_user_meta( $cart_data, $rule_meta_key, array() );

            if ( is_array( $meta_value ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];
            return WOOPCD_PartialCOD_Validation_Util::validate_value( $rule_compare, $meta_value, $rule_meta_value, $rule_yes_no );
        }

    }

    new WOOPCD_PartialCOD_Conditions_Customer();
}
