<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WOOPCD_PartialCOD_Conditions_Purchase_History' ) ) {

    class WOOPCD_PartialCOD_Conditions_Purchase_History {

        public function __construct() {

            add_filter( 'woopcd_partialcod/validate-purchased_products-condition', array( $this, 'validate_purchased_products' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-purchased_variations-condition', array( $this, 'validate_purchased_variations' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-purchased_categories-condition', array( $this, 'validate_purchased_categories' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-purchased_tags-condition', array( $this, 'validate_purchased_tags' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-purchased_attributes-condition', array( $this, 'validate_purchased_attributes' ), 10, 2 );
        }

        public function validate_purchased_products( $condition, $cart_data ) {

            $rule_date_type = $condition[ 'date_type' ];


            $rule_compare = $condition[ 'all_time_compare' ];

            if ( $rule_date_type != 'all_time' && $rule_date_type != '' ) {
                $rule_compare = $condition[ 'compare' ];
            }

            $rule_product_slugs = '';

            if ( isset( $condition[ 'all_time_product_slugs' ] ) ) {
                $rule_product_slugs = $condition[ 'all_time_product_slugs' ];
            }

            if ( $rule_date_type != 'all_time' && $rule_date_type != '' ) {

                $rule_product_slugs = '';

                if ( isset( $condition[ 'product_slugs' ] ) ) {
                    $rule_product_slugs = $condition[ 'product_slugs' ];
                }
            }


            if ( $rule_product_slugs == '' ) {
                return false;
            }

            $rule_product_ids = WOOPCD_PartialCOD_Util::get_product_ids_by_slugs( $rule_product_slugs );

            $from_date = WOOPCD_PartialCOD_DateTime_Util::get_date_from_args( $condition );

            $hash_key = $this->get_hash_key( $condition );

            $product_ids = WOOPCD_PartialCOD_Customer_Util::get_purchased_product_ids( $cart_data, $from_date, $hash_key );

            if ( count( $product_ids ) == 0 ) {
                return false;
            }

            return WOOPCD_PartialCOD_Validation_Util::validate_list_list( $product_ids, $rule_product_ids, $rule_compare );
        }

        public function validate_purchased_variations( $condition, $cart_data ) {

            $rule_date_type = $condition[ 'date_type' ];

            $rule_compare = $condition[ 'all_time_compare' ];

            if ( $rule_date_type != 'all_time' && $rule_date_type != '' ) {
                $rule_compare = $condition[ 'compare' ];
            }

            $rule_variation_slugs = '';

            if ( isset( $condition[ 'all_time_variation_slugs' ] ) ) {
                $rule_variation_slugs = $condition[ 'all_time_variation_slugs' ];
            }

            if ( $rule_date_type != 'all_time' && $rule_date_type != '' ) {

                $rule_variation_slugs = '';

                if ( isset( $condition[ 'variation_slugs' ] ) ) {
                    $rule_variation_slugs = $condition[ 'variation_slugs' ];
                }
            }

            if ( $rule_variation_slugs == '' ) {
                return false;
            }

            $rule_variation_ids = WOOPCD_PartialCOD_Util::get_variation_ids_by_slugs( $rule_variation_slugs );

            $from_date = WOOPCD_PartialCOD_DateTime_Util::get_date_from_args( $condition );

            $hash_key = $this->get_hash_key( $condition );

            $variation_ids = WOOPCD_PartialCOD_Customer_Util::get_purchased_variation_ids( $cart_data, $from_date, $hash_key );

            if ( count( $variation_ids ) == 0 ) {
                return false;
            }

            return WOOPCD_PartialCOD_Validation_Util::validate_list_list( $variation_ids, $rule_variation_ids, $rule_compare );
        }

        public function validate_purchased_categories( $condition, $cart_data ) {

            $rule_date_type = $condition[ 'date_type' ];

            $rule_compare = $condition[ 'all_time_compare' ];

            if ( $rule_date_type != 'all_time' && $rule_date_type != '' ) {
                $rule_compare = $condition[ 'compare' ];
            }

            $rule_category_slugs = '';

            if ( isset( $condition[ 'all_time_category_slugs' ] ) ) {
                $rule_category_slugs = $condition[ 'all_time_category_slugs' ];
            }

            if ( $rule_date_type != 'all_time' && $rule_date_type != '' ) {

                $rule_category_slugs = '';

                if ( isset( $condition[ 'category_slugs' ] ) ) {
                    $rule_category_slugs = $condition[ 'category_slugs' ];
                }
            }

            if ( $rule_category_slugs == '' ) {
                return false;
            }


            $rule_category_ids = WOOPCD_PartialCOD_Util::get_product_term_ids_by_slugs( $rule_category_slugs, 'product_cat' );

            $from_date = WOOPCD_PartialCOD_DateTime_Util::get_date_from_args( $condition );

            $hash_key = $this->get_hash_key( $condition );

            $category_ids = WOOPCD_PartialCOD_Customer_Util::get_purchased_term_ids( $cart_data, $from_date, 'product_cat', $hash_key );

            if ( count( $category_ids ) == 0 ) {
                return false;
            }

            return WOOPCD_PartialCOD_Validation_Util::validate_list_list( $category_ids, $rule_category_ids, $rule_compare );
        }

        public function validate_purchased_tags( $condition, $cart_data ) {

            $rule_date_type = $condition[ 'date_type' ];

            $rule_compare = $condition[ 'all_time_compare' ];

            if ( $rule_date_type != 'all_time' && $rule_date_type != '' ) {
                $rule_compare = $condition[ 'compare' ];
            }

            $rule_tag_slugs = '';

            if ( isset( $condition[ 'all_time_tag_slugs' ] ) ) {
                $rule_tag_slugs = $condition[ 'all_time_tag_slugs' ];
            }

            if ( $rule_date_type != 'all_time' && $rule_date_type != '' ) {

                $rule_tag_slugs = '';

                if ( isset( $condition[ 'tag_slugs' ] ) ) {
                    $rule_tag_slugs = $condition[ 'tag_slugs' ];
                }
            }

            if ( $rule_tag_slugs == '' ) {
                return false;
            }


            $rule_tag_ids = WOOPCD_PartialCOD_Util::get_product_term_ids_by_slugs( $rule_tag_slugs, 'product_tag' );

            $from_date = WOOPCD_PartialCOD_DateTime_Util::get_date_from_args( $condition );

            $hash_key = $this->get_hash_key( $condition );

            $tag_ids = WOOPCD_PartialCOD_Customer_Util::get_purchased_term_ids( $cart_data, $from_date, 'product_tag', $hash_key );

            if ( count( $tag_ids ) == 0 ) {
                return false;
            }

            return WOOPCD_PartialCOD_Validation_Util::validate_list_list( $tag_ids, $rule_tag_ids, $rule_compare );
        }

        public function validate_purchased_attributes( $condition, $cart_data ) {

            $rule_date_type = $condition[ 'date_type' ];

            $rule_compare = $condition[ 'all_time_compare' ];

            if ( $rule_date_type != 'all_time' && $rule_date_type != '' ) {
                $rule_compare = $condition[ 'compare' ];
            }

            $rule_attribute_slugs = '';

            if ( isset( $condition[ 'all_time_attribute_slugs' ] ) ) {
                $rule_attribute_slugs = $condition[ 'all_time_attribute_slugs' ];
            }

            if ( $rule_date_type != 'all_time' && $rule_date_type != '' ) {

                $rule_attribute_slugs = '';

                if ( isset( $condition[ 'attribute_slugs' ] ) ) {
                    $rule_attribute_slugs = $condition[ 'attribute_slugs' ];
                }
            }

            if ( $rule_attribute_slugs == '' ) {
                return false;
            }

            $rule_attribute_ids = WOOPCD_PartialCOD_Util::get_attribute_ids_by_slugs( $rule_attribute_slugs );

            $from_date = WOOPCD_PartialCOD_DateTime_Util::get_date_from_args( $condition );

            $hash_key = $this->get_hash_key( $condition );

            $attribute_ids = WOOPCD_PartialCOD_Customer_Util::get_purchased_attribute_ids( $cart_data, $from_date, $hash_key );

            if ( count( $attribute_ids ) == 0 ) {
                return false;
            }

            return WOOPCD_PartialCOD_Validation_Util::validate_list_list( $attribute_ids, $rule_attribute_ids, $rule_compare );
        }

        private function get_hash_key( $condition ) {

            $hash_args = array();

            if ( isset( $condition[ 'date_type' ] ) ) {
                $hash_args[ 'date_type' ] = $condition[ 'date_type' ];
            }

            if ( isset( $condition[ 'current' ] ) ) {
                $hash_args[ 'current' ] = $condition[ 'current' ];
            }

            if ( isset( $condition[ 'date_offset' ] ) ) {
                $hash_args[ 'date_offset' ] = $condition[ 'date_offset' ];
            }

            return md5( wp_json_encode( $hash_args ) );
        }

    }

    new WOOPCD_PartialCOD_Conditions_Purchase_History();
}