<?php

if (!defined('ABSPATH')) {
    exit;
}


if (!class_exists('WOOPCD_PartialCOD_Premium_Cart_Discounts_Engine')) {

    class WOOPCD_PartialCOD_Premium_Cart_Discounts_Engine {

        private static $instance = null;

        private static function get_instance() {
            if (null == self::$instance) {
                self::$instance = new self();
            }
            return self::$instance;
        }

        public static function can_apply_rule($rule_head, $cart_data) {

            if ('if_others' == $rule_head['apply_mode'] && !isset($cart_data['discounts'])) {
                return false;
            }

            if ('if_no_others' == $rule_head['apply_mode'] && isset($cart_data['discounts'])) {
                return false;
            }

            if ('first' == $rule_head['settings']['mode'] && isset($cart_data['discounts'])) {
                return false;
            }

            if (true == self::get_instance()->get_reached_limit($rule_head['settings'], $cart_data)) {
                return false;
            }

            return true;
        }

        public static function add_rule_discount($cart_data, $rule_discount, $rule_head) {

            $s_mode = $rule_head['settings']['mode'];

            // add last valid rules or only rule if valid
            if ('last' == $s_mode || 'only_this' == $rule_head['apply_mode']) {
                $cart_data = self::get_instance()->force_discount_rule($cart_data, $rule_discount, $rule_head);
                return $cart_data;
            }

            // add rules with higher discounts only
            if ('higher' == $s_mode) {
                if (self::get_instance()->get_is_higher($cart_data, $rule_discount)) {
                    $cart_data = self::get_instance()->force_discount_rule($cart_data, $rule_discount, $rule_head);
                }
                return $cart_data;
            }

            // add rules with lower discounts only
            if ('lower' == $s_mode) {
                if (self::get_instance()->get_is_lower($cart_data, $rule_discount)) {
                    $cart_data = self::get_instance()->force_discount_rule($cart_data, $rule_discount, $rule_head);
                }
                return $cart_data;
            }

            // add rule as usual
            $cart_data['discounts'][$rule_head['rule_id']] = self::get_instance()->get_discount_max($rule_discount, $rule_head, $cart_data);




            return $cart_data;
        }

        private function get_reached_limit($settings, $cart_data) {
            if ('no' == $settings['max_discount_type']) {
                return false;
            }

            $limit = $this->get_limit($settings, $cart_data);

            $cart_discount = 0;

            if (isset($cart_data['discounts'])) {
                foreach ($cart_data['discounts'] as $discount) {
                    $cart_discount += $discount['amount'];
                }
            }

            if ($cart_discount >= $limit && $limit > 0) {

                return true;
            }

            return false;
        }

        private function force_discount_rule($cart_data, $rule_discount, $rule_head) {

            if (isset($cart_data['discounts'])) {
                unset($cart_data['discounts']);
            }

            $cart_data['discounts'][$rule_head['rule_id']] = $this->get_discount_max($rule_discount, $rule_head, $cart_data);

            return $cart_data;
        }

        private function get_discount_max($discount_amount, $rule_head, $cart_data) {

            $total_discount = 0;

            if (isset($cart_data['discounts'])) {
                foreach ($cart_data['discounts'] as $key => $disc) {
                    $total_discount += $disc['amount'];
                }
            }

            // adjust discount based on max discount by rule
            $max_amount = $this->get_rule_limit($rule_head['rule_limit'], $cart_data);

            if ($discount_amount['amount'] > $max_amount - $total_discount && $max_amount > 0) {
                $discount_amount = $this->get_adjusted_discount($discount_amount, $total_discount, $max_amount);
            }

            // adjust discount based on global max discounts
            $max_amount = $this->get_limit($rule_head['settings'], $cart_data);

            if ($discount_amount['amount'] > $max_amount - $total_discount && $max_amount > 0) {
                $discount_amount = $this->get_adjusted_discount($discount_amount, $total_discount, $max_amount);
            }


            return $discount_amount;
        }

        private function get_adjusted_discount($discount_amount, $total_discount, $max_amount) {

            $r_disc = $max_amount - $total_discount;

            $r_disc_tax = ($r_disc / $discount_amount['amount']) * $discount_amount['amount_tax'];

            foreach ($discount_amount['taxes'] as $key => $tax) {
                $tax = ($r_disc / $discount_amount['amount']) * $tax;
                $discount_amount['taxes'][$key] = WOOPCD_PartialCOD_Util::round_num($tax, wc_get_price_decimals());
            }

            $discount_amount['amount'] = $r_disc;
            $discount_amount['amount_tax'] = array_sum($discount_amount['taxes']);

            return $discount_amount;
        }

        private function get_rule_limit($rule_limit_args, $cart_data) {
            if ('no' == $rule_limit_args['amount_type']) {
                return 0;
            }

            $max_amount = $rule_limit_args['amount'];
            if (!is_numeric($max_amount)) {
                $max_amount = 0;
            }

            if ('fixed_amount' == $rule_limit_args['amount_type']) {
                $limit = $max_amount;
                return $limit;
            }

            if ('per_amount' == $rule_limit_args['amount_type']) {

                $args = array(
                    'module' => 'cart-discounts',
                    'option_id' => $rule_limit_args['base_on']
                );

                $cart_totals = WOOPCD_PartialCOD_Cart_Total_Types::get_totals($args, $cart_data);
                if ($cart_totals > 0) {
                    $limit = ($max_amount / 100) * $cart_totals;
                }
                return $limit;
            }

            return 0;
        }

        private function get_limit($settings, $cart_data) {


            if ('no' == $settings['max_discount_type']) {
                return 0;
            }

            $max_amount = $settings['max_discount_amount'];
            if (!is_numeric($max_amount)) {
                $max_amount = 0;
            }

            if ('fixed_amount' == $settings['max_discount_type']) {
                $limit = $max_amount;
                return $limit;
            }

            if ('per_amount' == $settings['max_discount_type']) {
                $args = array(
                    'module' => 'cart-discounts',
                    'option_id' => $settings['base_on']
                );
                $cart_totals = WOOPCD_PartialCOD_Cart_Total_Types::get_totals($args, $cart_data);
                if ($cart_totals > 0) {
                    $limit = ($max_amount / 100) * $cart_totals;
                }
                return $limit;
            }
            return 0;
        }

        private function get_is_higher($cart_data, $rule_discount) {
            $d_value = 0;
            if (!isset($cart_data['discounts'])) {
                return true;
            }
            foreach ($cart_data['discounts'] as $key => $disc) {
                if ($disc['amount'] > $d_value) {
                    $d_value = $disc['amount'];
                }
            }

            return ($rule_discount['amount'] > $d_value);
        }

        private function get_is_lower($cart_data, $rule_discount) {
            $d_value = 0;
            if (!isset($cart_data['discounts'])) {
                return true;
            }

            foreach ($cart_data['discounts'] as $key => $disc) {
                if ($d_value < $disc['amount']) {
                    $d_value = $disc['amount'];
                }
            }
            return ($rule_discount['amount'] < $d_value);
        }

    }

}