<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WOOPCD_PartialCOD_Premium_Cart_Fees_Engine' ) ) {

    class WOOPCD_PartialCOD_Premium_Cart_Fees_Engine {

        private static $instance = null;

        private static function get_instance() {
            if ( null == self::$instance ) {
                self::$instance = new self();
            }
            return self::$instance;
        }

        public static function can_apply_rule( $rule_head, $cart_data ) {

            if ( 'if_others' == $rule_head[ 'apply_mode' ] && !isset( $cart_data[ 'fees' ] ) ) {
                return false;
            }

            if ( 'if_no_others' == $rule_head[ 'apply_mode' ] && isset( $cart_data[ 'fees' ] ) ) {
                return false;
            }

            if ( 'first' == $rule_head[ 'settings' ][ 'mode' ] && isset( $cart_data[ 'fees' ] ) ) {
                return false;
            }

            if ( true == self::get_instance()->get_reached_limit( $rule_head[ 'settings' ], $cart_data ) ) {
                return false;
            }

            return true;
        }

        public static function add_rule_fee( $cart_data, $rule_fee, $rule_head ) {

            $s_mode = $rule_head[ 'settings' ][ 'mode' ];

            // add last valid rules or only rule if valid
            if ( 'last' == $s_mode || 'only_this' == $rule_head[ 'apply_mode' ] ) {
                $cart_data = self::get_instance()->force_fee_rule( $cart_data, $rule_fee, $rule_head );
                return $cart_data;
            }

            // add rules with higher fees only
            if ( 'higher' == $s_mode ) {
                if ( self::get_instance()->get_is_higher( $cart_data, $rule_fee ) ) {
                    $cart_data = self::get_instance()->force_fee_rule( $cart_data, $rule_fee, $rule_head );
                }
                return $cart_data;
            }

            // add rules with lower fees only
            if ( 'lower' == $s_mode ) {
                if ( self::get_instance()->get_is_lower( $cart_data, $rule_fee ) ) {
                    $cart_data = self::get_instance()->force_fee_rule( $cart_data, $rule_fee, $rule_head );
                }
                return $cart_data;
            }

            // add rule as usual
            $cart_data[ 'fees' ][ $rule_head[ 'rule_id' ] ] = self::get_instance()->get_fee_max( $rule_fee, $rule_head, $cart_data );


            return $cart_data;
        }

        private function get_reached_limit( $settings, $cart_data ) {
            if ( 'no' == $settings[ 'max_fee_type' ] ) {
                return false;
            }

            $limit = $this->get_limit( $settings, $cart_data );

            $cart_fee = 0;

            if ( isset( $cart_data[ 'fees' ] ) ) {
                foreach ( $cart_data[ 'fees' ] as $fee ) {
                    $cart_fee += $fee[ 'amount' ];
                }
            }

            if ( $cart_fee >= $limit && $limit > 0 ) {

                return true;
            }

            return false;
        }

        private function force_fee_rule( $cart_data, $rule_fee, $rule_head ) {

            if ( isset( $cart_data[ 'fees' ] ) ) {
                unset( $cart_data[ 'fees' ] );
            }

            $cart_data[ 'fees' ][ $rule_head[ 'rule_id' ] ] = $this->get_fee_max( $rule_fee, $rule_head, $cart_data );

            return $cart_data;
        }

        private function get_fee_max( $fee_amount, $rule_head, $cart_data ) {

            $total_fee = 0;

            if ( isset( $cart_data[ 'fees' ] ) ) {
                foreach ( $cart_data[ 'fees' ] as $key => $disc ) {
                    $total_fee += $disc[ 'amount' ];
                }
            }


            // adjust fee based on max fee by rule
            $max_amount = $this->get_rule_limit( $rule_head[ 'rule_limit' ], $cart_data );

            if ( $fee_amount[ 'amount' ] > $max_amount - $total_fee && $max_amount > 0 ) {
                $fee_amount = $this->get_adjusted_fee( $fee_amount, $total_fee, $max_amount );
            }

            // adjust fee based on global max fees
            $max_amount = $this->get_limit( $rule_head[ 'settings' ], $cart_data );

            if ( $fee_amount[ 'amount' ] > $max_amount - $total_fee && $max_amount > 0 ) {
                $fee_amount = $this->get_adjusted_fee( $fee_amount, $total_fee, $max_amount );
            }


            return $fee_amount;
        }

        private function get_adjusted_fee( $fee_amount, $total_fee, $max_amount ) {

            $r_disc = $max_amount - $total_fee;

            $r_disc_tax = ($r_disc / $fee_amount[ 'amount' ]) * $fee_amount[ 'amount_tax' ];

            foreach ( $fee_amount[ 'taxes' ] as $key => $tax ) {
                $tax = ($r_disc / $fee_amount[ 'amount' ]) * $tax;
                $fee_amount[ 'taxes' ][ $key ] = WOOPCD_PartialCOD_Util::round_num( $tax, wc_get_price_decimals() );
            }



            $fee_amount[ 'amount' ] = $r_disc;
            $fee_amount[ 'amount_tax' ] = array_sum( $fee_amount[ 'taxes' ] );


            return $fee_amount;
        }

        private function get_rule_limit( $rule_limit_args, $cart_data ) {
            if ( 'no' == $rule_limit_args[ 'amount_type' ] ) {
                return 0;
            }

            $max_amount = $rule_limit_args[ 'amount' ];
            if ( !is_numeric( $max_amount ) ) {
                $max_amount = 0;
            }

            if ( 'fixed_amount' == $rule_limit_args[ 'amount_type' ] ) {
                $limit = $max_amount;
                return $limit;
            }

            if ( 'per_amount' == $rule_limit_args[ 'amount_type' ] ) {

                $args = array(
                    'module' => 'cart-fees',
                    'option_id' => $rule_limit_args[ 'base_on' ]
                );

                $cart_totals = WOOPCD_PartialCOD_Cart_Total_Types::get_totals( $args, $cart_data );
                if ( $cart_totals > 0 ) {
                    $limit = ($max_amount / 100) * $cart_totals;
                }

                return $limit;
            }

            return 0;
        }

        private function get_limit( $settings, $cart_data ) {


            if ( 'no' == $settings[ 'max_fee_type' ] ) {
                return 0;
            }

            $max_amount = $settings[ 'max_fee_amount' ];
            if ( !is_numeric( $max_amount ) ) {
                $max_amount = 0;
            }

            if ( 'fixed_amount' == $settings[ 'max_fee_type' ] ) {
                $limit = $max_amount;
                return $limit;
            }

            if ( 'per_amount' == $settings[ 'max_fee_type' ] ) {
                $args = array(
                    'module' => 'cart-fees',
                    'option_id' => $settings[ 'base_on' ]
                );
                $cart_totals = WOOPCD_PartialCOD_Cart_Total_Types::get_totals( $args, $cart_data );
                if ( $cart_totals > 0 ) {
                    $limit = ($max_amount / 100) * $cart_totals;
                }

                return $limit;
            }
            return 0;
        }

        private function get_is_higher( $cart_data, $rule_fee ) {
            $d_value = 0;
            if ( !isset( $cart_data[ 'fees' ] ) ) {
                return true;
            }
            foreach ( $cart_data[ 'fees' ] as $key => $disc ) {
                if ( $disc[ 'amount' ] > $d_value ) {
                    $d_value = $disc[ 'amount' ];
                }
            }

            return ($rule_fee[ 'amount' ] > $d_value);
        }

        private function get_is_lower( $cart_data, $rule_fee ) {
            $d_value = 0;
            if ( !isset( $cart_data[ 'fees' ] ) ) {
                return true;
            }

            foreach ( $cart_data[ 'fees' ] as $key => $disc ) {
                if ( $d_value < $disc[ 'amount' ] ) {
                    $d_value = $disc[ 'amount' ];
                }
            }
            return ($rule_fee[ 'amount' ] < $d_value);
        }

    }

}