<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WOOPCD_PartialCOD_Order_Activity' ) ) {
    WOOPCD_PartialCOD_Main::required_paths( dirname( __FILE__ ), array( 'order-activities.php' ) );

    class WOOPCD_PartialCOD_Order_Activity {

        private $order_activity_engine;
        private $delay_activity_hook;
        private $delay_key_prefix;

        public function __construct() {

            $this->order_activity_engine = new WOOPCD_PartialCOD_Order_Activity_Engine();
            $this->delay_activity_hook = 'partialcod-cron/delay-activity';
            $this->delay_key_prefix = 'woopcd_partialcod_activities_';

            add_filter( 'woopcd_partialcod/process-order-data', array( $this->order_activity_engine, 'process_order_data' ), 20, 1 );
            
            add_action($this->delay_activity_hook, array( $this, 'run_activities' ), 10 );
        }

        public function process_activities( $order_id, $order_data ) {

            $activity_list = $this->get_activity_list( $order_data );

            if ( !isset( $activity_list[ 'list' ] ) ) {
                return;
            }

            $acivities = array(
                'order_id' => $order_id,
                'list' => $activity_list[ 'list' ]
            );

            if ( 'yes' == $activity_list[ 'delay_activities' ] ) {

                $timer_key = $order_id . current_time( 'timestamp' );

                $option_key = $this->delay_key_prefix . $timer_key;

                update_option( $option_key, $acivities );

                $timestamp = $this->get_activity_time_schedule( $activity_list );

                $next_activities = wp_get_scheduled_event( $this->delay_activity_hook, array( $timer_key ) );

                if ( !$next_activities ) {
                    wp_schedule_single_event( $timestamp, $this->delay_activity_hook, array( $timer_key ) );
                }
            } else {

                $this->trigger_activity_list( $activity_list[ 'list' ], $order_id );
            }
        }

        public function run_activities( $timer_key ) {

            $option_key = $this->delay_key_prefix . $timer_key;

            $activity_list = get_option( $option_key, array() );

            if ( !count( $activity_list ) ) {
                return;
            }

            $this->trigger_activity_list( $activity_list[ 'list' ], $activity_list[ 'order_id' ] );

            delete_option( $option_key );
        }

        public function trigger_activity_list( $activities, $order_id ) {

            foreach ( $activities as $activity_id => $activity ) {

                // allows other plugins to modify option data before applying
                if ( has_filter( 'woopcd_partialcod/activity' ) ) {
                    $activity = apply_filters( 'woopcd_partialcod/activity', $activity, $activity_id, $order_id );
                }

                // allows other plugins to apply their stuff
                $activity_type = $activity[ 'activity_type' ];
                do_action( 'woopcd_partialcod/apply-' . $activity_type . '-activity', $order_id, $activity, $activity_id );
            }
        }

        private function get_activity_list( $order_data ) {

            $activity_list = array();
            if ( isset( $order_data[ 'activities' ] ) ) {

                foreach ( $order_data[ 'activities' ] as $rule_activity_list ) {
                    $activity_list = $this->get_activity_list_from_rule( $activity_list, $rule_activity_list );
                }
            }
            return $activity_list;
        }

        private function get_activity_list_from_rule( $activity_list, $rule_activity_list ) {

            foreach ( $rule_activity_list as $key => $activity ) {
                $activity_list[ $key ] = $activity;
            }

            return $activity_list;
        }

        private function get_activity_time_schedule( $activity_list ) {

            $seconds = current_time( 'timestamp' );

            if ( !isset( $activity_list[ 'timer' ] ) ) {
                return $seconds;
            }

            if ( !isset( $activity_list[ 'timer_mode' ] ) ) {
                return $seconds;
            }

            $timer = $activity_list[ 'timer' ];

            if ( !is_numeric( $timer ) ) {
                return $seconds;
            }

            $timer_mode = $activity_list[ 'timer_mode' ];

            switch ( $timer_mode ) {
                case 'minutes':
                    return $seconds + (MINUTE_IN_SECONDS * $timer);

                case 'hours':
                    return $seconds + (HOUR_IN_SECONDS * $timer);

                case 'days':
                    return $seconds + (DAY_IN_SECONDS * $timer);

                case 'weeks':
                    return $seconds + (WEEK_IN_SECONDS * $timer);

                case 'months':
                    return $seconds + (MONTH_IN_SECONDS * $timer);

                default:
                    return $seconds;
            }
        }

    }

}




