<?php

if ( !class_exists( 'WOOPCD_PartialCOD_RiskFree_Cart_Total' ) ) {

    class WOOPCD_PartialCOD_RiskFree_Cart_Total {

        private $calculating = false;
        private $in_order_review = false;
        private $creating_order = false;

        public function __construct() {

            add_action( 'woocommerce_before_calculate_totals', array( $this, 'after_calculate_totals' ) );
            add_action( 'woocommerce_after_calculate_totals', array( $this, 'after_calculate_totals' ) );

            add_action( 'woocommerce_review_order_before_cart_contents', array( $this, 'before_order_review' ) );
            add_action( 'woocommerce_review_order_after_order_total', array( $this, 'after_order_review' ) );
            add_action( 'woocommerce_before_checkout_process', array( $this, 'before_checkout_process' ), 1 );
        }

        public function before_checkout_process() {

            $this->creating_order = true;
        }

        public function before_calculate_totals( $cart ) {

            $this->calculating = true;
        }

        public function after_calculate_totals( $cart ) {

            $this->calculating = false;
        }

        public function before_order_review() {

            $this->in_order_review = true;
        }

        public function after_order_review() {

            $this->in_order_review = false;
        }

        public function get_total( $total, $advance_info ) {

            if ( !$this->can_adjust_total() ) {

                return $total;
            }

            $partial_total = $this->get_partial_total( $advance_info );

            if ( $partial_total ) {

                return $partial_total;
            }

            return $total;
        }

        private function can_adjust_total() {

            if ( !is_checkout() ) {

                return false;
            }

            if ( $this->creating_order ) {

                return false;
            }

            if ( $this->calculating ) {

                return false;
            }

            if ( !apply_filters( 'woopcd_partialcod/can_adjust_cart_total', true ) ) {

                return false;
            }

            if ( $this->in_order_review ) {

                return false;
            }

            return true;
        }

        public function get_partial_total( $advance_info ) {

            if ( isset( $advance_info[ 'advance_pay' ] ) ) {

                return $advance_info[ 'advance_pay' ];
            }

            return false;
        }

    }

}

