<?php

if ( !class_exists( 'WOOPCD_PartialCOD_RiskFree_Subtotals' ) ) {

    class WOOPCD_PartialCOD_RiskFree_Subtotals {

        private $calculating = false;
        private $order_data_list = array();

        public function __construct() {
            add_action( 'woocommerce_order_before_calculate_totals', array( $this, 'before_order_calculate_totals' ), 10, 2 );
            add_action( 'woocommerce_order_after_calculate_totals', array( $this, 'after_order_calculate_totals' ), 10, 2 );


            //Adjust order totals
            add_filter( 'woocommerce_order_amount_item_subtotal', array( $this, 'order_amount_item_subtotal' ), 10, 5 );
            add_filter( 'woocommerce_order_amount_line_subtotal', array( $this, 'order_amount_line_subtotal' ), 10, 5 );
            add_filter( 'woocommerce_order_amount_item_total', array( $this, 'order_amount_item_total' ), 10, 5 );
            add_filter( 'woocommerce_order_amount_line_total', array( $this, 'order_amount_line_total' ), 10, 5 );
            add_filter( 'woocommerce_order_amount_item_tax', array( $this, 'order_amount_item_tax' ), 10, 4 );
            add_filter( 'woocommerce_order_amount_line_tax', array( $this, 'order_amount_line_tax' ), 10, 3 );
            add_filter( 'woocommerce_order_get_shipping_total', array( $this, 'get_totals' ), 10, 2 );
            add_filter( 'woocommerce_order_get_shipping_tax', array( $this, 'get_totals' ), 10, 2 );

            add_filter( 'woocommerce_order_get_subtotal', array( $this, 'get_totals' ), 10, 2 );

            add_filter( 'woocommerce_order_get_total_discount', array( $this, 'get_totals' ), 10, 2 );

            add_filter( 'woocommerce_order_item_get_amount', array( $this, 'get_item_totals' ), 10, 2 );
            add_filter( 'woocommerce_order_item_get_total', array( $this, 'get_item_totals' ), 10, 2 );
            add_filter( 'woocommerce_order_item_get_total_tax', array( $this, 'get_item_totals' ), 10, 2 );


            add_filter( 'woocommerce_order_get_total_tax', array( $this, 'get_order_total' ), 10, 2 );
            add_filter( 'woocommerce_order_get_total', array( $this, 'get_order_total' ), 10, 2 );
        }

        public function before_order_calculate_totals( $and_taxes, $order ) {
            $this->calculating = true;
        }

        public function after_order_calculate_totals( $and_taxes, $order ) {
            $this->calculating = false;
        }

        public function order_amount_item_subtotal( $subtotal, $order, $item, $inc_tax, $round ) {

            if ( $this->can_adjust( $order ) ) {
                return 0;
            }

            return $subtotal;
        }

        public function order_amount_line_subtotal( $subtotal, $order, $item, $inc_tax, $round ) {

            if ( $this->can_adjust( $order ) ) {
                return 0;
            }

            return $subtotal;
        }

        public function order_amount_item_total( $total, $order, $item, $inc_tax, $round ) {

            if ( $this->can_adjust( $order ) ) {
                return 0;
            }

            return $total;
        }

        public function order_amount_line_total( $total, $order, $item, $inc_tax, $round ) {

            if ( $this->can_adjust( $order ) ) {
                return 0;
            }

            return $total;
        }

        public function order_amount_item_tax( $tax, $item, $round, $order ) {

            if ( $this->can_adjust( $order ) ) {
                return 0;
            }

            return $tax;
        }

        public function order_amount_line_tax( $tax, $item, $order ) {

            if ( $this->can_adjust( $order ) ) {
                return 0;
            }

            return $tax;
        }

        public function get_item_totals( $totals, $item ) {

            $order = $item->get_order();

            if ( $this->can_adjust( $order ) ) {
                return 0;
            }

            return $totals;
        }

        public function get_totals( $totals, $order ) {

            if ( $this->can_adjust( $order ) ) {
                return 0;
            }

            return $totals;
        }

        public function get_order_total( $total, $order ) {

            if ( $this->can_adjust( $order ) ) {

                $order_data = $this->get_order_data( $order );

                if ( isset( $order_data[ 'advance_pay' ] ) ) {

                    return $order_data[ 'advance_pay' ];
                }
            }

            return $total;
        }
        
        private function can_adjust( $order ) {

            if ( is_admin() ) {
                return false;
            }

            if ( !$order ) {

                return false;
            }

            if ( !method_exists( $order, 'is_paid' ) ) {

                return false;
            }

            if ( $order->is_paid() ) {

                return false;
            }

            if ( $this->calculating ) {

                return false;
            }

            if ( is_order_received_page() ) {

                return false;
            }

            if ( is_account_page() ) {

                return false;
            }

            if ( WOOPCD_PartialCOD_Email::is_email() ) {

                return false;
            }

            if ( WOOPCD_PartialCOD_Order::get_is_db_order_total() ) {

                return false;
            }

            if ( !$this->is_risk_free( $order ) ) {

                return false;
            }

            return true;
        }

        private function is_risk_free( $order ) {
            $order_data = $this->get_order_data( $order );
            return (count( $order_data ) > 0);
        }

        private function get_order_data( $order ) {

            $order_id = $order->get_id();

            if ( isset( $this->order_data_list[ $order_id ] ) ) {

                return $this->order_data_list[ $order_id ];
            }

            $order_data = false;

            if ( $order ) {

                $order_data = $order->get_meta( 'woopcd_partialcod_riskfree', true );
            }

            if ( !$order_data ) {

                $this->order_data_list[ $order_id ] = array();

                return $this->order_data_list[ $order_id ];
            }

            $this->order_data_list[ $order_id ] = $order_data;

            return $this->order_data_list[ $order_id ];
        }

    }

}