<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WOOPCD_PartialCOD_RiskFree' ) ) {
    WOOPCD_PartialCOD_Main::required_paths( dirname( __FILE__ ), array( 'risk-free.php' ) );

    class WOOPCD_PartialCOD_RiskFree {

        private $order_data_list;
        private $riskfree_engine;
        private $riskfree_subtotals;
        private $riskfree_cart_total;

        public function __construct() {
            $this->order_data_list = array();
            $this->riskfree_engine = new WOOPCD_PartialCOD_RiskFree_Engine();
            $this->riskfree_subtotals = new WOOPCD_PartialCOD_RiskFree_Subtotals();
            $this->riskfree_cart_total = new WOOPCD_PartialCOD_RiskFree_Cart_Total();
            add_filter( 'woopcd_partialcod/process-cart-data', array( $this->riskfree_engine, 'process_cart_data' ), 30, 1 );
        }

        public function get_allowed_methods( $methods, $cart_data ) {

            if ( isset( $cart_data[ 'wc' ][ 'method_ids' ] ) ) {
                $this->maybe_clear_riskfree_select( array_keys( $methods ), $cart_data[ 'wc' ][ 'method_ids' ] );
            }
            $get_allowed_ids = $this->get_allowed_ids( $cart_data, $methods );

            // returns full list if riskfree not selected
            if ( count( $get_allowed_ids ) == 0 ) {
                return $this->maybe_update_chosen( $methods, $this->get_methods( $cart_data ) );
            }

            // filter methods based on allowed methods
            $keys = array_keys( $methods );
            foreach ( $keys as $key ) {
                if ( !in_array( $key, $get_allowed_ids ) ) {
                    unset( $methods[ $key ] );
                }
            }

            return $this->maybe_update_chosen( $methods, $this->get_methods( $cart_data ) );
        }

        private function maybe_clear_riskfree_select( $method_ids, $cart_method_ids ) {

            if ( !isset( $cart_method_ids[ 'riskfree_id' ] ) ) {

                return;
            }

            if ( !in_array( $cart_method_ids[ 'riskfree_id' ], $method_ids ) ) {

                WOOPCD_PartialCOD_Cart::set_session_data( 'rf_method_id', '' );
            }
        }

        public function apply_partial_payment( $cart, $cart_data ) {
            // To-Do: Maybe remove this later
            // get the selected partial payment method
            $selected_method = $this->get_selected_method( $cart_data );

            // adjusts cart totals pased on selected partial payment
            if ( isset( $selected_method[ 'advance_pay' ] ) ) {
                $cart_totals = $cart->get_totals();
                $cart_totals[ 'total' ] = $selected_method[ 'advance_pay' ];
                $cart->set_totals( $cart_totals );
            }
        }

        public function get_methods( $cart_data ) {
            $methods = array();

            foreach ( $this->get_riskfree_data( $cart_data ) as $data ) {
                $method = array(
                    'id' => $data[ 'method_id' ],
                    'is_selected' => $data[ 'is_selected' ],
                    'desc' => '',
                );


                if ( isset( $data[ 'desc' ] ) ) {
                    $method[ 'desc' ] = $this->prepare_description( $data );
                }


                $methods[] = $method;
            }


            return $methods;
        }

        public function get_advance_payment_info( $cart_data ) {

            $advanc_info = array();

            // Get the selected method
            $selected_method = $this->get_selected_method( $cart_data );
            if ( 0 == count( $selected_method ) ) {
                return $advanc_info;
            }

            //Get advance information from the selected method
            $advanc_info[ 'totals' ] = $selected_method[ 'totals' ];
            $advanc_info[ 'advance_pay' ] = $selected_method[ 'advance_pay' ];
            $advanc_info[ 'delivery_pay' ] = $selected_method[ 'delivery_pay' ];
            $advanc_info[ 'rule_id' ] = $selected_method[ 'rule_id' ];
            $advanc_info[ 'method_id' ] = $selected_method[ 'method_id' ];

            // Get partial payment texts
            $advance_text = WOOPCD_PartialCOD::get_option( 'riskfree_text',
                            array(
                                'advance_pay' => esc_html__( 'Partial Payment', 'woopcd-partialcod-pro' ),
                                'advance_method' => esc_html__( 'Partial Payment Method', 'woopcd-partialcod-pro' ),
                                'delivery_pay' => esc_html__( 'Remaining Amount', 'woopcd-partialcod-pro' )
                            )
            );

            $advanc_info[ 'advance_pay_text' ] = $advance_text[ 'advance_pay' ];
            $advanc_info[ 'advance_method_text' ] = $advance_text[ 'advance_method' ];
            $advanc_info[ 'delivery_pay_text' ] = $advance_text[ 'delivery_pay' ];


            //Allows other plugins to modify advance payment informations
            if ( has_filter( 'woopcd_partialcod/get-advance-payment-info' ) ) {
                return apply_filters( 'woopcd_partialcod/get-advance-payment-info', $advanc_info );
            }

            return $advanc_info;
        }

        public function add_order_data( $order_id, $cart_data ) {

            // Get the selected method
            $selected_method = $this->get_selected_method( $cart_data );
            if ( 0 == count( $selected_method ) ) {
                return;
            }

            $order_data = array(
                'advance_pay' => $selected_method[ 'advance_pay' ],
                'delivery_pay' => $selected_method[ 'delivery_pay' ],
                'rule_id' => $selected_method[ 'rule_id' ],
                'method_id' => $selected_method[ 'method_id' ],
            );

            $adv_methods = WC()->payment_gateways->get_available_payment_gateways();
            if ( isset( $adv_methods[ $selected_method[ 'method_id' ] ] ) ) {
                $order_data[ 'method_title' ] = $adv_methods[ $selected_method[ 'method_id' ] ]->title;
            }

            $order = WOOPCD_PartialCOD_Order::get_order( $order_id, false );

            if ( !$order ) {

                return;
            }

            $order->update_meta_data( 'woopcd_partialcod_riskfree', $order_data );

            $order->save();
        }

        public function get_cart_total( $total, $advance_info ) {

            return $this->riskfree_cart_total->get_total( $total, $advance_info );
        }

        public function get_order_total( $total, $order_id ) {

            // Get order data
            $order_data = $this->get_order_data( $order_id );

            // Get order advance payment total
            if ( isset( $order_data[ 'advance_pay' ] ) ) {
                $total = $order_data[ 'advance_pay' ];
            }

            return $total;
        }

        public function get_formatted_order_total( $formatted_total, $order, $tax_display, $display_refunded ) {
            if ( !$order ) {
                return $formatted_total;
            }

            $formatted_total = wc_price( WOOPCD_PartialCOD_Order::get_db_order_total( $order ), array( 'currency' => $order->get_currency() ) );
            $order_total = WOOPCD_PartialCOD_Order::get_db_order_total( $order );
            $total_refunded = $order->get_total_refunded();
            $tax_string = '';

            // Tax for inclusive prices.
            if ( wc_tax_enabled() && 'incl' === $tax_display ) {
                $tax_string_array = array();
                $tax_totals = $order->get_tax_totals();

                if ( 'itemized' === get_option( 'woocommerce_tax_total_display' ) ) {
                    foreach ( $tax_totals as $code => $tax ) {
                        $tax_amount = ( $total_refunded && $display_refunded ) ? wc_price( WC_Tax::round( $tax->amount - $order->get_total_tax_refunded_by_rate_id( $tax->rate_id ) ), array( 'currency' => $order->get_currency() ) ) : $tax->formatted_amount;
                        $tax_string_array[] = sprintf( '%s %s', $tax_amount, $tax->label );
                    }
                } elseif ( !empty( $tax_totals ) ) {
                    $tax_amount = ( $total_refunded && $display_refunded ) ? $order->get_total_tax() - $order->get_total_tax_refunded() : $order->get_total_tax();
                    $tax_string_array[] = sprintf( '%s %s', wc_price( $tax_amount, array( 'currency' => $order->get_currency() ) ), WC()->countries->tax_or_vat() );
                }

                if ( !empty( $tax_string_array ) ) {
                    /* translators: %s: taxes */
                    $tax_string = ' <small class="includes_tax">' . sprintf( esc_html__( '(includes %s)', 'woocommerce' ), implode( ', ', $tax_string_array ) ) . '</small>';
                }
            }

            if ( $total_refunded && $display_refunded ) {
                $formatted_total = '<del>' . wp_strip_all_tags( $formatted_total ) . '</del> <ins>' . wc_price( $order_total - $total_refunded, array( 'currency' => $this->get_currency() ) ) . $tax_string . '</ins>';
            } else {
                $formatted_total .= $tax_string;
            }

            /**
             * Filter PartialCOD formatted order total.
             *
             * @param string   $formatted_total  Total to display.
             * @param WC_Order $order            Order data.
             * @param string   $tax_display      Type of tax display.
             * @param bool     $display_refunded If should include refunded value.
             */
            return apply_filters( 'woopcd_partialcod/get_formatted_order_total', $formatted_total, $order, $tax_display, $display_refunded );
        }

        public function get_order_item_totals( $total_rows, $order ) {

            // Get order data
            $order_data = $this->get_order_data( $order->get_id() );

            // Apply order item details
            if ( count( $order_data ) ) {

                // Get advance payment texts
                $advance_text = WOOPCD_PartialCOD::get_option( 'riskfree_text',
                                array(
                                    'advance_pay' => esc_html__( 'Partial Payment', 'woopcd-partialcod-pro' ),
                                    'advance_method' => esc_html__( 'Partial Payment Method', 'woopcd-partialcod-pro' ),
                                    'delivery_pay' => esc_html__( 'Remaining Amount', 'woopcd-partialcod-pro' )
                                )
                );
               
                $advance_text[ 'advance_pay' ] = apply_filters( 'woopcd_partialcod/get-order-advance_pay-label', $advance_text[ 'advance_pay' ] . ':' );
                $advance_text[ 'advance_method' ] = apply_filters( 'woopcd_partialcod/get-order-advance-method-label', $advance_text[ 'advance_method' ] . ':' );
                $advance_text[ 'delivery_pay' ] = apply_filters( 'woopcd_partialcod/get-order-delivery-pay-label', $advance_text[ 'delivery_pay' ] . ':' );


                $riskfree_rows = array();

                foreach ( $total_rows as $key => $total_row ) {
                    if ( 'order_total' == $key || 'payment_method' == $key ) {
                        continue;
                    }
                    $riskfree_rows[ $key ] = $total_row;
                }


                if ( is_checkout_pay_page() ) {

                    $riskfree_rows[ 'order_total' ] = $total_rows[ 'order_total' ];

                    $riskfree_rows[ 'advance_pay' ] = array(
                        'label' => $advance_text[ 'advance_pay' ],
                        'value' => wc_price( $order_data[ 'advance_pay' ], array( 'currency' => $order->get_currency() ) )
                    );
                } else if ( is_order_received_page() ) {
                    $riskfree_rows[ 'order_total' ] = $total_rows[ 'order_total' ];
                } else {
                    $riskfree_rows[ 'order_total' ] = $total_rows[ 'order_total' ];

                    $riskfree_rows[ 'advance_method' ] = array(
                        'label' => $advance_text[ 'advance_method' ],
                        'value' => $total_rows[ 'payment_method' ][ 'value' ]
                    );

                    $riskfree_rows[ 'payment_method' ] = array(
                        'label' => $total_rows[ 'payment_method' ][ 'label' ],
                        'value' => $order_data[ 'method_title' ]
                    );
                }

                if ( is_order_received_page() || is_account_page() ) {
                    $riskfree_rows[ 'advance_pay' ] = array(
                        'label' => $advance_text[ 'advance_pay' ],
                        'value' => wc_price( $order_data[ 'advance_pay' ], array( 'currency' => $order->get_currency() ) )
                    );
                }

                $riskfree_rows[ 'delivery_pay' ] = array(
                    'label' => $advance_text[ 'delivery_pay' ],
                    'value' => wc_price( $order_data[ 'delivery_pay' ], array( 'currency' => $order->get_currency() ) )
                );



                return $riskfree_rows;
            }

            return $total_rows;
        }

        public function prepare_rest_data( $response ) {

            //Check if partial payment feature is enabled in rest api
            $order_total = 0;

            $data = $response->get_data();

            $order_id = 0;
            if ( isset( $data[ 'id' ] ) ) {
                $order_id = $data[ 'id' ];
            }

            if ( $order_id > 0 ) {
                $order_total = WOOPCD_PartialCOD_Order::get_db_order_total( wc_get_order( $order_id ) );
            }

            if ( isset( $data[ 'total' ] ) && $order_total > 0 ) {
                $data[ 'total' ] = $order_total;
            }


            //Check if partial feature is enabled in rest api
            $settings = WOOPCD_PartialCOD::get_option( 'riskfree_settings', array( 'enable_on_rest_api' => 'yes_only' ) );


            $woopcd_partialcod_riskfree = array();

            //get the available partial data from meta
            if ( isset( $data[ 'meta_data' ] ) ) {
                $meta_data_list = array();
                foreach ( $data[ 'meta_data' ] as $key => $meta_data ) {
                    if ( 'woopcd_partialcod_riskfree' == $meta_data->key ) {
                        $woopcd_partialcod_riskfree = $meta_data->value;
                        continue;
                    }
                    $meta_data_list[] = $meta_data;
                }
                $data[ 'meta_data' ] = $meta_data_list;
            }

            //get the available partial data from order metadata
            if ( !count( $woopcd_partialcod_riskfree ) && isset( $data[ 'id' ] ) ) {

                $order_id = $data[ 'id' ];

                $partialcod_riskfree = false;

                $order = WOOPCD_PartialCOD_Order::get_order( $order_id, false );

                if ( $order ) {

                    $order->get_meta( 'woopcd_partialcod_riskfree', true );
                }

                if ( $partialcod_riskfree ) {

                    $woopcd_partialcod_riskfree = $partialcod_riskfree;
                }
            }


            //add the available partial payment data to order keys
            if ( count( $woopcd_partialcod_riskfree ) ) {
                $rest_data = array();
                foreach ( $data as $key => $data_value ) {

                    if ( $key == 'payment_method' && 'no' != $settings[ 'enable_on_rest_api' ] ) {
                        $rest_data[ 'woopcd_partialcod_riskfree' ] = $woopcd_partialcod_riskfree;
                    }
                    $rest_data[ $key ] = $data_value;
                }

                if ( 'yes' == $settings[ 'enable_on_rest_api' ] && isset( $data[ 'total' ] ) ) {
                    $rest_data[ 'total' ] = $woopcd_partialcod_riskfree[ 'advance_pay' ];
                }
                $response->set_data( $rest_data );
            }

            return $response;
        }

        private function get_allowed_ids( $cart_data, $methods ) {
            $allow_ids = array();

            $selected_method = $this->get_selected_method( $cart_data );

            if ( count( $selected_method ) > 0 ) {
                if ( count( $selected_method[ 'allow_methods' ] ) > 0 ) {
                    $allow_ids = $selected_method[ 'allow_methods' ];
                } else {
                    $allow_ids = $this->get_default_allowed_ids( $cart_data, $methods );
                }
                $allow_ids[] = $selected_method[ 'method_id' ];
            }

            return $allow_ids;
        }

        private function get_default_allowed_ids( $cart_data, $methods ) {
            $method_ids = array();

            $rf_ids = array();
            foreach ( $this->get_riskfree_data( $cart_data ) as $rf ) {
                $rf_ids[] = $rf[ 'method_id' ];
            }
            foreach ( array_keys( $methods ) as $method_id ) {
                if ( !in_array( $method_id, $rf_ids ) ) {
                    $method_ids[] = $method_id;
                }
            }

            return $method_ids;
        }

        private function get_selected_method( $cart_data ) {

            $rf_methods = $this->get_riskfree_data( $cart_data );

            foreach ( $rf_methods as $rf_method ) {
                if ( true == $rf_method[ 'is_selected' ] ) {
                    return $rf_method;
                }
            }

            return array();
        }

        private function get_riskfree_data( $cart_data ) {
            if ( !isset( $cart_data[ 'riskfee' ] ) ) {
                return array();
            }

            $riskfree_data = array();

            foreach ( $cart_data[ 'riskfee' ] as $method_id => $m_rf ) {
                foreach ( $m_rf as $rule_id => $rf ) {
                    $rf[ 'rule_id' ] = $rule_id;
                    $rf[ 'method_id' ] = $method_id;

                    $riskfree_data[] = $rf;
                }
            }

            if ( has_filter( 'woopcd_partialcod/get-partial-payment-data' ) ) {
                return apply_filters( 'woopcd_partialcod/get-partial-payment-data', $riskfree_data );
            }

            return $riskfree_data;
        }

        private function maybe_update_chosen( $methods, $riskfree_data ) {

            if ( !WC()->session ) {
                return $methods;
            }

            $chosen_method = WC()->session->get( 'chosen_payment_method', '' );

            $rf_ids = array();
            foreach ( $riskfree_data as $rf_data ) {
                $rf_ids[] = $rf_data[ 'id' ];
            }

            $keys = array_keys( $methods );

            // apply the chosen method if needed
            if ( in_array( $chosen_method, $keys ) && !in_array( $chosen_method, $rf_ids ) ) {
                return $methods;
            }

            // find next available none riskfree method
            $last_key = '';
            foreach ( $keys as $key ) {
                if ( in_array( $key, $rf_ids ) ) {
                    continue;
                }
                $last_key = $key;
                break;
            }

            // apply the chosen method
            if ( '' != $last_key ) {
                foreach ( $keys as $key ) {
                    if ( $key == $last_key ) {
                        $methods[ $key ]->chosen = true;
                    } else {
                        $methods[ $key ]->chosen = false;
                    }
                }
                WC()->session->set( 'chosen_payment_method', $last_key );
            }

            return $methods;
        }

        private function get_order_data( $order_id ) {

            // get order data from memory
            if ( isset( $this->order_data_list[ $order_id ] ) ) {

                return $this->order_data_list[ $order_id ];
            }

            // Get order partial payment data from database and store it in memory

            $order_data = false;

            $order = WOOPCD_PartialCOD_Order::get_order( $order_id, false );

            $order_data = $order->get_meta( 'woopcd_partialcod_riskfree', true );

            if ( $order_data ) {

                $order_total = WOOPCD_PartialCOD_Order::get_db_order_total( $order );

                $order_data[ 'delivery_pay' ] = $order_total - $order_data[ 'advance_pay' ];

                $this->order_data_list[ $order_id ] = $order_data;
            } else {

                $this->order_data_list[ $order_id ] = array();
            }

            return $this->order_data_list[ $order_id ];
        }

        private function prepare_description( $data ) {
            $desc = $data[ 'desc' ];
            if ( '' == $desc ) {
                return $desc;
            }

            //Controls partial payment transaction details, try {{advance_amount}} and {{delivery_pay_amount}}
            return $this->prepare_advance_amount( $desc, $data );
        }

        private function prepare_advance_amount( $desc, $data ) {
            $desc = preg_replace( '/{{partial_amount}}/', wc_price( $data[ 'advance_pay' ] ), $desc );
            return $this->prepare_delivery_pay( $desc, $data );
        }

        private function prepare_delivery_pay( $desc, $data ) {
            $desc = preg_replace( '/{{remaining_amount}}/', wc_price( $data[ 'delivery_pay' ] ), $desc );
            return $this->prepare_total( $desc, $data );
        }

        private function prepare_total( $desc, $data ) {
            return preg_replace( '/{{order_totals}}/', wc_price( $data[ 'totals' ] ), $desc );
        }

    }

}
