<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WOOPCD_PartialCOD_Order_Activity_Customers' ) ) {

    class WOOPCD_PartialCOD_Order_Activity_Customers {

        public function __construct() {

            add_filter( 'woopcd_partialcod/get-customer_update_role-activities', array( $this, 'get_update_user_role_activity' ), 10, 3 );
            add_filter( 'woopcd_partialcod/get-customer_update_meta-activities', array( $this, 'get_update_meta_activity' ), 10, 3 );
            add_filter( 'woopcd_partialcod/get-customer_remove_meta-activities', array( $this, 'get_remove_meta_activity' ), 10, 3 );

            add_action( 'woopcd_partialcod/apply-customer_update_role-activity', array( $this, 'process_update_user_role_activity' ), 10, 3 );
            add_action( 'woopcd_partialcod/apply-customer_update_meta-activity', array( $this, 'process_update_meta_activity' ), 10, 3 );
            add_action( 'woopcd_partialcod/apply-customer_remove_meta-activity', array( $this, 'process_remove_meta_activity' ), 10, 3 );
        }

        public function get_update_user_role_activity( $activity, $activities_args, $order_data ) {

            $activity[ 'user_role' ] = $activities_args[ 'user_role' ];

            return $activity;
        }

        public function get_update_meta_activity( $activity, $activities_args, $order_data ) {

            if ( !empty( $activities_args[ 'meta_key' ] ) ) {

                $activity[ 'meta_key' ] = $activities_args[ 'meta_key' ];

                $activity[ 'meta_value' ] = $activities_args[ 'meta_value' ];
            }

            return $activity;
        }

        public function get_remove_meta_activity( $activity, $activities_args, $order_data ) {

            if ( !empty( $activities_args[ 'meta_key' ] ) ) {

                $activity[ 'meta_key' ] = $activities_args[ 'meta_key' ];
            }

            return $activity;
        }

        public function process_update_user_role_activity( $order_id, $activity, $activity_id ) {

            $order = WOOPCD_PartialCOD_Order::get_order( $order_id );

            if ( is_null( $order ) ) {
                return;
            }

            $user_id = $order->get_customer_id();
            
            $user = new WP_User( $user_id );
            
            $user->set_role( $activity[ 'user_role' ] );
        }

        public function process_update_meta_activity( $order_id, $activity, $activity_id ) {

            $order = WOOPCD_PartialCOD_Order::get_order( $order_id );

            if ( is_null( $order ) ) {
                return;
            }

            $user_id = $order->get_customer_id();

            if ( isset( $activity[ 'meta_key' ] ) ) {

                update_user_meta( $user_id, $activity[ 'meta_key' ], $activity[ 'meta_value' ] );
            }
        }

        public function process_remove_meta_activity( $order_id, $activity, $activity_id ) {

            $order = WOOPCD_PartialCOD_Order::get_order( $order_id );

            if ( is_null( $order ) ) {
                return;
            }

            $user_id = $order->get_customer_id();

            if ( isset( $activity[ 'meta_key' ] ) ) {
                delete_user_meta( $user_id, $activity[ 'meta_key' ] );
            }
        }

    }

    new WOOPCD_PartialCOD_Order_Activity_Customers();
}
