<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WOOPCD_PartialCOD_Order_Activity_Orders' ) ) {

    class WOOPCD_PartialCOD_Order_Activity_Orders {

        public function __construct() {

            add_filter( 'woopcd_partialcod/get-order_update_status-activities', array( $this, 'get_update_status_activity' ), 10, 3 );
            add_filter( 'woopcd_partialcod/get-order_add_note-activities', array( $this, 'get_add_note_activity' ), 10, 3 );
            add_filter( 'woopcd_partialcod/get-order_update_meta-activities', array( $this, 'get_update_meta_activity' ), 10, 3 );
            add_filter( 'woopcd_partialcod/get-order_remove_meta-activities', array( $this, 'get_remove_meta_activity' ), 10, 3 );

            add_action( 'woopcd_partialcod/apply-order_update_status-activity', array( $this, 'process_update_status_activity' ), 10, 3 );
            add_action( 'woopcd_partialcod/apply-order_add_note-activity', array( $this, 'process_add_note_activity' ), 10, 3 );
            add_action( 'woopcd_partialcod/apply-order_update_meta-activity', array( $this, 'process_update_meta_activity' ), 10, 3 );
            add_action( 'woopcd_partialcod/apply-order_remove_meta-activity', array( $this, 'process_remove_meta_activity' ), 10, 3 );
        }

        public function get_update_status_activity( $activity, $activities_args, $order_data ) {

            $activity[ 'new_status' ] = $activities_args[ 'new_status' ];

            $activity[ 'note' ] = $activities_args[ 'note' ];

            return $activity;
        }

        public function get_add_note_activity( $activity, $activities_args, $order_data ) {

            $user_id = 0;

            $user = false;

            if ( !empty( $activities_args[ 'added_by_email' ] ) ) {
                $user = get_user_by( 'email', $activities_args[ 'added_by_email' ] );
            }

            if ( $user ) {
                $user_id = $user->ID;
            }

            $activity[ 'note' ] = $activities_args[ 'note' ];

            $activity[ 'is_customer_note' ] = ($activities_args[ 'is_customer_note' ] == 'yes');

            $activity[ 'added_by_user' ] = $user_id;

            return $activity;
        }

        public function get_update_meta_activity( $activity, $activities_args, $order_data ) {

            if ( !empty( $activities_args[ 'meta_key' ] ) ) {

                $activity[ 'meta_key' ] = $activities_args[ 'meta_key' ];

                $activity[ 'meta_value' ] = $activities_args[ 'meta_value' ];
            }

            return $activity;
        }

        public function get_remove_meta_activity( $activity, $activities_args, $order_data ) {

            if ( !empty( $activities_args[ 'meta_key' ] ) ) {

                $activity[ 'meta_key' ] = $activities_args[ 'meta_key' ];
            }

            return $activity;
        }

        public function process_update_status_activity( $order_id, $activity, $activity_id ) {

            $order = WOOPCD_PartialCOD_Order::get_order( $order_id );

            if ( is_null( $order ) ) {
                return;
            }

            $order->update_status( $activity[ 'new_status' ], $activity[ 'note' ], false );
        }

        public function process_add_note_activity( $order_id, $activity, $activity_id ) {

            $order = WOOPCD_PartialCOD_Order::get_order( $order_id, false );

            if ( !$order ) {

                return;
            }

            $order->add_order_note( $activity[ 'note' ], $activity[ 'is_customer_note' ], $activity[ 'added_by_user' ] );
        }

        public function process_update_meta_activity( $order_id, $activity, $activity_id ) {

            if ( !isset( $activity[ 'meta_key' ] ) ) {

                return;
            }

            if ( !isset( $activity[ 'meta_value' ] ) ) {

                return;
            }

            $order = WOOPCD_PartialCOD_Order::get_order( $order_id, false );

            if ( !$order ) {

                return;
            }

            $order->update_meta_data( $activity[ 'meta_key' ], $activity[ 'meta_value' ] );

            $order->save();
        }

        public function process_remove_meta_activity( $order_id, $activity, $activity_id ) {

            if ( !isset( $activity[ 'meta_key' ] ) ) {

                return;
            }

            $order = WOOPCD_PartialCOD_Order::get_order( $order_id, false );

            if ( !$order ) {

                return;
            }

            $order->delete_meta_data( $activity[ 'meta_key' ] );

            $order->save();
        }

    }

    new WOOPCD_PartialCOD_Order_Activity_Orders();
}
