<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WOOPCD_PartialCOD_Order_Conditions_DateTime_Created' ) ) {

    class WOOPCD_PartialCOD_Order_Conditions_DateTime_Created {

        public function __construct() {

            add_filter( 'woopcd_partialcod/validate-order-date_created-condition', array( $this, 'validate_date' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-order-time_created-condition', array( $this, 'validate_time' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-order-date_time_created-condition', array( $this, 'validate_date_time' ), 10, 2 );
        }

        public function validate_date( $condition, $order_data ) {

            if ( !isset( $condition[ 'date_type' ] ) ) {
                return false;
            }

            $current_date_time = $this->get_date( $order_data, true );

            if ( empty( $current_date_time ) ) {
                return false;
            }


            $date_type = $condition[ 'date_type' ];

            if ( $date_type == 'between' ) {

                $rule_from_date = $condition[ 'from_date' ];
                $rule_to_date = $condition[ 'to_date' ];

                if ( $rule_from_date == '' || $rule_to_date == '' ) {
                    return false;
                }

                $from_is_valid = WOOPCD_PartialCOD_Validation_Util::validate_date( '>=', $current_date_time, $rule_from_date . ' 00:00:00', 'Y-m-d H:i:s', 'Y-m-d H:i:s' );
                $to_is_valid = WOOPCD_PartialCOD_Validation_Util::validate_date( '<=', $current_date_time, $rule_to_date . ' 23:59:59', 'Y-m-d H:i:s', 'Y-m-d H:i:s' );

                return ($from_is_valid == true && $to_is_valid == true);
            } else if ( $date_type == 'date' ) {

                $rule_date = $condition[ 'date' ];

                if ( $rule_date == '' ) {
                    return false;
                }

                $from_is_valid = WOOPCD_PartialCOD_Validation_Util::validate_date( '>=', $current_date_time, $rule_date . ' 00:00:00', 'Y-m-d H:i:s', 'Y-m-d H:i:s' );
                $to_is_valid = WOOPCD_PartialCOD_Validation_Util::validate_date( '<=', $current_date_time, $rule_date . ' 23:59:59', 'Y-m-d H:i:s', 'Y-m-d H:i:s' );

                return ($from_is_valid == true && $to_is_valid == true);
            } else {
                $rule_date = $condition[ 'date' ];

                if ( $rule_date == '' ) {
                    return false;
                }

                $valid_type = '>=';
                $date_time = ' 00:00:00';

                if ( $date_type == 'to' ) {
                    $valid_type = '<=';
                    $date_time = ' 23:59:59';
                }

                return WOOPCD_PartialCOD_Validation_Util::validate_date( $valid_type, $current_date_time, $rule_date . $date_time, 'Y-m-d H:i:s', 'Y-m-d H:i:s' );
            }
        }

        public function validate_time( $condition, $order_data ) {

            if ( !isset( $condition[ 'time_type' ] ) ) {
                return false;
            }

            $current_date_time = $this->get_date( $order_data, true );

            $today = $this->get_date( $order_data, false ) . ' ';

            if ( empty( $current_date_time ) ) {
                return false;
            }

            $rule_time_type = $condition[ 'time_type' ];

            if ( $rule_time_type == 'between' ) {

                $rule_from_time = $condition[ 'from_time' ];
                $rule_to_time = $condition[ 'to_time' ];

                if ( $rule_from_time == '' || $rule_to_time == '' ) {
                    return false;
                }


                $from_is_valid = WOOPCD_PartialCOD_Validation_Util::validate_date( '>=', $current_date_time, $today . $rule_from_time, 'Y-m-d H:i:s', 'Y-m-d H:i:s' );
                $to_is_valid = WOOPCD_PartialCOD_Validation_Util::validate_date( '<=', $current_date_time, $today . $rule_to_time, 'Y-m-d H:i:s', 'Y-m-d H:i:s' );

                return ($from_is_valid == true && $to_is_valid == true);
            } else {

                $rule_time = $condition[ 'time' ];

                if ( $rule_time == '' ) {
                    return false;
                }

                $valid_type = '>=';
                if ( $rule_time_type == 'to' ) {
                    $valid_type = '<=';
                }

                return WOOPCD_PartialCOD_Validation_Util::validate_date( $valid_type, $current_date_time, $today . $rule_time, 'Y-m-d H:i:s', 'Y-m-d H:i:s' );
            }
        }

        public function validate_date_time( $condition, $order_data ) {

            $rule_date_type = $condition[ 'date_type' ];

            $current_date_time = $this->get_date( $order_data, true );

            if ( empty( $current_date_time ) ) {
                return false;
            }

            if ( $rule_date_type == 'between' ) {

                $rule_from_date_time = $condition[ 'from_date_time' ];
                $rule_to_date_time = $condition[ 'to_date_time' ];

                if ( $rule_from_date_time == '' || $rule_to_date_time == '' ) {
                    return false;
                }

                $from_is_valid = WOOPCD_PartialCOD_Validation_Util::validate_date( '>=', $current_date_time, $rule_from_date_time, 'Y-m-d H:i:s', 'Y-m-d H:i:s' );
                $to_is_valid = WOOPCD_PartialCOD_Validation_Util::validate_date( '<=', $current_date_time, $rule_to_date_time, 'Y-m-d H:i:s', 'Y-m-d H:i:s' );

                return ($from_is_valid == true && $to_is_valid == true);
            } else {

                $rule_date_time = $condition[ 'date_time' ];

                if ( $rule_date_time == '' ) {
                    return false;
                }

                $valid_type = '>=';
                if ( $rule_date_type == 'to' ) {
                    $valid_type = '<=';
                }

                return WOOPCD_PartialCOD_Validation_Util::validate_date( $valid_type, $current_date_time, $rule_date_time, 'Y-m-d H:i:s', 'Y-m-d H:i:s' );
            }
        }

        private function get_date( $order_data, $include_time = true ) {

            if ( !isset( $order_data[ 'wc' ][ 'date_created' ] ) ) {
                return '';
            }

            $created_date = $order_data[ 'wc' ][ 'date_created' ];

            if ( $include_time == true ) {
                return $created_date[ 'date' ] . ' ' . $created_date[ 'time' ];
            }

            return $created_date[ 'date' ];
        }

    }

    new WOOPCD_PartialCOD_Order_Conditions_DateTime_Created();
}
