<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WOOPCD_PartialCOD_Order_Conditions_Item_Quantity' ) ) {

    class WOOPCD_PartialCOD_Order_Conditions_Item_Quantity {

        public function __construct() {

            add_filter( 'woopcd_partialcod/validate-order-quantity_products-condition', array( $this, 'validate_quantity_products' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-order-quantity_variations-condition', array( $this, 'validate_quantity_variations' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-order-quantity_categories-condition', array( $this, 'validate_quantity_categories' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-order-quantity_tags-condition', array( $this, 'validate_quantity_tags' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-order-quantity_attributes-condition', array( $this, 'validate_quantity_attributes' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-order-quantity_virtuals-condition', array( $this, 'validate_quantity_virtuals' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-order-quantity_tax_classes-condition', array( $this, 'validate_quantity_tax_classes' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-order-quantity_shipping_classes-condition', array( $this, 'validate_quantity_shipping_classes' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-order-quantity_metas-condition', array( $this, 'validate_quantity_metas' ), 10, 2 );
        }

        public function validate_quantity_products( $condition, $order_data ) {

            if ( !isset( $condition[ 'product_slugs' ] ) ) {
                return false;
            }

            $rule_product_ids = WOOPCD_PartialCOD_Util::get_product_ids_by_slugs( $condition[ 'product_slugs' ] );

            if ( !count( $rule_product_ids ) ) {
                return false;
            }

            $quantity = $this->get_quantity( WOOPCD_PartialCOD_Order_Util::get_items_by_ids( $order_data, $rule_product_ids ) );

            $rule_quantity = $condition[ 'quantity' ];

            if ( !is_numeric( $rule_quantity ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $rule_compare, $quantity, $rule_quantity, 'no' );
        }

        public function validate_quantity_variations( $condition, $order_data ) {

            if ( !isset( $condition[ 'variation_slugs' ] ) ) {
                return false;
            }

            $rule_variation_ids = WOOPCD_PartialCOD_Util::get_variation_ids_by_slugs( $condition[ 'variation_slugs' ] );

            if ( !count( $rule_variation_ids ) ) {
                return false;
            }

            $quantity = $this->get_quantity( WOOPCD_PartialCOD_Order_Util::get_items_by_variation_ids( $order_data, $rule_variation_ids ) );

            $rule_quantity = $condition[ 'quantity' ];

            if ( !is_numeric( $rule_quantity ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $rule_compare, $quantity, $rule_quantity, 'no' );
        }

        public function validate_quantity_categories( $condition, $order_data ) {


            if ( !isset( $condition[ 'category_slugs' ] ) ) {
                return false;
            }

            $rule_category_ids = WOOPCD_PartialCOD_Util::get_product_term_ids_by_slugs( $condition[ 'category_slugs' ], 'product_cat' );

            if ( !count( $rule_category_ids ) ) {
                return false;
            }

            $quantity = $this->get_quantity( WOOPCD_PartialCOD_Order_Util::get_items_by_term_ids( $order_data, $rule_category_ids, 'product_cat' ) );

            $rule_quantity = $condition[ 'quantity' ];

            if ( !is_numeric( $rule_quantity ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $rule_compare, $quantity, $rule_quantity, 'no' );
        }

        public function validate_quantity_tags( $condition, $order_data ) {


            if ( !isset( $condition[ 'tag_slugs' ] ) ) {
                return false;
            }

            $rule_tag_ids = WOOPCD_PartialCOD_Util::get_product_term_ids_by_slugs( $condition[ 'tag_slugs' ], 'product_tag' );

            if ( !count( $rule_tag_ids ) ) {
                return false;
            }

            $quantity = $this->get_quantity( WOOPCD_PartialCOD_Order_Util::get_items_by_term_ids( $order_data, $rule_tag_ids, 'product_tag' ) );

            $rule_quantity = $condition[ 'quantity' ];

            if ( !is_numeric( $rule_quantity ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $rule_compare, $quantity, $rule_quantity, 'no' );
        }

        public function validate_quantity_attributes( $condition, $order_data ) {

            if ( !isset( $condition[ 'attribute_slugs' ] ) ) {
                return false;
            }

            $rule_attribute_ids = WOOPCD_PartialCOD_Util::get_attribute_ids_by_slugs( $condition[ 'attribute_slugs' ] );

            if ( !count( $rule_attribute_ids ) ) {
                return false;
            }

            $quantity = $this->get_quantity( WOOPCD_PartialCOD_Order_Util::get_items_by_attribute_ids( $order_data, $rule_attribute_ids ) );

            $rule_quantity = $condition[ 'quantity' ];

            if ( !is_numeric( $rule_quantity ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $rule_compare, $quantity, $rule_quantity, 'no' );
        }

        public function validate_quantity_virtuals( $condition, $order_data ) {

            if ( !isset( $condition[ 'is_virtual' ] ) ) {
                return false;
            }

            $rule_is_virtual = $condition[ 'is_virtual' ];


            $quantity = $this->get_quantity( WOOPCD_PartialCOD_Order_Util::get_items_by_virtuals( $order_data, $rule_is_virtual ) );

            $rule_quantity = $condition[ 'quantity' ];

            if ( !is_numeric( $rule_quantity ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $rule_compare, $quantity, $rule_quantity, 'no' );
        }

        public function validate_quantity_tax_classes( $condition, $order_data ) {

            if ( !isset( $condition[ 'tax_classes' ] ) ) {
                return false;
            }

            $rule_tax_classes = $condition[ 'tax_classes' ];

            if ( !count( $rule_tax_classes ) ) {
                return false;
            }

            $quantity = $this->get_quantity( WOOPCD_PartialCOD_Order_Util::get_items_by_tax_classes( $order_data, $rule_tax_classes ) );

            $rule_quantity = $condition[ 'quantity' ];

            if ( !is_numeric( $rule_quantity ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $rule_compare, $quantity, $rule_quantity, 'no' );
        }

        public function validate_quantity_shipping_classes( $condition, $order_data ) {

            if ( !isset( $condition[ 'shipping_classes' ] ) ) {
                return false;
            }

            $rule_shipping_classe_ids = WOOPCD_PartialCOD_Util::get_product_term_ids_by_slugs( $condition[ 'shipping_classes' ], 'product_shipping_class' );

            if ( !count( $rule_shipping_classe_ids ) ) {
                return false;
            }

            $quantity = $this->get_quantity( WOOPCD_PartialCOD_Order_Util::get_items_by_term_ids( $order_data, $rule_shipping_classe_ids, 'product_shipping_class' ) );

            $rule_quantity = $condition[ 'quantity' ];

            if ( !is_numeric( $rule_quantity ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $rule_compare, $quantity, $rule_quantity, 'no' );
        }

        public function validate_quantity_metas( $condition, $order_data ) {

            if ( !isset( $condition[ 'meta_key' ] ) || !isset( $condition[ 'meta_value' ] ) ) {
                return false;
            }

            $meta_key = $condition[ 'meta_key' ];
            $meta_value = $condition[ 'meta_value' ];


            $quantity = $this->get_quantity( WOOPCD_PartialCOD_Order_Util::get_items_by_meta( $order_data, $meta_key, $meta_value ) );

            $rule_quantity = $condition[ 'quantity' ];

            if ( !is_numeric( $rule_quantity ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $rule_compare, $quantity, $rule_quantity, 'no' );
        }

        private function get_quantity( $order_items ) {

            $quantity = 0;

            if ( !count( $order_items ) ) {
                return $quantity;
            }

            foreach ( $order_items as $order_item ) {

                $quantity += $order_item[ 'quantity' ];
            }

            return $quantity;
        }

    }

    new WOOPCD_PartialCOD_Order_Conditions_Item_Quantity();
}

