<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WOOPCD_PartialCOD_Order_Conditions_Order_Totals' ) ) {

    class WOOPCD_PartialCOD_Order_Conditions_Order_Totals {

        private $types_prefix;
        private $option_list;
        private $is_db_order_total = false;

        public function __construct() {

            add_filter( 'woopcd_partialcod/is_db_order_total', array( $this, 'get_is_db_order_total' ), 10, 1 );

            $this->types_prefix = 'order_totals_';
            $this->option_list = array();

            add_filter( 'woopcd_partialcod/validate-order-subtotal_inc_tax-condition', array( $this, 'validate_order_totals' ), 10, 2 );

            foreach ( $this->get_options() as $option ) {
                add_filter( 'woopcd_partialcod/validate-order-' . $this->types_prefix . $option[ 'option_id' ] . '-condition', array( $this, 'validate_order_totals' ), 10, 2 );
            }
        }

        public function validate_order_totals( $condition, $order_data ) {


            $option_id = $this->get_option_id_by_condition( $condition[ 'condition_type' ] );

            if ( '' == $option_id ) {
                return false;
            }

            $args = array(
                'module' => 'order-activities',
                'option_id' => $option_id
            );
            
            $this->is_db_order_total = true;
            $order_totals = WOOPCD_PartialCOD_Order_Total_Types::get_totals( $args, $order_data );
            $this->is_db_order_total = false;
            
            $rule_total = $condition[ 'totals' ];

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $rule_compare, $order_totals, $rule_total, 'no' );
        }

        public function get_is_db_order_total( $is_db_total ) {
            if ( $this->is_db_order_total ) {
                return true;
            }
            return $is_db_total;
        }

        private function get_option_id_by_condition( $condition_type ) {

            foreach ( $this->get_options() as $option ) {
                if ( $condition_type == $this->types_prefix . $option[ 'option_id' ] ) {
                    return $option[ 'option_id' ];
                }
            }
            return '';
        }

        private function get_options() {

            if ( count( $this->option_list ) ) {
                return $this->option_list;
            }

            $this->option_list = WOOPCD_PartialCOD::get_option( 'activity_order_totals', $this->get_default_options() );

            return $this->option_list;
        }

        private function get_default_options() {
            return array(
                array(
                    'option_id' => '2234343',
                ),
            );
        }

    }

    new WOOPCD_PartialCOD_Order_Conditions_Order_Totals();
}
