<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WOOPCD_PartialCOD_Order_Conditions_Cart_Orders' ) ) {

    class WOOPCD_PartialCOD_Order_Conditions_Cart_Orders {

        public function __construct() {
            add_filter( 'woopcd_partialcod/validate-order-currency-condition', array( $this, 'validate_currency' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-order-status-condition', array( $this, 'validate_status' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-order-quantity-condition', array( $this, 'validate_quantity' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-order-weight-condition', array( $this, 'validate_weight' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-order-line_count-condition', array( $this, 'validate_item_count' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-order-coupons-condition', array( $this, 'validate_coupons' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-order-advance_pay_methods-condition', array( $this, 'validate_advance_pay_methods' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-order-needs_payment-condition', array( $this, 'validate_is_needed' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-order-needs_processing-condition', array( $this, 'validate_is_needed' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-order-is_paid-condition', array( $this, 'validate_is_needed' ), 10, 2 );
        }

        public function validate_currency( $condition, $order_data ) {

            if ( !isset( $condition[ 'currencies' ] ) ) {
                return false;
            }

            $rule_currencies = $condition[ 'currencies' ];

            if ( !is_array( $rule_currencies ) ) {
                return false;
            }

            $currency = $order_data[ 'wc' ][ 'currency' ];

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value_list( $currency, $rule_currencies, $rule_compare );
        }

        public function validate_status( $condition, $order_data ) {

            if ( !isset( $condition[ 'statuses' ] ) ) {
                return false;
            }

            $rule_statuses = $condition[ 'statuses' ];

            if ( !is_array( $rule_statuses ) ) {
                return false;
            }

            $status = $order_data[ 'wc' ][ 'status' ];

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value_list( $status, $rule_statuses, $rule_compare );
        }

        public function validate_quantity( $condition, $order_data ) {

            $rule_total_quantity = $condition[ 'total_quantity' ];

            if ( empty( $rule_total_quantity ) ) {
                return false;
            }

            $quantity = $this->get_quantity( $order_data );

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $rule_compare, $quantity, $rule_total_quantity, 'no' );
        }

        public function validate_weight( $condition, $order_data ) {

            $rule_total_weight = $condition[ 'total_weight' ];

            if ( empty( $rule_total_weight ) ) {
                return false;
            }

            $weight = $this->get_weight( $order_data );

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $rule_compare, $weight, $rule_total_weight, 'no' );
        }

        public function validate_item_count( $condition, $order_data ) {

            $rule_line_count = $condition[ 'line_count' ];

            if ( empty( $rule_line_count ) ) {
                return false;
            }

            $line_count = $this->get_line_count( $order_data );

            if ( empty( $line_count ) ) {
                return false;
            }


            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $rule_compare, $line_count, $rule_line_count, 'no' );
        }

        public function validate_coupons( $condition, $order_data ) {

            $coupon_ids = $this->get_coupon_ids( $order_data );

            $rule_compare = $condition[ 'compare' ];

            if ( $rule_compare === 'any' ) {

                $is_any = $rule_compare = $condition[ 'is_any' ];

                return WOOPCD_PartialCOD_Validation_Util::validate_list_empty( $coupon_ids, $is_any );
            }

            $rule_coupons = $condition[ 'coupons' ];


            if ( !is_array( $rule_coupons ) ) {
                return false;
            }

            return WOOPCD_PartialCOD_Validation_Util::validate_list_list( $coupon_ids, $rule_coupons, $rule_compare );
        }

        public function validate_advance_pay_methods( $condition, $order_data ) {

            $rule_method_ids = $condition[ 'method_ids' ];

            if ( !is_array( $rule_method_ids ) ) {
                return false;
            }

            $method_id = $this->get_method_id( $order_data );

            $rule_compare = $condition[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value_list( $method_id, $rule_method_ids, $rule_compare );
        }

        public function validate_is_needed( $condition, $order_data ) {

            $condition_type = $condition[ 'condition_type' ];

            $rule_is_needed = 'yes';

            if ( $condition[ 'is_needed' ] == 'no' ) {

                $rule_is_needed = 'no';
            }

            $is_needed_value = $this->get_is_need_value( $condition_type, $order_data );

            return WOOPCD_PartialCOD_Validation_Util::validate_yes_no( $is_needed_value, $rule_is_needed );
        }

        private function get_is_need_value( $condition_type, $order_data ) {

            if ( 'needs_payment' == $condition_type ) {

                return $order_data[ 'wc' ][ 'needs_payment' ];
            }

            if ( 'needs_processing' == $condition_type ) {

                return $order_data[ 'wc' ][ 'needs_processing' ];
            }

            if ( 'is_paid' == $condition_type ) {

                return $order_data[ 'wc' ][ 'is_paid' ];
            }

            return false;
        }

        private function get_quantity( $order_data ) {

            $quantity = 0;

            if ( !isset( $order_data[ 'wc' ][ 'order_items' ] ) ) {
                return $quantity;
            }

            foreach ( $order_data[ 'wc' ][ 'order_items' ] as $order_item ) {
                $quantity += $order_item[ 'quantity' ];
            }

            return $quantity;
        }

        private function get_weight( $order_data ) {
            $weight = 0;

            if ( !isset( $order_data[ 'wc' ][ 'order_items' ] ) ) {
                return $weight;
            }

            foreach ( $order_data[ 'wc' ][ 'order_items' ] as $order_item ) {
                $product = wc_get_product( $order_item[ 'product_id' ] );

                if ( !$product ) {
                    continue;
                }

                $wght = $product->get_weight();
                if ( is_numeric( $wght ) && $wght > 0 ) {
                    $weight += ($wght * $order_item[ 'quantity' ]);
                }
            }

            return $weight;
        }

        private function get_line_count( $order_data ) {

            if ( !isset( $order_data[ 'wc' ][ 'order_items' ] ) ) {
                return 0;
            }

            return count( $order_data[ 'wc' ][ 'order_items' ] );
        }

        private function get_coupon_ids( $order_data ) {

            $coupon_ids = array();

            if ( !isset( $order_data[ 'wc' ][ 'applied_coupons' ] ) ) {
                return $coupon_ids;
            }


            $coupon_codes = array();

            foreach ( $order_data[ 'wc' ][ 'applied_coupons' ] as $coupon ) {

                $coupon_codes[] = $coupon[ 'coupon_code' ];
            }

            foreach ( $coupon_codes as $coupon_code ) {
                $coupon_id = wc_get_coupon_id_by_code( $coupon_code );
                if ( $coupon_id > 0 ) {
                    $coupon_ids[] = $coupon_id;
                }
            }

            return $coupon_ids;
        }

        private function get_method_id( $order_data ) {

            if ( !count( $order_data[ 'wc' ][ 'risk_free' ] ) ) {
                return '';
            }

            if ( isset( $order_data[ 'wc' ][ 'payment_method' ][ 'method_id' ] ) ) {
                return $order_data[ 'wc' ][ 'payment_method' ][ 'method_id' ];
            }

            return '';
        }

    }

    new WOOPCD_PartialCOD_Order_Conditions_Cart_Orders();
}