<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WOOPCD_PartialCOD_Order_Conditions_Shipping_Address' ) ) {

    class WOOPCD_PartialCOD_Order_Conditions_Shipping_Address {

        public function __construct() {
            add_filter( 'woopcd_partialcod/validate-order-shipping_countries-condition', array( $this, 'validate_countries' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-order-shipping_states-condition', array( $this, 'validate_states' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-order-shipping_cities-condition', array( $this, 'validate_cities' ), 10, 2 );
            add_filter( 'woopcd_partialcod/validate-order-shipping_postcodes-condition', array( $this, 'validate_postcodes' ), 10, 2 );
        }

        public function validate_countries( $condition, $order_data ) {

            $order = WOOPCD_PartialCOD_Order::get_order( $order_data[ 'wc' ][ 'id' ] );

            if ( is_null( $order ) ) {
                return false;
            }
            
            $rule_countries = $condition[ 'countries' ];

            $rule_compare = $condition[ 'compare' ];

            if ( !is_array( $rule_countries ) ) {
                return false;
            }

            $country = $order->get_shipping_country();

            return WOOPCD_PartialCOD_Validation_Util::validate_value_list( $country, $rule_countries, $rule_compare );
        }

        public function validate_states( $condition, $order_data ) {
          
            $order = WOOPCD_PartialCOD_Order::get_order( $order_data[ 'wc' ][ 'id' ] );

            if ( is_null( $order ) ) {
                return false;
            }
            
            $rule_states = $condition[ 'states' ];

            $rule_compare = $condition[ 'compare' ];

            if ( !is_array( $rule_states ) ) {
                return false;
            }
            
            $state = $order->get_shipping_country() . ':' . $order->get_shipping_state();

            return WOOPCD_PartialCOD_Validation_Util::validate_value_list( $state, $rule_states, $rule_compare );
        }

        public function validate_cities( $condition, $order_data ) {

            $order = WOOPCD_PartialCOD_Order::get_order( $order_data[ 'wc' ][ 'id' ] );

            if ( is_null( $order ) ) {
                return false;
            }
            
            $rule_city_str = $condition[ 'cities' ];

            if ( empty( $rule_city_str ) ) {
                return false;
            }

            $rule_cities = explode( ',', str_replace( ', ', ',', $rule_city_str ) );

            $rule_compare = $condition[ 'compare' ];

            $city = $order->get_shipping_city();

            return WOOPCD_PartialCOD_Validation_Util::validate_value_list( $city, $rule_cities, $rule_compare );
        }

        public function validate_postcodes( $condition, $order_data ) {
          
            $order = WOOPCD_PartialCOD_Order::get_order( $order_data[ 'wc' ][ 'id' ] );

            if ( is_null( $order ) ) {
                return false;
            }
            
            $rule_postcode = $condition[ 'postcode' ];

            if ( empty( $rule_postcode ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            $postcode = $order->get_shipping_postcode();

            return WOOPCD_PartialCOD_Validation_Util::validate_match_value( $rule_compare, $postcode, $rule_postcode );
        }

    }

    new WOOPCD_PartialCOD_Order_Conditions_Shipping_Address();
}