<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WOOPCD_PartialCOD_Order_Total_Types' ) ) {
    WOOPCD_PartialCOD_Main::required_paths( dirname( __FILE__ ), array( 'order-total-types.php' ) );

    class WOOPCD_PartialCOD_Order_Total_Types {

        private static $instance = null;

        private static function get_instance() {
            if ( null == self::$instance ) {
                self::$instance = new self();
            }
            return self::$instance;
        }

        public static function get_totals( $args, $order_data ) {

            $options = self::get_instance()->get_option( $args );
            $totals = 0;

            foreach ( $options as $option ) {

                switch ( $option ) {
                    case 'subtotal':
                        $order_subtotals = new WOOPCD_PartialCOD_Order_Total_Types_Subtotals();
                        $totals = $order_subtotals->calc_totals( $totals, $option, $order_data );
                        break;

                    case 'dicounts':
                    case 'dicounts_taxes':
                    case 'n_dicounts':
                    case 'n_dicounts_taxes':
                        $order_discount_totals = new WOOPCD_PartialCOD_Order_Total_Types_Coupon_Discounts();
                        $totals = $order_discount_totals->calc_totals( $totals, $option, $order_data );
                        break;

                    case 'fees':
                    case 'fee_taxes':
                        $order_fee_totals = new WOOPCD_PartialCOD_Order_Total_Types_Fees();
                        $totals = $order_fee_totals->calc_totals( $totals, $option, $order_data );
                        break;

                    case 'shipping_cost':
                    case 'shipping_cost_tax':
                        $order_shipping_totals = new WOOPCD_PartialCOD_Order_Total_Types_Shipping_Cost();
                        $totals = $order_shipping_totals->calc_totals( $totals, $option, $order_data );
                        break;

                    case 'total':
                    case 'total_tax':
                        $order_totals = new WOOPCD_PartialCOD_Order_Total_Types_Totals();
                        $totals = $order_totals->calc_totals( $totals, $option, $order_data );
                        break;

                    case 'total_shipping_refunded':
                    case 'total_refunded':
                    case 'total_tax_refunded':
                    case 'n_total_shipping_refunded':
                    case 'n_total_refunded':
                    case 'n_total_tax_refunded':
                        $order_refund_totals = new WOOPCD_PartialCOD_Order_Total_Types_Refunds();
                        $totals = $order_refund_totals->calc_totals( $totals, $option, $order_data );
                        break;

                    default:
                        break;
                }



                if ( has_filter( 'woopcd_partialcod/calculate-order-' . $option . '-totals' ) ) {
                    $totals = apply_filters( 'woopcd_partialcod/calculate-order-' . $option . '-totals', $totals, $order_data );
                }
            }

            if ( $totals < 0 ) {
                $totals = 0;
            }

            return $totals;
        }

        private function get_option( $args ) {
            $opts = array();


            $opts = WOOPCD_PartialCOD::get_option( 'activity_order_totals', $this->get_default_options() );


            $options = array();
            foreach ( $opts as $opt ) {

                if ( isset( $opt[ 'include' ] ) ) {
                    $options[ $opt[ 'option_id' ] ] = $opt[ 'include' ];
                } else {
                    $options[ $opt[ 'option_id' ] ] = array();
                }
            }

            if ( isset( $options[ $args[ 'option_id' ] ] ) ) {
                return $options[ $args[ 'option_id' ] ];
            }

            return $options[ $opts[ 0 ][ 'option_id' ] ];
        }

        private function get_default_options() {
            return array(
                array(
                    'option_id' => '2234343',
                    'include' => array( 'subtotal', 'subtotal_tax' ),
                )
            );
        }

    }

}
