<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WOOPCD_PartialCOD_Premium_Cart' ) ) {

    class WOOPCD_PartialCOD_Premium_Cart {

        private static $parent_products = array();

        public static function get_data( $cart_data, $cart ) {
            $cart_data = self::get_contents_data( $cart_data, $cart );
            return $cart_data;
        }

        private static function get_contents_data( $cart_data, $cart ) {

            $cart_data[ 'cart_items' ] = array();


            foreach ( $cart->cart_contents as $key => $item ) {
                $cart_data[ 'cart_items' ][ $key ] = self::get_item( $cart->cart_contents[ $key ] );
                $cart_data[ 'cart_items' ][ $key ][ 'data' ] = self::get_product_data( $cart->cart_contents[ $key ][ 'data' ], $key );
            }

            return self::get_totals_data( $cart_data, $cart );
        }

        private static function get_item( $cart_item ) {

            $item = array(
                'product_id' => $cart_item[ 'product_id' ],
                'variation_id' => $cart_item[ 'variation_id' ],
            );

            $quantity = $cart_item[ 'quantity' ];

            $line_subtotal = 0;
            $line_subtotal_tax = 0;
            $line_total = 0;
            $line_tax = 0;

            
            if ( isset( $cart_item[ 'line_subtotal' ] ) ) {

                $line_subtotal = $cart_item[ 'line_subtotal' ];
            }

            if ( isset( $cart_item[ 'line_subtotal_tax' ] ) ) {

                $line_subtotal_tax = $cart_item[ 'line_subtotal_tax' ];
            }

            
            if ( isset( $cart_item[ 'line_total' ] ) ) {

                $line_total = $cart_item[ 'line_total' ];
            }

            if ( isset( $cart_item[ 'line_tax' ] ) ) {

                $line_tax = $cart_item[ 'line_tax' ];
            }

            
            if ( $line_total == 0 ) {

                $line_total = $line_subtotal;
            }

            if ( $line_tax == 0 ) {

                $line_tax = $line_subtotal_tax;
            }


            $item[ 'quantity' ] = $quantity;
            $item[ 'line_price' ] = ($line_subtotal / $quantity);
            $item[ 'line_price_tax' ] = ($line_subtotal_tax / $quantity);
            $item[ 'line_total_price' ] = ($line_total / $quantity);
            $item[ 'line_total_price_tax' ] = ($line_tax / $quantity);

            $item[ 'line_subtotal' ] = $line_subtotal;
            $item[ 'line_subtotal_tax' ] = $line_subtotal_tax;

            $item[ 'line_total' ] = $line_total;
            $item[ 'line_tax' ] = $line_tax;

            if ( has_filter( 'woopcd_partialcod/get-cart-item' ) ) {

                $item = apply_filters( 'woopcd_partialcod/get-cart-item', $item, $cart_item );
            }

            return $item;
        }

        private static function get_product_data( $product, $item_key ) {
            $item_data = array(
                'regular_price' => $product->get_regular_price(),
                'sale_price' => $product->get_sale_price(),
                'price' => $product->get_price(),
                'total_sales' => 0,
                'stock_status' => $product->get_stock_status(),
                'stock_quantity' => $product->get_stock_quantity(),
                'sold_individually' => $product->get_sold_individually(),
                'is_featured' => false,
                'is_on_sale' => $product->is_on_sale(),
                'is_virtual' => $product->is_virtual(),
                'is_downloadable' => $product->is_downloadable(),
                'is_taxable' => $product->is_taxable(),
                'tax_status' => $product->get_tax_status(),
                'tax_class' => $product->get_tax_class(),
                'shipping_class_id' => $product->get_shipping_class_id(),
                'weight' => $product->get_weight(),
                'dimensions' => $product->get_dimensions( false ),
            );

            if ( $product->get_parent_id() > 0 ) {

                $v_product = self::get_parent_product( $product->get_parent_id() );

                $item_data[ 'total_sales' ] = $v_product->get_total_sales();
                $item_data[ 'is_featured' ] = $v_product->is_featured();
                $item_data[ 'category_ids' ] = $v_product->get_category_ids();
                $item_data[ 'tag_ids' ] = $v_product->get_tag_ids();

                $db_attrs = $v_product->get_attributes();
            } else {

                $item_data[ 'total_sales' ] = $product->get_total_sales();
                $item_data[ 'is_featured' ] = $product->is_featured();
                $item_data[ 'category_ids' ] = $product->get_category_ids();
                $item_data[ 'tag_ids' ] = $product->get_tag_ids();

                $db_attrs = $product->get_attributes();
            }

            $attrs = array();
            foreach ( $db_attrs as $db_attr ) {
                foreach ( $db_attr->get_options() as $attr_option ) {
                    $attrs[] = $attr_option;
                }
            }

            $item_data[ 'attribute_ids' ] = $attrs;


            if ( has_filter( 'woopcd_partialcod/get-cart-product-data' ) ) {
                $item_data = apply_filters( 'woopcd_partialcod/get-cart-product-data', $item_data, $product, $item_key );
            }
            return $item_data;
        }

        private static function get_totals_data( $cart_data, $cart ) {

            $cart_data[ 'totals' ] = $cart->get_totals();



            if ( has_filter( 'woopcd_partialcod/get-cart-totals' ) ) {
                $cart_data[ 'totals' ] = apply_filters( 'woopcd_partialcod/get-cart-totals', $cart_data[ 'totals' ], $cart_data[ 'source' ], $cart );
            }
            return self::get_fees_data( $cart_data, $cart );
        }

        private static function get_fees_data( $cart_data, $cart ) {

            $fee_keys = WOOPCD_PartialCOD_Cart::get_session_data( 'fee_keys', array() );
            $discount_keys = WOOPCD_PartialCOD_Cart::get_session_data( 'discount_keys', array() );

            $prev_cart_fees = WOOPCD_PartialCOD_Cart::get_session_data( 'previous_fees', array() );

            $partialcod_fees = array();
            $partialcod_discounts = array();
            $external_fees = array();

            foreach ( $prev_cart_fees as $key => $fee ) {

                if ( !in_array( $key, $fee_keys ) && !in_array( $key, $discount_keys ) ) {
                    $external_fees[ $key ] = $fee;
                }
            }


            $cart_data[ 'external_fees' ] = $external_fees;

            if ( has_filter( 'woopcd_partialcod/get-external-fees' ) ) {
                $cart_data[ 'partialcod_fees' ] = apply_filters( 'woopcd_partialcod/get-external-fees', $cart_data[ 'external_fees' ], $cart_data[ 'source' ], $cart );
            }


            return self::get_applied_coupons( $cart_data, $cart );
        }

        private static function get_applied_coupons( $cart_data, $cart ) {

            $cart_data[ 'partialcod_coupons' ] = array();
            $cart_data[ 'applied_coupons' ] = array();


            $coupon_discount_totals = WC()->session->get( 'coupon_discount_totals', array() );
            $coupon_discount_tax_totals = WC()->session->get( 'coupon_discount_tax_totals', array() );
            $coupons = WC()->session->get( 'applied_coupons', array() );

            $partialcod = WOOPCD_PartialCOD_Cart::get_session_data( 'coupons', array() );


            foreach ( $coupons as $coupon ) {
                if ( in_array( $coupon, $partialcod ) ) {
                    $cart_data[ 'partialcod_coupons' ][] = $coupon;
                }
                $cart_coupon = array(
                    'coupon_code' => $coupon,
                    'discount_totals' => 0,
                    'discount_tax_totals' => 0
                );

                if ( isset( $coupon_discount_totals[ $coupon ] ) ) {
                    $cart_coupon[ 'discount_totals' ] = $coupon_discount_totals[ $coupon ];
                }

                if ( isset( $coupon_discount_tax_totals[ $coupon ] ) ) {
                    $cart_coupon[ 'discount_tax_totals' ] = $coupon_discount_tax_totals[ $coupon ];
                }

                $cart_data[ 'applied_coupons' ][] = $cart_coupon;
            }

            if ( has_filter( 'woopcd_partialcod/get-cart-applied-coupons' ) ) {
                $cart_data[ 'applied_coupons' ] = apply_filters( 'woopcd_partialcod/get-cart-applied-coupons', $cart_data[ 'applied_coupons' ], $cart_data[ 'source' ], $cart );
            }

            return self::get_shipping_rate( $cart_data, $cart );
        }

        private static function get_shipping_rate( $cart_data, $cart ) {

            $needs_shipping = $cart->needs_shipping();

            $cart_data[ 'needs_shipping' ] = $needs_shipping;

            $cart_data[ 'shipping_rates' ] = array();

            $chosen_rate = WC()->session->get( 'chosen_shipping_methods', array() );

            $cnt = 0;

            while ( $package = WC()->session->get( 'shipping_for_package_' . $cnt, false ) ) {

                if ( isset( $package[ 'rates' ] ) && $needs_shipping ) {
                    foreach ( $package[ 'rates' ] as $key => $shipping_rate ) {

                        if ( in_array( $shipping_rate->get_id(), $chosen_rate ) ) {
                            $rate_id = $shipping_rate->get_id();
                            $cart_data[ 'shipping_rates' ][] = array(
                                'id' => $rate_id,
                                'method_id' => $shipping_rate->get_method_id(),
                                'instance_id' => $shipping_rate->get_instance_id(),
                                'cost' => $shipping_rate->get_cost(),
                                'shipping_tax' => $shipping_rate->get_shipping_tax(),
                                'taxes' => $shipping_rate->get_taxes(),
                            );
                        }
                    }
                }
                $cnt++;
            }


            if ( has_filter( 'woopcd_partialcod/get-cart-shipping-rates' ) ) {
                $cart_data[ 'shipping_rates' ] = apply_filters( 'woopcd_partialcod/get-cart-shipping-rates', $cart_data[ 'shipping_rates' ], $cart_data[ 'source' ], $cart );
            }

            return self::get_payment_method( $cart_data, $cart );
        }

        private static function get_payment_method( $cart_data, $cart ) {

            $cart_data[ 'method_ids' ] = array(
                'riskfree_id' => WOOPCD_PartialCOD_Cart::get_session_data( 'rf_method_id', '' ),
                'method_id' => WC()->session->get( 'chosen_payment_method', '' )
            );

            if ( class_exists( 'WOOPCD_PartialCOD_Cart_Session' ) ) {

                $cart_session = WOOPCD_PartialCOD_Cart_Session::get_instance();

                $cart_data[ 'method_ids' ][ 'method_id' ] = $cart_session->get_payment_method_id();
            }

            if ( has_filter( 'woopcd_partialcod/get-cart-method-ids' ) ) {
                $cart_data[ 'method_ids' ] = apply_filters( 'woopcd_partialcod/get-cart-method-ids', $cart_data[ 'method_ids' ], $cart_data[ 'source' ], $cart );
            }

            return self::get_customer( $cart_data, $cart );
        }

        private static function get_customer( $cart_data, $cart ) {

            $cart_data[ 'customer' ] = array();

            $customer = WC()->session->get( 'customer', false );

            if ( $customer ) {

                $cart_data[ 'customer' ] = array(
                    'id' => $customer[ 'id' ],
                    'email' => $customer[ 'email' ],
                );
            }

            if ( has_filter( 'woopcd_partialcod/get-cart-customer' ) ) {

                $cart_data[ 'customer' ] = apply_filters( 'woopcd_partialcod/get-cart-customer', $cart_data[ 'customer' ], $cart );
            }

            return $cart_data;
        }

        private static function get_parent_product( $parent_id ) {
            if ( isset( self::$parent_products[ $parent_id ] ) ) {
                return self::$parent_products[ $parent_id ];
            }
            self::$parent_products[ $parent_id ] = wc_get_product( $parent_id );
            return self::$parent_products[ $parent_id ];
        }

    }

}