<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WOOPCD_PartialCOD_Notifications' ) ) {

    class WOOPCD_PartialCOD_Notifications {

        public static function process_messages( $cart_data ) {

            // Cart discounts notifications
            self::process_group_messages( $cart_data, 'discounts' );

            // Cart fees notifications
            self::process_group_messages( $cart_data, 'fees' );
        }

        private static function process_group_messages( $cart_data, $group ) {

            // Cart notifications
            $notify_objs = self::get_message_objs( $cart_data, $group );
            if ( self::can_apply_messages( $notify_objs, $group ) ) {
                self::apply_notifications( $notify_objs, $group );
                self::store_hash( $notify_objs, $group );
            }
        }

        private static function apply_notifications( $notify_objs, $group ) {
            
            $allowed_html = WOOPCD_PartialCOD_Main::get_allow_html();
            
            foreach ( $notify_objs as $key => $notify_obj ) {

                $noti_message = wp_kses( self::prepare_message( $notify_obj, $key, $group ), $allowed_html );

                $message_type = "success";

                if ( !wc_has_notice( $noti_message, $message_type ) ) {

                    wc_add_notice( $noti_message, $message_type );
                }
            }
        }

        private static function get_message_objs( $cart_data, $group ) {

            $msgs = array();

            if ( isset( $cart_data[ $group ] ) ) {

                foreach ( $cart_data[ $group ] as $key => $message_data ) {
                    if ( isset( $message_data[ 'notify' ] ) && '' != $message_data[ 'notify' ] ) {

                        $msg = array(
                            'title' => $message_data[ 'title' ],
                            'amount' => $message_data[ 'amount' ],
                            'amount_tax' => $message_data[ 'amount_tax' ],
                            'notify' => $message_data[ 'notify' ],
                            'rule_id' => $key,
                            'method_id' => $message_data[ 'method_id' ],
                        );

                        $msgs[ $key ] = apply_filters( 'woopcd_partialcod/process-' . $group . '-message', $msg );
                    }
                }
            } else {

                self::store_hash( array(), $group );
            }

            return $msgs;
        }

        private static function can_apply_messages( $hash_obj, $group ) {


            $settings = self::get_notify_settings( $group );



            if ( 'no' == $settings[ 'show_on_cart' ] && is_cart() ) {
                self::store_hash( array(), $group ); // clear hash for later use
                return false;
            }




            if ( 'no' == $settings[ 'enable_notifications' ] ) {
                self::store_hash( array(), $group ); // clear hash for later use
                return false;
            }



            if ( !is_admin() && defined( 'DOING_AJAX' ) && 'yes_always' == $settings[ 'enable_notifications' ] && is_cart() ) {
                $settings[ 'enable_notifications' ] = 'yes'; // prevents long list of messages
            }


            if ( 'yes_always' == $settings[ 'enable_notifications' ] ) {
                return true;
            }

            $s_hash = self::get_stored_hash( $group );
            $hash = self::get_hash( $hash_obj );
            return ($s_hash != $hash && $hash != '');
        }

        private static function store_hash( $hash_obj, $group ) {

            WOOPCD_PartialCOD_Cart::set_session_data( $group, self::get_hash( $hash_obj ) );
        }

        private static function get_hash( $hash_obj ) {
            if ( count( $hash_obj ) > 0 ) {
                return md5( wp_json_encode( $hash_obj ) );
            }
            return '';
        }

        private static function get_stored_hash( $group ) {
            return WOOPCD_PartialCOD_Cart::get_session_data( $group, '' );
        }

        private static function get_notify_settings( $group ) {

            if ( 'discounts' == $group ) {
                return WOOPCD_PartialCOD::get_option( 'cart_discount_settings', array( 'show_on_cart' => 'no', 'enable_notifications' => 'no' ) );
            }

            if ( 'fees' == $group ) {
                return WOOPCD_PartialCOD::get_option( 'cart_fee_settings', array( 'show_on_cart' => 'no', 'enable_notifications' => 'no' ) );
            }
            return '';
        }

        private static function prepare_message( $notify_obj, $key, $group ) {

            if ( has_filter( 'woopcd_partialcod/cart-notification-message' ) ) {
                $notify_obj = apply_filters( 'woopcd_partialcod/cart-notification-message', $notify_obj, $key, $group );
            }

            return self::prepare_title( $notify_obj[ 'notify' ], $notify_obj );
        }

        private static function prepare_title( $message, $notify_obj ) {
            $msg = preg_replace( '/{{title}}/', $notify_obj[ 'title' ], $message );
            return self::prepare_amount_ex_tax( $msg, $notify_obj );
        }

        private static function prepare_amount_ex_tax( $message, $notify_obj ) {
            $msg = preg_replace( '/{{amount_ex_tax}}/', wc_price( $notify_obj[ 'amount' ] ), $message );
            return self::prepare_amount_inc_tax( $msg, $notify_obj );
        }

        private static function prepare_amount_inc_tax( $message, $notify_obj ) {
            $amount_inc_tax = $notify_obj[ 'amount' ] + $notify_obj[ 'amount_tax' ];
            return preg_replace( '/{{amount_inc_tax}}/', wc_price( $amount_inc_tax ), $message );
        }

    }

}






