<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WOOPCD_PartialCOD_Order' ) ) {

    class WOOPCD_PartialCOD_Order {

        private static $order_list;
        private static $is_db_order_total = false;

        public static function get_is_db_order_total() {

            if ( self::$is_db_order_total ) {

                return true;
            }

            return apply_filters( 'woopcd_partialcod/is_db_order_total', false );
        }

        /**
         * @return bool|null|WC_Order|WC_Order_Refund
         */
        public static function get_order( $order_id, $default = null ) {

            if ( isset( self::$order_list[ $order_id ] ) ) {
                return self::$order_list[ $order_id ];
            }

            $order = wc_get_order( $order_id );

            if ( is_wp_error( $order_id ) ) {

                return $default;
            }

            if ( !$order ) {

                return $default;
            }

            self::$order_list[ $order_id ] = $order;

            return self::$order_list[ $order_id ];
        }

        public static function get_db_order_total( $order ) {

            self::$is_db_order_total = true;

            $order_total = $order->get_total();

            self::$is_db_order_total = false;

            return $order_total;
        }

        public static function get_data( $order_id, $source ) {
            $order_data = array(
                'source' => $source,
            );

            $order = self::get_order( $order_id );

            if ( is_null( $order ) ) {
                return $order_data;
            }

            return self::get_props( $order_data, $order );
        }

        private static function get_props( $order_data, $order ) {

            $order_data[ 'id' ] = $order->get_id();
            $order_data[ 'order_number' ] = $order->get_order_number();
            $order_data[ 'version' ] = $order->get_version();
            $order_data[ 'status' ] = $order->get_status();
            $order_data[ 'currency' ] = $order->get_currency();
            $order_data[ 'prices_include_tax' ] = $order->get_prices_include_tax();
            $order_data[ 'is_download_permitted' ] = $order->is_download_permitted();
            $order_data[ 'is_editable' ] = $order->is_editable();
            $order_data[ 'is_paid' ] = $order->is_paid();

            $order_data[ 'needs_payment' ] = $order->needs_payment();
            $order_data[ 'needs_processing' ] = $order->needs_processing();
            $order_data[ 'needs_shipping_address' ] = $order->needs_shipping_address();

            return self::get_items( $order_data, $order );
        }

        private static function get_items( $order_data, $order ) {

            foreach ( $order->get_items() as $key => $item ) {
                $order_data[ 'order_items' ][ $key ] = self::get_item( $item );
            }

            return self::get_totals( $order_data, $order );
        }

        private static function get_item( $order_item ) {

            $item = array(
                'product_id' => $order_item[ 'product_id' ],
                'variation_id' => $order_item[ 'variation_id' ],
                'quantity' => $order_item[ 'quantity' ],
                'tax_status' => $order_item->get_tax_status(),
                'tax_class' => $order_item[ 'tax_class' ],
                'subtotal' => $order_item[ 'subtotal' ],
                'subtotal_tax' => $order_item[ 'subtotal_tax' ],
                'total' => $order_item[ 'total' ],
                'total_tax' => $order_item[ 'total_tax' ],
            );

            return $item;
        }

        private static function get_totals( $order_data, $order ) {

            $totals = array();
            $totals[ 'subtotal' ] = $order->get_subtotal();
            $totals[ 'discount_total' ] = $order->get_discount_total();
            $totals[ 'discount_tax' ] = $order->get_discount_tax();
            $totals[ 'shipping_total' ] = $order->get_shipping_total();
            $totals[ 'shipping_tax' ] = $order->get_shipping_tax();
            $totals[ 'total_fees' ] = $order->get_total_fees();
            $totals[ 'total' ] = self::get_db_order_total( $order );
            $totals[ 'total_tax' ] = $order->get_total_tax();
            $totals[ 'total_shipping_refunded' ] = $order->get_total_shipping_refunded();
            $totals[ 'total_refunded' ] = $order->get_total_refunded();
            $totals[ 'total_tax_refunded' ] = $order->get_total_tax_refunded();

            $order_data[ 'totals' ] = $totals;

            return self::get_dates( $order_data, $order );
        }

        private static function get_dates( $order_data, $order ) {

            $order_data[ 'created_via' ] = $order->get_created_via();
            $order_data[ 'date_created' ] = self::get_datetime_array( $order->get_date_created() );
            $order_data[ 'date_modified' ] = self::get_datetime_array( $order->get_date_modified() );
            $order_data[ 'date_paid' ] = self::get_datetime_array( $order->get_date_paid() );
            $order_data[ 'date_completed' ] = self::get_datetime_array( $order->get_date_completed() );

            return self::get_shipping( $order_data, $order );
        }

        private static function get_shipping( $order_data, $order ) {

            $shippings = array();

            foreach ( $order->get_shipping_methods() as $shipping_method ) {

                $shipping = array(
                    'id' => $shipping_method->get_id(),
                    'name' => $shipping_method->get_name(),
                    'method_id' => $shipping_method->get_method_id(),
                    'instance_id' => $shipping_method->get_instance_id(),
                    'method_title' => $shipping_method->get_method_title(),
                    'total' => $shipping_method->get_total(),
                    'total_tax' => $shipping_method->get_total_tax(),
                );

                $taxes = $shipping_method->get_taxes();
                if ( isset( $taxes[ 'total' ] ) ) {
                    $shipping[ 'taxes' ] = $taxes[ 'total' ];
                }

                $shippings[] = $shipping;
            }

            $order_data[ 'shipping_rates' ] = $shippings;

            return self::get_fees( $order_data, $order );
        }

        private static function get_fees( $order_data, $order ) {
            $fees = array();

            foreach ( $order->get_fees() as $order_fee ) {
                $fee = array();
                $fee[ 'id' ] = $order_fee->get_id();
                $fee[ 'name' ] = $order_fee->get_name();
                $fee[ 'total' ] = $order_fee->get_total();
                $fee[ 'total_tax' ] = $order_fee->get_total_tax();
                $taxes = $order_fee->get_taxes();
                if ( isset( $taxes[ 'total' ] ) ) {
                    $fee[ 'taxes' ] = $taxes[ 'total' ];
                }

                $fee_meta = $order_fee->get_meta( 'woopcd_partialcod_data', true );
                if ( $fee_meta ) {
                    $fee[ 'woopcd_partialcod_data' ] = $fee_meta;
                }

                $fees[] = $fee;
            }
            $order_data[ 'fees' ] = $fees;

            return self::get_payment_method( $order_data, $order );
        }

        private static function get_payment_method( $order_data, $order ) {

            $payment_method = array(
                'method_id' => $order->get_payment_method(),
                'method_title' => $order->get_payment_method_title()
            );

            $order_data[ 'payment_method' ] = $payment_method;

            $order_data[ 'risk_free' ] = array();

            $risk_free = $order->get_meta( 'woopcd_partialcod_riskfree', true );

            if ( $risk_free ) {
                $order_data[ 'risk_free' ] = $risk_free;
            }

            $order_data[ 'allowed_methods' ] = array();

            $allowed_methods = $order->get_meta( 'woopcd_partialcod_methods', true );

            if ( $allowed_methods ) {
                $order_data[ 'allowed_methods' ] = $allowed_methods;
            }

            return self::get_coupons( $order_data, $order );
        }

        private static function get_coupons( $order_data, $order ) {

            $coupons = array();

            foreach ( $order->get_coupons() as $coupon ) {

                $coupon_data = $coupon->get_data();
                $coupons[] = array(
                    'coupon_code' => $coupon_data[ 'code' ],
                    'discount' => $coupon_data[ 'discount' ],
                    'discount_tax' => $coupon_data[ 'discount_tax' ],
                );
            }

            $order_data[ 'applied_coupons' ] = $coupons;

            return self::get_customer( $order_data, $order );
        }

        private static function get_customer( $order_data, $order ) {

            $order_data[ 'customer' ] = array(
                'id' => $order->get_customer_id(),
                'ip_address' => $order->get_customer_ip_address(),
            );

            return $order_data;
        }

        private static function get_datetime_array( $datetime ) {

            if ( !$datetime ) {

                return array();
            }

            if ( !method_exists( $datetime, 'format' ) ) {

                return array();
            }

            return array(
                'date' => $datetime->format( 'Y-m-d' ),
                'time' => $datetime->format( 'H:i:s' ),
                'timestamp' => $datetime->getTimestamp(),
                'timezone' => $datetime->getTimezone()->getName()
            );
        }

    }

}