<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WOOPCD_PartialCOD_Premium' ) ) {

    require_once dirname( __FILE__ ) . '/utils/utils.php';

    require_once dirname( __FILE__ ) . '/partialcod-notifications.php';
    require_once dirname( __FILE__ ) . '/partialcod-email.php';
    require_once dirname( __FILE__ ) . '/partialcod-cart.php';
    require_once dirname( __FILE__ ) . '/partialcod-order.php';

    require_once dirname( __FILE__ ) . '/modules/method-options/method-options.php';
    require_once dirname( __FILE__ ) . '/modules/risk-free/risk-free.php';
    require_once dirname( __FILE__ ) . '/modules/cart-discounts/cart-discounts.php';
    require_once dirname( __FILE__ ) . '/modules/cart-fees/cart-fees.php';
    require_once dirname( __FILE__ ) . '/modules/order-activities/order-activities.php';

    require_once dirname( __FILE__ ) . '/condition-types/condition-types.php';
    require_once dirname( __FILE__ ) . '/product-filter-types/product-filter-types.php';
    require_once dirname( __FILE__ ) . '/order-condition-types/order-condition-types.php';
    require_once dirname( __FILE__ ) . '/amount-types/amount-types.php';
    require_once dirname( __FILE__ ) . '/option-types/option-types.php';
    require_once dirname( __FILE__ ) . '/payment-amount-types/payment-amount-types.php';
    require_once dirname( __FILE__ ) . '/order-activity-trigger-types/order-activity-trigger-types.php';
    require_once dirname( __FILE__ ) . '/order-activity-types/order-activity-types.php';

    require_once dirname( __FILE__ ) . '/cart-total-types/cart-total-types.php';
    require_once dirname( __FILE__ ) . '/order-total-types/order-total-types.php';

    class WOOPCD_PartialCOD_Premium {

        private $riskfree;
        private $order_activities;
        private $created_via_checkout = false;

        public function __construct() {

            $this->riskfree = new WOOPCD_PartialCOD_RiskFree();
            $this->order_activities = new WOOPCD_PartialCOD_Order_Activity();

            add_filter( 'woopcd_partialcod/get-allow-methods', array( $this, 'get_allow_methods' ), 1, 2 );

            add_action( 'woocommerce_checkout_process', array( $this, 'checkout_process' ), WOOPCD_PARTIALCOD_HOOKS_INDEX );
            add_action( 'woopcd_partialcod/order_processed', array( $this, 'order_processed' ), 10, 3 );
            add_filter( 'woocommerce_order_get_total', array( $this, 'order_get_total' ), WOOPCD_PARTIALCOD_HOOKS_INDEX, 2 );
            add_filter( 'woocommerce_get_formatted_order_total', array( $this, 'get_formatted_order_total' ), WOOPCD_PARTIALCOD_HOOKS_INDEX, 4 );
            add_filter( 'woocommerce_get_order_item_totals', array( $this, 'get_order_item_totals' ), WOOPCD_PARTIALCOD_HOOKS_INDEX, 3 );

            add_filter( 'woocommerce_update_order_review_fragments', array( $this, 'update_order_review_fragments' ), WOOPCD_PARTIALCOD_HOOKS_INDEX - 1, 1 );
            add_action( 'woocommerce_checkout_order_review', array( $this, 'checkout_order_review' ), WOOPCD_PARTIALCOD_HOOKS_INDEX );

            add_action( 'woocommerce_cart_totals_after_order_total', array( $this, 'checkout_after_totals' ), WOOPCD_PARTIALCOD_HOOKS_INDEX );
            add_action( 'woocommerce_review_order_after_order_total', array( $this, 'checkout_after_totals' ), WOOPCD_PARTIALCOD_HOOKS_INDEX );

            add_filter( 'woopcd_partialcod/rest-prepare-data', array( $this, 'rest_prepare_data' ), 10 );

            add_action( 'woopcd_partialcod/trigger-order-activities', array( $this, 'trigger_activities' ), 10, 2 );

            add_action( 'woocommerce_after_calculate_totals', array( $this, 'store_fees_data' ), WOOPCD_PARTIALCOD_HOOKS_INDEX );

            add_filter( 'woocommerce_cart_get_total', array( $this, 'get_cart_total' ), WOOPCD_PARTIALCOD_HOOKS_INDEX );
        }

        public static function get_available_gateways( $gateways, $cart_data ) {

            return apply_filters( 'woopcd_partialcod/get-allow-methods', $gateways, $cart_data );
        }

        public function get_allow_methods( $gateways, $cart_data ) {
            return $this->riskfree->get_allowed_methods( $gateways, $cart_data );
        }

        public function checkout_process() {
            if ( is_admin() ) {
                return;
            }
            $this->created_via_checkout = true;
        }

        public static function get_order_available_methods( $method_ids ) {
            $not_riskfree_ids = array();

            foreach ( $method_ids as $method_id ) {
                if ( WOOPCD_PartialCOD_Main::is_risky_method( $method_id ) ) {
                    continue;
                }
                $not_riskfree_ids[] = $method_id;
            }
            return $not_riskfree_ids;
        }

        public static function checkout_order_processed( $order_id, $posted_data, $order ) {
            return do_action( 'woopcd_partialcod/order_processed', $order_id, $posted_data, $order );
        }

        public function order_processed( $order_id, $posted_data, $order ) {
            if ( is_admin() ) {
                $this->created_via_checkout = false;
                return;
            }
            if ( is_wp_error( $order_id ) ) {
                $this->created_via_checkout = false;
                return;
            }
            // Get cart data
            $cart_data = WOOPCD_PartialCOD::process_cart_data( 'riskfree_details' );


            // Add Order data
            $this->riskfree->add_order_data( $order_id, $cart_data );

            $this->created_via_checkout = false;
        }

        public function order_get_total( $total, $order ) {

            if ( WOOPCD_PartialCOD_Order::get_is_db_order_total() ) {

                return $total;
            }

            if ( is_admin() ) {
                return $total;
            }

            if ( $order->is_paid() ) {
                return $total;
            }


            //Check if order total should be adjusted
            $settings = WOOPCD_PartialCOD::get_option( 'riskfree_settings', array( 'enable_on_my_account' => 'yes_only', 'enable_on_email' => 'yes_only' ) );

            if ( is_order_received_page() ) {
                return $total;
            }


            if ( 'yes' != $settings[ 'enable_on_my_account' ] && is_account_page() ) {
                return $total;
            }

            if ( 'yes' != $settings[ 'enable_on_email' ] && WOOPCD_PartialCOD_Email::is_email() ) {
                return $total;
            }

            // Adjust order total
            $total = $this->riskfree->get_order_total( $total, $order->get_id() );

            return $total;
        }

        public function get_formatted_order_total( $formatted_total, $order = null, $tax_display = '', $display_refunded = true ) {

            if ( $order->is_paid() ) {
                return $formatted_total;
            }

            if ( !is_checkout() ) {
                return $formatted_total;
            }
            return $this->riskfree->get_formatted_order_total( $formatted_total, $order, $tax_display, $display_refunded );
        }

        public function get_order_item_totals( $total_rows, $order, $tax_display ) {

            if ( is_admin() ) {
                return $total_rows;
            }

            //Check if order total should be adjusted
            $settings = WOOPCD_PartialCOD::get_option( 'riskfree_settings', array( 'enable_on_my_account' => 'yes_only', 'enable_on_email' => 'yes_only' ) );


            if ( 'no' == $settings[ 'enable_on_my_account' ] && is_account_page() ) {
                return $total_rows;
            }

            if ( 'no' == $settings[ 'enable_on_email' ] && WOOPCD_PartialCOD_Email::is_email() ) {
                return $total_rows;
            }


            // Apply partial payment order item details
            return $this->riskfree->get_order_item_totals( $total_rows, $order );
        }

        public function update_order_review_fragments( $fragments ) {
            ob_start();

            // Get cart data
            $cart_data = WOOPCD_PartialCOD::process_cart_data( 'riskfree_details' );

            // Get riskfree data
            $methods = $this->riskfree->get_methods( $cart_data );

            // Render description
            include 'views/riskfree-desc.php';
            $html = ob_get_clean();
            $fragments[ '#riskfree_data' ] = $html;

            return $fragments;
        }

        public function checkout_order_review() {

            if ( is_admin() ) {
                return;
            }



            // Get cart data
            $cart_data = WOOPCD_PartialCOD::process_cart_data( 'riskfree_details' );

            // Get riskfree data
            $methods = $this->riskfree->get_methods( $cart_data );

            // Render description
            include 'views/riskfree-desc.php';
        }

        public function checkout_after_totals() {

            //Check if advance payment information should be shown on cart page
            $settings = WOOPCD_PartialCOD::get_option( 'riskfree_settings', array( 'enable_on_cart' => 'no' ) );

            if ( 'no' == $settings[ 'enable_on_cart' ] && is_cart() ) {
                return;
            }

            // Get cart data
            $cart_data = WOOPCD_PartialCOD::process_cart_data( 'riskfree_details' );

            // Get advance payment informations
            $advance_info = $this->riskfree->get_advance_payment_info( $cart_data );
            if ( !count( $advance_info ) ) {
                return;
            }

            include 'views/risk-free-details.php';
        }

        public function get_cart_total( $total ) {

            // Get cart data
            $cart_data = WOOPCD_PartialCOD::process_cart_data( 'riskfree_details' );

            // Get advance payment informations
            $advance_info = $this->riskfree->get_advance_payment_info( $cart_data );

            return $this->riskfree->get_cart_total( $total, $advance_info );
        }

        public function trigger_activities( $order_id, $source ) {

            $order_data = self::process_order_data( $order_id, $source );

            $this->order_activities->process_activities( $order_id, $order_data );
        }

        public static function process_order_data( $order_id, $source ) {

            // Pre-process all data
            $order_data = array(
                'wc' => WOOPCD_PartialCOD_Order::get_data( $order_id, $source )
            );

            // Process all data
            return apply_filters( 'woopcd_partialcod/process-order-data', $order_data );
        }

        public static function rest_prepare( $response ) {
            return apply_filters( 'woopcd_partialcod/rest-prepare-data', $response );
        }

        public function rest_prepare_data( $response ) {
            return $this->riskfree->prepare_rest_data( $response );
        }

        public function store_fees_data( $cart ) {
            $fees = array();

            foreach ( $cart->get_fees() as $key => $fee ) {
                $fees[ $key ][ 'total' ] = $fee->total;
                $fees[ $key ][ 'tax' ] = $fee->tax;
                $fees[ $key ][ 'tax_data' ] = $fee->tax_data;
            }

            WOOPCD_PartialCOD_Cart::set_session_data( 'previous_fees', $fees );
        }

        public static function get_scrip_params( $script_params ) {

            $riskfree_checkbox = WOOPCD_PartialCOD::get_option( 'riskfree_checkbox', array( 'enabled' => 'no' ) );

            $script_params[ 'ajaxurl' ] = admin_url( 'admin-ajax.php' );
            $script_params[ 'custom_rf_box' ] = ('yes' == $riskfree_checkbox[ 'enabled' ]);

            return $script_params;
        }

    }

    new WOOPCD_PartialCOD_Premium();
}