<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WOOPCD_PartialCOD_Payment_Amount_Type_Cart_Totals' ) ) {

    class WOOPCD_PartialCOD_Payment_Amount_Type_Cart_Totals {

        private $types_prefix;
        private $option_list;

        public function __construct() {

            $this->types_prefix = 'cart_totals_';
            $this->option_list = array();

            foreach ( $this->get_options() as $option ) {

                $option_key = $this->types_prefix . $option[ 'option_id' ];

                add_filter( 'woopcd_partialcod/calculate-' . $option_key . '-payment-amount', array( $this, 'calculate_cart_totals_amount' ), 10, 3 );
            }
        }

        public function calculate_cart_totals_amount( $amount, $amount_args, $cart_data ) {

            $option_id = $this->get_option_id_by_args( $amount_args );

            if ( '' == $option_id ) {
                return $amount;
            }
            $amount = $this->get_cart_totals( $option_id, $cart_data );

            return $amount;
        }

        private function get_cart_totals( $option_id, $cart_data ) {

            $args = array(
                'module' => 'partial-payment',
                'option_id' => $option_id
            );

            return WOOPCD_PartialCOD_Cart_Total_Types::get_totals( $args, $cart_data );
        }

        private function get_option_id_by_args( $amount_args ) {

            foreach ( $this->get_options() as $option ) {
                if ( $amount_args[ 'amount_type' ] == $this->types_prefix . $option[ 'option_id' ] ) {
                    return $option[ 'option_id' ];
                }
            }
            return '';
        }

        private function get_options() {

            if ( count( $this->option_list ) ) {
                return $this->option_list;
            }

            $this->option_list = WOOPCD_PartialCOD::get_option( 'riskfree_cart_totals', $this->get_default_options() );

            return $this->option_list;
        }

        private function get_default_options() {
            return array(
                array(
                    'option_id' => '2234343',
                    'include' => array( 'subtotal', 'subtotal_tax' ),
                ),
                array(
                    'option_id' => '2234344',
                    'include' => array( 'subtotal' ),
                ),
            );
        }

    }

    new WOOPCD_PartialCOD_Payment_Amount_Type_Cart_Totals();
}