<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WOOPCD_PartialCOD_Payment_Amount_Type_Specifics' ) ) {

    class WOOPCD_PartialCOD_Payment_Amount_Type_Specifics {

        public function __construct() {
            
            add_filter( 'woopcd_partialcod/calculate-fixed_amount-payment-amount', array( $this, 'calculate_fixed_amount' ), 10, 3 );
            add_filter( 'woopcd_partialcod/calculate-fixed_amount_item-payment-amount', array( $this, 'calculate_fixed_item_amount' ), 10, 3 );
            add_filter( 'woopcd_partialcod/calculate-per_amount-payment-amount', array( $this, 'calculate_per_amount' ), 10, 3 );
        }

        public function calculate_fixed_amount( $amount, $amount_args, $cart_data ) {

            $amount = ( float ) $amount_args[ 'amount' ];

            return $amount;
        }

        public function calculate_fixed_item_amount( $amount, $amount_args, $cart_data ) {

            $amount = ( float ) $amount_args[ 'amount' ];

            if ( 0 == $amount ) {

                return $amount;
            }

            $cart_items = $this->get_cart_items( $cart_data, $amount_args );

            $quantity = $this->get_item_quantity( $cart_items );

            if ( 0 == $quantity ) {

                return $amount;
            }

            return $amount * $quantity;
        }

        public function calculate_per_amount( $amount, $amount_args, $cart_data ) {

            if ( 0 >= $amount_args[ 'amount' ] ) {

                return $amount;
            }

            $cart_totals = $this->get_cart_totals( $amount_args, $cart_data );

            $amount = ($amount_args[ 'amount' ] / 100) * $cart_totals;

            return $amount;
        }

        private function get_cart_totals( $amount_args, $cart_data ) {

            $args = array(
                'module' => 'partial-payment',
                'option_id' => $amount_args[ 'based_on' ]
            );

            return WOOPCD_PartialCOD_Cart_Total_Types::get_totals( $args, $cart_data );
        }

        private function get_item_quantity( $cart_items ) {
            
            $quantity = 0;

            foreach ( $cart_items as $cart_item ) {

                $quantity += $cart_item[ 'quantity' ];
            }

            return $quantity;
        }

        private function get_cart_items( $cart_data, $amount_args ) {

            $product_args = array();

            if ( isset( $amount_args[ 'products_args' ] ) && is_array( $amount_args[ 'products_args' ] ) ) {
                
                $product_args = $amount_args[ 'products_args' ];
            }

            return WOOPCD_PartialCOD_Product_Filter_Types::get_cart_items( $cart_data, $product_args );
        }

    }

    new WOOPCD_PartialCOD_Payment_Amount_Type_Specifics();
}

