<?php

if (!defined('ABSPATH')) {
    exit;
}

if (!class_exists('WOOPCD_PartialCOD_Payment_Amount_Types')) {
    WOOPCD_PartialCOD_Main::required_paths(dirname(__FILE__), array('payment-amount-types.php'));

    class WOOPCD_PartialCOD_Payment_Amount_Types {

        private $limits = -1;
        private static $instance = null;

        private static function get_instance() {
            if (null == self::$instance) {
                self::$instance = new self();
            }
            return self::$instance;
        }

        public static function calculate_amounts($amount, $amounts_args, $settings, $cart_data) {

            $limit = self::get_instance()->get_limit($settings, $cart_data);
            
            foreach ($amounts_args as $amount_args) {
            
                if (!self::get_instance()->can_calculate_amount($amount, $limit)) {
                
                    return $amount; //do nothing
                }

                $amount += apply_filters('woopcd_partialcod/calculate-' . $amount_args['amount_type'] . '-payment-amount', 0, $amount_args, $cart_data);
                
                if ($limit > 0 && $amount > $limit) {
                
                    $amount = $limit;
                }
            }

            // allows other plugins to modify the processed amount
            if (has_filter('woopcd_partialcod/calculated-payment-amount')) {
                
                $amount = apply_filters('woopcd_partialcod/calculated-payment-amount', $amount, $amount_args, $cart_data);
            }

            return $amount;
        }

        private function can_calculate_amount($prev_amount, $limit) {

            return ($limit <= 0 || $prev_amount < $limit);
        }

        private function get_limit($settings, $cart_data) {

            if ('no' == $settings['max_amount_type']) {
                return 0;
            }

            // cached limit value
            if ($this->limits >= 0) {
                return $this->limits;
            }

            $this->limits = 0;

            // process limit value
            $max_amount = $settings['max_amount'];
            if (!is_numeric($max_amount)) {
                $max_amount = 0;
            }

            if ('fixed_amount' == $settings['max_amount_type']) {
                $this->limits = $max_amount;
            }

            if ('per_amount' == $settings['max_amount_type']) {
                $args = array(
                    'module' => 'partial-payment',
                    'option_id' => $settings['base_on']
                );
                $cart_totals = WOOPCD_PartialCOD_Cart_Total_Types::get_totals($args, $cart_data);
                if ($cart_totals > 0) {
                    $this->limits = ($max_amount / 100) * $cart_totals;
                }
            }

            return $this->limits;
        }

    }

}