<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WOOPCD_PartialCOD_Product_Filter_Type_Products' ) ) {

    class WOOPCD_PartialCOD_Product_Filter_Type_Products {

        public function __construct() {

            add_filter( 'woopcd_partialcod/validate-spec_products-filter', array( $this, 'validate_specific_products' ), 1, 2 );
            add_filter( 'woopcd_partialcod/validate-product_var-filter', array( $this, 'validate_product_variations' ), 1, 2 );
            add_filter( 'woopcd_partialcod/validate-product_cats-filter', array( $this, 'validate_product_categories' ), 1, 2 );
            add_filter( 'woopcd_partialcod/validate-product_tags-filter', array( $this, 'validate_product_tags' ), 1, 2 );
            add_filter( 'woopcd_partialcod/validate-product_attrs-filter', array( $this, 'validate_product_attributes' ), 1, 2 );
            add_filter( 'woopcd_partialcod/validate-product_qty-filter', array( $this, 'validate_product_quantity' ), 1, 2 );
        }

        public function validate_specific_products( $filter_args, $cart_item ) {

            if ( !isset( $filter_args[ 'product_slugs' ] ) ) {
                return false;
            }

            $filter_product_ids = WOOPCD_PartialCOD_Util::get_product_ids_by_slugs( $filter_args[ 'product_slugs' ] );

            if ( !count( $filter_product_ids ) ) {
                return false;
            }

            $filter_compare = $filter_args[ 'compare' ];

            $product_id = $cart_item[ 'product_id' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value_list( $product_id, $filter_product_ids, $filter_compare );
        }

        public function validate_product_variations( $filter_args, $cart_item ) {

            if ( !isset( $filter_args[ 'variation_slugs' ] ) ) {
                return false;
            }

            $filter_variation_ids = WOOPCD_PartialCOD_Util::get_variation_ids_by_slugs( $filter_args[ 'variation_slugs' ] );

            if ( !count( $filter_variation_ids ) ) {
                return false;
            }

            $filter_compare = $filter_args[ 'compare' ];

            $variation_id = $cart_item[ 'variation_id' ];

            if ( 0 >= $variation_id ) {
                return false;
            }

            return WOOPCD_PartialCOD_Validation_Util::validate_value_list( $variation_id, $filter_variation_ids, $filter_compare );
        }

        public function validate_product_categories( $filter_args, $cart_item ) {

            if ( !isset( $filter_args[ 'category_slugs' ] ) ) {
                return false;
            }

            $filter_category_ids = WOOPCD_PartialCOD_Util::get_product_term_ids_by_slugs( $filter_args[ 'category_slugs' ], 'product_cat' );

            if ( !count( $filter_category_ids ) ) {
                return false;
            }

            $filter_compare = $filter_args[ 'compare' ];

            $category_ids = $cart_item[ 'data' ][ 'category_ids' ];


            return WOOPCD_PartialCOD_Validation_Util::validate_list_list( $category_ids, $filter_category_ids, $filter_compare );
        }

        public function validate_product_tags( $filter_args, $cart_item ) {

            if ( !isset( $filter_args[ 'tag_slugs' ] ) ) {
                return false;
            }

            $filter_tag_ids = WOOPCD_PartialCOD_Util::get_product_term_ids_by_slugs( $filter_args[ 'tag_slugs' ], 'product_tag' );

            if ( !count( $filter_tag_ids ) ) {
                return false;
            }

            $filter_compare = $filter_args[ 'compare' ];

            $tag_ids = $cart_item[ 'data' ][ 'tag_ids' ];


            return WOOPCD_PartialCOD_Validation_Util::validate_list_list( $tag_ids, $filter_tag_ids, $filter_compare );
        }

        public function validate_product_attributes( $filter_args, $cart_item ) {

            if ( !isset( $filter_args[ 'attribute_slugs' ] ) ) {
                return false;
            }

            $filter_attribute_ids = WOOPCD_PartialCOD_Util::get_attribute_ids_by_slugs( $filter_args[ 'attribute_slugs' ] );

            if ( !count( $filter_attribute_ids ) ) {
                return false;
            }

            $filter_compare = $filter_args[ 'compare' ];

            $attribute_ids = $cart_item[ 'data' ][ 'attribute_ids' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_list_list( $attribute_ids, $filter_attribute_ids, $filter_compare );
        }

        public function validate_product_quantity( $filter_args, $cart_item ) {

            $filter_quantity = 0;

            if ( is_numeric( $filter_args[ 'quantity' ] ) ) {
                $filter_quantity = $filter_args[ 'quantity' ];
            }

            if ( 0 >= $filter_quantity ) {
                return false;
            }

            $filter_compare = $filter_args[ 'compare' ];

            $item_quantity = $cart_item[ 'quantity' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $filter_compare, $item_quantity, $filter_quantity, 'no' );
        }

    }

    new WOOPCD_PartialCOD_Product_Filter_Type_Products();
}
