<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WOOPCD_PartialCOD_Product_Filter_Type_Properties' ) ) {

    class WOOPCD_PartialCOD_Product_Filter_Type_Properties {

        public function __construct() {
            add_filter( 'woopcd_partialcod/validate-item_is_virtual-filter', array( $this, 'validate_is_yes' ), 1, 2 );
            add_filter( 'woopcd_partialcod/validate-item_is_downloadable-filter', array( $this, 'validate_is_yes' ), 1, 2 );
            add_filter( 'woopcd_partialcod/validate-item_is_featured-filter', array( $this, 'validate_is_yes' ), 1, 2 );
            add_filter( 'woopcd_partialcod/validate-item_sales_total-filter', array( $this, 'validate_totals' ), 1, 2 );
            add_filter( 'woopcd_partialcod/validate-item_is_on_sale-filter', array( $this, 'validate_is_yes' ), 1, 2 );
            add_filter( 'woopcd_partialcod/validate-item_stock_status-filter', array( $this, 'validate_stock_status' ), 1, 2 );
            add_filter( 'woopcd_partialcod/validate-item_stock_quantity-filter', array( $this, 'validate_totals' ), 1, 2 );
            add_filter( 'woopcd_partialcod/validate-item_shipping_class-filter', array( $this, 'validate_shipping_class' ), 1, 2 );
            add_filter( 'woopcd_partialcod/validate-item_is_taxable-filter', array( $this, 'validate_is_yes' ), 1, 2 );
            add_filter( 'woopcd_partialcod/validate-item_tax_class-filter', array( $this, 'validate_tax_class' ), 1, 2 );
            add_filter( 'woopcd_partialcod/validate-item_weight-filter', array( $this, 'validate_weight' ), 1, 2 );
            add_filter( 'woopcd_partialcod/validate-item_length-filter', array( $this, 'validate_dimensions' ), 1, 2 );
            add_filter( 'woopcd_partialcod/validate-item_width-filter', array( $this, 'validate_dimensions' ), 1, 2 );
            add_filter( 'woopcd_partialcod/validate-item_height-filter', array( $this, 'validate_dimensions' ), 1, 2 );
            add_filter( 'woopcd_partialcod/validate-item_surface_area-filter', array( $this, 'validate_dimensions' ), 1, 2 );
            add_filter( 'woopcd_partialcod/validate-item_volume-filter', array( $this, 'validate_dimensions' ), 1, 2 );
            add_filter( 'woopcd_partialcod/validate-item_meta-filter', array( $this, 'validate_meta' ), 1, 2 );
        }

        public function validate_is_yes( $filter_args, $cart_item ) {

            $filter_type = $filter_args[ 'filter_type' ];

            $filter_value = 'no';

            if ( isset( $filter_args[ 'is_yes' ] ) && $filter_args[ 'is_yes' ] == 'yes' ) {

                $filter_value = 'yes';
            }

            $item_value = $this->get_is_yes( $filter_type, $cart_item );

            return WOOPCD_PartialCOD_Validation_Util::validate_yes_no( $item_value, $filter_value );
        }

        public function validate_totals( $filter_args, $cart_item ) {

            $filter_type = $filter_args[ 'filter_type' ];

            $filter_totals = 0;

            if ( is_numeric( $filter_args[ 'totals' ] ) ) {

                $filter_totals = $filter_args[ 'totals' ];
            }

            $filter_compare = $filter_args[ 'compare' ];

            $item_totals = $this->get_totals( $filter_type, $cart_item );

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $filter_compare, $item_totals, $filter_totals, 'no' );
        }

        public function validate_stock_status( $filter_args, $cart_item ) {

            if ( !is_array( $filter_args[ 'stock_statuses' ] ) ) {
                return false;
            }

            $filter_stock_statuses = $filter_args[ 'stock_statuses' ];

            $filter_compare = $filter_args[ 'compare' ];

            $item_stock_status = $cart_item[ 'data' ][ 'stock_status' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value_list( $item_stock_status, $filter_stock_statuses, $filter_compare );
        }

        public function validate_shipping_class( $filter_args, $cart_item ) {

            if ( !isset( $filter_args[ 'shipping_class_slugs' ] ) ) {
                return false;
            }

            $filter_shipping_class_ids = WOOPCD_PartialCOD_Util::get_product_term_ids_by_slugs( $filter_args[ 'shipping_class_slugs' ], 'product_shipping_class' );

            if ( !count( $filter_shipping_class_ids ) ) {
                return false;
            }

            $filter_compare = $filter_args[ 'compare' ];

            $item_shipping_class_id = $cart_item[ 'data' ][ 'shipping_class_id' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value_list( $item_shipping_class_id, $filter_shipping_class_ids, $filter_compare );
        }

        public function validate_tax_class( $filter_args, $cart_item ) {

            if ( !is_array( $filter_args[ 'tax_class_slugs' ] ) ) {
                return false;
            }

            $filter_tax_class_slugs = $filter_args[ 'tax_class_slugs' ];

            $filter_compare = $filter_args[ 'compare' ];

            $item_tax_class_slug = $this->get_tax_class( $cart_item );

            return WOOPCD_PartialCOD_Validation_Util::validate_value_list( $item_tax_class_slug, $filter_tax_class_slugs, $filter_compare );
        }

        public function validate_weight( $filter_args, $cart_item ) {


            $filter_weight = 0;

            if ( is_numeric( $filter_args[ 'weight' ] ) ) {

                $filter_weight = $filter_args[ 'weight' ];
            }

            $filter_compare = $filter_args[ 'compare' ];

            $item_weight = 0;

            if ( is_numeric( $cart_item[ 'data' ][ 'weight' ] ) ) {

                $item_weight = $cart_item[ 'data' ][ 'weight' ];
            }

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $filter_compare, $item_weight, $filter_weight, 'no' );
        }

        public function validate_dimensions( $filter_args, $cart_item ) {

            $filter_type = $filter_args[ 'filter_type' ];

            $filter_dimension = 0;

            if ( is_numeric( $filter_args[ 'dimension' ] ) ) {

                $filter_dimension = $filter_args[ 'dimension' ];
            }

            $filter_compare = $filter_args[ 'compare' ];

            $item_dimension = $this->get_dimensions( $filter_type, $cart_item );

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $filter_compare, $item_dimension, $filter_dimension, 'no' );
        }

        public function validate_meta( $filter_args, $cart_item ) {

            $yes_no = 'no';

            $filter_value = '';

            if ( isset( $filter_args[ 'yes_no' ] ) ) {
                $yes_no = $filter_args[ 'yes_no' ];
            }

            if ( isset( $filter_args[ 'meta_value' ] ) ) {
                $filter_value = $filter_args[ 'meta_value' ];
            }
            
            $filter_key = $filter_args[ 'meta_key' ];

            $meta_value = get_post_meta( $cart_item[ 'product_id' ], $filter_key, true );

            $filter_compare = $filter_args[ 'compare' ];

            return WOOPCD_PartialCOD_Validation_Util::validate_value( $filter_compare, $meta_value, $filter_value, $yes_no );
        }

        private function get_is_yes( $filter_type, $cart_item ) {

            switch ( $filter_type ) {

                case 'item_is_virtual':

                    return $cart_item[ 'data' ][ 'is_virtual' ];

                case 'item_is_downloadable':

                    return $cart_item[ 'data' ][ 'is_downloadable' ];

                case 'item_is_featured':

                    return $cart_item[ 'data' ][ 'is_featured' ];

                case 'item_is_on_sale':

                    return $cart_item[ 'data' ][ 'is_on_sale' ];

                case 'item_is_taxable':

                    return $cart_item[ 'data' ][ 'is_taxable' ];

                default:

                    return false;
            }
        }

        private function get_totals( $filter_type, $cart_item ) {

            switch ( $filter_type ) {

                case 'item_sales_total':

                    return $cart_item[ 'data' ][ 'total_sales' ];

                case 'item_stock_quantity':
                    if ( is_numeric( $cart_item[ 'data' ][ 'stock_quantity' ] ) ) {
                        return $cart_item[ 'data' ][ 'stock_quantity' ];
                    }
                    return 0;
                default:

                    return 0;
            }
        }

        private function get_tax_class( $cart_item ) {

            if ( 'taxable' == $cart_item[ 'data' ][ 'tax_status' ] && '' == $cart_item[ 'data' ][ 'tax_class' ] ) {
                return '--0';
            }
            return $cart_item[ 'data' ][ 'tax_class' ];
        }

        private function get_dimensions( $filter_type, $cart_item ) {

            switch ( $filter_type ) {

                case 'item_length':
                    if ( is_numeric( $cart_item[ 'data' ][ 'dimensions' ][ 'length' ] ) ) {
                        return $cart_item[ 'data' ][ 'dimensions' ][ 'length' ];
                    }
                    return 0;
                case 'item_width':
                    if ( is_numeric( $cart_item[ 'data' ][ 'dimensions' ][ 'width' ] ) ) {
                        return $cart_item[ 'data' ][ 'dimensions' ][ 'width' ];
                    }
                    return 0;
                case 'item_height':
                    if ( is_numeric( $cart_item[ 'data' ][ 'dimensions' ][ 'height' ] ) ) {
                        return $cart_item[ 'data' ][ 'dimensions' ][ 'height' ];
                    }
                    return 0;

                case 'item_surface_area':

                    $width = $cart_item[ 'data' ][ 'dimensions' ][ 'width' ];

                    $length = $cart_item[ 'data' ][ 'dimensions' ][ 'length' ];

                    if ( !is_numeric( $width ) ) {
                        return 0;
                    }

                    if ( !is_numeric( $length ) ) {
                        return 0;
                    }

                    return $length * $width;
                case 'item_volume':

                    $width = $cart_item[ 'data' ][ 'dimensions' ][ 'width' ];

                    $length = $cart_item[ 'data' ][ 'dimensions' ][ 'length' ];

                    $height = $cart_item[ 'data' ][ 'dimensions' ][ 'height' ];

                    if ( !is_numeric( $width ) ) {
                        return 0;
                    }

                    if ( !is_numeric( $length ) ) {
                        return 0;
                    }

                    if ( !is_numeric( $height ) ) {
                        return 0;
                    }

                    return ($length * $width) * $height;
                default:

                    return 0;
            }
        }

    }

    new WOOPCD_PartialCOD_Product_Filter_Type_Properties();
}