<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WOOPCD_PartialCOD_Product_Filter_Types' ) ) {
    WOOPCD_PartialCOD_Main::required_paths( dirname( __FILE__ ), array( 'product-filter-types.php' ) );

    class WOOPCD_PartialCOD_Product_Filter_Types {

        private static function get_instance() {
            return new self();
        }

        public static function get_cart_items( $cart_data, $product_filters ) {

            if ( !isset( $cart_data[ 'wc' ][ 'cart_items' ] ) ) {
                return array();
            }

            if ( !count( $product_filters ) ) {
                return $cart_data[ 'wc' ][ 'cart_items' ];
            }

            return self::get_instance()->validate_cart_items( $cart_data[ 'wc' ][ 'cart_items' ], $product_filters, $cart_data );
        }

        private function validate_cart_items( $cart_items, $product_filters, $cart_data ) {

            $items = array();

            foreach ( $cart_items as $key => $cart_item ) {

                if ( true == $this->validate_filters( $cart_item, $product_filters, $cart_data ) ) {

                    $items[ $key ] = $cart_item;
                }
            }

            return $items;
        }

        private function validate_filters( $cart_item, $product_filters, $cart_data ) {

            $is_valid = false;

            foreach ( $this->get_filters( $product_filters, true ) as $filter_args ) {

                $is_vld = apply_filters( 'woopcd_partialcod/validate-' . $filter_args[ 'filter_type' ] . '-filter', $filter_args, $cart_item, $cart_data );

                if ( true === $is_vld ) {
                    $is_valid = true;
                }
                
                if ( true != $is_valid ) {

                    return $is_valid;
                }
            }

            if ( true === $is_valid ) {
                return $is_valid;
            }

            foreach ( $this->get_filters( $product_filters, false ) as $filter_args ) {

                $is_vld_op = apply_filters( 'woopcd_partialcod/validate-' . $filter_args[ 'filter_type' ] . '-filter', $filter_args, $cart_item, $cart_data );

                if ( true === $is_vld_op ) {
                    $is_valid = true;
                }
            }

            return $is_valid;
        }

        private function get_filters( $product_filters, $is_required ) {

            $filters = array();

            foreach ( $product_filters as $product_filter ) {

                $filter_type = $product_filter[ 'filter_type' ];
                $filter_arg = $product_filter[ 'filter_type_' . $filter_type ];

                if ( true == $is_required && 'yes' != $filter_arg[ 'is_req' ] ) {
                    continue;
                }

                if ( true != $is_required && 'yes' == $filter_arg[ 'is_req' ] ) {
                    continue;
                }


                $filters[] = $this->prepare_filter( $filter_arg, $filter_type );
            }

            return $filters;
        }

        private function prepare_filter( $filter_args, $filter_type ) {

            $filter = array(
                'filter_type' => $filter_type
            );

            foreach ( $filter_args as $key => $value ) {
                $filter[ $key ] = $value;
            }

            return $filter;
        }

    }

}
