<?php

if ( !defined( 'ABSPATH' ) ) {

    exit;
}


if ( !class_exists( 'WOOPCD_PartialCOD_Order_History_Posts_Util' ) ) {

    class WOOPCD_PartialCOD_Order_History_Posts_Util {

        public function get_coupon_used( $user_id, $from_date, $default ) {

            $coupons_used = array();

            try {

                global $wpdb;

                $sql = "SELECT DISTINCT order_items.order_item_name as coupon_code FROM {$wpdb->prefix}posts AS posts"
                        . " LEFT JOIN {$wpdb->prefix}woocommerce_order_items AS order_items ON posts.id = order_items.order_id"
                        . " LEFT JOIN {$wpdb->prefix}postmeta AS mt_user ON posts.id = mt_user.post_id"
                        . " LEFT JOIN {$wpdb->prefix}postmeta AS mt_paid ON posts.id = mt_paid.post_id"
                        . " WHERE (posts.post_type = 'shop_order')";

                if ( !empty( $from_date ) ) {

                    $sql = $sql . " AND (mt_paid.meta_key = '_paid_date')"
                            . " AND (mt_paid.meta_value >= '" . esc_sql( $from_date ) . "')";
                }

                $sql = $sql . " AND (mt_user.meta_key = '_customer_user')"
                        . " AND (mt_user.meta_value = " . esc_sql( $user_id ) . ")"
                        . " AND (order_items.order_item_type = 'coupon')"
                        . " AND (posts.post_status IN ('wc-" . implode( "','wc-", array_map( 'esc_sql', wc_get_is_paid_statuses() ) ) . "'))";


                $results = $wpdb->get_results( $sql, ARRAY_A );

                $coupon_codes = array();

                foreach ( $results as $row ) {

                    $coupon_codes[] = $row[ 'coupon_code' ];
                }

                $sql = "SELECT post_name as coupon_slug FROM {$wpdb->prefix}posts"
                        . " WHERE (post_type='shop_coupon')"
                        . " AND (post_title IN('" . implode( "','", array_map( 'esc_sql', $coupon_codes ) ) . "'))";

                $results = $wpdb->get_results( $sql, ARRAY_A );

                foreach ( $results as $row ) {

                    $coupons_used[] = $row[ 'coupon_slug' ];
                }
            } catch ( Exception $ex ) {

                return $default;
            }

            return $coupons_used;
        }

        public function get_order_total( $user_id, $from_date, $total_type, $default ) {

            try {

                global $wpdb;

                $sql_select = "SELECT SUM(mt_total.meta_value)";

                $round_decimal = false;

                switch ( $total_type ) {
                    case 'COUNT':
                        $sql_select = "SELECT COUNT(posts.id)";
                        break;
                    case 'MIN':
                        $sql_select = "SELECT MIN(mt_total.meta_value)";
                        break;
                    case 'MAX':
                        $sql_select = "SELECT MAX(mt_total.meta_value)";
                        break;
                    case 'AVG':
                        $round_decimal = true;
                        $sql_select = "SELECT AVG(mt_total.meta_value)";
                        break;
                    default:
                        break;
                }

                $sql = $sql_select . " FROM {$wpdb->prefix}posts AS posts"
                        . " LEFT JOIN {$wpdb->prefix}postmeta AS mt_user ON posts.id = mt_user.post_id";

                if ( $from_date != '' ) {
                    $sql = $sql . " LEFT JOIN {$wpdb->prefix}postmeta AS mt_paid ON posts.id = mt_paid.post_id";
                }

                $sql = $sql . " LEFT JOIN {$wpdb->prefix}postmeta AS mt_total ON posts.id = mt_total.post_id"
                        . " WHERE (posts.post_type = 'shop_order')"
                        . " AND (posts.post_status IN('wc-" . implode( "','wc-", array_map( 'esc_sql', wc_get_is_paid_statuses() ) ) . "'))"
                        . " AND (mt_user.meta_key = '_customer_user')"
                        . " AND (mt_user.meta_value = " . esc_sql( $user_id ) . ")"
                        . " AND (mt_total.meta_key = '_order_total')";

                if ( $from_date != '' ) {
                    $sql = $sql . " AND (mt_paid.meta_key = '_paid_date')"
                            . " AND (mt_paid.meta_value >= '" . esc_sql( $from_date ) . "')";
                }

                $results = $wpdb->get_var( $sql );

                if ( !$results ) {

                    return $default;
                }

                if ( $round_decimal == true ) {

                    return WOOPCD_PartialCOD_Util::round_num( $results, wc_get_price_decimals() );
                }

                return $results;
            } catch ( Exception $ex ) {
                
            }

            return $default;
        }

        public function get_last_order_date( $user_id, $default ) {

            try {

                global $wpdb;

                $sql = "SELECT mt_paid.meta_value FROM {$wpdb->prefix}posts AS posts"
                        . " LEFT JOIN {$wpdb->prefix}postmeta AS mt_user ON posts.id = mt_user.post_id"
                        . " LEFT JOIN {$wpdb->prefix}postmeta AS mt_paid ON posts.id = mt_paid.post_id"
                        . " WHERE (posts.post_type = 'shop_order')"
                        . " AND (posts.post_status IN('wc-" . implode( "','wc-", array_map( 'esc_sql', wc_get_is_paid_statuses() ) ) . "'))"
                        . " AND (mt_user.meta_key = '_customer_user')"
                        . " AND (mt_user.meta_value = " . esc_sql( $user_id ) . ")"
                        . " AND (mt_paid.meta_key = '_paid_date')"
                        . " ORDER BY mt_paid.meta_value DESC"
                        . " LIMIT 1";


                $results = $wpdb->get_var( $sql );

                if ( $results ) {

                    return $results;
                }
            } catch ( Exception $ex ) {
                
            }

            return $default;
        }

        public function get_last_order_totals( $user_id, $default ) {

            try {

                global $wpdb;

                $sql = "SELECT mt_total.meta_value FROM {$wpdb->prefix}posts AS posts"
                        . " LEFT JOIN {$wpdb->prefix}postmeta AS mt_user ON posts.id = mt_user.post_id"
                        . " LEFT JOIN {$wpdb->prefix}postmeta AS mt_paid ON posts.id = mt_paid.post_id"
                        . " LEFT JOIN {$wpdb->prefix}postmeta AS mt_total ON posts.id = mt_total.post_id"
                        . " WHERE (posts.post_type = 'shop_order')"
                        . " AND (posts.post_status IN('wc-" . implode( "','wc-", array_map( 'esc_sql', wc_get_is_paid_statuses() ) ) . "'))"
                        . " AND (mt_user.meta_key = '_customer_user')"
                        . " AND (mt_user.meta_value = " . esc_sql( $user_id ) . ")"
                        . " AND (mt_total.meta_key = '_order_total')"
                        . " AND (mt_paid.meta_key = '_paid_date')"
                        . " ORDER BY mt_paid.meta_value DESC"
                        . " LIMIT 1";

                $results = $wpdb->get_var( $sql );

                if ( !$results ) {

                    return $default;
                }

                return WOOPCD_PartialCOD_Util::round_num( $results, wc_get_price_decimals() );
            } catch ( Exception $ex ) {
                
            }

            return $default;
        }

        public function get_history_data( $user_id, $from_date, $default ) {

            try {

                global $wpdb;

                $sql = $this->process_history_data_sql( $wpdb->prefix, $user_id, $from_date );

                $results = $wpdb->get_results( $sql, ARRAY_A );

                $order_history = array();

                foreach ( $results as $row ) {

                    $key = $row[ 'product_id' ] . ':' . $row[ 'variation_id' ];

                    $order_id = $row[ 'order_id' ];

                    if ( !isset( $order_history[ $order_id ][ $key ] ) ) {

                        $order_history[ $order_id ][ $key ] = array(
                            'order_id' => $order_id,
                            'product_id' => $row[ 'product_id' ],
                            'variation_id' => $row[ 'variation_id' ],
                            'quantity' => $row[ 'quantity' ],
                            'subtotal' => $row[ 'subtotal' ],
                            'subtotal_tax' => $row[ 'subtotal_tax' ],
                        );

                        continue;
                    }

                    $order_history[ $order_id ][ $key ][ 'quantity' ] += $row[ 'quantity' ];
                    $order_history[ $order_id ][ $key ][ 'subtotal' ] += $row[ 'subtotal' ];
                    $order_history[ $order_id ][ $key ][ 'subtotal_tax' ] += $row[ 'subtotal_tax' ];
                }

                $history_data = array();

                foreach ( $order_history as $data_list ) {

                    $history_data = $this->process_history_data_list( $history_data, $data_list );
                }

                return $history_data;
            } catch ( Exception $ex ) {
                
            }

            return $default;
        }

        private function process_history_data_list( $history_data, $data_list ) {

            foreach ( $data_list as $data ) {

                $history_data[] = $data;
            }

            return $history_data;
        }

        private function process_history_data_sql( $prefix, $user_id, $from_date ) {

            $sql_selects = "SELECT"
                    . " posts.id AS order_id,"
                    . " products.meta_value AS product_id,"
                    . " variations.meta_value AS variation_id,"
                    . " qty.meta_value AS quantity,"
                    . " subtotal.meta_value AS subtotal,"
                    . " subtotal_tax.meta_value AS subtotal_tax"
                    . " FROM {$prefix}posts AS posts";


            $sql_joins = " LEFT JOIN {$prefix}postmeta AS mt_user ON posts.id = mt_user.post_id"
                    . " LEFT JOIN {$prefix}postmeta AS mt_paid ON posts.id = mt_paid.post_id"
                    . " LEFT JOIN {$prefix}woocommerce_order_items AS order_items ON posts.id = order_items.order_id"
                    . " LEFT JOIN {$prefix}woocommerce_order_itemmeta AS products ON products.order_item_id = order_items.order_item_id"
                    . " LEFT JOIN {$prefix}woocommerce_order_itemmeta AS variations ON variations.order_item_id = order_items.order_item_id"
                    . " LEFT JOIN {$prefix}woocommerce_order_itemmeta AS qty ON qty.order_item_id = order_items.order_item_id"
                    . " LEFT JOIN {$prefix}woocommerce_order_itemmeta AS subtotal ON subtotal.order_item_id = order_items.order_item_id"
                    . " LEFT JOIN {$prefix}woocommerce_order_itemmeta AS subtotal_tax ON subtotal_tax.order_item_id = order_items.order_item_id";


            $sql_wheres = " WHERE (posts.post_type = 'shop_order')"
                    . " AND (posts.post_status IN('wc-" . implode( "','wc-", array_map( 'esc_sql', wc_get_is_paid_statuses() ) ) . "'))"
                    . " AND (mt_user.meta_key = '_customer_user')"
                    . " AND (mt_user.meta_value = " . esc_sql( $user_id ) . ")"
                    . " AND (order_items.order_item_type='line_item')"
                    . " AND (products.meta_key ='_product_id')"
                    . " AND (variations.meta_key ='_variation_id')"
                    . " AND (qty.meta_key ='_qty')"
                    . " AND (subtotal.meta_key ='_line_subtotal')"
                    . " AND (subtotal_tax.meta_key ='_line_subtotal_tax')"
                    . " AND (mt_paid.meta_key = '_paid_date')";



            if ( !empty( $from_date ) ) {

                $sql_from_date = " AND (mt_paid.meta_value >= '" . esc_sql( $from_date ) . "')";

                return $sql_selects . $sql_joins . $sql_wheres . $sql_from_date;
            }

            return $sql_selects . $sql_joins . $sql_wheres;
        }

    }

}
