<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WOOPCD_PartialCOD_Cart_Util' ) ) {

    class WOOPCD_PartialCOD_Cart_Util {

        public static function get_product_ids( $cart_data ) {
            $product_ids = array();

            if ( !isset( $cart_data[ 'wc' ][ 'cart_items' ] ) ) {
                return $product_ids;
            }

            foreach ( $cart_data[ 'wc' ][ 'cart_items' ] as $cart_item ) {

                if ( isset( $cart_item[ 'product_id' ] ) && 0 < $cart_item[ 'product_id' ] ) {
                    $product_ids[] = $cart_item[ 'product_id' ];
                }
            }

            return $product_ids;
        }

        public static function get_variation_ids( $cart_data ) {
            $variation_ids = array();

            if ( !isset( $cart_data[ 'wc' ][ 'cart_items' ] ) ) {
                return $variation_ids;
            }

            foreach ( $cart_data[ 'wc' ][ 'cart_items' ] as $cart_item ) {

                if ( isset( $cart_item[ 'variation_id' ] ) && 0 < $cart_item[ 'variation_id' ] ) {
                    $variation_ids[] = $cart_item[ 'variation_id' ];
                }
            }

            return $variation_ids;
        }

        public static function get_category_ids( $cart_data ) {
            $category_ids = array();

            if ( !isset( $cart_data[ 'wc' ][ 'cart_items' ] ) ) {
                return $category_ids;
            }

            foreach ( $cart_data[ 'wc' ][ 'cart_items' ] as $cart_item ) {

                if ( !isset( $cart_item[ 'data' ][ 'category_ids' ] ) ) {
                    continue;
                }

                foreach ( $cart_item[ 'data' ][ 'category_ids' ] as $category_id ) {
                    if ( !in_array( $category_id, $category_ids ) ) {
                        $category_ids[] = $category_id;
                    }
                }
            }

            return $category_ids;
        }

        public static function get_tag_ids( $cart_data ) {
            $tag_ids = array();

            if ( !isset( $cart_data[ 'wc' ][ 'cart_items' ] ) ) {
                return $tag_ids;
            }

            foreach ( $cart_data[ 'wc' ][ 'cart_items' ] as $cart_item ) {

                if ( !isset( $cart_item[ 'data' ][ 'tag_ids' ] ) ) {
                    continue;
                }

                foreach ( $cart_item[ 'data' ][ 'tag_ids' ] as $tag_id ) {
                    if ( !in_array( $tag_id, $tag_ids ) ) {
                        $tag_ids[] = $tag_id;
                    }
                }
            }

            return $tag_ids;
        }

        public static function get_attribute_ids( $cart_data ) {
            $tag_ids = array();

            if ( !isset( $cart_data[ 'wc' ][ 'cart_items' ] ) ) {
                return $tag_ids;
            }

            foreach ( $cart_data[ 'wc' ][ 'cart_items' ] as $cart_item ) {

                if ( !isset( $cart_item[ 'data' ][ 'attribute_ids' ] ) ) {
                    continue;
                }

                foreach ( $cart_item[ 'data' ][ 'attribute_ids' ] as $tag_id ) {
                    if ( !in_array( $tag_id, $tag_ids ) ) {
                        $tag_ids[] = $tag_id;
                    }
                }
            }

            return $tag_ids;
        }

        public static function get_has_virtual( $cart_data ) {

            if ( !isset( $cart_data[ 'wc' ][ 'cart_items' ] ) ) {
                return false;
            }

            foreach ( $cart_data[ 'wc' ][ 'cart_items' ] as $cart_item ) {
                if ( isset( $cart_item[ 'data' ][ 'is_virtual' ] ) && $cart_item[ 'data' ][ 'is_virtual' ] ) {
                    return true;
                }
            }

            return false;
        }

        public static function get_tax_classes( $cart_data ) {

            $tax_classes = array();

            if ( !isset( $cart_data[ 'wc' ][ 'cart_items' ] ) ) {
                return $tax_classes;
            }

            foreach ( $cart_data[ 'wc' ][ 'cart_items' ] as $cart_item ) {

                if ( !isset( $cart_item[ 'data' ][ 'tax_status' ] ) || !isset( $cart_item[ 'data' ][ 'tax_class' ] ) ) {
                    continue;
                }

                $tax_class = $cart_item[ 'data' ][ 'tax_class' ];
                $tax_status = $cart_item[ 'data' ][ 'tax_status' ];
                if ( 'none' == $tax_status ) {
                    continue;
                }
                if ( '' == $tax_class ) {
                    $tax_class = '--0';
                }
                if ( !in_array( $tax_class, $tax_classes ) ) {
                    $tax_classes[] = $tax_class;
                }
            }

            return $tax_classes;
        }

        public static function get_shipping_classes( $cart_data ) {
            $shipping_classes = array();


            if ( !isset( $cart_data[ 'wc' ][ 'cart_items' ] ) ) {
                return $shipping_classes;
            }

            foreach ( $cart_data[ 'wc' ][ 'cart_items' ] as $cart_item ) {
                if ( !isset( $cart_item[ 'data' ][ 'shipping_class_id' ] ) ) {
                    continue;
                }
                $shipping_class = $cart_item[ 'data' ][ 'shipping_class_id' ];

                if ( 0 < $shipping_class ) {
                    $shipping_classes[] = $shipping_class;
                }
            }

            return $shipping_classes;
        }

        public static function get_product_metas( $cart_data, $meta_key ) {
            $product_metas = array();

            if ( !isset( $cart_data[ 'wc' ][ 'cart_items' ] ) ) {
                return $product_metas;
            }

            $product_ids = array();

            foreach ( $cart_data[ 'wc' ][ 'cart_items' ] as $key => $cart_item ) {

                $product_ids[ $key ] = $cart_item[ 'product_id' ];
            }

            $metas = WOOPCD_PartialCOD_Product_Util::get_metas_by_ids( $product_ids, $meta_key );

            foreach ( $metas as $meta ) {
                $product_metas[] = $meta;
            }

            return $product_metas;
        }

        public static function get_items_by_ids( $cart_data, $product_ids ) {
            $cart_items = array();

            foreach ( $cart_data[ 'wc' ][ 'cart_items' ] as $cart_item ) {

                if ( !isset( $cart_item[ 'product_id' ] ) ) {
                    continue;
                }

                if ( WOOPCD_PartialCOD_Validation_Util::validate_value_list( $cart_item[ 'product_id' ], $product_ids, 'in_list' ) != true ) {
                    continue;
                }

                $cart_items[] = $cart_item;
            }

            return $cart_items;
        }

        public static function get_items_by_variation_ids( $cart_data, $variation_ids ) {
            $cart_items = array();

            foreach ( $cart_data[ 'wc' ][ 'cart_items' ] as $cart_item ) {

                if ( !isset( $cart_item[ 'variation_id' ] ) || 0 >= $cart_item[ 'variation_id' ] ) {
                    continue;
                }

                if ( WOOPCD_PartialCOD_Validation_Util::validate_value_list( $cart_item[ 'variation_id' ], $variation_ids, 'in_list' ) != true ) {
                    continue;
                }

                $cart_items[] = $cart_item;
            }

            return $cart_items;
        }

        public static function get_items_by_category_ids( $cart_data, $category_ids ) {
            $cart_items = array();

            foreach ( $cart_data[ 'wc' ][ 'cart_items' ] as $cart_item ) {

                if ( !isset( $cart_item[ 'data' ][ 'category_ids' ] ) ) {
                    continue;
                }

                if ( WOOPCD_PartialCOD_Validation_Util::validate_list_list( $cart_item[ 'data' ][ 'category_ids' ], $category_ids, 'in_list' ) != true ) {
                    continue;
                }

                $cart_items[] = $cart_item;
            }

            return $cart_items;
        }

        public static function get_items_by_tag_ids( $cart_data, $category_ids ) {
            $cart_items = array();

            foreach ( $cart_data[ 'wc' ][ 'cart_items' ] as $cart_item ) {

                if ( !isset( $cart_item[ 'data' ][ 'tag_ids' ] ) ) {
                    continue;
                }

                if ( WOOPCD_PartialCOD_Validation_Util::validate_list_list( $cart_item[ 'data' ][ 'tag_ids' ], $category_ids, 'in_list' ) != true ) {
                    continue;
                }

                $cart_items[] = $cart_item;
            }

            return $cart_items;
        }

        public static function get_items_by_attribute_ids( $cart_data, $attribute_ids ) {
            $cart_items = array();

            foreach ( $cart_data[ 'wc' ][ 'cart_items' ] as $cart_item ) {

                if ( !isset( $cart_item[ 'data' ][ 'attribute_ids' ] ) ) {
                    continue;
                }

                if ( WOOPCD_PartialCOD_Validation_Util::validate_list_list( $cart_item[ 'data' ][ 'attribute_ids' ], $attribute_ids, 'in_list' ) != true ) {
                    continue;
                }

                $cart_items[] = $cart_item;
            }

            return $cart_items;
        }

        public static function get_items_by_virtuals( $cart_data, $is_virtual ) {

            $cart_items = array();

            foreach ( $cart_data[ 'wc' ][ 'cart_items' ] as $cart_item ) {

                if ( !isset( $cart_item[ 'data' ][ 'is_virtual' ] ) ) {
                    continue;
                }

                $item_is_virtual = $cart_item[ 'data' ][ 'is_virtual' ];

                if ( WOOPCD_PartialCOD_Validation_Util::validate_yes_no( $item_is_virtual, $is_virtual ) != true ) {
                    continue;
                }

                $cart_items[] = $cart_item;
            }

            return $cart_items;
        }

        public static function get_items_by_tax_classes( $cart_data, $tax_classes ) {
            $cart_items = array();

            foreach ( $cart_data[ 'wc' ][ 'cart_items' ] as $cart_item ) {

                if ( !isset( $cart_item[ 'data' ][ 'tax_status' ] ) || !isset( $cart_item[ 'data' ][ 'tax_class' ] ) ) {
                    continue;
                }

                $tax_class = $cart_item[ 'data' ][ 'tax_class' ];
                $tax_status = $cart_item[ 'data' ][ 'tax_status' ];
                if ( 'none' == $tax_status ) {
                    continue;
                }
                if ( '' == $tax_class ) {
                    $tax_class = '--0';
                }

                if ( WOOPCD_PartialCOD_Validation_Util::validate_value_list( $tax_class, $tax_classes, 'in_list' ) != true ) {
                    continue;
                }

                $cart_items[] = $cart_item;
            }

            return $cart_items;
        }

        public static function get_items_by_shipping_class_ids( $cart_data, $shipping_class_id ) {
            $cart_items = array();

            foreach ( $cart_data[ 'wc' ][ 'cart_items' ] as $cart_item ) {

                if ( !isset( $cart_item[ 'data' ][ 'shipping_class_id' ] ) ) {
                    continue;
                }

                $item_shipping_class_id = $cart_item[ 'data' ][ 'shipping_class_id' ];

                if ( 0 >= $item_shipping_class_id ) {
                    continue;
                }

                if ( WOOPCD_PartialCOD_Validation_Util::validate_value_list( $item_shipping_class_id, $shipping_class_id, 'in_list' ) != true ) {
                    continue;
                }

                $cart_items[] = $cart_item;
            }

            return $cart_items;
        }

        public static function get_items_by_meta( $cart_data, $meta_key, $meta_value ) {
            
            $cart_items = array();
  
           $product_metas = WOOPCD_PartialCOD_Product_Util::get_metas_by_ids( self::get_product_ids( $cart_data ), $meta_key );
       
            foreach ( $cart_data[ 'wc' ][ 'cart_items' ] as $cart_item ) {

                if ( !isset( $cart_item[ 'product_id' ] ) ) {
                    continue;
                }

                $product_id = $cart_item[ 'product_id' ];

                if ( !isset( $product_metas[ $product_id ] ) ) {
                    continue;
                }

                $product_meta = $product_metas[ $product_id ];


                if ( WOOPCD_PartialCOD_Validation_Util::validate_value( '==', $product_meta, $meta_value ) != true ) {
                    continue;
                }

                $cart_items[] = $cart_item;
            }

            return $cart_items;
        }

    }

}