<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WOOPCD_PartialCOD_DateTime_Util' ) ) {

    class WOOPCD_PartialCOD_DateTime_Util {

        public static function get_date_from_args( $args ) {

            $result = '';
            if ( $args[ 'date_type' ] == 'current' ) {

                $current_type = 'day';

                if ( $args[ 'current' ] != '' ) {
                    $current_type = $args[ 'current' ];
                }

                $result = self::get_date_from_current( $current_type );
            } else if ( $args[ 'date_type' ] == 'hours' || $args[ 'date_type' ] == 'days' || $args[ 'date_type' ] == 'weeks' || $args[ 'date_type' ] == 'months' || $args[ 'date_type' ] == 'years' ) {

                $result = self::get_date_from_offset( $args[ 'date_type' ], $args[ 'date_offset' ] );
            }
            return $result;
        }

        public static function get_current_date( $include_time = true ) {
            if ( $include_time == true ) {
                return date( "Y-m-d H:i:s", current_time( 'timestamp' ) );
            }
            return date( "Y-m-d", current_time( 'timestamp' ) );
        }

        public static function get_date_from_week_days( $compare, $week_days ) {

            $current_week = date( 'W', current_time( 'timestamp' ) );

            $current_year = date( "Y", current_time( 'timestamp' ) );

            $c_date = new DateTime();

            $c_date->setISODate( $current_year, $current_week );

            $c_date->setTime( 0, 0, 0 );

            $date_from_monday = $c_date->format( 'U' );


            $selected_day_range = self::get_selected_week_days( $compare, $week_days );

            if ( count( $selected_day_range ) > 0 ) {

                return array(
                    'from' => date( 'Y-m-d', ($date_from_monday + (DAY_IN_SECONDS * $selected_day_range[ 0 ]) ) ) . ' 00:00:00',
                    'to' => date( 'Y-m-d', ($date_from_monday + (DAY_IN_SECONDS * $selected_day_range[ 1 ]) ) ) . ' 23:59:59',
                );
            } else {
                return array();
            }
        }

        public static function get_date_from_month_days( $compare, $month_days ) {

            $selected_day_range = self::get_selected_month_days( $compare, $month_days );

            if ( count( $selected_day_range ) > 0 ) {

                $current_month = date( 'm', current_time( 'timestamp' ) );

                $current_year = date( "Y", current_time( 'timestamp' ) );

                $c_date = new DateTime();


                $date_range = array();

                $c_date->setDate( $current_year, $current_month, $selected_day_range[ 0 ] );

                $c_date->setTime( 0, 0, 0 );

                $date_u = $c_date->format( 'U' );

                $date_range[ 'from' ] = date( 'Y-m-d', $date_u ) . ' 00:00:00';

                $c_date->setDate( $current_year, $current_month, $selected_day_range[ 1 ] );

                $c_date->setTime( 0, 0, 0 );

                $date_u = $c_date->format( 'U' );

                $date_range[ 'to' ] = date( 'Y-m-d', $date_u ) . ' 23:59:59';

                return $date_range;
            } else {
                return array();
            }
        }

        public static function get_date_from_year_months( $compare, $months ) {

            $selected_month_range = self::get_selected_months( $compare, $months );

            if ( count( $selected_month_range ) > 0 ) {


                $current_year = date( "Y", current_time( 'timestamp' ) );
                $c_date = new DateTime();


                $date_range = array();

                $c_date->setDate( $current_year, $selected_month_range[ 0 ][ 'month' ], $selected_month_range[ 0 ][ 'day' ] );

                $c_date->setTime( 0, 0, 0 );

                $date_u = $c_date->format( 'U' );

                $date_range[ 'from' ] = date( 'Y-m-d', $date_u ) . ' 00:00:00';

                $c_date->setDate( $current_year, $selected_month_range[ 1 ][ 'month' ], $selected_month_range[ 1 ][ 'day' ] );

                $c_date->setTime( 0, 0, 0 );

                $date_u = $c_date->format( 'U' );

                $date_range[ 'to' ] = date( 'Y-m-d', $date_u ) . ' 23:59:59';

                return $date_range;
            } else {
                return array();
            }
        }

        private static function get_date_from_current( $date_mode = 'day' ) {

            switch ( $date_mode ) {

                case 'week':
                    $current_week = date( 'W', current_time( 'timestamp' ) );

                    $current_year = date( "Y", current_time( 'timestamp' ) );

                    $c_date = new DateTime();

                    $c_date->setISODate( $current_year, $current_week );

                    return $c_date->format( 'Y-m-d' ) . " 00:00:00";

                case 'month':

                    $current_month = date( 'm', current_time( 'timestamp' ) );

                    $current_year = date( "Y", current_time( 'timestamp' ) );

                    $c_date = new DateTime();

                    $c_date->setDate( $current_year, $current_month, 1 );

                    return $c_date->format( 'Y-m-d' ) . " 00:00:00";

                case 'year':

                    $current_year = date( "Y", current_time( 'timestamp' ) );

                    $c_date = new DateTime();

                    $c_date->setDate( $current_year, 1, 1 );

                    return $c_date->format( 'Y-m-d' ) . " 00:00:00";

                default :

                    $current_year = date( "Y", current_time( 'timestamp' ) );

                    $current_month = date( "m", current_time( 'timestamp' ) );

                    $current_day = date( "d", current_time( 'timestamp' ) );

                    $c_date = new DateTime();

                    $c_date->setDate( $current_year, $current_month, $current_day );

                    return $c_date->format( 'Y-m-d' ) . " 00:00:00";
            }
        }

        private static function get_date_from_offset( $offset_mode = 'hours', $offset = 1 ) {

            $current_time = current_time( 'timestamp' );

            switch ( $offset_mode ) {
                case 'years':

                    return date( "Y-m-d", $current_time - (YEAR_IN_SECONDS * $offset) ) . " 00:00:00";
                case 'months':

                    return date( "Y-m-d", $current_time - (MONTH_IN_SECONDS * $offset) ) . " 00:00:00";
                case 'weeks':

                    return date( "Y-m-d", $current_time - (WEEK_IN_SECONDS * $offset) ) . " 00:00:00";
                case 'days':

                    return date( "Y-m-d", $current_time - (DAY_IN_SECONDS * $offset) ) . " 00:00:00";
                default:

                    return date( "Y-m-d H:i", $current_time - (HOUR_IN_SECONDS * $offset) ) . ":00";
            }
        }

        private static function get_selected_week_days( $compare, $week_days ) {

            if ( $compare != 'in_list' ) {

                $selected_week_days = array();

                for ( $i = 0; $i < 7; $i++ ) {

                    if ( !in_array( $i, $week_days ) ) {
                        $selected_week_days[] = $i;
                    }
                }
            } else {

                $selected_week_days = $week_days;
            }


            $weeks_range = array();

            $range = array();

            for ( $i = 0; $i < 7; $i++ ) {

                if ( in_array( $i, $selected_week_days ) && count( $range ) == 0 ) {

                    $range[ 0 ] = $i;

                    $range[ 1 ] = $i;
                } else if ( in_array( $i, $selected_week_days ) && count( $range ) > 0 ) {

                    $range[ 1 ] = $i;
                } else if ( count( $range ) > 0 ) {

                    $weeks_range[] = $range;

                    $range = array();
                }
            }
            if ( count( $range ) > 0 ) {

                $weeks_range[] = $range;
            }



            $jd = cal_to_jd( CAL_GREGORIAN, date( "m", current_time( 'timestamp' ) ), date( "d", current_time( 'timestamp' ) ), date( "Y", current_time( 'timestamp' ) ) );

            $week_day = self::map_week_day( jddayofweek( $jd, 0 ) );

            foreach ( $weeks_range as $week_day_range ) {

                if ( $week_day >= $week_day_range[ 0 ] && $week_day <= $week_day_range[ 1 ] ) {

                    return $week_day_range;
                }
            }

            return array();
        }

        private static function get_selected_months( $compare, $months ) {

            if ( $compare != 'in_list' ) {

                $selected_months = array();

                for ( $i = 1; $i <= 12; $i++ ) {

                    if ( !in_array( $i, $months ) ) {

                        $selected_months[] = $i;
                    }
                }
            } else {

                $selected_months = $months;
            }

            $months_range = array();


            $range = array();

            for ( $i = 1; $i <= 31; $i++ ) {

                if ( in_array( $i, $selected_months ) && count( $range ) == 0 ) {

                    $range[ 0 ] = $i;

                    $range[ 1 ] = $i;
                } else if ( in_array( $i, $selected_months ) && count( $range ) > 0 ) {

                    $range[ 1 ] = $i;
                } else if ( count( $range ) > 0 ) {

                    $months_range[] = $range;

                    $range = array();
                }
            }
            if ( count( $range ) > 0 ) {

                $months_range[] = $range;
            }


            $month = date( "m", current_time( 'timestamp' ) );


            foreach ( $months_range as $month_range ) {

                if ( $month >= $month_range[ 0 ] && $month <= $month_range[ 1 ] ) {

                    $sl_month_range = array();

                    $sl_month_range[ 0 ][ 'month' ] = $month_range[ 0 ];

                    $sl_month_range[ 0 ][ 'day' ] = 1;

                    $sl_month_range[ 1 ][ 'month' ] = $month_range[ 1 ];

                    $sl_month_range[ 1 ][ 'day' ] = self::get_month_max_days( $month_range[ 1 ] );

                    return $sl_month_range;
                }
            }

            return array();
        }

        private static function get_selected_month_days( $compare, $month_days ) {

            if ( $compare != 'in_list' ) {

                $selected_month_days = array();

                for ( $i = 1; $i <= 31; $i++ ) {

                    if ( !in_array( $i, $month_days ) ) {

                        $selected_month_days[] = $i;
                    }
                }
            } else {

                $selected_month_days = $month_days;
            }

            $days_range = array();

            $range = array();

            for ( $i = 1; $i <= 31; $i++ ) {

                if ( in_array( $i, $selected_month_days ) && count( $range ) == 0 ) {

                    $range[ 0 ] = $i;

                    $range[ 1 ] = $i;
                } else if ( in_array( $i, $selected_month_days ) && count( $range ) > 0 ) {

                    $range[ 1 ] = $i;
                } else if ( count( $range ) > 0 ) {

                    $days_range[] = $range;

                    $range = array();
                }
            }
            if ( count( $range ) > 0 ) {

                $days_range[] = $range;
            }


            $month_day = date( "d", current_time( 'timestamp' ) );

            $current_month = date( "m", current_time( 'timestamp' ) );

            foreach ( $days_range as $month_day_range ) {

                if ( $month_day >= $month_day_range[ 0 ] && $month_day <= $month_day_range[ 1 ] ) {

                    $max_day = self::get_month_max_days( $current_month );

                    if ( $month_day_range[ 0 ] > $max_day ) {

                        $month_day_range[ 0 ] = $max_day;
                    }
                    if ( $month_day_range[ 1 ] > $max_day ) {

                        $month_day_range[ 1 ] = $max_day;
                    }

                    return $month_day_range;
                }
            }

            return array();
        }

        private static function get_month_max_days( $month ) {

            switch ( $month ) {

                case 2:

                    $is_leap_year = (date( 'L', current_time( 'timestamp' ) ) === 1);

                    if ( $is_leap_year == true ) {
                        return 29;
                    }

                    return 28;
                case 4:
                case 6:
                case 9:
                case 11:

                    return 30;
                default :

                    return 31;
            }
        }

        private static function map_week_day( $jd_day ) {

            $days = array(
                0 => 6,
                1 => 0,
                2 => 1,
                3 => 2,
                4 => 3,
                5 => 4,
                6 => 5,
            );

            return $days[ $jd_day ];
        }

    }

}