<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WOOPCD_PartialCOD_Order_Util' ) ) {

    class WOOPCD_PartialCOD_Order_Util {

        public static function get_product_ids( $order_data ) {
            $product_ids = array();

            if ( !isset( $order_data[ 'wc' ][ 'order_items' ] ) ) {
                return $product_ids;
            }

            foreach ( $order_data[ 'wc' ][ 'order_items' ] as $order_item ) {

                if ( !isset( $order_item[ 'product_id' ] ) ) {
                    continue;
                }

                if ( 0 >= $order_item[ 'product_id' ] ) {
                    continue;
                }

                if ( in_array( $order_item[ 'product_id' ], $product_ids ) ) {
                    continue;
                }

                $product_ids[] = $order_item[ 'product_id' ];
            }

            return $product_ids;
        }

        public static function get_variation_ids( $order_data ) {

            $variation_ids = array();

            if ( !isset( $order_data[ 'wc' ][ 'order_items' ] ) ) {

                return $variation_ids;
            }

            foreach ( $order_data[ 'wc' ][ 'order_items' ] as $order_item ) {

                if ( !isset( $order_item[ 'variation_id' ] ) ) {
                    continue;
                }

                if ( 0 >= $order_item[ 'variation_id' ] ) {
                    continue;
                }

                if ( in_array( $order_item[ 'variation_id' ], $variation_ids ) ) {
                    continue;
                }

                $variation_ids[] = $order_item[ 'variation_id' ];
            }

            return $variation_ids;
        }

        public static function get_term_ids( $order_data, $taxonomy ) {

            $term_ids = array();

            if ( !isset( $order_data[ 'wc' ][ 'order_items' ] ) ) {
                return $term_ids;
            }

            $product_ids = array();

            foreach ( $order_data[ 'wc' ][ 'order_items' ] as $order_item ) {

                if ( !isset( $order_item[ 'product_id' ] ) ) {
                    continue;
                }

                if ( 0 >= $order_item[ 'product_id' ] ) {
                    continue;
                }

                if ( in_array( $order_item[ 'product_id' ], $product_ids ) ) {
                    continue;
                }

                $product_ids[] = $order_item[ 'product_id' ];
            }

            if ( !count( $product_ids ) ) {
                return $term_ids;
            }

            $product_terms = WOOPCD_PartialCOD_Product_Util::get_terms_by_product_ids( $product_ids, $taxonomy );

            foreach ( $product_terms as $product_term ) {

                foreach ( $product_term as $term_id ) {

                    if ( in_array( $term_id, $term_ids ) ) {
                        continue;
                    }

                    $term_ids[] = $term_id;
                }
            }

            return $term_ids;
        }

        public static function get_attribute_ids( $order_data ) {

            $attribute_ids = array();

            if ( !isset( $order_data[ 'wc' ][ 'order_items' ] ) ) {
                return $attribute_ids;
            }

            $product_ids = array();

            foreach ( $order_data[ 'wc' ][ 'order_items' ] as $order_item ) {

                if ( !isset( $order_item[ 'product_id' ] ) ) {
                    continue;
                }

                if ( 0 >= $order_item[ 'product_id' ] ) {
                    continue;
                }

                if ( in_array( $order_item[ 'product_id' ], $product_ids ) ) {
                    continue;
                }

                $product_ids[] = $order_item[ 'product_id' ];
            }

            if ( !count( $product_ids ) ) {
                return $attribute_ids;
            }


            $product_attrs = WOOPCD_PartialCOD_Product_Util::get_attributes_by_product_ids( $product_ids );

            foreach ( $product_attrs as $product_attr ) {

                foreach ( $product_attr as $attribute_id ) {

                    if ( in_array( $attribute_id, $attribute_ids ) ) {
                        continue;
                    }

                    $attribute_ids[] = $attribute_id;
                }
            }

            return $attribute_ids;
        }

        public static function get_has_virtual( $order_data ) {

            if ( !isset( $order_data[ 'wc' ][ 'order_items' ] ) ) {
                return false;
            }

            $product_ids = array();

            foreach ( $order_data[ 'wc' ][ 'order_items' ] as $order_item ) {

                if ( !isset( $order_item[ 'product_id' ] ) ) {
                    continue;
                }

                if ( 0 >= $order_item[ 'product_id' ] ) {
                    continue;
                }

                if ( in_array( $order_item[ 'product_id' ], $product_ids ) ) {
                    continue;
                }

                $product_ids[] = $order_item[ 'product_id' ];
            }

            if ( !count( $product_ids ) ) {
                return false;
            }

            $is_virtuals = WOOPCD_PartialCOD_Product_Util::get_metas_by_ids( $product_ids, '_virtual' );

            if ( !count( $product_ids ) ) {
                return false;
            }

            foreach ( $is_virtuals as $is_virtual ) {

                if ( 'yes' == $is_virtual ) {
                    return true;
                }
            }

            return false;
        }

        public static function get_tax_classes( $order_data ) {

            $tax_classes = array();

            if ( !isset( $order_data[ 'wc' ][ 'order_items' ] ) ) {
                return $tax_classes;
            }

            foreach ( $order_data[ 'wc' ][ 'order_items' ] as $order_item ) {

                if ( !isset( $order_item[ 'tax_status' ] ) || !isset( $order_item[ 'tax_class' ] ) ) {
                    continue;
                }

                $tax_class = $order_item[ 'tax_class' ];

                $tax_status = $order_item[ 'tax_status' ];

                if ( 'none' == $tax_status ) {
                    continue;
                }

                if ( '' == $tax_class ) {
                    $tax_class = '--0';
                }
                if ( !in_array( $tax_class, $tax_classes ) ) {
                    $tax_classes[] = $tax_class;
                }
            }

            return $tax_classes;
        }

        public static function get_product_metas( $order_data, $meta_key ) {

            $product_metas = array();

            if ( !isset( $order_data[ 'wc' ][ 'order_items' ] ) ) {
                return $product_metas;
            }

            $product_ids = array();

            foreach ( $order_data[ 'wc' ][ 'order_items' ] as $key => $order_item ) {

                $product_ids[ $key ] = $order_item[ 'product_id' ];
            }

            $metas = WOOPCD_PartialCOD_Product_Util::get_metas_by_ids( $product_ids, $meta_key );

            foreach ( $metas as $meta ) {
                $product_metas[] = $meta;
            }

            return $product_metas;
        }

        public static function get_items_by_ids( $order_data, $product_ids ) {

            $order_items = array();

            if ( !isset( $order_data[ 'wc' ][ 'order_items' ] ) ) {

                return $order_items;
            }

            foreach ( $order_data[ 'wc' ][ 'order_items' ] as $key => $order_item ) {

                if ( !isset( $order_item[ 'product_id' ] ) ) {
                    continue;
                }

                if ( WOOPCD_PartialCOD_Validation_Util::validate_value_list( $order_item[ 'product_id' ], $product_ids, 'in_list' ) != true ) {
                    continue;
                }

                $order_items[ $key ] = $order_item;
            }


            return $order_items;
        }

        public static function get_items_by_variation_ids( $order_data, $variation_ids ) {

            $order_items = array();

            if ( !isset( $order_data[ 'wc' ][ 'order_items' ] ) ) {

                return $order_items;
            }

            foreach ( $order_data[ 'wc' ][ 'order_items' ] as $key => $order_item ) {

                if ( !isset( $order_item[ 'variation_id' ] ) || 0 >= $order_item[ 'variation_id' ] ) {
                    continue;
                }

                if ( WOOPCD_PartialCOD_Validation_Util::validate_value_list( $order_item[ 'variation_id' ], $variation_ids, 'in_list' ) != true ) {
                    continue;
                }

                $order_items[ $key ] = $order_item;
            }

            return $order_items;
        }

        public static function get_items_by_term_ids( $order_data, $terms_ids, $taxonomy ) {

            $order_items = array();

            if ( !isset( $order_data[ 'wc' ][ 'order_items' ] ) ) {

                return $order_items;
            }

            $product_terms = WOOPCD_PartialCOD_Product_Util::get_terms_by_product_ids( self::get_product_ids( $order_data ), $taxonomy );

            foreach ( $order_data[ 'wc' ][ 'order_items' ] as $key => $order_item ) {

                if ( !isset( $order_item[ 'product_id' ] ) ) {
                    continue;
                }

                $product_id = $order_item[ 'product_id' ];

                if ( !isset( $product_terms[ $product_id ] ) ) {
                    continue;
                }

                if ( WOOPCD_PartialCOD_Validation_Util::validate_list_list( $product_terms[ $product_id ], $terms_ids, 'in_list' ) != true ) {
                    continue;
                }

                $order_items[ $key ] = $order_item;
            }

            return $order_items;
        }

        public static function get_items_by_attribute_ids( $order_data, $attribute_ids ) {

            $order_items = array();

            if ( !isset( $order_data[ 'wc' ][ 'order_items' ] ) ) {

                return $order_items;
            }

            $product_attrs = WOOPCD_PartialCOD_Product_Util::get_attributes_by_product_ids( self::get_product_ids( $order_data ) );

            foreach ( $order_data[ 'wc' ][ 'order_items' ] as $key => $order_item ) {

                if ( !isset( $order_item[ 'product_id' ] ) ) {
                    continue;
                }

                $product_id = $order_item[ 'product_id' ];

                if ( !isset( $product_attrs[ $product_id ] ) ) {
                    continue;
                }

                if ( WOOPCD_PartialCOD_Validation_Util::validate_list_list( $product_attrs[ $product_id ], $attribute_ids, 'in_list' ) != true ) {
                    continue;
                }

                $order_items[ $key ] = $order_item;
            }

            return $order_items;
        }

        public static function get_items_by_virtuals( $order_data, $is_virtual ) {

            $order_items = array();

            if ( !isset( $order_data[ 'wc' ][ 'order_items' ] ) ) {

                return $order_items;
            }

            $product_metas = WOOPCD_PartialCOD_Product_Util::get_metas_by_ids( self::get_product_ids( $order_data ), '_virtual' );

            foreach ( $order_data[ 'wc' ][ 'order_items' ] as $key => $order_item ) {

                if ( !isset( $order_item[ 'product_id' ] ) ) {
                    continue;
                }

                $product_id = $order_item[ 'product_id' ];

                if ( !isset( $product_metas[ $product_id ] ) ) {
                    continue;
                }

                $item_is_virtual = ($product_metas[ $product_id ] == 'yes');

                if ( WOOPCD_PartialCOD_Validation_Util::validate_yes_no( $item_is_virtual, $is_virtual ) != true ) {
                    continue;
                }

                $order_items[ $key ] = $order_item;
            }

            return $order_items;
        }

        public static function get_items_by_tax_classes( $order_data, $tax_classes ) {

            $order_items = array();

            if ( !isset( $order_data[ 'wc' ][ 'order_items' ] ) ) {

                return $order_items;
            }

            foreach ( $order_data[ 'wc' ][ 'order_items' ] as $key => $order_item ) {

                if ( !isset( $order_item[ 'tax_status' ] ) || !isset( $order_item[ 'tax_class' ] ) ) {
                    continue;
                }

                $tax_class = $order_item[ 'tax_class' ];
                $tax_status = $order_item[ 'tax_status' ];

                if ( 'none' == $tax_status ) {
                    continue;
                }

                if ( '' == $tax_class ) {
                    $tax_class = '--0';
                }

                if ( WOOPCD_PartialCOD_Validation_Util::validate_value_list( $tax_class, $tax_classes, 'in_list' ) != true ) {
                    continue;
                }

                $order_items[ $key ] = $order_item;
            }

            return $order_items;
        }

        public static function get_items_by_meta( $order_data, $meta_key, $meta_value ) {

            $order_items = array();

            if ( !isset( $order_data[ 'wc' ][ 'order_items' ] ) ) {

                return $order_items;
            }

            $product_metas = WOOPCD_PartialCOD_Product_Util::get_metas_by_ids( self::get_product_ids( $order_data ), $meta_key );

            foreach ( $order_data[ 'wc' ][ 'order_items' ] as $order_item ) {

                if ( !isset( $order_item[ 'product_id' ] ) ) {
                    continue;
                }

                $product_id = $order_item[ 'product_id' ];


                if ( !isset( $product_metas[ $product_id ] ) ) {
                    continue;
                }

                $product_meta = $product_metas[ $product_id ];

                if ( WOOPCD_PartialCOD_Validation_Util::validate_value( '==', $product_meta, $meta_value ) != true ) {
                    continue;
                }

                $order_items[] = $order_item;
            }

            return $order_items;
        }

    }

}